@@ -10,21 +10,28 @@
  *  Pour plus de details voir le fichier COPYING.txt ou l'aide en ligne.   *
 \***************************************************************************/
 
-if (!defined('_ECRIRE_INC_VERSION')) return;
+/**
+ * Gestion de l'action annuler_job
+ *
+ * @package SPIP\Core\Job
+ **/
+
+if (!defined('_ECRIRE_INC_VERSION')) {
+	return;
+}
 
 /**
  * Annuler un travail
+ *
  * @return void
  */
-function action_annuler_job_dist(){
-	$securiser_action = charger_fonction('securiser_action','inc');
+function action_annuler_job_dist() {
+	$securiser_action = charger_fonction('securiser_action', 'inc');
 	$id_job = $securiser_action();
 
 	if ($id_job = intval($id_job)
-		AND autoriser('annuler','job',$id_job)
-	){
+		and autoriser('annuler', 'job', $id_job)
+	) {
 		job_queue_remove($id_job);
 	}
 }
-
-?>
\ No newline at end of file
