@@ -10,28 +10,35 @@
  *  Pour plus de details voir le fichier COPYING.txt ou l'aide en ligne.   *
 \***************************************************************************/
 
-if (!defined('_ECRIRE_INC_VERSION')) return;
+/**
+ * Gestion de l'action auth
+ *
+ * @package SPIP\Core\Authentification
+ **/
+
+if (!defined('_ECRIRE_INC_VERSION')) {
+	return;
+}
 
 /**
  * Retour d'authentification pour les SSO
  */
 function action_auth_dist() {
-	
+
 	$securiser_action = charger_fonction('securiser_action', 'inc');
 	$arg = $securiser_action();
 
 	if (!preg_match(",^(\w+)[/](.+)$,", $arg, $r)) {
 		spip_log("action_auth_dist $arg pas compris");
-	}
-	else {
+	} else {
 		$auth_methode = $r[1];
 		$login = $r[2];
 		include_spip('inc/auth');
 		$res = auth_terminer_identifier_login($auth_methode, $login);
 
-		if (is_string($res)){ // Erreur
+		if (is_string($res)) { // Erreur
 			$redirect = _request('redirect');
-			$redirect = parametre_url($redirect,'var_erreur',$res,'&');
+			$redirect = parametre_url($redirect, 'var_erreur', $res, '&');
 			include_spip('inc/headers');
 			redirige_par_entete($redirect);
 		}
@@ -40,6 +47,3 @@ function action_auth_dist() {
 		auth_loger($res);
 	}
 }
-
-
-?>
