@@ -10,24 +10,31 @@
  *  Pour plus de details voir le fichier COPYING.txt ou l'aide en ligne.   *
 \***************************************************************************/
 
-if (!defined('_ECRIRE_INC_VERSION')) return;
+/**
+ * Action pour exécuter un job en attente, tout de suite
+ *
+ * @package SPIP\Core\Job
+ */
+
+if (!defined('_ECRIRE_INC_VERSION')) {
+	return;
+}
 
 /**
  * Executer un travaille immediatement
+ *
  * @return void
  */
-function action_forcer_job_dist(){
-	$securiser_action = charger_fonction('securiser_action','inc');
+function action_forcer_job_dist() {
+	$securiser_action = charger_fonction('securiser_action', 'inc');
 	$id_job = $securiser_action();
 
 	if ($id_job = intval($id_job)
-		AND autoriser('forcer','job',$id_job)
-	){
+		and autoriser('forcer', 'job', $id_job)
+	) {
 		include_spip('inc/queue');
 		include_spip('inc/genie');
 		queue_schedule(array($id_job));
 	}
 
 }
-
-?>
\ No newline at end of file
