@@ -10,31 +10,44 @@
  *  Pour plus de details voir le fichier COPYING.txt ou l'aide en ligne.   *
 \***************************************************************************/
 
-if (!defined("_ECRIRE_INC_VERSION")) return;
+/**
+ * Action pour instituer un objet avec les puces rapides
+ *
+ * @package SPIP\Core\PuceStatut
+ */
+
+if (!defined("_ECRIRE_INC_VERSION")) {
+	return;
+}
 
 /**
  * Instituer un objet avec les puces rapides
+ *
  * @param null|string $arg
- * @return 
+ *     Chaîne "objet id statut". En absence utilise l'argument
+ *     de l'action sécurisée.
  */
-function action_instituer_objet_dist($arg=null) {
+function action_instituer_objet_dist($arg = null) {
 
-	if (is_null($arg)){
+	if (is_null($arg)) {
 		$securiser_action = charger_fonction('securiser_action', 'inc');
 		$arg = $securiser_action();
 	}
 
 	list($objet, $id_objet, $statut) = preg_split('/\W/', $arg);
-	if (!$statut) $statut = _request('statut_nouv'); // cas POST
-	if (!$statut) return; // impossible mais sait-on jamais
+	if (!$statut) {
+		$statut = _request('statut_nouv');
+	} // cas POST
+	if (!$statut) {
+		return;
+	} // impossible mais sait-on jamais
 
 	if ($id_objet = intval($id_objet)
-		AND autoriser('instituer',$objet,$id_objet,'',array('statut'=>$statut))){
+		and autoriser('instituer', $objet, $id_objet, '', array('statut' => $statut))
+	) {
 
 		include_spip('action/editer_objet');
-		objet_modifier($objet,$id_objet,array('statut' => $statut));
+		objet_modifier($objet, $id_objet, array('statut' => $statut));
 	}
 
 }
-
-?>
\ No newline at end of file
