@@ -10,21 +10,27 @@
  *  Pour plus de details voir le fichier COPYING.txt ou l'aide en ligne.   *
 \***************************************************************************/
 
-if (!defined('_ECRIRE_INC_VERSION')) return;
+/**
+ * Gestion de l'action de purge des travaux en attente
+ *
+ * @package SPIP\Core\Queue
+ **/
+if (!defined('_ECRIRE_INC_VERSION')) {
+	return;
+}
 
 /**
  * Purger la liste des travaux en attente
+ *
  * @return void
  */
-function action_purger_queue_dist(){
-	$securiser_action = charger_fonction('securiser_action','inc');
+function action_purger_queue_dist() {
+	$securiser_action = charger_fonction('securiser_action', 'inc');
 	$securiser_action();
 
-	if (autoriser('purger','queue')){
+	if (autoriser('purger', 'queue')) {
 		include_spip('inc/queue');
 		queue_purger();
 	}
 
 }
-
-?>
\ No newline at end of file
