@@ -17,12 +17,12 @@
  *     Nettoyages à faire dans le core : on ne devrait plus appeler
  *     Ce fichier mais directement base/objets si nécessaire
  *
- * @package SPIP\SQL\Tables
-**/
+ * @package SPIP\Core\SQL\Tables
+ **/
 
-if (!defined('_ECRIRE_INC_VERSION')) return;
+if (!defined('_ECRIRE_INC_VERSION')) {
+	return;
+}
 
 include_spip('base/objets');
 lister_tables_objets_sql();
-
-?>
