@@ -10,7 +10,15 @@
  *  Pour plus de details voir le fichier COPYING.txt ou l'aide en ligne.   *
 \***************************************************************************/
 
-if (!defined('_ECRIRE_INC_VERSION')) return;
+/**
+ * Affichage des étapes d'installation de SPIP
+ *
+ * @package SPIP\Core\Exec
+ */
+
+if (!defined('_ECRIRE_INC_VERSION')) {
+	return;
+}
 
 include_spip('inc/minipres');
 include_spip('inc/install');
@@ -19,18 +27,30 @@ include_spip('inc/autoriser');
 define('_ECRIRE_INSTALL', "1");
 define('_FILE_TMP', '_install');
 
-// http://doc.spip.org/@exec_install_dist
-function exec_install_dist()
-{
+/**
+ * Affiche un des écrans d'installation de SPIP
+ *
+ * Affiche l'étape d'installation en cours, en fonction du paramètre
+ * d'url `etape`
+ *
+ * @uses inc_auth_dist()
+ * @uses verifier_visiteur()
+ *
+ * @uses install_etape__dist()
+ *   Affiche l'écran d'accueil de l'installation,
+ *   si aucune étape n'est encore définie.
+ *
+ **/
+function exec_install_dist() {
 	$etape = _request('etape');
-	$deja = (_FILE_CONNECT AND analyse_fichier_connection(_FILE_CONNECT));
+	$deja = (_FILE_CONNECT and analyse_fichier_connection(_FILE_CONNECT));
 
 	// Si deja installe, on n'a plus le droit qu'a l'etape chmod
 	// pour chgt post-install ou aux etapes supplementaires
 	// de declaration de base externes.
 	// Mais alors il faut authentifier car ecrire/index.php l'a omis
 
-	if ($deja AND in_array($etape, array('chmod', 'sup1', 'sup2'))) {
+	if ($deja and in_array($etape, array('chmod', 'sup1', 'sup2'))) {
 
 		$auth = charger_fonction('auth', 'inc');
 		if (!$auth()) {
@@ -40,12 +60,10 @@ function exec_install_dist()
 	}
 	if ($deja) {
 		// Rien a faire ici
-	  	echo minipres();
+		echo minipres();
 	} else {
 		include_spip('base/create');
 		$fonc = charger_fonction("etape_$etape", 'install');
 		$fonc();
 	}
 }
-
-?>
