@@ -10,27 +10,40 @@
  *  Pour plus de details voir le fichier COPYING.txt ou l'aide en ligne.   *
 \***************************************************************************/
 
-if (!defined('_ECRIRE_INC_VERSION')) return;
+/**
+ * Gestion d'affichage ajax des sous rubriques dans le mini navigateur
+ *
+ * @package SPIP\Core\Exec
+ */
 
-# afficher les sous-rubriques d'une rubrique (composant du mini-navigateur)
+if (!defined('_ECRIRE_INC_VERSION')) {
+	return;
+}
 
-// http://doc.spip.org/@exec_plonger_dist
-function exec_plonger_dist()
-{
+/**
+ * Afficher en ajax les sous-rubriques d'une rubrique (composant du mini-navigateur)
+ *
+ * @uses inc_plonger_dist()
+ * @uses ajax_retour()
+ **/
+function exec_plonger_dist() {
 	include_spip('inc/actions');
-	
+
 	$rac = _request('rac');
 	$id = intval(_request('id'));
 	$exclus = intval(_request('exclus'));
 	$col = intval(_request('col'));
-	$do  = _request('do');
+	$do = _request('do');
 	if (preg_match('/^\w*$/', $do)) {
-		if (!$do) $do = 'aff';
+		if (!$do) {
+			$do = 'aff';
+		}
 
 		$plonger = charger_fonction('plonger', 'inc');
 		$r = $plonger($id, spip_htmlentities($rac), array(), $col, $exclus, $do);
-	} else $r = '';
+	} else {
+		$r = '';
+	}
 
 	ajax_retour($r);
 }
-?>
