@@ -10,27 +10,39 @@
  *  Pour plus de details voir le fichier COPYING.txt ou l'aide en ligne.   *
 \***************************************************************************/
 
-if (!defined('_ECRIRE_INC_VERSION')) return;
+/**
+ * Gestion le l'affichage du sélecteur de rubrique AJAX
+ *
+ * @package SPIP\Core\Rubriques
+ **/
+if (!defined('_ECRIRE_INC_VERSION')) {
+	return;
+}
 
 include_spip('inc/actions');
 
-# afficher un mini-navigateur de rubriques
-
-// http://doc.spip.org/@exec_selectionner_dist
-function exec_selectionner_dist()
-{
+/**
+ * Affichage en ajax du sélecteur (mini-navigateur) de rubrique AJAX
+ *
+ * @uses inc_selectionner_dist()
+ * @uses ajax_retour()
+ **/
+function exec_selectionner_dist() {
 	$id = intval(_request('id'));
 	$exclus = intval(_request('exclus'));
 	$type = _request('type');
 	$rac = _request('racine');
-	$do  = _request('do');
+	$do = _request('do');
 	if (preg_match('/^\w*$/', $do)) {
-		if (!$do) $do = 'aff';
+		if (!$do) {
+			$do = 'aff';
+		}
 
 		$selectionner = charger_fonction('selectionner', 'inc');
 
-		$r = $selectionner($id, "choix_parent", $exclus, $rac, $type!='breve', $do);
-	} else $r = '';
+		$r = $selectionner($id, "choix_parent", $exclus, $rac, $type != 'breve', $do);
+	} else {
+		$r = '';
+	}
 	ajax_retour($r);
 }
-?>
