@@ -10,7 +10,9 @@
  *  Pour plus de details voir le fichier COPYING.txt ou l'aide en ligne.   *
 \***************************************************************************/
 
-if (!defined('_ECRIRE_INC_VERSION')) return;
+if (!defined('_ECRIRE_INC_VERSION')) {
+	return;
+}
 
 /*
  * Cette fonction prend une URL et la raccourcit si elle est trop longue
@@ -23,11 +25,9 @@ function inc_lien_court($url) {
 	$long_url = defined('_MAX_LONG_URL') ? _MAX_LONG_URL : 40;
 	$coupe_url = defined('_MAX_COUPE_URL') ? _MAX_COUPE_URL : 35;
 
-	if (strlen($url)>$long_url) {
-		$url = substr($url,0,$coupe_url).'...';
+	if (strlen($url) > $long_url) {
+		$url = substr($url, 0, $coupe_url) . '...';
 	}
 
 	return $url;
 }
-
-?>
\ No newline at end of file
