@@ -10,21 +10,29 @@
  *  Pour plus de details voir le fichier COPYING.txt ou l'aide en ligne.   *
 \***************************************************************************/
 
-##
-## Module de compatibilite ascendante : desormais inc/envoyer_mail
-##
+/**
+ * Module de compatibilite ascendante : desormais inc/envoyer_mail
+ *
+ * @deprecated Utiliser inc/envoyer_mail
+ * @package SPIP\Core\Mail
+ */
 
-if (!defined('_ECRIRE_INC_VERSION')) return;
+if (!defined('_ECRIRE_INC_VERSION')) {
+	return;
+}
 
 if (!function_exists('envoyer_mail')) {
 	define('_FUNCTION_ENVOYER_MAIL', charger_fonction('envoyer_mail', 'inc'));
-// http://doc.spip.org/@envoyer_mail
+	/**
+	 * Envoie un mail.
+	 *
+	 * @uses inc_envoyer_mail_dist()
+	 * @deprecated Utiliser inc_envoyer_mail_dist() via charger_fonction()
+	 **/
 	function envoyer_mail() {
 		$args = func_get_args();
-		if (_FUNCTION_ENVOYER_MAIL)
+		if (_FUNCTION_ENVOYER_MAIL) {
 			return call_user_func_array(_FUNCTION_ENVOYER_MAIL, $args);
+		}
 	}
 }
-
-
-?>
