@@ -10,11 +10,23 @@
  *  Pour plus de details voir le fichier COPYING.txt ou l'aide en ligne.   *
 \***************************************************************************/
 
-if (!defined('_ECRIRE_INC_VERSION')) return;
 
-// http://doc.spip.org/@install_etape__dist
-function install_etape__dist()
-{
+/**
+ * Affichage de l'écran d'installation (étape 0 : écran d'accueil)
+ *
+ * @package SPIP\Core\Installation
+ */
+
+if (!defined('_ECRIRE_INC_VERSION')) {
+	return;
+}
+
+/**
+ * Affiche l'étape 0 d'installation : écran d'accueil.
+ *
+ * @uses info_copyright()
+ **/
+function install_etape__dist() {
 	utiliser_langue_visiteur();
 	$menu_langues = menu_langues('var_lang_ecrire');
 	if (!$menu_langues) {
@@ -22,12 +34,11 @@ function install_etape__dist()
 	} else {
 		include_spip('inc/presentation'); // pour info_copyright
 
-		$res = "<div class='petit-centre'><img alt='SPIP' src='" .  chemin_image('logo-spip2.gif') . "' />\n" .
-			"<p class='small'>" .info_copyright() ."</p></div>\n" .
-			"<p>" ._T('install_select_langue') ."</p>" .
-			"<div>" .$menu_langues ."</div>\n" .
+		$res = "<div class='petit-centre'><img alt='SPIP' src='" . chemin_image('logo-spip2.gif') . "' />\n" .
+			"<p class='small'>" . info_copyright() . "</p></div>\n" .
+			"<p>" . _T('install_select_langue') . "</p>" .
+			"<div>" . $menu_langues . "</div>\n" .
 			generer_form_ecrire('install', "<input type='hidden' name='etape' value='chmod' />" . bouton_suivant());
 		echo minipres('AUTO', $res);
 	}
 }
-?>
