@@ -11,11 +11,12 @@
 \***************************************************************************/
 
 
-if (!defined('_ECRIRE_INC_VERSION')) return;
+if (!defined('_ECRIRE_INC_VERSION')) {
+	return;
+}
 
-// http://doc.spip.org/@install_etape_ldap3_dist
-function install_etape_ldap3_dist()
-{
+// http://code.spip.net/@install_etape_ldap3_dist
+function install_etape_ldap3_dist() {
 	$adresse_ldap = _request('adresse_ldap');
 	$login_ldap = _request('login_ldap');
 	$pass_ldap = _request('pass_ldap');
@@ -27,7 +28,8 @@ function install_etape_ldap3_dist()
 
 	echo install_debut_html('AUTO', ' onload="document.getElementById(\'suivant\').focus();return false;"');
 
-	echo info_etape(_T('info_chemin_acces_1'),info_progression_etape(3,'etape_ldap','install/')),_T('info_chemin_acces_2');
+	echo info_etape(_T('info_chemin_acces_1'),
+		info_progression_etape(3, 'etape_ldap', 'install/')), _T('info_chemin_acces_2');
 
 	$ldap_link = @ldap_connect("$adresse_ldap", "$port_ldap");
 	if ($ldap_link) {
@@ -36,11 +38,11 @@ function install_etape_ldap3_dist()
 		$info = @ldap_get_entries($ldap_link, $result);
 		@ldap_close($ldap_link);
 	}
-	
+
 	$checked = false;
 	$res = '';
-	if (is_array($info) AND $info["count"] > 0) {
-		$res .= "<p>"._T('info_selection_chemin_acces')."</p>";
+	if (is_array($info) and $info["count"] > 0) {
+		$res .= "<p>" . _T('info_selection_chemin_acces') . "</p>";
 		$res .= "<ul>";
 		$n = 0;
 		for ($i = 0; $i < $info["count"]; $i++) {
@@ -48,18 +50,18 @@ function install_etape_ldap3_dist()
 			if (is_array($names)) {
 				for ($j = 0; $j < $names["count"]; $j++) {
 					$n++;
-					$res .= "<li><input name=\"base_ldap\" value=\"".spip_htmlspecialchars($names[$j])."\" type='radio' id='tab$n'";
+					$res .= "<li><input name=\"base_ldap\" value=\"" . spip_htmlspecialchars($names[$j]) . "\" type='radio' id='tab$n'";
 					if (!$checked) {
 						$res .= " checked=\"checked\"";
 						$checked = true;
 					}
 					$res .= " />";
-					$res .= "<label for='tab$n'>".spip_htmlspecialchars($names[$j])."</label></li>\n";
+					$res .= "<label for='tab$n'>" . spip_htmlspecialchars($names[$j]) . "</label></li>\n";
 				}
 			}
 		}
 		$res .= "</ul>";
-		$res .= _T('info_ou')." ";
+		$res .= _T('info_ou') . " ";
 	}
 	$res .= "<br />\n<input name=\"base_ldap\" value=\"\" type='radio' id='manuel'";
 	if (!$checked) {
@@ -68,18 +70,15 @@ function install_etape_ldap3_dist()
 	}
 
 	$res .= " />"
-	. "\n<label for='manuel'>"._T('entree_chemin_acces')."</label> "
-	. "\n<fieldset>"
-	. "<input type='text' name='base_ldap_text' class='text' value=\"$base_ldap_text\" size='40' />"
-	. "\n</fieldset>"
-	. "\n<input type='hidden' name='etape' value='ldap4' />"
-	. install_propager(array('adresse_ldap','port_ldap','login_ldap','pass_ldap','protocole_ldap','tls_ldap'))
-	. bouton_suivant();
+		. "\n<label for='manuel'>" . _T('entree_chemin_acces') . "</label> "
+		. "\n<fieldset>"
+		. "<input type='text' name='base_ldap_text' class='text' value=\"$base_ldap_text\" size='40' />"
+		. "\n</fieldset>"
+		. "\n<input type='hidden' name='etape' value='ldap4' />"
+		. install_propager(array('adresse_ldap', 'port_ldap', 'login_ldap', 'pass_ldap', 'protocole_ldap', 'tls_ldap'))
+		. bouton_suivant();
 
 	echo generer_form_ecrire('install', $res);
 
 	echo install_fin_html();
 }
-
-
-?>
