@@ -11,12 +11,31 @@
  *  Pour plus de details voir le fichier COPYING.txt ou l'aide en ligne.   *
 \***************************************************************************/
 
-if (!defined('_ECRIRE_INC_VERSION')) return;
+/**
+ * Gestion de l'itérateur PHP
+ *
+ * @package SPIP\Core\Iterateur\PHP
+ **/
 
-//
-// creer une boucle sur un iterateur
-// annonce au compilo les "champs" disponibles
-//
+
+if (!defined('_ECRIRE_INC_VERSION')) {
+	return;
+}
+
+
+/**
+ * Créer une boucle sur un itérateur PHP
+ *
+ * Annonce au compilateur les "champs" disponibles, c'est à dire
+ * 'cle', 'valeur' et toutes les méthodes de l'itérateur désigné.
+ *
+ * @param Boucle $b
+ *     Description de la boucle
+ * @param string $iteratorName
+ *     Nom de l'itérateur à utiliser
+ * @return Boucle
+ *     Description de la boucle complétée des champs
+ */
 function iterateur_php_dist($b, $iteratorName) {
 	$b->iterateur = $iteratorName; # designe la classe d'iterateur
 	$b->show = array(
@@ -26,15 +45,14 @@ function iterateur_php_dist($b, $iteratorName) {
 		)
 	);
 	foreach (get_class_methods($iteratorName) as $method) {
-		$b->show['field'][ strtolower($method) ] = 'METHOD';
+		$b->show['field'][strtolower($method)] = 'METHOD';
 	}
+
 	/*
 	foreach (get_class_vars($iteratorName) as $property) {
 		$b->show['field'][ strtolower($property) ] = 'PROPERTY';
 	}
 	*/
+
 	return $b;
 }
-
-
-?>
