@@ -3,7 +3,9 @@
 // extrait automatiquement de http://trad.spip.net/tradlang_module/ecrire_?lang_cible=bs
 // ** ne pas modifier le fichier **
 
-if (!defined('_ECRIRE_INC_VERSION')) return;
+if (!defined('_ECRIRE_INC_VERSION')) {
+	return;
+}
 
 $GLOBALS[$GLOBALS['idx_lang']] = array(
 
@@ -21,60 +23,36 @@ $GLOBALS[$GLOBALS['idx_lang']] = array(
 	'avis_connexion_ldap_echec_2' => 'Vratite se na prethodnu stranicu i provjerite unesene podatke.',
 	'avis_connexion_ldap_echec_3' => 'Ne koristite podrsku LDAP kao alternativu za importovanje korisnika.',
 	'avis_deplacement_rubrique' => 'Paznja! Ova rubrika sadrzi @contient_breves@ kratke poruke: Ako je zelite premjestiti, oznacite  ovo polje kao potvrdu.',
-	'avis_destinataire_obligatoire' => 'Trebate naznaciti primaoca prije nego sto posaljete ovu poruku.',
 	'avis_erreur_connexion_mysql' => 'Greska u SQL konekciji', # MODIF
-	'avis_erreur_version_archive' => '<b>Paznja! Dokument @archive@  odgovara drugoj verziji SPIP od one koju ste instalirali.</b>  Riskirate velike poteskoce: opasnost od unistenja vase baze podataka, razne disfunkcije stranice, itd. Ne potvrdjujte ovaj zahtjev za importovanje! Za vise informacija pogledajte <a  href="@spipnet@"> SPIP dokumentaciju</a>.', # MODIF
 	'avis_espace_interdit' => '<b>Zabranjen prostor</b><p>SPIP je  vec instaliran.</p>', # MODIF
 	'avis_lecture_noms_bases_1' => 'Instalacijski program nije uspio ucitati imena instaliranih baza podataka.',
 	'avis_lecture_noms_bases_2' => 'Ili nijedna baza nije na  raspolaganju, ili je funkcija, koja dozvoljava izlistavanje  baza, dezaktivirana iz sigurnosnih razloga (sto je slucaj kod  mnogih racunara).',
 	'avis_lecture_noms_bases_3' => 'Ako je u pitanju druga alternativa, moguce je da se koristi baza koja nosi isto ime kao vas login:',
-	'avis_non_acces_message' => 'Nemate pristup ovoj poruci.',
 	'avis_non_acces_page' => 'Nemate pristup ovoj strani.',
 	'avis_operation_echec' => 'Operacija nije uspijela.',
-	'avis_probleme_archive' => 'Problem kod citanja dokumenta @archive@',
 	'avis_suppression_base' => 'PAZNJA, brisanje podataka je  nepovratno',
-	'avis_version_mysql' => 'Vasa SQL verzija (@version_mysql@) ne dozvoljava automatsko popravljanje (ispravljanje) tabela  baze.', # MODIF
 
 	// B
 	'bouton_acces_ldap' => 'Dodaj pristup za LDAP >>', # MODIF
 	'bouton_ajouter' => 'Dodaj',
-	'bouton_ajouter_participant' => 'DODAJ UCESNIKA:',
-	'bouton_annonce' => 'NAJAVA',
-	'bouton_checkbox_envoi_message' => 'mogucnost slanja poruke',
-	'bouton_checkbox_indiquer_site' => 'obavezno naznaciti jednu web stranicu',
-	'bouton_checkbox_signature_unique_email' => 'samo jedan potpis po e-mail adresi',
-	'bouton_checkbox_signature_unique_site' => 'samo jedan potpis po web stranici',
 	'bouton_demande_publication' => 'Trazi publikaciju ovog clanka',
-	'bouton_effacer_index' => 'Izbrisi indekse',
 	'bouton_effacer_tout' => 'Izbrisi SVE',
-	'bouton_envoi_message_02' => 'POSALJI PORUKU',
 	'bouton_envoyer_message' => 'Definitivna poruka: posalji',
 	'bouton_modifier' => 'Izmijeni',
-	'bouton_pense_bete' => 'LICNA BILJESKA',
-	'bouton_radio_activer_messagerie' => 'Aktiviraj interni servis poruka',
-	'bouton_radio_activer_messagerie_interne' => 'Aktiviraj interni servis poruka',
-	'bouton_radio_activer_petition' => 'Aktiviraj peticiju',
 	'bouton_radio_afficher' => 'Prikazi',
 	'bouton_radio_apparaitre_liste_redacteurs_connectes' => 'Prikazi u listi prisutnih urednika',
-	'bouton_radio_desactiver_messagerie' => 'Dezaktivirati servis poruka',
 	'bouton_radio_envoi_annonces_adresse' => 'Posalji najave na adresu:',
 	'bouton_radio_envoi_liste_nouveautes' => 'Posalji listu novosti',
 	'bouton_radio_non_apparaitre_liste_redacteurs_connectes' => 'Ne prikazuj u listi urednika',
 	'bouton_radio_non_envoi_annonces_editoriales' => 'Ne salji editorijalne najave',
-	'bouton_radio_pas_petition' => 'Bez peticije',
-	'bouton_radio_petition_activee' => 'Peticija je aktivirana',
-	'bouton_radio_supprimer_petition' => 'Izbrisi peticiju',
 	'bouton_redirection' => 'PREUSMJERI',
 	'bouton_relancer_installation' => 'Ponovo pokreni instalaciju',
 	'bouton_suivant' => 'Sljedece',
 	'bouton_tenter_recuperation' => 'Pokusaj popraviti',
 	'bouton_test_proxy' => 'Provjeri proxy',
 	'bouton_vider_cache' => 'Isprazni kes',
-	'bouton_voir_message' => 'Pregledaj poruku prije ovjere',
 
 	// C
-	'cache_mode_compresse' => 'Dokumenti kesa su snimljeni u kompresovanoj formi;.',
-	'cache_mode_non_compresse' => 'Dokumenti kesa su pisani u nekompresovanoj formi.',
 	'cache_modifiable_webmestre' => 'Webmaster stranice moze promijeniti ovaj parametar.',
 	'calendrier_synchro' => 'Ako koristite neki kompaktibilni kalendarski software <b>iCal</b>, mozete ga uskladiti sa informacijama ove stranice.',
 
@@ -100,7 +78,6 @@ $GLOBALS[$GLOBALS['idx_lang']] = array(
 	'entree_login' => 'Vas login',
 	'entree_login_connexion_1' => 'Login konekcije',
 	'entree_login_connexion_2' => '(Nekada odgovara vasem loginu za pristup na FTP; nekada je ostavljen prazan)',
-	'entree_login_ldap' => 'Inicijalni LDAP login',
 	'entree_mot_passe' => 'Vasa lozinka',
 	'entree_mot_passe_1' => 'Lozinka konekcije',
 	'entree_mot_passe_2' => '(Nekada odgovara vasoj lozinki za pristup na FTP, a nekada je ostavljeno prazno)',
@@ -120,7 +97,7 @@ $GLOBALS[$GLOBALS['idx_lang']] = array(
 	'ical_info2' => 'Za sve informacije o ovim metodama, mozete konsultovati <a href="@spipnet@"> SPIP  dokumentaciju </a>.', # MODIF
 	'ical_info_calendrier' => 'Na raspolaganju vam stoje dva kalendara. Jedan je plan stranice koji najavljuje sve publicirane artikle. Drugi sadrzi editorijalne najave, kao sto su vase posljednje privatne poruke: On je rezervisan za vas zahvaljujuci licnom kljucu, koji mozete izmijeniti u svakom  momentu, dok mijenjate svoju lozinku.',
 	'ical_methode_http' => 'Download',
-	'ical_methode_webcal' => 'Sinhronizacija (webcal://)',
+	'ical_methode_webcal' => 'Sinhronizacija (webcal://)', # MODIF
 	'ical_texte_js' => 'Jedna linija javascripta vam omogucuje da recentne clanke, objavljene na ovoj web stranici, jako jednostavno objavite na vasoj web stranici.',
 	'ical_texte_prive' => 'Ovaj kalendar, koji je iskljucivo za licnu upotrebu, obavjestava vas o privatnim editorijalnim  aktivnostima na ovoj stranici (zadaci i licni sastanci, clanci i objavljene kratke poruke).',
 	'ical_texte_rss' => 'Novosti sa ove stranice mozete sindikovati u bilo kojem citacu dokumenata XML/RSS (Rich Site Summary). Takodze, to je format koji dozvoljava SPIP-u da cita novosti objavljene na drugim stranicama, koristeci kompatibilan format  za razmjenu (sindikovane stranice).',
@@ -135,9 +112,7 @@ $GLOBALS[$GLOBALS['idx_lang']] = array(
 	'icone_creer_auteur' => 'Kreiraj novog autora i asociraj ga s ovim clankom',
 	'icone_creer_mot_cle' => 'Kreiraj novu kljucnu rijec i povezi je sa ovim clankom',
 	'icone_creer_rubrique_2' => 'Kreiraj novu rubriku',
-	'icone_envoyer_message' => 'Posalji ovu poruku',
 	'icone_modifier_article' => 'Izmijeni ovaj clanak',
-	'icone_modifier_message' => 'Izmijeni ovu poruku',
 	'icone_modifier_rubrique' => 'Izmijeni ovu rubriku',
 	'icone_retour' => 'Nazad',
 	'icone_retour_article' => 'Nazad na clanak',
@@ -147,10 +122,7 @@ $GLOBALS[$GLOBALS['idx_lang']] = array(
 	'icone_valider_signature' => 'Ovjeri ovaj potpis',
 	'image_administrer_rubrique' => 'Mozete biti administrator ove rubrike',
 	'info_1_article' => '1. clanak',
-	'info_1_site' => '1. stranica',
 	'info_activer_cookie' => 'Mozete aktivirati jedan <b> cookie za administraciu </b>, koji ce vam dozvoliti lak prelaz iz javnog u privati prostor.',
-	'info_admin_gere_rubriques' => 'Ovaj administrator uredzuje sljedece rubrike:',
-	'info_admin_gere_toutes_rubriques' => 'Ovaj administrator uredzuje <b>sve rubrike</b>.', # MODIF
 	'info_administrateur' => 'Administrator',
 	'info_administrateur_1' => 'Administrator',
 	'info_administrateur_2' => 'stranice (<i>pazljiva  upotreba</i>)',
@@ -160,13 +132,10 @@ $GLOBALS[$GLOBALS['idx_lang']] = array(
 	'info_administrer_rubrique' => 'Mozete biti administrator ove rubrike',
 	'info_adresse' => 'na adresu:',
 	'info_adresse_url' => 'URL adresa stranice za javnost',
-	'info_afficher_visites' => 'Prikazi posjete za:',
 	'info_aide_en_ligne' => 'Online pomoc za SPIP',
 	'info_ajout_image' => 'Ako clanku dodajete fotografije u formi dokumenta, SPIP moze kreirati vinjete (minijature) dodanih  fotografija. To naprimjer dozvoljava automatsko kreiranje  galerije ili portfolija.',
-	'info_ajout_participant' => 'Dodan je sljedeci ucesnik:',
 	'info_ajouter_rubrique' => 'Dodaj drugu rubriku za administraciju:',
 	'info_annonce_nouveautes' => 'Najava novosti',
-	'info_anterieur' => 'nazad',
 	'info_article' => 'clanak',
 	'info_article_2' => 'clanci',
 	'info_article_a_paraitre' => 'Prikazi clanke sa kasnijim  datumom',
@@ -174,10 +143,9 @@ $GLOBALS[$GLOBALS['idx_lang']] = array(
 	'info_articles_2' => 'Clanci',
 	'info_articles_auteur' => 'Clanci ovog autora',
 	'info_articles_trouves' => 'Pronadjeni clanci',
-	'info_articles_trouves_dans_texte' => 'Pronadjeni clanci (u tekstu)',
 	'info_attente_validation' => 'Vasi clanci koji cekaju ovjeru',
 	'info_aujourdhui' => 'danas:',
-	'info_auteur_message' => 'AUTOR PORUKE:',
+	'info_auteur_gere_toutes_rubriques_2' => 'Je gère <b>toutes les rubriques</b>', # MODIF
 	'info_auteurs' => 'Autori',
 	'info_auteurs_par_tri' => 'Autori@partri@',
 	'info_auteurs_trouves' => 'Pronadjeni autori',
@@ -193,7 +161,6 @@ $GLOBALS[$GLOBALS['idx_lang']] = array(
 	'info_classement_1' => '<sup>er</sup> iz @liste@',
 	'info_classement_2' => '<sup>e</sup> iz @liste@',
 	'info_code_acces' => 'Ne zaboravite vas kod za pristup!',
-	'info_compresseur_gzip' => '<b>N. B. :</b> Il est recommandé de vérifier au préalable si l’hébergeur compresse déjà systématiquement les scripts php ; pour cela, vous pouvez par exemple utiliser le service suivant : @testgzip@', # MODIF
 	'info_config_suivi' => 'Ako ova adresa odgovara mailing listi, ispod mozete naznaciti adresu na koju se ucesnici mogu registrovati. Ta adresa moze biti URL (npr. strana za  upisivanje na listu putem web-a), ili e-mail adresa opremljena  specificnim subjektom(npr.:  <tt>@adresse_suivi@?subject=prijava</tt>):',
 	'info_config_suivi_explication' => 'Mozete se prikljuciti mailing-listi ove stranice. Poslije cete u elektronskim putem primiti najave clanaka i kratkih poruka, koje su predlozene za publikaciju',
 	'info_confirmer_passe' => 'Potvrdi novu lozinku:',
@@ -211,15 +178,12 @@ $GLOBALS[$GLOBALS['idx_lang']] = array(
 	'info_date_publication_anterieure' => 'Datum proslog objavljivanja:',
 	'info_date_referencement' => 'DATUM PREPORUKE OVE STRANICE:',
 	'info_derniere_etape' => 'Posljednja etapa: <b>Zavrseno je!', # MODIF
-	'info_derniers_articles_publies' => 'Vasi posljednji objavljeni  clanci',
-	'info_desactiver_messagerie_personnelle' => 'Mozete aktivirati  ili dezaktivirati vas licni servis poruka na ovoj stranici.',
 	'info_descriptif' => 'Opis:',
 	'info_discussion_cours' => 'Aktivne diskusije',
 	'info_ecrire_article' => 'Prije nego mozete pisati clanke, morate kreirati najmanje jednu rubriku.',
 	'info_email_envoi' => 'E-mail adresa za slanje (fakultativno)',
 	'info_email_envoi_txt' => 'Ovdje oznacite adresu za slanje e-mailova (po standardu ce adresa primaoca biti koristena kao adresa za slanje):',
 	'info_email_webmestre' => 'E-mail adresa webmastera (fakultativno)', # MODIF
-	'info_entrer_code_alphabet' => 'Unesite kod alfabeta koji ce se koristiti:',
 	'info_envoi_email_automatique' => 'Automatsko slanje e-mailova',
 	'info_envoyer_maintenant' => 'Posalji sada',
 	'info_etape_suivante' => 'Pristupi sljedecoj etapi',
@@ -229,24 +193,16 @@ $GLOBALS[$GLOBALS['idx_lang']] = array(
 	'info_facilite_suivi_activite' => 'U svrhu posmatranja  editorijalne aktivnosti stranice, SPIP moze elektronskom postom  (npr. mailing listom urednika) proslijedjivati najave zahtijeva za publikaciju i ovjeru clanaka.',
 	'info_fichiers_authent' => 'Dokument autentifikacije « .htpasswd »',
 	'info_forums_abo_invites' => 'Vasa stranica obudhvata i forume za clanove; posjetioci se pozivaju na registraciju u javnom  prostoru stanice.',
-	'info_gauche_admin_effacer' => '<b>Ova strana je dostupna samo  osobama odgovornim za web stranicu.</b><p> Ona daje pristup raznim funkcijama tehnickog odrzavanja. Neke od njih pruzaju  mogucnost specificne autentifikacije, koja zahtijeva pristup FTP-u web stranice.</p>', # MODIF
 	'info_gauche_admin_tech' => '<b>Ova strana je dostupna samo osobama odgovornim za web stranicu.</b><p> Ona daje pristup raznim funkcijama tehnickog odrzavanja. Neke od njih pruzaju  mogucnost specificne autentifikacije, koja zahtijeva pristup FTP-u web stranice.</p>', # MODIF
 	'info_gauche_admin_vider' => '<b>Ova strana je dostupna samo osobama odgovornim za web stranicu.</b><p> Ona daje pristup raznim funkcijama tehnickog odrzavanja. Neke od njih pruzaju mogucnost specificne autentifikacije, koja zahtijeva pristup FTP-u web stranice.</p>', # MODIF
 	'info_gauche_auteurs' => 'Ovdje cete pronaci sve autore ove web stranice. Njihov status je naznacen bojom njihove ikone (administrator = zelena; urednik = zuta).',
 	'info_gauche_auteurs_exterieurs' => 'Vanjski autori bez pristupa stranici su oznaceni plavom ikonom, a izbrisani autori sa ikonicom korpe za smece.', # MODIF
 	'info_gauche_messagerie' => 'Servis za slanje poruka vam omogucuje razmjenu poruka medju piscima, cuvanje biljeske (za licnu upotrebu) ili, ako ste administrator, postavljanje najava na pocetnu stranicu u privatnom prostoru.',
-	'info_gauche_numero_auteur' => 'BROJ AUTORA',
 	'info_gauche_statistiques_referers' => 'Ova strana predstavlja  listu <i>referenci</i>, sto znaci stranice koje sadrze linkove  sa vasom licnom stranicom, ali samo za jucer i danas; ova lista se vraca na nulu svaka 20 sata.',
 	'info_gauche_visiteurs_enregistres' => 'Ovdje mozete pronaci posjetioce koji su registrovani na javnoj stranici (forumi za clanove).',
 	'info_generation_miniatures_images' => 'Obradjivanje minijaturnih slika',
-	'info_gerer_trad' => 'Zelite li ukljuciti linkove za prevod?',
 	'info_hebergeur_desactiver_envoi_email' => 'Neki kompjuteri dezaktiviraju automatsko slanje mailova njihovim serverima. U tom slucaju sljedece funkcije SPIP-a nece biti u uptrebi.',
 	'info_hier' => 'Jucer:',
-	'info_historique_activer' => 'Aktivirati pracenje revizija',
-	'info_historique_affiche' => 'Prikazati reviziju',
-	'info_historique_comparaison' => 'uporedi',
-	'info_historique_desactiver' => 'Dezaktivirati pracenje revizija',
-	'info_historique_texte' => 'Pracenje revizija omogucuje ocuvanje historije svih izmjena na sadrzaju clanka i  prikazivanje razlika verzija koje slijede.',
 	'info_identification_publique' => 'Vas javni identitet...',
 	'info_image_process' => 'Izaberite najbolju metodu pravljenja vinjeta tako sto cete kliknuti na odgovarajucu sliku.',
 	'info_image_process2' => '<b>N.B.</b> <i>Ako se ne pojavljuje nijedna slika, onda vas server nije konfigurisan za koristenje tih funkcija. Ako zelite koristiti te funkcije, kontaktirajte ososbu odgovornu za tehnicko odrzavanje i pitajte za extenzije «GD» ili  «Imagick».</i>', # MODIF
@@ -264,8 +220,6 @@ $GLOBALS[$GLOBALS['idx_lang']] = array(
 	'info_login_trop_court' => 'Ovaj login je prekratak.',
 	'info_maximum' => 'maksimalno:',
 	'info_meme_rubrique' => 'U istoj rubrici',
-	'info_message' => 'Poruka od',
-	'info_message_efface' => 'PORUKA IZBRISANA',
 	'info_message_en_redaction' => 'Vase poruke u toku uredjivanja',
 	'info_message_technique' => 'Tehnicka poruka:',
 	'info_messagerie_interne' => 'Interni servis za poruke',
@@ -274,19 +228,14 @@ $GLOBALS[$GLOBALS['idx_lang']] = array(
 	'info_modifier_rubrique' => 'Izmijeni rubriku:',
 	'info_modifier_titre' => 'Izmijeni: @titre@',
 	'info_mon_site_spip' => 'Moja SPIP stranica',
-	'info_mot_sans_groupe' => '(Kljucne rijeci bez grupe...)',
-	'info_moteur_recherche' => 'integrisani motor za pretragu',
 	'info_moyenne' => 'prosjek:',
-	'info_multi_articles' => 'Aktivirati jezicki meni za clanke?',
 	'info_multi_cet_article' => 'Jezik ovog clanka:',
 	'info_multi_langues_choisies' => 'Izaberite jezike koji ce biti na raspolaganju urednicima vase stranice. Jezici koji se vec koriste na vasoj stranici, ne mogu se iskluciti.',
-	'info_multi_rubriques' => 'Aktivirati jezicki meni za rubrike?',
 	'info_multi_secteurs' => '... samo za rubrike koje se nalaze na root-u?',
 	'info_nom' => 'Ime',
 	'info_nom_destinataire' => 'Ime primaoca',
 	'info_nom_site' => 'Ime vase stranice',
 	'info_nombre_articles' => '@nb_articles@ clanci,',
-	'info_nombre_partcipants' => 'UCESNICI DISKUSIJE:',
 	'info_nombre_rubriques' => '@nb_rubriques@ rubrike,',
 	'info_nombre_sites' => '@nb_sites@ stranice,',
 	'info_non_deplacer' => 'Ne premijestati...',
@@ -295,48 +244,35 @@ $GLOBALS[$GLOBALS['idx_lang']] = array(
 	'info_non_modifiable' => 'Ne moze se modifikovati',
 	'info_non_suppression_mot_cle' => 'Ne zelim izbrisati ovu kljucnu rijec.',
 	'info_notes' => 'Biljeske',
-	'info_nouveaux_message' => 'Nove poruke',
 	'info_nouvel_article' => 'Novi clanak',
 	'info_nouvelle_traduction' => 'Novi prevod:',
 	'info_numero_article' => 'CLANAK BROJ:',
 	'info_obligatoire_02' => '[Obavezno]', # MODIF
 	'info_option_accepter_visiteurs' => 'Prihvati upisivanje posjetioca na javnoj stranici',
-	'info_option_faire_suivre' => 'Omoguci autorima clanaka pracenje poruka na forumima',
 	'info_option_ne_pas_accepter_visiteurs' => 'Odbij upisivanje posjetioca',
 	'info_options_avancees' => 'NAPREDNE OPCIJE',
-	'info_ortho_activer' => 'Aktiviraj ortografsku provjeru',
-	'info_ortho_desactiver' => 'Dezaktiviraj ortografsku provjeru',
 	'info_ou' => 'ili...',
 	'info_page_interdite' => 'Ova strana je zabranjena',
 	'info_par_nombre_article' => '(po broju clanaka)', # MODIF
 	'info_passe_trop_court' => 'Prekratka lozinka.',
 	'info_passes_identiques' => 'Lozinke nisu identicne.',
-	'info_pense_bete_ancien' => 'Vase stare biljeske', # MODIF
 	'info_plus_cinq_car' => 'vise od pet karaktera',
 	'info_plus_cinq_car_2' => '(Vise od pet karaktera)',
 	'info_plus_trois_car' => '(Vise od tri karaktera)',
 	'info_popularite' => 'popularnosti: @popularite@ ;  posjete: @visites@',
-	'info_popularite_4' => 'popularnost: @popularite@ ;  posjete: @visites@',
 	'info_post_scriptum' => 'Post-Scriptum',
 	'info_post_scriptum_2' => 'Post-scriptum :',
 	'info_pour' => 'za',
-	'info_preview_admin' => 'Samo administratori mogu stranicu pogledati online',
-	'info_preview_comite' => 'Svi urednici mogu stranicu pogledati online',
-	'info_preview_desactive' => 'Nije moguce pogledati stranicu online. Ova opcija je dezaktivirana.',
-	'info_preview_texte' => 'Moguce je stranicu pogledati online, kao da su svi clanci i kratke poruke objavljene, ukoliko iste imaju « predlozen » status. Da li ova opcija treba biti otvorena samo administratorima, svim urednicima ili nikome?',
-	'info_principaux_correspondants' => 'Vasi glavni korespodenti',
+	'info_preview_texte' => 'Moguce je stranicu pogledati online, kao da su svi clanci i kratke poruke objavljene, ukoliko iste imaju « predlozen » status. Da li ova opcija treba biti otvorena samo administratorima, svim urednicima ili nikome?', # MODIF
 	'info_procedez_par_etape' => 'Slijedite etape',
 	'info_procedure_maj_version' => 'Potrebno je pokrenuti update, da bi se baza podataka prikljucila novoj verziji SPIP-a.',
 	'info_ps' => 'P.S.:', # MODIF
 	'info_publier' => 'objavi moje clanke',
 	'info_question_accepter_visiteurs' => 'Ako obrasci vase stranice ukljucuju upisivanje posjetioca bez pristupa u  privatnu stranicu, aktivirajte sljedecu opciju:',
 	'info_question_inscription_nouveaux_redacteurs' => 'Da li prihvatate upisivanje novih urednika u javnom prostoru  stranice? Ako prihvatate, posjetioci ce se moci registrovati putem automatskog formulara, a zatim ce moci pristupiti privatnom prostoru i predlagati svoje clanke. <blockquote><i>Tokom faze upisivanja, korisnici ce primiti  automatski e-mail sa kodom za pristup u privatnu stranicu. Neki kompjuteri sprecavaju slanje mailova putem njihovih servera: u tom slucaju ce automatsko upisivanje biti nemoguce.', # MODIF
-	'info_question_utilisation_moteur_recherche' => 'Zelite li koristiti motor pretrage koji je integrisan u SPIP? (dezaktiviranje ove opcije ubrzava funkcionisanje sistema.)',
 	'info_qui_edite' => '@nom_auteur_modif@ a travaillé sur ce contenu il y a @date_diff@ minutes', # MODIF
 	'info_racine_site' => 'Korjen stranice',
 	'info_recharger_page' => 'Restartujte ovu stranicu za nekoliko momenata.',
-	'info_recherche_auteur_a_affiner' => 'Previse rezultata za "@cherche_auteur@"; redefinisite opcije pretrage.',
-	'info_recherche_auteur_ok' => 'Pronadjeno je vise urednika za  "@cherche_auteur@":',
 	'info_recherche_auteur_zero' => 'Nema rezultata za « @cherche_auteur@ ».',
 	'info_recommencer' => 'Pocnite ponovo.',
 	'info_redacteur_1' => 'Urednik',
@@ -353,7 +289,6 @@ $GLOBALS[$GLOBALS['idx_lang']] = array(
 	'info_rubriques' => 'Rubrike',
 	'info_rubriques_02' => 'rubrike',
 	'info_rubriques_trouvees' => 'Pronadjene rubrike',
-	'info_rubriques_trouvees_dans_texte' => 'Pronadjene rubrike (u ovom tekstu)',
 	'info_sans_titre' => 'Bez naslova',
 	'info_selection_chemin_acces' => '<b>Izaberite</b> putanju pristupa direktoriju:',
 	'info_signatures' => 'potpisi',
@@ -366,11 +301,9 @@ $GLOBALS[$GLOBALS['idx_lang']] = array(
 	'info_sites_lies_mot' => 'Preporucene stranice koje su vezane za ovu kljucnu rijec',
 	'info_sites_proxy' => 'Koristi proxy',
 	'info_sites_trouves' => 'Pronadjene stranice',
-	'info_sites_trouves_dans_texte' => 'Pronadjene stranice (u tekstu)',
 	'info_sous_titre' => 'Podnaslov:',
 	'info_statut_administrateur' => 'Administrator',
 	'info_statut_auteur' => 'Status ovog autora:', # MODIF
-	'info_statut_efface' => 'Izbrisano',
 	'info_statut_redacteur' => 'Urednik',
 	'info_statut_utilisateurs_1' => 'Standardni status importovanih korisnika',
 	'info_statut_utilisateurs_2' => 'Izaberita koji status ce imati osobe koje su prisutne u LDAP direktoriju, kada se konektuju  prvi put. Kasnije ce te biti u mogucnosti da status svakog autora individualno izmijenite.',
@@ -388,7 +321,6 @@ $GLOBALS[$GLOBALS['idx_lang']] = array(
 	'info_tous_articles_en_redaction' => 'Svi clanci koji su fazi obradjivanja',
 	'info_tous_articles_presents' => 'Svi objavljeni clanci u ovoj rubrici',
 	'info_tous_les' => 'svi:',
-	'info_tous_redacteurs' => 'Najava svim urednicima',
 	'info_tout_site' => 'Citava web stranica',
 	'info_tout_site2' => 'Clanak nije preveden na ovaj jezik.',
 	'info_tout_site3' => 'Clanak je preveden na ovaj jezik, ali su usvojene izmjene preporucenog clanka. Potrebno je obnoviti  prevod.',
@@ -402,7 +334,6 @@ Prevodi su (sa bojom koja ukazuje na njihovo stanje) povezani sa originalnim cla
 	'info_une_rubrique' => 'jedna rubrika,',
 	'info_une_rubrique_02' => '1 rubrika',
 	'info_url' => 'URL:',
-	'info_url_site' => 'URL WEB STRANICE:',
 	'info_urlref' => 'Hiperlink:',
 	'info_utilisation_spip' => 'Mozete poceti sa koristenjem sistema za asistirano objavljivanje...',
 	'info_visites_par_mois' => 'Prikazi po mjesecu:',
@@ -419,15 +350,12 @@ Prevodi su (sa bojom koja ukazuje na njihovo stanje) povezani sa originalnim cla
 	'item_activer_messages_avertissement' => 'Aktiviraj poruke upozorenja',
 	'item_administrateur_2' => 'administrator',
 	'item_afficher_calendrier' => 'Prikazati u kalendaru',
-	'item_autoriser_documents_joints' => 'Ododbri dokumente pridruzene clancima',
-	'item_autoriser_documents_joints_rubriques' => 'Odobri dokumente u rubrikama',
 	'item_choix_administrateurs' => 'administratori',
 	'item_choix_generation_miniature' => 'Automatski uredi minijature slika.',
 	'item_choix_non_generation_miniature' => 'Ne uredjuj minijature slika.',
 	'item_choix_redacteurs' => 'urednici',
 	'item_choix_visiteurs' => 'posjetioci javne stranice',
 	'item_creer_fichiers_authent' => 'kreiraj dokumente .htpasswd',
-	'item_limiter_recherche' => 'Pretragu ograniciti na informacije sa vase stranice',
 	'item_login' => 'Login',
 	'item_mots_cles_association_articles' => 'za clanke',
 	'item_mots_cles_association_rubriques' => 'za rubrike',
@@ -436,34 +364,24 @@ Prevodi su (sa bojom koja ukazuje na njihovo stanje) povezani sa originalnim cla
 	'item_non_accepter_inscriptions' => 'Ne dozvoljavaj upise',
 	'item_non_activer_messages_avertissement' => 'Bez poruka upozorenja',
 	'item_non_afficher_calendrier' => 'Ne prikazuj u kalendaru',
-	'item_non_autoriser_documents_joints' => 'Ne odobravaj dokumente bez clanaka',
-	'item_non_autoriser_documents_joints_rubriques' => 'Ne odobravaj dokumente u rubrikama',
 	'item_non_creer_fichiers_authent' => 'Ne kreiraj ove dokumente',
-	'item_non_gerer_statistiques' => 'Ne uredjuj statistike',
-	'item_non_limiter_recherche' => 'Pretragu prosiriti na sadrzaj preporuka',
 	'item_non_publier_articles' => 'Ne objavljuj clanke poslije datuma odredjenog za publikaciju.',
-	'item_non_utiliser_moteur_recherche' => 'Ne koristi motor',
 	'item_nouvel_auteur' => 'Novi autor',
 	'item_nouvelle_rubrique' => 'Nova rubrika',
 	'item_oui' => 'Da',
 	'item_publier_articles' => 'Objavi clanke bez obzira na datum odredjen za njihovu publikaciju.',
 	'item_reponse_article' => 'Odgovor na clanak',
-	'item_utiliser_moteur_recherche' => 'Koristi motor za pretragu',
 	'item_visiteur' => 'posjetioc',
 
 	// J
 	'jour_non_connu_nc' => 'nepoznato',
 
 	// L
-	'lien_ajout_destinataire' => 'Dodaj ovog primaoca',
 	'lien_ajouter_auteur' => 'Dodaj ovog autora',
-	'lien_ajouter_participant' => 'Dodaj ucesnika',
 	'lien_email' => 'e-mail',
 	'lien_nom_site' => 'IME STRANICE:',
 	'lien_retirer_auteur' => 'Odstrani autora',
-	'lien_retrait_particpant' => 'Odstrani ovog ucesnika',
 	'lien_site' => 'stranica',
-	'lien_supprimer_rubrique' => 'Izbrisi ovu rubriku',
 	'lien_tout_deplier' => 'Sve otvoriti',
 	'lien_tout_replier' => 'Sve zatvoriti',
 	'lien_trier_nom' => 'Poredaj po imenu',
@@ -498,6 +416,7 @@ Prevodi su (sa bojom koja ukazuje na njihovo stanje) povezani sa originalnim cla
 
 	// R
 	'repertoire_plugins' => 'Directorij:',
+	'required' => '[Obavezno]', # MODIF
 
 	// S
 	'statut_admin_restreint' => '(ograniceni admin)', # MODIF
@@ -520,13 +439,10 @@ Prevodi su (sa bojom koja ukazuje na njihovo stanje) povezani sa originalnim cla
 	'texte_article_virtuel_reference' => '<b>Virtuelni clanak:</b> clanak je preporucen na vasoj SPIP stranici, ali apreusmjeren na drugi URL. Da bi ste sprijecili preusmjeravanje, izbrisite nize prikazani URL.',
 	'texte_aucun_resultat_auteur' => 'Nema rezultata za"@cherche_auteur@"',
 	'texte_auteur_messagerie' => 'Ova stranica vam moze permanentno ukazivati na listu konektovanih urednika, sto vam omogucuje online razmjenu poruka. Mozete odluciti da se ne pojavljujete na ovoj listi (nevidljivi ste za druge korisnike).',
-	'texte_auteur_messagerie_1' => 'Ova stranica vam dozvoljava razmjenu poruka i formiranje foruma za diskusiju izmedju ucesnika na stranici. Mozete odluciti da ne ucestvujete u ovim  promjenama.',
 	'texte_auteurs' => 'AUTORI',
 	'texte_choix_base_1' => 'Izaberite vasu bazu:',
 	'texte_choix_base_2' => 'SQL server sadrzi vise baza podataka.', # MODIF
 	'texte_choix_base_3' => '<b>Izaberite</b> Ispod one koja vam je dodjeljena od vaseg kompjutera:', # MODIF
-	'texte_commande_vider_tables_indexation' => 'Koristite ovu komandu da biste ispraznili tabele za indeksiranje, koje koriste motori za pretragu integrisani u SPIP. To ce vam  omoguciti da dobijete na prostoru na disku .',
-	'texte_compresse_ou_non' => '(Ovo moze biti kompresovano ili ne)',
 	'texte_compte_element' => '@count@ element',
 	'texte_compte_elements' => '@count@ elementi',
 	'texte_connexion_mysql' => 'Provjerite informacije koje ste dobili od vaseg kompjutera: Trebate pronaci da li vas kompjuter podrzava SQL i kodove za konekciju na SQL  server.', # MODIF
@@ -538,10 +454,8 @@ Prevodi su (sa bojom koja ukazuje na njihovo stanje) povezani sa originalnim cla
 	'texte_date_publication_anterieure' => 'Datum proslog uredjivanja:',
 	'texte_date_publication_anterieure_nonaffichee' => 'Ne prikazuj datum proslog uredjivanja.',
 	'texte_date_publication_article' => 'DATUM OBJAVLJIVANJA:',
-	'texte_descriptif_petition' => 'Opis peticije',
 	'texte_descriptif_rapide' => 'Brzi opis',
 	'texte_effacer_base' => 'Izbrisati SPIP bazu podataka',
-	'texte_effacer_donnees_indexation' => 'Izbrisati podatke indexiranja',
 	'texte_en_cours_validation' => 'Dole navedeni clanci i kratke poruke su predlozene za publikaciju. Vase misljenje mozete iznijeti u njima prikljucenim forumima.', # MODIF
 	'texte_enrichir_mise_a_jour' => 'Mozete obogatiti izgled vaseg teksta na stranici, koristeci se « tipogrfskim  precicama ».',
 	'texte_fichier_authent' => '<b>Treba li SPIP kreirati specijalne dokumente <tt>.htpasswd</tt> i  <tt>.htpasswd-admin</tt> u repertoaru @dossier@ ?</b><p> Ti dokumenti vam omogucuju zabranu pristupa autorima  i administratorima na drugim mjestima vase stranice (npr.  eksterni program za statistike).</p><p>  Ako od ovoga nemate  nikakve koristi, mozete ostaviti standardnu vrijednost za ovu  opciju (nema kreacije dokumenata).</p>', # MODIF
@@ -549,19 +463,13 @@ Prevodi su (sa bojom koja ukazuje na njihovo stanje) povezani sa originalnim cla
 	'texte_informations_personnelles_2' => '(Napomena: ako se radi o reinstalaciji i ako vas pristup uvijek funkcionise, mozete', # MODIF
 	'texte_introductif_article' => '(Uvodni tekst u clanak.)',
 	'texte_jeu_caractere' => 'Ova opcija je korisna ako vasa  stranica treba postavljati tekstove sa alfabetom (ukljucujuci  njegove derivate) koji nije romanski (ili  « okcidentalni »). U tom slucaju je  pozeljno promijeniti standardnu postavku u odgovarajuci set  karaktera; u svakum slucaju vam savjetujemo da napravite  testove i pronadjete zadovoljavajuce rijesenje. Ako izmlijenite  ovaj parametar, ne zaboravite javnu stranicu prilagoditi  izmjenama (balise <tt>#CHARSET</tt>).',
-	'texte_jeu_caractere_2' => 'Ova postavka nema retroaktivni  efekat. Radi toga, vec uneseni tekstovi mogu radi biti pogresno  prikazani uslijed izmjene postavke. U svako slucaju, mozete se  bez gubitka vratiti na prethodnu postavku.',
-	'texte_lien_hypertexte' => '(Ako se vasa poruka odnosi na  clanak objavljen na web-u ili stranicu koja pruza vise  informacija, naznacite naziv stranice i njenu URL adresu.)',
 	'texte_login_ldap_1' => '(Ostaviti prazno za anonimni pristup ili unjeti kompletnu putanju, npr. « <tt>uid=dupont,  ou=users, dc=mon-domaine, dc=com</tt> ».)',
 	'texte_login_precaution' => 'Paznja! Ovo je login kojim ste trenutno konektovani. Pazljivo se koristite ovim  formularom...',
-	'texte_message_edit' => 'Paznja: ovu poruku moze imijeniti svaki administrator stranice, a vidljiva je svim urednicima.  Koristite se najavama samo da biste najavili vazne dogadjaje  zivota stranice.',
 	'texte_mise_a_niveau_base_1' => 'Upravo ste obnovili SPIP dokumente. Sada je potrebna nadogrdnja baze podataka.',
 	'texte_modifier_article' => 'Izmijeni clanak:',
-	'texte_moteur_recherche_active' => '<b>Motor za pretragu je  aktivan.</b> Koristite se ovom komandom ako zelite pristupiti brze reindeksacije (npr. nakon pohranjivanja).  Dokumenti koji su izmijenjeni na normalan nacin (prema SPIP rasoredu) su reindeksovani automatski: dakle, ova komanda je korisna samo u iznimnim slucajevima.',
-	'texte_moteur_recherche_non_active' => 'Motor za pretragu nije aktiviran.',
 	'texte_multilinguisme' => 'Ako zelita obradjivati clanke na vise jezika, sa kompleksnom navigacijom, u organizaciju vase  stranice mozete dodati meni za odabir jezika u clancima i/ili  rubrikama.', # MODIF
 	'texte_multilinguisme_trad' => 'Svakako mozete aktivirati sistem sa obradjivanje linkova izmedju razlicitih prevoda  clanaka.', # MODIF
 	'texte_non_compresse' => '<i>nije kompresovan</i> (vas server ne podrzava ovu funkciju)',
-	'texte_nouveau_message' => 'Nova poruka',
 	'texte_nouvelle_version_spip_1' => 'Instalirali ste novu verziju SPIP-a.',
 	'texte_nouvelle_version_spip_2' => 'Ovoj verziji je potrebno obnavljanje kompletnije od uobicajenog. Ako ste webmaster stranice, izbrisite dokument <tt>inc_connect.php3</tt> iz  repertoara <tt>ecrire</tt> i ponovo otpocnite instalaciju da  biste obnovili parametre konekcije sa bazom podataka.<p>  (Napomena: ako ste zaboravili parametre vase konekcije  pogledajte dokument <tt>inc_connect.php3</tt> prije nego ga  izbrisete...)</p>', # MODIF
 	'texte_operation_echec' => 'Vratite se na prethodnu stranu, izaberite drugu bazu ili napravite novu. Provjerite podatke  koje vam je dao vas kompjuter.',
@@ -573,7 +481,6 @@ Prevodi su (sa bojom koja ukazuje na njihovo stanje) povezani sa originalnim cla
 	'texte_publication_articles_post_dates' => 'Kako se SPIP treba ponasati prema clancima ciji je datum objavljivanja odredjen za buducnost? ',
 	'texte_rappel_selection_champs' => '[Ne zaboravite ispravno izabrati ovo polje.]',
 	'texte_recalcul_page' => 'Ako zelite preracunati samo jednu stranu, predjite u javni prostor i koristite « preracunati ».',
-	'texte_recapitiule_liste_documents' => 'Ova strana ponavlja spisak dokumenata koje ste postavili u rubrikama. Da biste izmijenili informacije svakog dokumenta, pratite link do strane sa njegovom rubrikom.',
 	'texte_recuperer_base' => 'Popravi bazu podataka',
 	'texte_reference_mais_redirige' => 'clanak je preporucen u vasoj SPIP stranici, ali je preusmjeren na drugi URL.',
 	'texte_requetes_echouent' => '<b>Ako odredzeni SQL zahtijevi sistematski i bez ociglednog razloga ne uspijevaju, moguce je da je problem u samoj bazi podataka.</b><p> SQL raspolaze mogucnosti popravljanja njegovih tabela, ako su one slucajno ostecene. Ovdje mozete isprobati popravku; u slucaju neuspijeha, sacuvajte kopiju prikaza na monitoru, koja mozda sadrzi naznake problema...</p><p> Ako se problem nastavi, kontaktirajte vas hosting servis.</p>', # MODIF
@@ -590,7 +497,6 @@ Prevodi su (sa bojom koja ukazuje na njihovo stanje) povezani sa originalnim cla
 	'texte_suppression_fichiers' => 'Koristite se ovom komandom da biste sve prisutne dokumente u SPIP kes. To omogucuje npr. izazivanje preracunavanja svih strana, u slucaju da ste izveli vazne izmjene grafizma ili strukture stranice.',
 	'texte_sur_titre' => 'Nadnaslov',
 	'texte_table_ok' => ':ova tabela je OK.',
-	'texte_tables_indexation_vides' => 'Tabele indeksacije motora su prazne.',
 	'texte_tentative_recuperation' => 'Pokusaj popravke',
 	'texte_tenter_reparation' => 'Pokusati popravljanje baze podataka',
 	'texte_test_proxy' => 'Da bi ste probali ovaj proxy, ovdje naznacite adresu (web stranice) koju zelite testirati.',
@@ -598,13 +504,8 @@ Prevodi su (sa bojom koja ukazuje na njihovo stanje) povezani sa originalnim cla
 	'texte_titre_obligatoire' => '<b>Naslov</b> [Obavezan]', # MODIF
 	'texte_travail_article' => '@nom_auteur_modif@ ostaje @date_diff@ minuta za rad na ovom clanku',
 	'texte_travail_collaboratif' => 'Ako je uobicajeno da vise urednika radi na istom clanku, sistem moze postavljati posljednje « otvarane » clanke, da bi se izbjegle simultane izmjene. Ova opcija je standardno iskljucena, da bi se izbjeglo postavljanje neodgovarajucih poruka upozorenja.',
-	'texte_trop_resultats_auteurs' => 'Previse rezultata za pretragu "@cherche_auteur@" ; predefinisite opcije pretrazivanja.',
-	'texte_unpack' => 'download posljednje verzije',
-	'texte_utilisation_moteur_syndiques' => 'Ako koristitie motor pretrage koji je integrisan u SPIP, mozete na dva razlicita nacina izvesti pretragu na sindikovanim stranicama i clancima. <br /><img  src=\\"puce.gif\\"> Najjednostavnije je pretrazivati samo naslove i opise clanaka. <br /><img src=\\"puce.gif\\"> Mnogo jaca metoda dozvoljava SPIP-u da trazi unutar tekstova preporucenih sranica. Dakle, ako preporucite neku stranicu, SPIP ce izvrsiti pretragu unutar samog teksta stranice.', # MODIF
-	'texte_utilisation_moteur_syndiques_2' => 'Ova metoda obavezuje SPIP da redovno posjecuje preporucene stranice, sto moze izazvati lahko usporavanje vase sopstvene stranice.',
 	'texte_vide' => 'prazno',
 	'texte_vider_cache' => 'Isprazniti kes',
-	'titre_admin_effacer' => 'Tehnicko odrzavanje',
 	'titre_admin_tech' => 'Tehnicko odrzavanje',
 	'titre_admin_vider' => 'Tehnicko odrzavanje',
 	'titre_cadre_afficher_article' => 'Prikazi clanke',
@@ -624,32 +525,19 @@ Prevodi su (sa bojom koja ukazuje na njihovo stanje) povezani sa originalnim cla
 	'titre_naviguer_dans_le_site' => 'Navigacija stranicom...',
 	'titre_nouvelle_rubrique' => 'Nova rubrika',
 	'titre_numero_rubrique' => 'RUBRIKA BROJ:',
-	'titre_page_admin_effacer' => 'Tehnicko odrzavanje: brisanje baze',
 	'titre_page_articles_edit' => 'Izmjeni: @titre@',
 	'titre_page_articles_page' => 'Clanci',
 	'titre_page_articles_tous' => 'Cijela stranica',
-	'titre_page_auteurs' => 'Posjetioci',
 	'titre_page_calendrier' => 'Kalendar @nom_mois@ @annee@',
 	'titre_page_config_contenu' => 'Konfiguracija stranice',
-	'titre_page_config_fonctions' => 'Konfiguracija stranice',
-	'titre_page_configuration' => 'Konfiguracija stranice',
-	'titre_page_controle_petition' => 'Pracenje peticija',
 	'titre_page_delete_all' => 'cjelokupno i nepovratno otklanjanje',
-	'titre_page_documents_liste' => 'Dokumenti rubrike',
-	'titre_page_index' => 'Vas privatni prostor',
-	'titre_page_message_edit' => 'Napisi poruku',
-	'titre_page_messagerie' => 'Vas transfer poruka',
 	'titre_page_recherche' => 'Rezultati pretrage @recherche@',
 	'titre_page_statistiques_referers' => 'Statistike (linkovi unosenja)',
 	'titre_page_upgrade' => 'Postavljanje SPIP-a na aktuelni nivo',
 	'titre_publication_articles_post_dates' => 'Objavljivanje clanaka sa kasnijim datumom',
-	'titre_referencer_site' => 'Preporuciti stranicu:',
-	'titre_rendez_vous' => 'SASTANAK:',
 	'titre_reparation' => 'Popravka',
 	'titre_suivi_petition' => 'Pracenje peticija',
-	'trad_article_inexistant' => 'Ne postoji clanak koji nosi ovaj broj.',
 	'trad_article_traduction' => 'Sve verzije ovog clanka:',
-	'trad_deja_traduit' => 'Ovaj clanak je vec prevod prethodnog clanka.', # MODIF
 	'trad_delier' => 'Ne vezati vise ovaj clanak za ove prevode', # MODIF
 	'trad_lier' => 'Ovaj clanak je prevod clanka broj:',
 	'trad_new' => 'Napisati novi prevod ovog clanka' # MODIF
