@@ -3,7 +3,9 @@
 // extrait automatiquement de http://trad.spip.net/tradlang_module/ecrire_?lang_cible=ca
 // ** ne pas modifier le fichier **
 
-if (!defined('_ECRIRE_INC_VERSION')) return;
+if (!defined('_ECRIRE_INC_VERSION')) {
+	return;
+}
 
 $GLOBALS[$GLOBALS['idx_lang']] = array(
 
@@ -11,10 +13,10 @@ $GLOBALS[$GLOBALS['idx_lang']] = array(
 	'activer_plugin' => 'Activar el connector',
 	'affichage' => 'Presentació',
 	'aide_non_disponible' => 'Aquesta part de l’ajuda en línia no està encara disponible en aquesta llengua.',
-	'annuler_recherche' => 'Anul-lar la cerca',
+	'annuler_recherche' => 'Anul·lar la cerca',
 	'auteur' => 'Autor:',
 	'avis_acces_interdit' => 'Accès prohibit',
-	'avis_article_modifie' => 'Atenció, @nom_auteur_modif@ ha treballat en aquest article fa @date_diff@ minuts',
+	'avis_article_modifie' => 'Atenció, @nom_auteur_modif@ ha treballat a aquest article fa @date_diff@ minuts',
 	'avis_aucun_resultat' => 'Cap resultat',
 	'avis_base_inaccessible' => 'Impossible connectar-se a la base de dades @base@.',
 	'avis_chemin_invalide_1' => 'El camí que heu triat',
@@ -22,6 +24,7 @@ $GLOBALS[$GLOBALS['idx_lang']] = array(
 	'avis_connexion_echec_1' => 'La connexió a la base de dades ha fracassat.',
 	'avis_connexion_echec_2' => 'Tornar a la pàgina precedent per verificar les dades que heu ficat.',
 	'avis_connexion_echec_3' => '<b>N.B.</b> A molts dels servidors, heu de <b>demanar</b> l’activació del vostre accés a la base de dades abans de poder-la utilitzar. Si no podeu connectar-vos, verifiqueu que heu efectuat aquest pas.',
+	'avis_connexion_erreur_creer_base' => 'La base de dades no s’ha pogut crear.',
 	'avis_connexion_erreur_nom_base' => 'El nom de la base només pot contenir lletres, xifres i guions',
 	'avis_connexion_ldap_echec_1' => ' La connexió amb el servidor LDAP ha caigut.',
 	'avis_connexion_ldap_echec_2' => 'Tornar a la pàgina precedent per verificar les dades que heu ficat.',
@@ -42,6 +45,8 @@ desactivada per raons de seguretat (cosa normal en molts proveïdors d’hostatg
 	'bouton_acces_ldap' => 'Afegir l’accés a LDAP',
 	'bouton_ajouter' => 'Afegir',
 	'bouton_annuler' => 'Anul·lar',
+	'bouton_cache_activer' => 'Reactivar la memòria cau',
+	'bouton_cache_desactiver' => 'Desactivar temporalment la memòria cau',
 	'bouton_demande_publication' => 'Demanar la publicació d’aquest article',
 	'bouton_desactive_tout' => 'Desactivar-ho tot',
 	'bouton_desinstaller' => 'desinstal·lar ',
@@ -131,7 +136,9 @@ desactivada per raons de seguretat (cosa normal en molts proveïdors d’hostatg
 	'entree_url' => 'L’adreça (URL) del vostre lloc',
 	'entree_url_2' => 'Adreça (URL) del lloc',
 	'erreur_connect_deja_existant' => 'Ja existeix un servidor amb aquest nom',
+	'erreur_email_deja_existant' => 'Aquesta adreça email està ja registrada.',
 	'erreur_nom_connect_incorrect' => 'Aquest nom de servidor no està autoritzat',
+	'erreur_plugin_attribut_balise_manquant' => 'Atribut @attribut@ que manca a l’etiqueta @balise@.',
 	'erreur_plugin_desinstalation_echouee' => 'La desinstal·lació del connector ha fracassat. No obstant el podeu desactivar. ',
 	'erreur_plugin_fichier_absent' => 'Fitxer absent',
 	'erreur_plugin_fichier_def_absent' => 'Fitxer de definició absent',
@@ -171,6 +178,7 @@ desactivada per raons de seguretat (cosa normal en molts proveïdors d’hostatg
 	'icone_creer_auteur' => 'Crear un nou autor i associar-lo a aquest article',
 	'icone_creer_mot_cle' => 'Crear una nova paraula clau i lligar-la a aquest article',
 	'icone_creer_rubrique_2' => 'Crear una nova secció',
+	'icone_developpement' => 'Desenvolupament',
 	'icone_edition' => 'Edició',
 	'icone_ma_langue' => 'La meva llengua',
 	'icone_mes_infos' => 'Les meves informacions',
@@ -195,10 +203,8 @@ desactivada per raons de seguretat (cosa normal en molts proveïdors d’hostatg
 	'info_1_rubrique' => '1 secció',
 	'info_1_visiteur' => '1 visitant',
 	'info_activer_cookie' => 'Podeu activar una <b>galeta de correspondència</b>, us permetrà passar fàcilment del lloc públic al lloc privat.',
+	'info_activer_menu_developpement' => 'Afegir el menú Desenvolupament',
 	'info_admin_etre_webmestre' => 'Donar-me els drets d’administrador',
-	'info_admin_gere_rubriques' => 'Aquest administrador gestiona les següents seccions:',
-	'info_admin_gere_toutes_rubriques' => 'Aquest administrador gestiona <b>totes les seccions</b>',
-	'info_admin_gere_toutes_rubriques_2' => 'Gestiono <b>totes les seccions</b>',
 	'info_admin_je_suis_webmestre' => 'Sóc <b>administrador</b>',
 	'info_admin_statuer_webmestre' => 'Donar a aquest administrador els drets de webmestre',
 	'info_admin_webmestre' => 'Aquest administrador és <b>webmestre</b>',
@@ -210,6 +216,7 @@ desactivada per raons de seguretat (cosa normal en molts proveïdors d’hostatg
 	'info_administrateurs' => 'Administradors',
 	'info_administrer_rubrique' => 'Podeu administrar aquesta secció',
 	'info_adresse' => 'a l’adreça:',
+	'info_adresse_desinscription' => 'Adreça de desinscripció:',
 	'info_adresse_url' => 'Adreça (URL) del lloc públic',
 	'info_afficher_par_nb' => 'Mostrar per',
 	'info_aide_en_ligne' => 'Ajuda en línia d’SPIP',
@@ -231,6 +238,8 @@ desactivada per raons de seguretat (cosa normal en molts proveïdors d’hostatg
 	'info_aucun_message' => 'Cap missatge',
 	'info_aucun_rubrique' => 'Cap secció',
 	'info_aujourdhui' => 'avui:',
+	'info_auteur_gere_toutes_rubriques' => 'Aquest autor gestiona <b>totes les seccions</b>',
+	'info_auteur_gere_toutes_rubriques_2' => 'Gestiono <b>totes les seccions</b>', # MODIF
 	'info_auteurs' => 'Els autors',
 	'info_auteurs_par_tri' => 'Autors@partri@',
 	'info_auteurs_trouves' => 'Autors trobats',
@@ -239,6 +248,7 @@ desactivada per raons de seguretat (cosa normal en molts proveïdors d’hostatg
 	'info_barre_outils' => 'amb la seva barra d’eines?',
 	'info_base_installee' => 'L’estructura de la vostra bases de dades s’ha instal·lat.',
 	'info_bio' => 'Biografia',
+	'info_cache_desactive' => 'La memòria cau està temporalment desactivada.',
 	'info_chapeau' => 'Encapçalament',
 	'info_chapeau_2' => 'Encapçalament:',
 	'info_chemin_acces_1' => 'Opcions: <b>Camí d’accés al directori</b>',
@@ -294,7 +304,7 @@ desactivada per raons de seguretat (cosa normal en molts proveïdors d’hostatg
 	'info_gauche_auteurs' => 'Aquí hi trobareu tots els autors del lloc.
  El seu estat s’indica pel color de la seva icona (administrador = verd; redactor = groc).',
 	'info_gauche_auteurs_exterieurs' => 'Els autors externs, sense accés al lloc web, estan indicats amb una icona blava;
- els autors esborrats amb una paperera.', # RELIRE
+ els autors esborrats amb una icona grissa.',
 	'info_gauche_messagerie' => 'La missatgeria us permet intercanviar missatges entre els redactors, conservar recordatoris (pel vostre ús personal) o mostrar avisos a la pàgina inicial de l’espai privat (si sóu administrador).',
 	'info_gauche_statistiques_referers' => 'Aquesta pàgina mostra la llista de  <i>referidors</i>, és a dir, dels llocs que contenen enllaços cap al vostre propi lloc Web, únicament per ahir i avui; aquesta llista es posa a zero cada 24 hores. ',
 	'info_gauche_visiteurs_enregistres' => 'Aquí hi trobareu els visitants registrats
@@ -308,6 +318,7 @@ desactivada per raons de seguretat (cosa normal en molts proveïdors d’hostatg
 	'info_image_process2' => '<b>N.B.</b> <i>Si no apareix cap imatge, aleshores és que el servidor que allotja el vostre lloc web no ha estat configurat per utilitzar aquestes eines. Si desitgeu emprar aquestes funcions, poseu-vos en contacte amb el responsable tècnic i demaneu les extensions «GD» o «Imagick».</i>',
 	'info_images_auto' => 'Imatges calculades automàticament',
 	'info_informations_personnelles' => 'Informacions personals',
+	'info_inscription' => 'Inscripció le',
 	'info_inscription_automatique' => 'Inscripció automàtica dels nous redactors',
 	'info_jeu_caractere' => 'Joc de caràcters del lloc',
 	'info_jours' => 'dies',
@@ -347,6 +358,7 @@ desactivada per raons de seguretat (cosa normal en molts proveïdors d’hostatg
 	'info_nb_visiteurs' => '@nb@ visitants',
 	'info_nom' => 'Nom',
 	'info_nom_destinataire' => 'Nom del destinatari',
+	'info_nom_pas_conforme' => 'les etiquetes html no estàn permeses',
 	'info_nom_site' => 'Nom del vostre lloc',
 	'info_nombre_articles' => '@nb_articles@ articles,',
 	'info_nombre_rubriques' => '@nb_rubriques@ seccions,',
@@ -381,7 +393,7 @@ desactivada per raons de seguretat (cosa normal en molts proveïdors d’hostatg
 	'info_post_scriptum' => 'Postdata',
 	'info_post_scriptum_2' => 'Postdata:',
 	'info_pour' => 'per',
-	'info_preview_texte' => 'És possible previsualitzar el lloc com si tots els articles i breus (que almenys tinguen l’estat de "proposats") estigueren publicats. Aquesta possibilitat ha d’estar oberta només als administradors, a tots els redactors, o a ningú?',
+	'info_preview_texte' => 'És possible previsualitzar el lloc com si tots els articles i breus (que almenys tinguen l’estat de "proposats") estigueren publicats. Aquesta possibilitat ha d’estar oberta només als administradors, a tots els redactors, o a ningú?', # MODIF
 	'info_procedez_par_etape' => 'procediu pas per pas',
 	'info_procedure_maj_version' => 'El procés d’actualització s’ha de tornar a arrancar per tal d’adaptar la base de dades a la nova versió d’SPIP.',
 	'info_proxy_ok' => 'Test del proxy amb èxit.',
@@ -392,7 +404,7 @@ desactivada per raons de seguretat (cosa normal en molts proveïdors d’hostatg
 	'info_question_inscription_nouveaux_redacteurs' => 'Accepteu les inscripcions de nous redactors a partir del lloc web públic? Si ho accepteu, els visitants es podran inscriure
  mitjançant un formulari  automatitzat i llavors accediran a l’espai privat per proposar els seus propis articles.<blockquote><i>Durant el procés d’inscripció, els usuaris reben un correu electrònic automàtic en el que se’ls dóna els seus codis d’accés a la web privada. Alguns proveïdors d’hostatge desactiven l’enviament de correus electrònics des dels seus servidors: en aquest
  cas, la inscripció automàtica és impossible.</i></blockquote>',
-	'info_qui_edite' => '@nom_auteur_modif@ ha treballat en aquest contingut fa @date_diff@ minuts', # MODIF
+	'info_qui_edite' => '@nom_auteur_modif@ ha treballat en aquest contingut fa @date_diff@ minuts',
 	'info_racine_site' => 'Arrel del lloc',
 	'info_recharger_page' => 'Actualitzeu aquesta pàgina en breus instants.',
 	'info_recherche_auteur_zero' => 'Cap resultat per « @cherche_auteur@ ».',
@@ -403,6 +415,7 @@ desactivada per raons de seguretat (cosa normal en molts proveïdors d’hostatg
 	'info_redaction_en_cours' => 'En procés de redacció',
 	'info_redirection' => 'Redireccionament',
 	'info_redirection_activee' => 'La redirecció està activada.',
+	'info_redirection_boucle' => 'Tracta de redirigir l’article sobre ell mateix.',
 	'info_redirection_desactivee' => 'S’ha suprimit la redirecció.',
 	'info_refuses' => 'Els vostres articles rebutjats',
 	'info_reglage_ldap' => 'Opcions: <b>Posta a punt de la importació LDAP</b>',
@@ -469,6 +482,7 @@ amb un color que indica el seu estat:',
 	'info_une_rubrique_02' => '1 secció',
 	'info_url' => 'URL:',
 	'info_url_proxy' => 'URL del proxy',
+	'info_url_site_pas_conforme' => 'l’URL del lloc web no és vàlida',
 	'info_url_test_proxy' => 'URL de test',
 	'info_urlref' => 'Enllaç hipertext:',
 	'info_utilisation_spip' => 'Podeu començar a utilitzar el sistema de publicació assistida...',
@@ -497,8 +511,8 @@ amb un color que indica el seu estat:',
 	'install_serveur_hebergeur' => 'Servidor de base de dades atribuït per l’hostatjador',
 	'install_table_prefix_hebergeur' => 'Prefix de taula donat per l’hostatjador:',
 	'install_tables_base' => 'Taules de la base',
-	'install_types_db_connus' => 'SPIP sap utilitzar <b>MySQL</b> (el més difós), <b>PostgreSQL</b> i <b>SQLite</b>.', # RELIRE
-	'install_types_db_connus_avertissement' => 'Alerta: Diversos plugins només funcionen amb MySQL', # RELIRE
+	'install_types_db_connus' => 'SPIP sap utilitzar <b>MySQL</b> (el més difós) i <b>SQLite</b>.',
+	'install_types_db_connus_avertissement' => 'El suport de <b>PostgreSQL</b> és proposat igualment a títol experimental',
 	'instituer_erreur_statut_a_change' => 'L’estat ja s’ha modificat',
 	'instituer_erreur_statut_non_autorise' => 'No podeu escollir aquest estat',
 	'intem_redacteur' => 'redactor',
@@ -546,7 +560,7 @@ amb un color que indica el seu estat:',
 	'label_choix_langue' => 'Seleccioneu la vostra llengua',
 	'label_nom_fichier_connect' => 'Indiqueu el nom utilitzat per aquest servidor',
 	'label_slogan_site' => 'Eslògan del lloc',
-	'label_taille_ecran' => 'Amplada de la pantalla',
+	'label_taille_ecran' => 'Amplada de la pantalla', # MODIF
 	'label_texte_et_icones_navigation' => 'Menú de navegació',
 	'label_texte_et_icones_page' => 'Visualització a la pàgina',
 	'ldap_correspondance' => 'herència del camp @champ@',
@@ -561,6 +575,7 @@ amb un color que indica el seu estat:',
 	'lien_retirer_tous_auteurs' => 'Retirar tots els autors',
 	'lien_retirer_toutes_rubriques' => 'elimina totes les seccions',
 	'lien_site' => 'lloc',
+	'lien_tout_decocher' => 'Desmarcar tot',
 	'lien_tout_deplier' => 'Obrir-ho tot',
 	'lien_tout_replier' => 'Tancar-ho tot',
 	'lien_tout_supprimer' => 'Suprimir-ho tot',
@@ -585,7 +600,7 @@ amb un color que indica el seu estat:',
 	'mois_non_connu' => 'desconegut',
 
 	// N
-	'nouvelle_version_spip' => 'Està disponible la versió @version@ d’SPIP',
+	'nouvelle_version_spip' => 'Està disponible la versió @version@ d’SPIP', # MODIF
 
 	// O
 	'onglet_contenu' => 'Contingut',
@@ -631,15 +646,18 @@ amb un color que indica el seu estat:',
 	'plugin_info_plugins_dist_1' => 'Les extensions que hi ha a sota es carreguen i s’activen al directori @plugins_dist@.',
 	'plugin_info_plugins_dist_2' => 'No es poden desactivar.',
 	'plugin_info_telecharger' => 'baixar-lo des de @url@ i instal·lar-lo a @rep@',
+	'plugin_info_upgrade_ok' => 'L’actualització ha estat exitosa',
 	'plugin_librairies_installees' => 'Llibreries instal·lades',
 	'plugin_necessite_lib' => 'Aquest plugin necessita la llibreria @lib@',
 	'plugin_necessite_plugin' => 'Requereix el plugin @plugin@ com a mínim en la versió @version@.',
+	'plugin_necessite_plugin_sans_version' => 'Requereix el plugin @plugin@',
 	'plugin_necessite_spip' => 'Requereix com a mínim la versió @version@ d’SPIP.',
 	'plugin_source' => 'font: ',
 	'plugin_titre_automatique' => 'Instal·lació automàtica',
 	'plugin_titre_automatique_ajouter' => 'Afegir plugins',
 	'plugin_titre_installation' => 'Instal·lació del connector @plugin@',
 	'plugin_titre_modifier' => 'els meus plugins',
+	'plugin_utilise_plugin' => 'Utilitza el plugin @plugin@ a la versió @version@.',
 	'plugin_zip_active' => 'Continueu per activar-lo',
 	'plugin_zip_adresse' => 'indiqueu més avall l’adreça d’un fitxer zip de plugin a baixar, o fins i tot l’adreça d’una llista de plugins.',
 	'plugin_zip_adresse_champ' => 'Adreça del plugin o de la llista ',
@@ -657,7 +675,7 @@ amb un color que indica el seu estat:',
 	'plugins_disponibles' => '@count@ plugins disponibles.',
 	'plugins_erreur' => 'Error en els plugins: @plugins@',
 	'plugins_liste' => 'Llista dels connectors',
-	'plugins_liste_dist' => 'Extensions', # RELIRE
+	'plugins_liste_dist' => 'Extensions bloquejades',
 	'plugins_recents' => 'Connectors recents.',
 	'plugins_tous_liste' => 'Tots',
 	'plugins_vue_hierarchie' => 'Jerarquia',
@@ -666,6 +684,7 @@ amb un color que indica el seu estat:',
 
 	// Q
 	'queue_executer_maintenant' => 'Executar ara',
+	'queue_info_purger' => 'Vous pouvez supprimer tous les travaux en attente et ré-inialiser la liste avec les travaux périodiques', # MODIF
 	'queue_nb_jobs_in_queue' => '@nb@ treballs en espera',
 	'queue_next_job_in_nb_sec' => 'Proper treball en @nb@ s',
 	'queue_no_job_in_queue' => 'Cap treball en espera',
@@ -680,6 +699,7 @@ amb un color que indica el seu estat:',
 	// S
 	'sans_heure' => 'sense hora',
 	'statut_admin_restreint' => '(admin restringida)',
+	'statut_webmestre' => 'webmestre',
 
 	// T
 	'tache_cron_asap' => 'Tasca CRON @function@ (ASAP)',
@@ -687,7 +707,8 @@ amb un color que indica el seu estat:',
 	'taille_cache_image' => 'Les imatges calculades automàticament per SPIP (miniatures dels documents, títols presentats en forma gràfica, función matemàtiques en format TeX...) ocupen en el directori @dir@ un total de @taille@.',
 	'taille_cache_infinie' => 'Aquest lloc Web no preveu limitar la mida del directori de la memòria cau (cache).',
 	'taille_cache_maxi' => 'SPIP prova de limitar la mida del directori de la memòria cau (cache) d’aquest lloc a aproximadament <b>@octets@</b> de dades.',
-	'taille_cache_octets' => 'La mida de la memòria cau és actualment de @octets@.', # RELIRE
+	'taille_cache_moins_de' => 'La mida de la memòria cau és de menys de @octets@.',
+	'taille_cache_octets' => 'La mida de la memòria cau és actualment de @octets@.',
 	'taille_cache_vide' => 'La memòria cau està buida.',
 	'taille_repertoire_cache' => 'Mida del directori de la memòria cau',
 	'text_article_propose_publication' => 'Article proposat per ser publicat.',
