@@ -3,7 +3,9 @@
 // extrait automatiquement de http://trad.spip.net/tradlang_module/ecrire_?lang_cible=cpf
 // ** ne pas modifier le fichier **
 
-if (!defined('_ECRIRE_INC_VERSION')) return;
+if (!defined('_ECRIRE_INC_VERSION')) {
+	return;
+}
 
 $GLOBALS[$GLOBALS['idx_lang']] = array(
 
@@ -138,8 +140,6 @@ Bann zinformasyon-la, sé komandèr-sistèm ou komandèr-rézo sak i dwa donn a
 	'image_administrer_rubrique' => 'Ou néna drwa d-komandman sir rubrik-la',
 	'info_1_article' => '1 lartik',
 	'info_activer_cookie' => 'I pé fé zwé inn <b>gatomakro drokonésans </b>. Kom sa ou sra kav pas fasilman dopwi lafigirwèb piblik sir lo sit privé.',
-	'info_admin_gere_rubriques' => 'Komandèr-la lé responsab si bann rubrik anba :',
-	'info_admin_gere_toutes_rubriques' => 'Komandèr-la lé responsab pou <b>TOUT bann rubrik</b>.', # MODIF
 	'info_administrateur' => 'Komandèr',
 	'info_administrateur_1' => 'Komandèr',
 	'info_administrateur_2' => 'lo sitwèb(<i>anserv èk prékosyon</i>)',
@@ -165,6 +165,7 @@ inn liv-zimaz (sédir inn galri).',
 	'info_articles_trouves' => 'Bann zartik la finn dèt trouvé',
 	'info_attente_validation' => 'Out bann zartik sak i espèr lakonfirmasyon',
 	'info_aujourdhui' => 'Zordi :',
+	'info_auteur_gere_toutes_rubriques_2' => 'Je gère <b>toutes les rubriques</b>', # MODIF
 	'info_auteurs' => 'Bann lotèr',
 	'info_auteurs_par_tri' => 'Bann lotèr@partri@',
 	'info_auteurs_trouves' => 'Bann lotèr la finn dèt trouvé',
@@ -293,7 +294,7 @@ la finn dèt publyé).',
 	'info_post_scriptum' => 'Koz-Déryèr',
 	'info_post_scriptum_2' => 'Koz-déryèr :',
 	'info_pour' => 'pou',
-	'info_preview_texte' => 'Lé posib vwar lo sit avan komsi tout bann zartik èk bann tit-nouvèl (sat néna omwin lo statu « pou pibliyé ») zot sré astèr an liny. Ou pé swazi si lé sèlman po komandèr, po rédaktèr ou si lé pa posib ni po lin ni po lot. ',
+	'info_preview_texte' => 'Lé posib vwar lo sit avan komsi tout bann zartik èk bann tit-nouvèl (sat néna omwin lo statu « pou pibliyé ») zot sré astèr an liny. Ou pé swazi si lé sèlman po komandèr, po rédaktèr ou si lé pa posib ni po lin ni po lot. ', # MODIF
 	'info_procedez_par_etape' => 'azi étap sanm étap',
 	'info_procedure_maj_version' => 'Lé nésésèr fé zwé arnouvèlman la bazdodné pou giny roul ron la nouvèl
 versyon SPIP.',
