@@ -3,7 +3,9 @@
 // extrait automatiquement de http://trad.spip.net/tradlang_module/ecrire_?lang_cible=cs
 // ** ne pas modifier le fichier **
 
-if (!defined('_ECRIRE_INC_VERSION')) return;
+if (!defined('_ECRIRE_INC_VERSION')) {
+	return;
+}
 
 $GLOBALS[$GLOBALS['idx_lang']] = array(
 
@@ -137,8 +139,6 @@ $GLOBALS[$GLOBALS['idx_lang']] = array(
 	'info_1_article' => '1 článek',
 	'info_activer_cookie' => 'Můžete nastavit <b>administrátorské cookie</b>, které vám dovolí
  snadno přecházet mezi prohlížením webu a jeho editací.',
-	'info_admin_gere_rubriques' => 'Tento správce ospovídá za následující sekce:',
-	'info_admin_gere_toutes_rubriques' => 'Tento správce odpovídá ua <b>všechny sekce</b>.', # MODIF
 	'info_administrateur' => 'Správce',
 	'info_administrateur_1' => 'Správce',
 	'info_administrateur_2' => 'webu (<i>používat opatrně</i>)',
@@ -299,7 +299,7 @@ pro technickou údržbu. Některé z nich spouští autentifikaci, jež vyžaduj
 	'info_post_scriptum' => 'P.S.',
 	'info_post_scriptum_2' => 'P.S.:',
 	'info_pour' => 'pro',
-	'info_preview_texte' => 'Náhled umožňuje zobrazit web tak, jakoby všechny články a novinky (minimálně ve stavu "předloženo") byly zveřejněny. Chcete náhled povolit jen správcům, všem redaktorům nebo jej nechcete povolit nikomu?',
+	'info_preview_texte' => 'Náhled umožňuje zobrazit web tak, jakoby všechny články a novinky (minimálně ve stavu "předloženo") byly zveřejněny. Chcete náhled povolit jen správcům, všem redaktorům nebo jej nechcete povolit nikomu?', # MODIF
 	'info_procedez_par_etape' => 'postupujte krok za krokem',
 	'info_procedure_maj_version' => 'pro úpravu nové verze systému SPIP je třeba spustit aktualizaci
  databáze.',
