@@ -3,7 +3,9 @@
 // extrait automatiquement de http://trad.spip.net/tradlang_module/ecrire_?lang_cible=da
 // ** ne pas modifier le fichier **
 
-if (!defined('_ECRIRE_INC_VERSION')) return;
+if (!defined('_ECRIRE_INC_VERSION')) {
+	return;
+}
 
 $GLOBALS[$GLOBALS['idx_lang']] = array(
 
@@ -21,64 +23,35 @@ $GLOBALS[$GLOBALS['idx_lang']] = array(
 	'avis_connexion_ldap_echec_2' => 'Gå tilbage til sidste side og kontroller de oplysninger, du har indtastet.',
 	'avis_connexion_ldap_echec_3' => 'Alternativt kan du vælge ikke at benytte LDAP til at importere brugere.',
 	'avis_deplacement_rubrique' => 'Advarsel! Dette afsnit indeholder @contient_breves@ nyheder@scb@: Hvis du vil flytte den, så afkryds venligst her for at bekræfte.',
-	'avis_destinataire_obligatoire' => 'Du skal vælge en modtager, før du kan sende meddelelsen.',
 	'avis_erreur_connexion_mysql' => 'Fejl i forbindelse til SQL',
-	'avis_erreur_version_archive' => ' <b>Advarsel! Filen @archive@ hører til 
-    en anden version af SPIP end den du har
-    installeret.</b> Du risikerer store
-    vanskeligheder: risiko for at ødelægge din database, 
-    forskellige funktionsfejl på webstedet, osv. 
-    Fortsæt ikke indlæsningen.<p>For mere
-    information henvises til <a href="@spipnet@">,
-                                SPIP-dokumentationen</A>.', # MODIF
 	'avis_espace_interdit' => '<b>Forbudt område</b><p>SPIP er allerede installeret.',
 	'avis_lecture_noms_bases_1' => 'Installationsprogrammet kunne ikke læse navnene på de installerede databaser.',
 	'avis_lecture_noms_bases_2' => 'Enten er databasen ikke tilgængelig, eller også er funktionen, som giver oversigt
 		over databaser, sat ud af kraft af sikkerhedsårsager (hvilket er tilfældet på mange servere).',
 	'avis_lecture_noms_bases_3' => 'Hvis det sidstnævnte er tilfældet, er det muligt at en database, som er navngivet efter dit login, kan anvendes:',
-	'avis_non_acces_message' => 'Du har ikke adgang til denne meddelelse.',
 	'avis_non_acces_page' => 'Du har ikke adgang til denne side.',
 	'avis_operation_echec' => 'Opgaven mislykkedes.',
-	'avis_probleme_archive' => 'Læsefejl i filen @archive@',
 	'avis_suppression_base' => 'ADVARSEL, sletning kan ikke omgøres',
-	'avis_version_mysql' => 'Din version af SQL (@version_mysql@) tillader ikke automatisk reparation af tabeller.',
 
 	// B
 	'bouton_acces_ldap' => 'Tilføj adgang til LDAP >>',
 	'bouton_ajouter' => 'Tilføj',
-	'bouton_ajouter_participant' => 'TILFØJ DELTAGER:',
-	'bouton_annonce' => 'ANNONCERING',
-	'bouton_checkbox_envoi_message' => 'mulighed for at sende en meddelelse',
-	'bouton_checkbox_indiquer_site' => 'obligatorisk angivelse af websted ',
-	'bouton_checkbox_signature_unique_email' => 'kun en signatur pr. e-mail-adresse',
-	'bouton_checkbox_signature_unique_site' => 'kun en signatur pr. websted',
 	'bouton_demande_publication' => 'Anmod om at få offentliggjort denne artikel',
-	'bouton_effacer_index' => 'Slet indeksering',
 	'bouton_effacer_tout' => 'Slet alt',
-	'bouton_envoi_message_02' => 'SEND MEDDELELSE',
 	'bouton_envoyer_message' => 'Send færdig meddelelse',
 	'bouton_modifier' => 'Ret',
-	'bouton_pense_bete' => 'PERSONLIGT MEMO',
-	'bouton_radio_activer_messagerie' => 'Tillad interne meddelelser',
-	'bouton_radio_activer_messagerie_interne' => 'Tillad interne meddelelser',
-	'bouton_radio_activer_petition' => 'Tillad appeller',
 	'bouton_radio_afficher' => 'Vis',
 	'bouton_radio_apparaitre_liste_redacteurs_connectes' => 'Medtag i listen over tilknyttede redaktører',
-	'bouton_radio_desactiver_messagerie' => 'Slå meddelelsesfunktion fra',
 	'bouton_radio_envoi_annonces_adresse' => 'Send nyheder til adressen:',
 	'bouton_radio_envoi_liste_nouveautes' => 'Send seneste nyhedsliste',
 	'bouton_radio_non_apparaitre_liste_redacteurs_connectes' => 'Medtag ikke i listen over tilknyttede redaktører',
 	'bouton_radio_non_envoi_annonces_editoriales' => 'Send ingen redaktionelle nyheder',
-	'bouton_radio_pas_petition' => 'Ingen appeller',
-	'bouton_radio_petition_activee' => 'Appelfunktion slået til',
-	'bouton_radio_supprimer_petition' => 'Slet appellen',
 	'bouton_redirection' => 'VIDERESTIL',
 	'bouton_relancer_installation' => 'Gentag installationen',
 	'bouton_suivant' => 'Næste',
 	'bouton_tenter_recuperation' => 'Reparationsforsøg',
 	'bouton_test_proxy' => 'Test proxy',
 	'bouton_vider_cache' => 'Tøm cache',
-	'bouton_voir_message' => 'Vis indlæg før godkendelse',
 
 	// C
 	'calendrier_synchro' => 'Hvis du benytter en kalenderapplikation, der er kompatibel med <b>iCal</b>, kan du synkronisere med information på dette websted.',
@@ -105,7 +78,6 @@ $GLOBALS[$GLOBALS['idx_lang']] = array(
 	'entree_login' => 'Dit login',
 	'entree_login_connexion_1' => 'Tilkoblingslogin',
 	'entree_login_connexion_2' => '(Undertiden identisk med dit FTP-login, andre gange blank)',
-	'entree_login_ldap' => 'LDAP basis-login',
 	'entree_mot_passe' => 'Din adgangskode',
 	'entree_mot_passe_1' => 'Tilkoblingsadgangskode',
 	'entree_mot_passe_2' => '(Undertiden identisk med dit FTP-login, andre gange blank)',
@@ -125,7 +97,7 @@ $GLOBALS[$GLOBALS['idx_lang']] = array(
 	'ical_info2' => 'For mere information, besøg <a href="@spipnet@">SPIP dokumentation</a>.', # MODIF
 	'ical_info_calendrier' => 'To kalendere står til rådighed. Den første er en oversigt over webstedet, der viser alle offentliggjorte artikler.Den anden indeholder både redaktionelle annonceringer og dine seneste private meddelelser. Den er forbeholdt dig i kraft af en personlig nøgle, som du kan ændre når som helst ved at forny din adgangskode.',
 	'ical_methode_http' => 'Filhentning',
-	'ical_methode_webcal' => 'Synkronisering (webcal://)',
+	'ical_methode_webcal' => 'Synkronisering (webcal://)', # MODIF
 	'ical_texte_js' => 'Med en linies javascript kan du nemt vise de senest offentliggjorte artikler på et websted, der tilhører dig.',
 	'ical_texte_prive' => 'Denne strengt personlige kalender holder dig underrettet om private redaktionelle aktiviteter på webstedet (opgaver, personlige aftaler, indsendte artikler, nyheder ...).',
 	'ical_texte_public' => 'Med denne kalender kan du følge de offentlige aktiviteter på webstedet (offentliggjorte artikler og nyheder).',
@@ -141,9 +113,7 @@ $GLOBALS[$GLOBALS['idx_lang']] = array(
 	'icone_creer_auteur' => 'Opret ny forfatter og tilknyt til denne artikel',
 	'icone_creer_mot_cle' => 'Opret nyt nøgleord og tilknyt til denne artikel',
 	'icone_creer_rubrique_2' => 'Opret nyt afsnit',
-	'icone_envoyer_message' => 'Send denne meddelelse',
 	'icone_modifier_article' => 'Ret denne artikel',
-	'icone_modifier_message' => 'Ret denne meddelelse',
 	'icone_modifier_rubrique' => 'Ret dette afsnit',
 	'icone_retour' => 'Tilbage',
 	'icone_retour_article' => 'Tilbage til artikel',
@@ -153,10 +123,7 @@ $GLOBALS[$GLOBALS['idx_lang']] = array(
 	'icone_valider_signature' => 'Godkend signatur',
 	'image_administrer_rubrique' => 'Du kan administrere dette afsnit',
 	'info_1_article' => '1 artikel',
-	'info_1_site' => '1 websted',
 	'info_activer_cookie' => 'Du kan installere en <b>administrationscookie</b>, som tillader dig at skifte nemt mellem det offentlige websted og dit private afsnit.',
-	'info_admin_gere_rubriques' => 'Denne administrator administrerer følgende afsnit:',
-	'info_admin_gere_toutes_rubriques' => 'Denne administrator administrerer <b>alle afsnit</b>.', # MODIF
 	'info_administrateur' => 'Administrator',
 	'info_administrateur_1' => 'Administrator',
 	'info_administrateur_2' => 'af webstedet (<i>anvend med forsigtighed</i>)',
@@ -166,16 +133,13 @@ $GLOBALS[$GLOBALS['idx_lang']] = array(
 	'info_administrer_rubrique' => 'Du kan administrere dette afsnit',
 	'info_adresse' => 'til adressen:',
 	'info_adresse_url' => 'Dit offentlige websteds URL',
-	'info_afficher_visites' => 'Vis besøg for:',
 	'info_aide_en_ligne' => 'SPIP online hjælp',
 	'info_ajout_image' => 'Når du vedhæfter billeder til en artikel, kan
 		SPIP automatisk lave miniatureudgaver af billederne.
 		Dette muliggør f.eks. automatisk oprettelse af et
 		galleri eller et album.',
-	'info_ajout_participant' => 'Følgende deltager er tilføjet:',
 	'info_ajouter_rubrique' => 'Tilføj endnu et afsnit at administrere:',
 	'info_annonce_nouveautes' => 'Seneste annonceringer',
-	'info_anterieur' => 'forrige',
 	'info_article' => 'artikel',
 	'info_article_2' => 'artikler',
 	'info_article_a_paraitre' => 'Fremdaterede artikler der skal offentliggøres',
@@ -183,10 +147,8 @@ $GLOBALS[$GLOBALS['idx_lang']] = array(
 	'info_articles_2' => 'Artikler',
 	'info_articles_auteur' => 'Denne forfatters artikler',
 	'info_articles_trouves' => 'Fundne artikler',
-	'info_articles_trouves_dans_texte' => 'Artikler fundet (i teksten)',
 	'info_attente_validation' => 'Dine artikler som afventer godkendelse',
 	'info_aujourdhui' => 'i dag:',
-	'info_auteur_message' => 'MEDDELELSESAFSENDER:',
 	'info_auteurs' => 'Forfattere',
 	'info_auteurs_par_tri' => 'Forfattere@partri@',
 	'info_auteurs_trouves' => 'Forfattere fundet',
@@ -219,15 +181,12 @@ $GLOBALS[$GLOBALS['idx_lang']] = array(
 	'info_date_publication_anterieure' => 'Dato for tidligere offentliggørelse:',
 	'info_date_referencement' => 'DATO FOR HENVISNING TIL DETTE WEBSTED:',
 	'info_derniere_etape' => 'Sidste skridt: <b>Det er overstået!',
-	'info_derniers_articles_publies' => 'Dine senest offentliggjorte artikler',
-	'info_desactiver_messagerie_personnelle' => 'Du kan åbne eller lukke for personlige meddelelser på dette websted.',
 	'info_descriptif' => 'Beskrivelse:',
 	'info_discussion_cours' => 'Igangværende diskussioner',
 	'info_ecrire_article' => 'Før du kan lave artikler, skal du oprette mindst et afsnit.',
 	'info_email_envoi' => 'Afsenderens e-mail adresse (valgfri)',
 	'info_email_envoi_txt' => 'Indtast afsenderens e-mail adresse ved afsendelse af e-mails (som standard bruges modtagerens adresse som afsenderadresse) :',
 	'info_email_webmestre' => 'E-mail-adresse på webmaster (valgfrit)', # MODIF
-	'info_entrer_code_alphabet' => 'Indtast koden for det tegnsæt, der skal benyttes:',
 	'info_envoi_email_automatique' => 'Automatisk e-mail-forsendelse',
 	'info_envoyer_maintenant' => 'Send nu',
 	'info_etape_suivante' => 'Gå til næste trin',
@@ -236,18 +195,15 @@ $GLOBALS[$GLOBALS['idx_lang']] = array(
 	'info_exportation_base' => 'eksporter database til @archive@',
 	'info_facilite_suivi_activite' => 'For at lette opfølgning på webstedets redaktionelle aktiviteter sender SPIP e-mails med anmodning om offentliggørelse og godkendelse til f.eks. redaktørens adresseliste.',
 	'info_fichiers_authent' => 'Adgangskontrolfil ".htpasswd"',
-	'info_gauche_admin_effacer' => '<b>Kun administratorer har adgang til denne side.</b><p> Den giver adgang til forskellige tekniske vedligeholdelsesopgaver. Nogle af dem giver anledning til en særlig adgangskontrol, der kræver FTP-adgang til siden.', # MODIF
 	'info_gauche_admin_tech' => '<b>Kun administratorer har adgang til denne side.</b><p> Den giver adgang til forskellige tekniske vedligeholdelsesopgaver. Nogle af dem giver anledning til en særlig adgangskontrol, der kræver FTP-adgang til siden.', # MODIF
 	'info_gauche_admin_vider' => '<b>Kun administratorer har adgang til denne side.</b><p> Den giver adgang til forskellige tekniske vedligeholdelsesopgaver. Nogle af dem giver anledning til en særlig adgangskontrol, der kræver FTP-adgang til siden.', # MODIF
 	'info_gauche_auteurs' => 'Her finder du alle webstedets forfattere. Status på hver enkelt fremgår af farven på ikonet (redaktør = grøn, administrator = gul).',
 	'info_gauche_auteurs_exterieurs' => 'Udenforstående forfattere uden adgang til webstedet vises med et blåt symbol; slettede forfattere repræsenteres af en papirkurv.', # MODIF
 	'info_gauche_messagerie' => 'Meddelelsessystemet giver mulighed for at udveksle meddelelser mellem redaktører, for at gemme huskesedler (til personlig brug) 
 	eller for at vise annonceringer i det private område (hvis du er administrator).',
-	'info_gauche_numero_auteur' => 'FORFATTER NUMMER:',
 	'info_gauche_statistiques_referers' => 'Denne side viser en oversigt over <i>henvisende sider</i>, dvs. websteder der har linket til dit websted alene i dag. Faktisk nulstilles oversigten med 24 timers mellemrum.',
 	'info_gauche_visiteurs_enregistres' => 'Her finder du de besøgende, der er tilmeldt til webstedets offentlige afsnit (fora med tilmelding).',
 	'info_generation_miniatures_images' => 'Dannelse af piktogrammer',
-	'info_gerer_trad' => 'Danne link til oversættelse?',
 	'info_hebergeur_desactiver_envoi_email' => 'Nogle webhoteller tillader ikke automatisk udsendelse af e-mails. I så fald kan følgende funktioner i SPIP ikke benyttes.',
 	'info_hier' => 'i går:',
 	'info_identification_publique' => 'Din offentlige identitet...',
@@ -265,8 +221,6 @@ $GLOBALS[$GLOBALS['idx_lang']] = array(
 	'info_login_existant' => 'Dette login findes allerede.',
 	'info_login_trop_court' => 'Login for kort.',
 	'info_maximum' => 'maksimum:',
-	'info_message' => 'Meddelelse fra',
-	'info_message_efface' => 'MEDDELELSE SLETTET',
 	'info_message_en_redaction' => 'Dine meddelelser under redaktion',
 	'info_message_technique' => 'Teknisk meddelelse:',
 	'info_messagerie_interne' => 'Interne meddelelser',
@@ -275,21 +229,16 @@ $GLOBALS[$GLOBALS['idx_lang']] = array(
 	'info_modifier_rubrique' => 'Ret afsnit:',
 	'info_modifier_titre' => 'Ret: @titre@',
 	'info_mon_site_spip' => 'Mit SPIP-websted',
-	'info_mot_sans_groupe' => '(Nøgleord uden en gruppe...)',
-	'info_moteur_recherche' => 'Indbygget søgemaskine',
 	'info_moyenne' => 'gennemsnit:',
-	'info_multi_articles' => 'Muliggøre valg af sprog til artiklerne?',
 	'info_multi_cet_article' => 'Denne artikel er på:',
 	'info_multi_langues_choisies' => 'Vælg de sprog der skal være til rådighed for redaktører på webstedet.
   Sprog der allerede er i brug på webstedet (de øverste på listen) kan ikke fravælges.
  ',
-	'info_multi_rubriques' => 'Muliggøre sprogvalg til afsnit?',
 	'info_multi_secteurs' => 'Kun for afsnit placeret i roden ?',
 	'info_nom' => 'Navn',
 	'info_nom_destinataire' => 'Navn på modtager',
 	'info_nom_site' => 'Dit websteds navn',
 	'info_nombre_articles' => '@nb_articles@ artikler,',
-	'info_nombre_partcipants' => 'DELTAGERE I DISKUSSIONEN:',
 	'info_nombre_rubriques' => '@nb_rubriques@ afsnit',
 	'info_nombre_sites' => '@nb_sites@ websteder,',
 	'info_non_deplacer' => 'Flyt ikke...',
@@ -299,28 +248,23 @@ $GLOBALS[$GLOBALS['idx_lang']] = array(
 	'info_non_modifiable' => 'kan ikke ændres',
 	'info_non_suppression_mot_cle' => 'Jeg ønsker ikke at slette dette nøgleord.',
 	'info_notes' => 'Fodnoter',
-	'info_nouveaux_message' => 'Nye meddelelser',
 	'info_nouvel_article' => 'Ny artikel',
 	'info_nouvelle_traduction' => 'Ny oversættelse:',
 	'info_numero_article' => 'ARTIKEL NUMMER:',
 	'info_obligatoire_02' => '[Skal udfyldes]', # MODIF
-	'info_option_faire_suivre' => 'Videresend meddelelser i forummer til artiklernes forfattere',
 	'info_options_avancees' => 'AVANCEREDE INDSTILLINGER',
 	'info_ou' => 'eller...',
 	'info_page_interdite' => 'Forbudt side',
 	'info_par_nombre_article' => '(efter antal artiker)',
 	'info_passe_trop_court' => 'Adgangskode for kort.',
 	'info_passes_identiques' => 'De to adgangskoder er ikke ens.',
-	'info_pense_bete_ancien' => 'Dine gamle huskesedler', # MODIF
 	'info_plus_cinq_car' => 'mere end 5 tegn',
 	'info_plus_cinq_car_2' => '(Mere end 5 tegn)',
 	'info_plus_trois_car' => '(Mere end 3 tegn)',
 	'info_popularite' => 'popularitet: @popularite@; besøg: @visites@',
-	'info_popularite_4' => 'polularitet: @popularite@; besøg: @visites@',
 	'info_post_scriptum' => 'Efterskrift',
 	'info_post_scriptum_2' => 'Efterskrift:',
 	'info_pour' => 'til',
-	'info_principaux_correspondants' => 'Dine hovedbidragydere',
 	'info_procedez_par_etape' => 'gå frem skridt for skridt',
 	'info_procedure_maj_version' => 'opgraderingsprocdeduren bør følges for at tilpasse databasen til den nye version af SPIP.',
 	'info_ps' => 'P.S.',
@@ -331,13 +275,9 @@ $GLOBALS[$GLOBALS['idx_lang']] = array(
 		<blockquote><i>Under tilmeldingen modtager brugerne en automatisk dannet e-mail med deres adgangskode til det
 		private websted. Nogle webhoteller tillader ikke at der sendes e-mails fra deres servere. I så fald kan automatisk
 		tilmelding ikke finde sted.', # MODIF
-	'info_question_utilisation_moteur_recherche' => 'Ønsker du at anvende den søgefunktion, der findes i SPIP?
-	(At fravælge søgefunktionen gør webstedet hurtigere.)',
 	'info_qui_edite' => '@nom_auteur_modif@ a travaillé sur ce contenu il y a @date_diff@ minutes', # MODIF
 	'info_racine_site' => 'Top',
 	'info_recharger_page' => 'Vær venlig at genindlæse denne side om et øjeblik.',
-	'info_recherche_auteur_a_affiner' => 'For mange resultater fundet til "@cherche_auteur@"; vær venlig at afgrænse søgningen mere.',
-	'info_recherche_auteur_ok' => 'Der er fundet flere redaktører til "@cherche_auteur@":',
 	'info_recherche_auteur_zero' => '<b>Ingen resultater fundet til "@cherche_auteur@".',
 	'info_recommencer' => 'Vær venlig at forsøge igen.',
 	'info_redacteur_1' => 'Redaktør',
@@ -354,7 +294,6 @@ $GLOBALS[$GLOBALS['idx_lang']] = array(
 	'info_rubriques' => 'Afsnit',
 	'info_rubriques_02' => 'afsnit',
 	'info_rubriques_trouvees' => 'Afsnit fundet',
-	'info_rubriques_trouvees_dans_texte' => 'Afsnit fundet (i teksten)',
 	'info_sans_titre' => 'Uden overskrift',
 	'info_selection_chemin_acces' => '<b>Vælg</b> nedenfor stien til kataloget:',
 	'info_signatures' => 'underskrifter',
@@ -367,11 +306,9 @@ $GLOBALS[$GLOBALS['idx_lang']] = array(
 	'info_sites_lies_mot' => 'Links til websteder knyttet til dette nøgleord',
 	'info_sites_proxy' => 'Brug proxy',
 	'info_sites_trouves' => 'Websteder fundet',
-	'info_sites_trouves_dans_texte' => 'Websteder fundet (i teksten)',
 	'info_sous_titre' => 'Underrubrik:',
 	'info_statut_administrateur' => 'Administrator',
 	'info_statut_auteur' => 'Denne forfatters status:', # MODIF
-	'info_statut_efface' => 'Slettet',
 	'info_statut_redacteur' => 'Redaktør',
 	'info_statut_utilisateurs_1' => 'Importerede brugeres standardstatus',
 	'info_statut_utilisateurs_2' => 'Vælg den status som skal tildeles personerne i LDAP kataloget, når de logger ind første gang. Senere kan du ændre værdien for hver forfatter fra sag til sag.',
@@ -389,7 +326,6 @@ $GLOBALS[$GLOBALS['idx_lang']] = array(
 	'info_tous_articles_en_redaction' => 'Alle artikler undervejs',
 	'info_tous_articles_presents' => 'Alle artikler offentliggjort i dette afsnit',
 	'info_tous_les' => 'for hver:',
-	'info_tous_redacteurs' => 'Annonceringer til alle redaktører',
 	'info_tout_site' => 'Hele webstedet',
 	'info_tout_site2' => 'Artiklen er ikke blevet oversat til dette sprog.',
 	'info_tout_site3' => 'Artiklen er blevet oversat til dette sprig, men nogle ændringer er senere blevet tilføjet til referenceartiklen. Oversættelsen skal opdateres.   ',
@@ -404,7 +340,6 @@ i en farve, der angiver deres status:',
 	'info_une_rubrique' => 'et afsnit,',
 	'info_une_rubrique_02' => '1 afsnit',
 	'info_url' => 'URL:',
-	'info_url_site' => 'WEBSTEDETS URL:',
 	'info_urlref' => 'Hyperlink:',
 	'info_utilisation_spip' => 'SPIP er nu klar til brug...',
 	'info_visites_par_mois' => 'Besøg pr. måned:',
@@ -418,15 +353,12 @@ i en farve, der angiver deres status:',
 	'item_activer_messages_avertissement' => 'Tillad advarselsmeddelelser',
 	'item_administrateur_2' => 'administrator',
 	'item_afficher_calendrier' => 'Vis i kalenderen',
-	'item_autoriser_documents_joints' => 'Tillad at vedhæfte dokumenter til artikler',
-	'item_autoriser_documents_joints_rubriques' => 'Tillad dokumenter i afsnit',
 	'item_choix_administrateurs' => 'administratorer',
 	'item_choix_generation_miniature' => 'Dan miniaturepiktogrammer automatisk.',
 	'item_choix_non_generation_miniature' => 'Dan ikke miniaturebilleder.',
 	'item_choix_redacteurs' => 'redaktører',
 	'item_choix_visiteurs' => 'besøgende på den offentlige websted',
 	'item_creer_fichiers_authent' => 'Dan .htpasswd filer',
-	'item_limiter_recherche' => 'Begræns søgning til information på din eget websted',
 	'item_login' => 'Login',
 	'item_mots_cles_association_articles' => 'artiklerne',
 	'item_mots_cles_association_rubriques' => 'afsnittene',
@@ -435,34 +367,24 @@ i en farve, der angiver deres status:',
 	'item_non_accepter_inscriptions' => 'Tillad ikke tilmelding',
 	'item_non_activer_messages_avertissement' => 'Ingen advarselsmeddelelser',
 	'item_non_afficher_calendrier' => 'Vis ikke i kalender',
-	'item_non_autoriser_documents_joints' => 'Tillad ikke vedhæftning af dokumenter til artikler',
-	'item_non_autoriser_documents_joints_rubriques' => 'Tillad ikke dokumenter i afsnit',
 	'item_non_creer_fichiers_authent' => 'Dan ikke disse filer',
-	'item_non_gerer_statistiques' => 'Dan ikke statistik',
-	'item_non_limiter_recherche' => 'Udvid søgning til indholdet i linkede websteder',
 	'item_non_publier_articles' => 'Vent med at offentliggøre artikler til deres publiceringsdato.',
-	'item_non_utiliser_moteur_recherche' => 'Benyt ikke søgefunktion',
 	'item_nouvel_auteur' => 'Ny forfatter',
 	'item_nouvelle_rubrique' => 'Nyt afsnit',
 	'item_oui' => 'Ja',
 	'item_publier_articles' => 'Offentliggør artikler uden hensyn til deres publiceringsdato.',
 	'item_reponse_article' => 'Kommenter artiklen',
-	'item_utiliser_moteur_recherche' => 'Benyt søgefunktion',
 	'item_visiteur' => 'besøgende',
 
 	// J
 	'jour_non_connu_nc' => ' ',
 
 	// L
-	'lien_ajout_destinataire' => 'Tilføj denne modtager',
 	'lien_ajouter_auteur' => 'Tilføj denne forfatter',
-	'lien_ajouter_participant' => 'Tilføj modtager',
 	'lien_email' => 'e-mail',
 	'lien_nom_site' => 'WEBSTEDETS NAVN:',
 	'lien_retirer_auteur' => 'Fjern forfatter',
-	'lien_retrait_particpant' => 'fjern denne modtager',
 	'lien_site' => 'websted',
-	'lien_supprimer_rubrique' => 'slet dette afsnit',
 	'lien_tout_deplier' => 'Udfold alle',
 	'lien_tout_replier' => 'Sammenfold alle',
 	'lien_trier_nom' => 'Sorter efter navn',
@@ -488,6 +410,9 @@ i en farve, der angiver deres status:',
 	// O
 	'onglet_repartition_actuelle' => 'nu',
 
+	// R
+	'required' => '[Skal udfyldes]', # MODIF
+
 	// S
 	'statut_admin_restreint' => '(begrænset admin)', # MODIF
 
@@ -505,14 +430,10 @@ i en farve, der angiver deres status:',
 	'texte_article_virtuel_reference' => '<b>Virtuel artikel:</b> fremstår som en artikel på dit websted, men viderestiller til en anden URL. Slet URL’en for at fjerne viderestillingen.',
 	'texte_aucun_resultat_auteur' => 'Ingen resultater til "@cherche_auteur@".',
 	'texte_auteur_messagerie' => 'Dette websted kan løbende holde øje med, hvilke redaktører der er logget ind. Dette muliggør realtidsudveksling af meddelelser (hvis udveksling af meddelser ovenfor er fravalgt, vedligeholdes oversigten over redaktører, der er online, heller ikke). Du kan vælge ikke at være synlig i oversigten (du er så «usynlig» for andre brugere).',
-	'texte_auteur_messagerie_1' => 'Dette websted tillader udveksling af meddelelser og oprettelse af private diskussionsforummer mellem deltagere på webstedet. Du kan vælge ikke at deltage i udvekslingen.',
 	'texte_auteurs' => 'FORFATTERNE',
 	'texte_choix_base_1' => 'Vælg database:',
 	'texte_choix_base_2' => 'SQL server indeholder et antal databaser.',
 	'texte_choix_base_3' => '<b>Vælg</b> vælg nedenfor den database, som webhotellet har tildelt dig:',
-	'texte_commande_vider_tables_indexation' => 'Brug denne kommando til at tømme de indekstabeller, som benyttes af SPIP’s indbyggede søgefunktion.
-			Derved kan du spare diskplads.',
-	'texte_compresse_ou_non' => '(denne kan være komprimeret eller ikke)',
 	'texte_compte_element' => '@count@ element',
 	'texte_compte_elements' => '@count@ elementer',
 	'texte_connexion_mysql' => 'Slå op i de oplysninger, som dit webhotel har stillet til rådighed: Hvis webhotellet understøtter SQL, bør det indeholde oplysninger om opkobling.', # MODIF
@@ -525,10 +446,8 @@ i en farve, der angiver deres status:',
 	'texte_date_publication_anterieure' => 'DATO FOR TIDLIGERE OFFENTLIGGØRELSE',
 	'texte_date_publication_anterieure_nonaffichee' => 'Skjul dato for tidligere offentliggørelse.',
 	'texte_date_publication_article' => 'DATO FOR ONLINE OFFENTLIGGØRELSE:',
-	'texte_descriptif_petition' => 'Beskrivelse af appellen',
 	'texte_descriptif_rapide' => 'Kort beskrivelse',
 	'texte_effacer_base' => 'Slet SPIP databasen',
-	'texte_effacer_donnees_indexation' => 'Slet indekseringsdata',
 	'texte_en_cours_validation' => 'Følgende artikler og nyheder er foreslået offentliggjort. Tøv ikke med at give din mening til kende via de fora, som er knyttet til artiklerne.', # MODIF
 	'texte_enrichir_mise_a_jour' => 'Du kan forbedre layoutet af teksten ved at benytte «typografiske koder».',
 	'texte_fichier_authent' => '<b>Skal SPIP oprette specielle <tt>.htpasswd</tt>
@@ -541,25 +460,15 @@ i en farve, der angiver deres status:',
 	'texte_introductif_article' => '(Introduktion til artiklen)',
 	'texte_jeu_caractere' => 'Denne indstilling er nyttig, hvis dit websted viser andre alfabeter end det latinske alfabet (dvs. det «vestlige») og dets afledninger. 
  I så fald skal standardindstillingen ændres til et passende tegnsæt. Vi anbefaler dig at prøve med forskellige indstillinger for at finde den bedste løsning. Husk også at tilpasse webstedet tilsvarende (<tt>#CHARSET</tt> parameteren).',
-	'texte_jeu_caractere_2' => 'Denne indstilling har ikke tilbagevirkende kraft.
-	Tekst, der allerede er lagt ind, kan derfor blive vist forkert efter ændring af denne indstilling.
-	Du kan dog altid vende tilbage til den oprindelige indstilling.',
-	'texte_lien_hypertexte' => '(Hvis din meddelelse henviser til en artikel der er offentliggjort på webben, eller til en side der giver flere oplysninger, så indtast her artiklens overskrift og dens URL.)',
 	'texte_login_ldap_1' => '(Efterlad tom for anonym adgang eller indtast en fuldstændig sti, f.eks. «<tt>uid=hansen, ou=brugere, dc=mit-domæne, dc=dk</tt>».)',
 	'texte_login_precaution' => 'Advarsel! Dette er den login, du er koblet på med nu.
 	Brug denne formular med forsigtighed ...',
-	'texte_message_edit' => 'Advarsel: Denne meddelelse kan ændres af alle webstedets administratorer, og den er synlig for alle redaktører. Benyt kun annonceringer til at gøre opmærksom på vigtige begivenheder på webstedet.',
 	'texte_mise_a_niveau_base_1' => 'Du har netop opdateret SPIP’s filer.
 	Du skal nu opdatere webstedets database.',
 	'texte_modifier_article' => 'Ret artiklen:',
-	'texte_moteur_recherche_active' => '<b>Søgefunktionen er valgt til.</b> Brug denne kommando, hvis du ønsker at udføre en hurtig reindeksering
-		(f.eks. efter at have indlæst en sikkerhedskopi). Bemærk, at dokumenter der ændres normalt (f.eks. fra SPIP’s brugergrænseflade)
-		automatisk indekseres igen: derfor er denne kommando kun nyttig under ekstraordinære omstændigheder.',
-	'texte_moteur_recherche_non_active' => 'Søgefunktionen er valgt fra.',
 	'texte_multilinguisme' => 'Hvis du ønsker at administrere artikler på flere sprog med den deraf følgende større kompleksitet, kan du forsyne afsnit og/eller artikler med en sprogvalgsmenu. Denne funktion er afhængig af strukturen på websiden.', # MODIF
 	'texte_multilinguisme_trad' => 'Du kan også vælge at have link mellem de forskellige sprogversioner af en artikel.', # MODIF
 	'texte_non_compresse' => '<i>ukomprimeret</i> (din server understøtter ikke denne funktion)',
-	'texte_nouveau_message' => 'Ny meddelelse',
 	'texte_nouvelle_version_spip_1' => 'Du har netop installeret en ny version af SPIP.',
 	'texte_nouvelle_version_spip_2' => 'Denne nye version kræver en mere omfattende opdatering end sædvanligt. Hvis du er webmaster på webstedet, så slet venligst filen <tt>inc_connect.php3</tt> i kataloget <tt>ecrire</tt> og genstart installationen for at opdatere dine opkoblingsparametre til databasen. <p>(NB.: hvis du har glemt dine opkoblingsparametre, så kast et blik på indholdet af filen <tt>inc_connect.php3</tt> før du sletter den...)', # MODIF
 	'texte_operation_echec' => 'Gå tilbage til forrige side og vælg en anden database eller opret en ny. Kontroller de oplysninger, dit webhotel har stillet til rådighed.',
@@ -575,7 +484,6 @@ i en farve, der angiver deres status:',
 		fremtiden?',
 	'texte_rappel_selection_champs' => '[Husk at vælge dette felt korrekt.]',
 	'texte_recalcul_page' => 'Hvis du kun ønsker at opdatere en side, bør du gøre det ved fra det offentlige område at benytte knappen « Opdater ».',
-	'texte_recapitiule_liste_documents' => 'Denne side er en oversigt over de dokumenter, du har anbragt i afsnittene. For at ændre oplysningerne om et dokument, skal du følge linket til dets afsnitsside.',
 	'texte_recuperer_base' => 'Reparer databasen',
 	'texte_reference_mais_redirige' => 'artikler der refereres til på dit SPIP websted, men som viderestiller til en anden URL.',
 	'texte_requetes_echouent' => '<b>Når nogle SQL forespørgsler systematisk og uden tilsyneladende grund går galt, er det muligt at fejlen ligger i selve databasen.</b>
@@ -604,7 +512,6 @@ i en farve, der angiver deres status:',
 		at du har lavet væsentlige grafiske eller strukturelle ændringer på webstedet.',
 	'texte_sur_titre' => 'Hovedoverskrift',
 	'texte_table_ok' => ': denne tabel er OK.',
-	'texte_tables_indexation_vides' => 'Søgefunktionens indekstabeller er tomme.',
 	'texte_tentative_recuperation' => 'Reparationsforsøg',
 	'texte_tenter_reparation' => 'Forsøg på at reparere databasen',
 	'texte_test_proxy' => 'For at afprøve proxy’en, kan du indtaste adressen på et websted som du ønsker at teste.',
@@ -614,18 +521,8 @@ i en farve, der angiver deres status:',
 	'texte_travail_collaboratif' => 'Hvis det sker hyppigt at flere redaktører arbejder på samme artikel, kan systemet
 		vise «åbne» artikler for at undgå samtidige ændringer. Denne indstilling er som standard
 		slået fra for at undgå utidige advarselsmeddelelser.',
-	'texte_trop_resultats_auteurs' => 'For mange resultater til "@cherche_auteur@"; vær venlig at afgrænse søgningen yderligere.',
-	'texte_unpack' => 'download af seneste version',
-	'texte_utilisation_moteur_syndiques' => 'Hvis du benytter SPIP’s indbyggede søgefunktion, kan du på forskellig vis foretage
-		søgninger på websteder og i syndikerede artikler. <br /><img src=\'puce.gif\' /> Den enkleste består i kun at 
-		søge i artiklernes overskrifter og beskrivelser. <br /><img src=\'puce.gif\' /> 
-		En anden metode, som er stærkere, lader SPIP søge i teksten på de websteder, der henvises til. 
-		Hvis du henviser til et websted, vil SPIP selv søge i dens tekst.', # MODIF
-	'texte_utilisation_moteur_syndiques_2' => 'Denne metode tvinger SPIP til jævnligt at besøge webstedet, hvilket kan koste 
-		en forringelse af svartiderne på din eget websted.',
 	'texte_vide' => 'tom',
 	'texte_vider_cache' => 'Tøm cachen',
-	'titre_admin_effacer' => 'Teknisk vedligeholdelse',
 	'titre_admin_tech' => 'Teknisk vedligeholdelse',
 	'titre_admin_vider' => 'Teknisk vedligeholdelse',
 	'titre_cadre_afficher_article' => 'Vis artikler som er',
@@ -645,32 +542,19 @@ i en farve, der angiver deres status:',
 	'titre_naviguer_dans_le_site' => 'Gennemse webstedet...',
 	'titre_nouvelle_rubrique' => 'Nyt afsnit',
 	'titre_numero_rubrique' => 'AFSNITSNUMMER:',
-	'titre_page_admin_effacer' => 'Teknisk vedligeholdelse: sletning af database',
 	'titre_page_articles_edit' => 'Ret: @titre@',
 	'titre_page_articles_page' => 'Artikler',
 	'titre_page_articles_tous' => 'Hele webstedet',
-	'titre_page_auteurs' => 'Besøgende',
 	'titre_page_calendrier' => 'Kalender @nom_mois@ @annee@',
 	'titre_page_config_contenu' => 'Webstedskonfigurering',
-	'titre_page_config_fonctions' => 'Webstedkonfigurering',
-	'titre_page_configuration' => 'Konfiguration af websted',
-	'titre_page_controle_petition' => 'Opfølgning på appel',
 	'titre_page_delete_all' => 'total og uigenkaldelig sletning',
-	'titre_page_documents_liste' => 'Dokumenter i afsnit',
-	'titre_page_index' => 'Dit private område',
-	'titre_page_message_edit' => 'Skriv meddelelse',
-	'titre_page_messagerie' => 'Din meddelelsesfunktion',
 	'titre_page_recherche' => 'Søgeresultater @recherche@',
 	'titre_page_statistiques_referers' => 'Statistik (indkommende links)',
 	'titre_page_upgrade' => 'SPIP opgradering',
 	'titre_publication_articles_post_dates' => 'Offentliggørelse af fremdaterede artikler',
-	'titre_referencer_site' => 'Henvis til webstedet:',
-	'titre_rendez_vous' => 'AFTALER:',
 	'titre_reparation' => 'Reparer',
 	'titre_suivi_petition' => 'Opfølgning på appeller',
-	'trad_article_inexistant' => 'Der findes ingen artikel med dette nummer.',
 	'trad_article_traduction' => 'Alle udgaver af denne artikel :',
-	'trad_deja_traduit' => 'Denne artikel er allerede en oversættelse af den aktuelle artikel.',
 	'trad_delier' => 'Afbryd forbindelsen mellem denne artikel og oversættelserne', # MODIF
 	'trad_lier' => 'Denne artikel er en oversættelse af artikel nummer :',
 	'trad_new' => 'Lav en ny oversættelse af denne artikel' # MODIF
