@@ -3,14 +3,16 @@
 // extrait automatiquement de http://trad.spip.net/tradlang_module/ecrire_?lang_cible=de
 // ** ne pas modifier le fichier **
 
-if (!defined('_ECRIRE_INC_VERSION')) return;
+if (!defined('_ECRIRE_INC_VERSION')) {
+	return;
+}
 
 $GLOBALS[$GLOBALS['idx_lang']] = array(
 
 	// A
 	'activer_plugin' => 'Plugin aktivieren',
 	'affichage' => 'Anzeigen',
-	'aide_non_disponible' => 'Teil der Online-Hilfe in dieser Sprache noch nicht verfügbar.',
+	'aide_non_disponible' => 'Dieser Teil der Online-Hilfe ist in dieser Sprache noch nicht verfügbar.',
 	'annuler_recherche' => 'Sucheingabe löschen',
 	'auteur' => 'Autor:',
 	'avis_acces_interdit' => 'Zugang verweigert.',
@@ -201,9 +203,6 @@ $GLOBALS[$GLOBALS['idx_lang']] = array(
 	'info_activer_cookie' => 'Sie können ein <b>Verwaltungs-Cookie</b> setzen. Es erlaubt Ihnen, Artikel und Rubriken direkt aus der Website zu bearbeiten.',
 	'info_activer_menu_developpement' => 'Entwicklermenü anzeigen',
 	'info_admin_etre_webmestre' => 'Mir Webmaster-Rechte geben',
-	'info_admin_gere_rubriques' => 'Dieser Administrator verwaltet die folgenden Rubriken:',
-	'info_admin_gere_toutes_rubriques' => 'Dieser Administrator verwaltet <b>alle Rubriken</b>.',
-	'info_admin_gere_toutes_rubriques_2' => 'Ich verwalte <b>alle Rubriken</b>.',
 	'info_admin_je_suis_webmestre' => 'Ich bin <b>Webmaster</b>',
 	'info_admin_statuer_webmestre' => 'Diesem Administrator Webmaster-Rechte geben',
 	'info_admin_webmestre' => 'Dieser Administrator ist <b>Webmaster</b>',
@@ -237,6 +236,9 @@ $GLOBALS[$GLOBALS['idx_lang']] = array(
 	'info_aucun_message' => 'Keine Nachricht',
 	'info_aucun_rubrique' => 'Keine Rubrik',
 	'info_aujourdhui' => 'heute: ',
+	'info_auteur_gere_rubriques' => 'Dieser Autor verwaltet folgende Rubriken :',
+	'info_auteur_gere_toutes_rubriques' => 'Dieser Autor verwaltet <b>alle Rubriken</b>.',
+	'info_auteur_gere_toutes_rubriques_2' => 'Ich verwalte <b>alle Rubriken</b>.',
 	'info_auteurs' => 'Autoren',
 	'info_auteurs_par_tri' => 'Autoren@partri@',
 	'info_auteurs_trouves' => 'Gefundene Autoren',
@@ -386,7 +388,7 @@ Ihr Status wird durch die Farbe ihres Symbols angezeigt (Redakteur = gelb; Admin
 	'info_post_scriptum' => 'Post-Scriptum',
 	'info_post_scriptum_2' => 'Post-scriptum:',
 	'info_pour' => 'für',
-	'info_preview_texte' => 'Man kann sich die Website so anzeigen lassen, als ob alle Artikel veröffentlicht wären, die mindestens den Status « vorgeschlagen » haben. Wem soll diese Möglichkeit zur Verfügung stehen (Adminsitratoren, Redakteure, niemand)?',
+	'info_preview_texte' => 'Man kann sich alle Elemente der Website so anzeigen lassen, als ob sie veröffentlicht wären, vorausgesetzt sie haben mindestens den Status « vorgeschlagen » oder man ist ihr Autor . Wem soll diese Möglichkeit zur Verfügung stehen (Adminsitratoren, Redakteure, niemand)?',
 	'info_procedez_par_etape' => 'gehen Sie Schritt für Schritt vor',
 	'info_procedure_maj_version' => 'Sie müssen die Update-Funktion starten, um Ihre Datenbank an die neue Version von SPIP anzupassen.',
 	'info_proxy_ok' => 'Proxytest erfolgreich.',
@@ -598,6 +600,7 @@ in einer Farbe, die den Status anzeigt :',
 
 	// N
 	'nouvelle_version_spip' => 'SPIP Version @version@ ist verfügbar.',
+	'nouvelle_version_spip_majeure' => 'Eine neue SPIP Version @version@ steht zur Verfügung.',
 
 	// O
 	'onglet_contenu' => 'Inhalt',
@@ -646,7 +649,7 @@ in einer Farbe, die den Status anzeigt :',
 	'plugin_info_upgrade_ok' => 'Upgrade erfolgreich',
 	'plugin_librairies_installees' => 'Installierte Bibliotheken',
 	'plugin_necessite_lib' => 'Dieses Plugin benötigt die Bibliothek @lib@',
-	'plugin_necessite_plugin' => 'Benötigt mindestens Version @version@ des Plugin @plugin@.',
+	'plugin_necessite_plugin' => 'Benötigt Version @version@ des Plugin @plugin@.',
 	'plugin_necessite_plugin_sans_version' => 'Benötigt das Plugin @plugin@',
 	'plugin_necessite_spip' => 'Benötigt mindestens Version @version@ von SPIP.',
 	'plugin_source' => 'Quelle: ',
@@ -654,6 +657,7 @@ in einer Farbe, die den Status anzeigt :',
 	'plugin_titre_automatique_ajouter' => 'Plugins hinzufügen',
 	'plugin_titre_installation' => 'Installation des Plugins @plugin@',
 	'plugin_titre_modifier' => 'Meine Plugins',
+	'plugin_utilise_plugin' => 'Verwendet das Plugin @plugin@ in der Version @version@.',
 	'plugin_zip_active' => 'Weiter zum Aktivieren',
 	'plugin_zip_adresse' => 'Geben Sie hier die Adresse einer ZIP-Datei, die das Plugin enthält, oder die Adresse einer Plugin-Liste an.',
 	'plugin_zip_adresse_champ' => 'Adresse des Plugins oder der Liste ',
@@ -700,7 +704,7 @@ in einer Farbe, die den Status anzeigt :',
 	// T
 	'tache_cron_asap' => 'Cronjob @function@ (unverzüglich)',
 	'tache_cron_secondes' => 'Cronjob @function@ (alle @nb@ Sekunden)',
-	'taille_cache_image' => 'Dei von SPIP automatisch berechneten Grafiken (Icons für Dokumente, als Grafiken gespeicherte Titel, mathematische Ausdrücke im Format TeX...) belegen insgesamt @taille@ im Verzeichnis @dir@.',
+	'taille_cache_image' => 'Die von SPIP automatisch berechneten Grafiken (Icons für Dokumente, als Grafiken gespeicherte Titel, mathematische Ausdrücke im Format TeX...) belegen insgesamt @taille@ im Verzeichnis @dir@.',
 	'taille_cache_infinie' => 'Die Grösse des <code>CACHE/</code> dieser Website wird nicht begrenzt.',
 	'taille_cache_maxi' => 'SPIP versucht die Grösse des <code>CACHE/</code> der Website auf ca. <b>@octets@</b> Byte zu begrenzen.',
 	'taille_cache_moins_de' => 'Die Größe des Caches beträgt mindestens  @octets@.',
@@ -739,6 +743,7 @@ in einer Farbe, die den Status anzeigt :',
 	'texte_date_publication_anterieure_nonaffichee' => 'Kein Datum einer früheren Bearbeitung anzeigen.',
 	'texte_date_publication_article' => 'ONLINE VERÖFFENTLICHT AM:',
 	'texte_date_publication_objet' => 'Veröffentlichungsdatum:',
+	'texte_definir_comme_traduction_rubrique' => 'Diese Rubrik ist eine Übersetzung der Rubik mit der Nummer',
 	'texte_descriptif_rapide' => 'Kurzbeschreibung',
 	'texte_effacer_base' => 'SPIP-Datenbank löschen',
 	'texte_effacer_statistiques' => 'Statistiken löschen',
