@@ -3,7 +3,9 @@
 // extrait automatiquement de http://trad.spip.net/tradlang_module/ecrire_?lang_cible=fa
 // ** ne pas modifier le fichier **
 
-if (!defined('_ECRIRE_INC_VERSION')) return;
+if (!defined('_ECRIRE_INC_VERSION')) {
+	return;
+}
 
 $GLOBALS[$GLOBALS['idx_lang']] = array(
 
@@ -198,9 +200,6 @@ $GLOBALS[$GLOBALS['idx_lang']] = array(
 	'info_1_visiteur' => 'بازديد‌كننده‌ي 1',
 	'info_activer_cookie' => ' شما ميتوانيد  كوكى مكاتبه  را فعال نماپيد اينكار به شما اجازه خواهد داد كه براحتى از سايت همگانى به سايت خصوصى برويد',
 	'info_admin_etre_webmestre' => 'دادن حق وب مستر به من',
-	'info_admin_gere_rubriques' => ':اين گرداننده سايت بخشهاى زير را اداره ميكند',
-	'info_admin_gere_toutes_rubriques' => 'اين گرداننده سايت <b> تمام بخش‌ها را اداره مي‌كند</b>.',
-	'info_admin_gere_toutes_rubriques_2' => 'من <b> تمام بخش‌ها را اداره مي‌كنم</b>',
 	'info_admin_je_suis_webmestre' => 'من <b>webmestre</b> هستم',
 	'info_admin_statuer_webmestre' => 'تفويض حق وب مستري به اين مدير',
 	'info_admin_webmestre' => 'اين مدير <b>webmestre</b> است',
@@ -234,6 +233,7 @@ $GLOBALS[$GLOBALS['idx_lang']] = array(
 	'info_aucun_message' => 'هيچ پيامي موجود نيست',
 	'info_aucun_rubrique' => 'هيچ بخش',
 	'info_aujourdhui' => ': امروز',
+	'info_auteur_gere_toutes_rubriques_2' => 'من <b> تمام بخش‌ها را اداره مي‌كنم</b>', # MODIF
 	'info_auteurs' => 'نويسندگان ',
 	'info_auteurs_par_tri' => '@partri@ نويسنده گان',
 	'info_auteurs_trouves' => 'نويسنده گان پيدا شده   ',
@@ -382,7 +382,7 @@ $GLOBALS[$GLOBALS['idx_lang']] = array(
 	'info_post_scriptum' => 'نوشتار پس از متن اصلى',
 	'info_post_scriptum_2' => ':نوشتار پس از متن اصلى',
 	'info_pour' => 'براى',
-	'info_preview_texte' => 'اين امكان وجود دارد كه سايت را پيش از آماده شدن (پيش از پيشنهاد مقالات) بازبينى كرد مانند زمانيكه همه ى مقالات و اخبار منتشر شده اند.اين امكان ميتواند تنها براى گردانند گان سايت يا نويسندگان يا براى هيچكس نباشد.',
+	'info_preview_texte' => 'اين امكان وجود دارد كه سايت را پيش از آماده شدن (پيش از پيشنهاد مقالات) بازبينى كرد مانند زمانيكه همه ى مقالات و اخبار منتشر شده اند.اين امكان ميتواند تنها براى گردانند گان سايت يا نويسندگان يا براى هيچكس نباشد.', # MODIF
 	'info_procedez_par_etape' => 'مرحله به مرحله اقدام كنيد',
 	'info_procedure_maj_version' => 'روند به روز كردن بايد به جريان بيفتد تا داده پى ها بتوانند با نسخه جديد منطبق شوند.',
 	'info_proxy_ok' => 'آزمایش پروکسی با موفقیت انجام شد.',
@@ -544,7 +544,7 @@ $GLOBALS[$GLOBALS['idx_lang']] = array(
 	'label_choix_langue' => 'زبان خود را انتخاب كنيد',
 	'label_nom_fichier_connect' => 'اعلام نام مورد استفاده براي اين سرور ',
 	'label_slogan_site' => 'شعار سايت',
-	'label_taille_ecran' => 'پهناي پرده‌ي نمايش',
+	'label_taille_ecran' => 'پهناي پرده‌ي نمايش', # MODIF
 	'label_texte_et_icones_navigation' => 'منوي ناوبري ',
 	'label_texte_et_icones_page' => 'صفحه‌ي نمايش ',
 	'ldap_correspondance' => 'ميدان موروثي @champ@',
@@ -583,7 +583,7 @@ $GLOBALS[$GLOBALS['idx_lang']] = array(
 	'mois_non_connu' => 'شناخته نشده',
 
 	// N
-	'nouvelle_version_spip' => 'اسپيپ نسخه‌ي @version@ در دسترس است  ',
+	'nouvelle_version_spip' => 'اسپيپ نسخه‌ي @version@ در دسترس است  ', # MODIF
 
 	// O
 	'onglet_contenu' => 'محتوا',
@@ -632,7 +632,7 @@ $GLOBALS[$GLOBALS['idx_lang']] = array(
 	'plugin_info_upgrade_ok' => ' روزآمدسازي موفق',
 	'plugin_librairies_installees' => 'آرشيو‌هاي نصب‌ شده',
 	'plugin_necessite_lib' => 'اين پلاگين به آرشيو @lib@ نياز دارد',
-	'plugin_necessite_plugin' => 'به plugin @plugin@ نسخه ی @version@ نیاز دارید',
+	'plugin_necessite_plugin' => 'به plugin @plugin@ نسخه ی @version@ نیاز دارید', # MODIF
 	'plugin_necessite_plugin_sans_version' => 'پلاگين @plugin@ لازم است ',
 	'plugin_necessite_spip' => 'به اسپیپ نسخه ی @version@ نیاز دارید.',
 	'plugin_source' => 'منبع: ',
@@ -666,7 +666,7 @@ $GLOBALS[$GLOBALS['idx_lang']] = array(
 
 	// Q
 	'queue_executer_maintenant' => 'اجرا حالا',
-	'queue_info_purger' => 'مي‌‌توانيد تمام كارهاي در دست انجام را حذف كنيد و فهرست  كارهاي دوره‌اي را بازتنظيم (ريست) كنيد',
+	'queue_info_purger' => 'مي‌‌توانيد تمام كارهاي در دست انجام را حذف كنيد و فهرست  كارهاي دوره‌اي را بازتنظيم (ريست) كنيد', # MODIF
 	'queue_nb_jobs_in_queue' => '@nb@ وظيفه در صف ',
 	'queue_next_job_in_nb_sec' => 'وظيفه‌ي بعدي در  @nb@ امين',
 	'queue_no_job_in_queue' => 'وظيفه‌اي در دست اجرا نيست',
