@@ -3,7 +3,9 @@
 // extrait automatiquement de http://trad.spip.net/tradlang_module/ecrire_?lang_cible=fon
 // ** ne pas modifier le fichier **
 
-if (!defined('_ECRIRE_INC_VERSION')) return;
+if (!defined('_ECRIRE_INC_VERSION')) {
+	return;
+}
 
 $GLOBALS[$GLOBALS['idx_lang']] = array(
 
@@ -21,60 +23,36 @@ $GLOBALS[$GLOBALS['idx_lang']] = array(
 	'avis_connexion_ldap_echec_2' => 'Mi bo lɛ kɔ  yi wekpa gudo tɔ̂n ji bo kpɔn ɖɔ xogbè mi tɔn mi sɛdo lɛ ',
 	'avis_connexion_ldap_echec_3' => 'Mi ma zan LDAP bo do ylɔ zizantɔ lɛ do zɛnzɛn o',
 	'avis_deplacement_rubrique' => 'vlɛ! @contient_breves@ brève@scb@ ɖé lɛ̂ do akpa é lɔ mɛ : n sɛ sinɔ, mi tɛnkpɔn bo sɔ xlɛ tɔn do fi.',
-	'avis_destinataire_obligatoire' => 'Mi ɖo na wlan mɛ gɔn wɛn na yi ɔ co na sɛ wɛn do',
 	'avis_erreur_connexion_mysql' => 'afɔkiklɛn do cacado mysql tɔn mɛ ',
-	'avis_erreur_version_archive' => 'vlɛ ! xota @archive@  é jɛ do alɔ supipu tɔn dévo ji.Mi jan na kpé afɔ nyanya  ɖé lɛ, gblogbloji ɔ sin walɔ nyanya, mi mà na gbe sisɛ do é lɔ o. Nu mi na sè xo gɔ na', # MODIF
 	'avis_espace_interdit' => 'acɛku Yé ko  ze supipu do fi nɛ',
 	'avis_lecture_noms_bases_1' => 'nyikɔ kpodo gbɛtakɛnxokplé lɛ̂  ye do Titomɛ ɔ mɛ a  ',
 	'avis_lecture_noms_bases_2' => 'Kabi gbɛtakɛnxokplé ɖé a , kabi  nuwé nɔ zɔn bɔ mi nɔ to gbɛtakɛnxokplé lɛ sin acɛ ku.sɔ ɖo ayi ni ja wu ɔ ( mɔ wɛ e ɖé lo xwétɔ gege gɔn)',
 	'avis_lecture_noms_bases_3' => 'ɖo sisɔ akpa dévo tɔn mɛ ɔ, Yé siwu zan gbɛtakɛnxokplé ɖé sɔ nyikɔ mi tɔn ',
-	'avis_non_acces_message' => 'Mi siwu xa wɛn é lɔ a ',
 	'avis_non_acces_page' => 'Mi siwu yi wekpa é lɔ ji à ',
 	'avis_operation_echec' => 'azɔ̂ gbé',
-	'avis_probleme_archive' => 'xota xixā glo @archive@',
 	'avis_suppression_base' => 'vlɛ ! nu mi sunsun gbètakɛn lɛ̂ ɔ é vɔ bi sésé',
-	'avis_version_mysql' => 'Mysql mitɔn ɖévo ( @ ɖévo_mysql@) siwu blo akɔnta gbètakɛn lɛ̂ tɔn a ',
 
 	// B
 	'bouton_acces_ldap' => 'Mi zé gɔna LDAP',
 	'bouton_ajouter' => 'Mi gɔna ',
-	'bouton_ajouter_participant' => 'Mi zé mɛɖokpo gɔna',
-	'bouton_annonce' => 'Xo ɖɔdotoji',
-	'bouton_checkbox_envoi_message' => 'mi hɛn ɔ mi na sɛ wɛn ɖokpo ɖo',
-	'bouton_checkbox_indiquer_site' => 'mi ɖo na xlɛgblogbloji ɖokpo',
-	'bouton_checkbox_signature_unique_email' => 'e-mail ɖokpo, alɔɖowémàmɛ ɖokpo',
-	'bouton_checkbox_signature_unique_site' => 'gblogbloji ɖokpo,  alɔɖowémàmɛ ɖokpo',
 	'bouton_demande_publication' => 'Mi kàn ɖiɖétɔn wékpa é lɔ tɔn byɔ',
-	'bouton_effacer_index' => 'Mi sùnsun indexu ɔ ',
 	'bouton_effacer_tout' => 'Mi sùnsun bi',
-	'bouton_envoi_message_02' => 'sɛ wɛn ɖo',
 	'bouton_envoyer_message' => 'wɛn gudogudotɔn : sɛdo',
 	'bouton_modifier' => 'ɖyɔ',
-	'bouton_pense_bete' => 'Lin tamɛ ɖo zizan whɛ dé su tɔn wu ',
-	'bouton_radio_activer_messagerie' => 'Mi ta wɛnwiwlan ',
-	'bouton_radio_activer_messagerie_interne' => 'Mi ta wɛnwiwlan ',
-	'bouton_radio_activer_petition' => 'mi sɔ kɛn ',
 	'bouton_radio_afficher' => 'mi xlɛ',
 	'bouton_radio_apparaitre_liste_redacteurs_connectes' => 'ɖo xlɛ ɖo ɖiɖè nyɔwlantɔ̂é ɖo kan ji lɛ',
-	'bouton_radio_desactiver_messagerie' => 'Mi jo wiwlanmɛ ɖo',
 	'bouton_radio_envoi_annonces_adresse' => 'Mi sɛ xojla do',
 	'bouton_radio_envoi_liste_nouveautes' => 'mi  kplé xogbè yɔyɔ lɛ̂ do ',
 	'bouton_radio_non_apparaitre_liste_redacteurs_connectes' => 'mi ma ɖo xlɛ ɖo ɖiɖè nyɔwlantɔ  tɔn mɛ o ',
 	'bouton_radio_non_envoi_annonces_editoriales' => 'mi ma sɛ gbètàxojla do',
-	'bouton_radio_pas_petition' => 'Tajijla ɖé dé  a ',
-	'bouton_radio_petition_activee' => 'Tajijla ɖé ',
-	'bouton_radio_supprimer_petition' => 'mi sunsùn Tajijla ',
 	'bouton_redirection' => 'mi lɛ vɔ jlɛ',
 	'bouton_relancer_installation' => 'Mi lɛ vɔ  afɔɖotè ɔ blo',
 	'bouton_suivant' => 'E jɛ gudo  ɔ',
 	'bouton_tenter_recuperation' => 'mi nà tɛnkpɔn bo bloɖo',
 	'bouton_test_proxy' => 'mi  tɛn proxy kpɔn ',
 	'bouton_vider_cache' => 'bɛ simɛ',
-	'bouton_voir_message' => 'mi xa wɛn é lɔ co bo sɔ  kɛn na',
 
 	// C
-	'cache_mode_compresse' => 'Wli gbètā jando gudo lɛ̂  hɛn',
-	'cache_mode_non_compresse' => 'Wli gbètā jando gudo lɛ̂  hɛn',
 	'cache_modifiable_webmestre' => 'mɛ lò mɔɔjí ɔ hɛn ɔ é ná vɔ ɖiɖèmɛ bló',
 	'calendrier_synchro' => 'Nú jó ná zán gbèta, mi siwú xò bí kplé ',
 
@@ -100,7 +78,6 @@ $GLOBALS[$GLOBALS['idx_lang']] = array(
 	'entree_login' => 'nyìkɔ mī tɔn ',
 	'entree_login_connexion_1' => 'nyìkɔ mī tɔn ',
 	'entree_login_connexion_2' => 'nyìkɔ mī tɔn ',
-	'entree_login_ldap' => 'nyìkɔ mī tɔn  LDAP tɔn  ',
 	'entree_mot_passe' => 'cávì mī tɔn ',
 	'entree_mot_passe_1' => 'cávì mī tɔn ',
 	'entree_mot_passe_2' => 'cávì mī tɔn ',
@@ -120,7 +97,7 @@ $GLOBALS[$GLOBALS['idx_lang']] = array(
 	'ical_info2' => 'Nú mi lɛ lò xógbè xwítíxwítí bà wɛ ɔ mi síkú yí sùpípú sín xóxòkplémɛ.', # MODIF
 	'ical_info_calendrier' => 'Yè sɛ kàlànɖlyé wè ɖó mí. ɖòkpó nyí gblogblojí ɔ sín tìtòmɛ tɔn bó nɔ xlɛ wě ɖé yè wlàn lɛ bí. Wègɔ ɔ é nyí xógbèɖòtàjì kpó wɛn mì tɔn vívɛná lɛ kpó jí : mi ɖó càvì mi tɔn, bɔ mi lɛ hɛn ɔ mi ná lɛ  nɔ ɖyɔ ɛ kpódó gbètákɛn. .',
 	'ical_methode_http' => 'ɖìɖɔn ',
-	'ical_methode_webcal' => 'mìmá',
+	'ical_methode_webcal' => 'mìmá', # MODIF
 	'ical_texte_js' => 'ɖìdèmɛ javasùclipù tɔn  ná síwú nɔ mi ná xlɛ wěkpá gùdógùdó tɔn lɛ ɖò gblogblojí ɖébújí..',
 	'ical_texte_prive' => 'kàlànɖlyé é lɔ é nyí miɖɛsú tɔn ɔn, nɔ ná xógbè ɖó xógbèɖòtàjìzɔ gblogblojí ɔ tɔ wú',
 	'ical_texte_public' => 'kàlànɖlyé ná ná bɔ nùkún mi tɔn ná nɔ gblogblojí ɔ sín àzɔnùkùnɖéjí ɔ jí.',
@@ -136,9 +113,7 @@ $GLOBALS[$GLOBALS['idx_lang']] = array(
 	'icone_creer_auteur' => 'Mi ɖè gbètakɛn yɔyɔ dévó tɔn ',
 	'icone_creer_mot_cle' => 'Mi zé nyɔwlántɔ yɔyɔ dévó tɔn bó cáɖó wěkpá',
 	'icone_creer_rubrique_2' => 'Mi ɖè àkpáxwé dévó tɔn',
-	'icone_envoyer_message' => 'sɛ whɛn ɖó',
 	'icone_modifier_article' => 'mi vɔ ɖyɔ wékpá',
-	'icone_modifier_message' => 'mi vɔ ɖyɔ wɛn ɔ ',
 	'icone_modifier_rubrique' => 'mi vɔ ɖyɔ àkpáxwé ɔ',
 	'icone_retour' => 'lɛkɔ',
 	'icone_retour_article' => 'lɛkɔ yì wěkpá ɔ jí',
@@ -148,10 +123,7 @@ $GLOBALS[$GLOBALS['idx_lang']] = array(
 	'icone_valider_signature' => 'sɔ kɛn nú àlɔɖówěmámɛ é lɔ',
 	'image_administrer_rubrique' => 'Mi síw tò àkpáxwé é lɔ',
 	'info_1_article' => 'wěkpá ɖòkpó',
-	'info_1_site' => 'gblogblojí ɖòkpó',
 	'info_activer_cookie' => 'Mi sí wlán xógbè é sɔgbèbɔ mi ná dó jɛ àgun dévómɛ.',
-	'info_admin_gere_rubriques' => 'tìtòt é lɔ nɔ bló àkpáxwé é lɔ lɛ ɖó:',
-	'info_admin_gere_toutes_rubriques' => 'tìtòt é lɔ nɔ bló àkpáxwé é lɔ lɛ ɖó', # MODIF
 	'info_administrateur' => ' tìtòtɔ ',
 	'info_administrateur_1' => 'tìtòtɔ',
 	'info_administrateur_2' => 'gblogblojí  yè z kpó yɛyì',
@@ -161,13 +133,10 @@ $GLOBALS[$GLOBALS['idx_lang']] = array(
 	'info_administrer_rubrique' => 'mi hɛn ɔ mi ná to àkpáxwé é lɔ ',
 	'info_adresse' => 'nɔtɛn',
 	'info_adresse_url' => 'nɔtɛn gblogblojí ɔ tɔn ',
-	'info_afficher_visites' => 'mi xlɛ jònɔbíbà ɛ:',
 	'info_aide_en_ligne' => 'àlɔdó sùpípù tɔn',
 	'info_ajout_image' => 'àlɔdó sùpípù tɔn.',
-	'info_ajout_participant' => 'mɛ dókpó lɛ gɔná:',
 	'info_ajouter_rubrique' => 'mi gɔ xókwín dókpó  ná:',
 	'info_annonce_nouveautes' => 'xójíjlá yɔyɔ lɛ',
-	'info_anterieur' => 'ɖàyí xóxó',
 	'info_article' => 'wěkpá',
 	'info_article_2' => 'wěkpá',
 	'info_article_a_paraitre' => 'wěkpá yé ɖó àzán ná',
@@ -175,10 +144,8 @@ $GLOBALS[$GLOBALS['idx_lang']] = array(
 	'info_articles_2' => 'wěmâ',
 	'info_articles_auteur' => 'nyɔwlántɔ é lɔ sín wěmà',
 	'info_articles_trouves' => 'wěmà yè mɔ é',
-	'info_articles_trouves_dans_texte' => 'wěmà yè mɔ é',
 	'info_attente_validation' => 'mi ɖòtè bò ná sɔ kɛn nú wěmà lɛ ',
 	'info_aujourdhui' => 'égbé:',
-	'info_auteur_message' => 'Wɛn sɛɖótɔ :',
 	'info_auteurs' => 'Nyɔwlántɔ lɛ̂',
 	'info_auteurs_par_tri' => 'Nyɔwlántɔ (lɛ̂)',
 	'info_auteurs_trouves' => 'Nyɔwlántɔ lɛ̂ ɖê mi mɔ ɔ',
@@ -210,15 +177,12 @@ $GLOBALS[$GLOBALS['idx_lang']] = array(
 	'info_date_publication_anterieure' => 'àzán gùdó tɔn :',
 	'info_date_referencement' => 'àzán gùdó tɔn :',
 	'info_derniere_etape' => 'Nɔtɛn gùdó tɔn ɔ!',
-	'info_derniers_articles_publies' => 'wékpá gùdó tɔn ɔ',
-	'info_desactiver_messagerie_personnelle' => 'mi hɛn mi ná sú kàbí mi ná hùn wlántɛn gblogblojí é lɔ tɔn.',
 	'info_descriptif' => 'ɖìɖèmɛ :',
 	'info_discussion_cours' => 'xó kpó ɖò yìyì wɛ',
 	'info_ecrire_article' => 'có hwɛ mi nɛ nú wlán jí ɔ, mi ɖó ná ɖè àkpáxwé tɔn hwɛ',
 	'info_email_envoi' => 'e-mailù',
 	'info_email_envoi_txt' => 'mi dó gesi bó ná sɛ e-mailù lɛ ɖó:',
 	'info_email_webmestre' => 'tìtòtì sín e-mailù', # MODIF
-	'info_entrer_code_alphabet' => 'mi sɔ gbètákɛn ê mi ján zán ɔ:',
 	'info_envoi_email_automatique' => 'sɛ e-mailù ɖó àzɔn ɖókpó',
 	'info_envoyer_maintenant' => 'sɛɖó ɖìn',
 	'info_etape_suivante' => 'mi yí tɛnɔtɛ é bɔɖéwú ɔ jí',
@@ -228,24 +192,16 @@ $GLOBALS[$GLOBALS['idx_lang']] = array(
 	'info_facilite_suivi_activite' => 'bíbɛ xóxókplé sɔ yì',
 	'info_fichiers_authent' => 'xó xókplé ',
 	'info_forums_abo_invites' => 'jōnɔ lɛ ní ná nyíkɔ.',
-	'info_gauche_admin_effacer' => ' wémà é lɔ Tìtòtɔ lɛ kɛɖɛ wɛ síwú dàlɔmɛ.', # MODIF
 	'info_gauche_admin_tech' => 'wémà é lɔ Tìtòtɔ lɛ kɛɖɛ wɛ síwú dàlɔmɛ', # MODIF
 	'info_gauche_admin_vider' => 'wémà é lɔ Tìtòtɔ lɛ kɛɖɛ wɛ síwú dàlɔmɛ', # MODIF
 	'info_gauche_auteurs' => 'Dò fyɔ, mí ná mɔ Tìtòtɔ gblogblojí ɔ tɔn lɛ .',
 	'info_gauche_auteurs_exterieurs' => 'Dò fyɔ, mí ná mɔ Tìtòtɔ gblogblojí ɔ tɔn lɛ .', # MODIF
 	'info_gauche_messagerie' => 'Winwlántɛnmɛ nɔ ná bɔ nyɔwlántɔ síwú nɔ ɖɔxó ɖó kpɔ.',
-	'info_gauche_numero_auteur' => 'nyɔwlántɔ nùmɛló',
 	'info_gauche_statistiques_referers' => 'wémà é lɔ Tìtòtɔ lɛ kɛɖɛ wɛ síwú dàlɔmɛ',
 	'info_gauche_visiteurs_enregistres' => 'jōnɔ bíbà sín akɔnŋtà',
 	'info_generation_miniatures_images' => 'Nú títɛ lɛ ɖê yē zé bló gbètákɛn ná',
-	'info_gerer_trad' => 'Tìtò tímɛ tɔn lɛ?',
 	'info_hebergeur_desactiver_envoi_email' => 'e-mailù càcà.',
 	'info_hier' => 'sɔ tó fí:',
-	'info_historique_activer' => 'sɔ tó fí',
-	'info_historique_affiche' => 'zé wàlɔ ɔ xlɛ',
-	'info_historique_comparaison' => 'kpɔnɖéwú',
-	'info_historique_desactiver' => 'mi jó kpɔnɖéwú ɔ dó',
-	'info_historique_texte' => 'mi zé ɖìdyɔ sín àfɔ ɖìɖè xlɛ.',
 	'info_identification_publique' => 'Nyíkɔ mi tɔn tòbítùn...',
 	'info_image_process' => 'Mi cyán wàlɔ ɖàgbè lɛ.',
 	'info_image_process2' => 'Mi cyán wàlɔ ɖàgbè lɛ', # MODIF
@@ -262,8 +218,6 @@ $GLOBALS[$GLOBALS['idx_lang']] = array(
 	'info_login_trop_court' => 'nyíkɔ̂ hwè.',
 	'info_maximum' => 'Bísésé:',
 	'info_meme_rubrique' => 'Akpáxwé ɖókpó ɔ',
-	'info_message' => 'wɛn',
-	'info_message_efface' => 'yè súsú wɛn',
 	'info_message_en_redaction' => 'yè kpò ɖò wɛn wlàn wɛ',
 	'info_message_technique' => 'wɛn xwítxwítí :',
 	'info_messagerie_interne' => 'Winwlántɛnmɛ',
@@ -272,19 +226,14 @@ $GLOBALS[$GLOBALS['idx_lang']] = array(
 	'info_modifier_rubrique' => 'ɖyɔ Akpáxwé ɔ:',
 	'info_modifier_titre' => 'ɖyɔ Akpáxwé ɔ: @xota@',
 	'info_mon_site_spip' => 'gblogblojí supipu tɔn cè',
-	'info_mot_sans_groupe' => '(xókwín máɖó àgùn...)',
-	'info_moteur_recherche' => 'Mɔ mɔjɛmɛbátɔ',
 	'info_moyenne' => 'Tɛntímɛ:',
-	'info_multi_articles' => 'Gbè lɛ sín Akpáxwé ní yí àzɔ?',
 	'info_multi_cet_article' => 'Gbè wékpá é lɔ tɔn :',
 	'info_multi_langues_choisies' => 'Mi kɛnklɛn bó sɔ gbè é jló myɔ',
-	'info_multi_rubriques' => 'Gbè lɛ sín Akpáxwé ní yí àzɔ?',
 	'info_multi_secteurs' => 'Akpáxwé é lò ɖòkɔ lɛ kɛɖɛ a ?',
 	'info_nom' => 'E wó',
 	'info_nom_destinataire' => 'nyíkɔ mɛ ná yí ɔ tɔn',
 	'info_nom_site' => 'gblogblojí mi tɔn sín nyíkɔ',
 	'info_nombre_articles' => '@nb_articles@ wékpá,',
-	'info_nombre_partcipants' => 'mi byɔ kplé mɛ:',
 	'info_nombre_rubriques' => '@nb_rubriques@ àkpáxwé lɛ,',
 	'info_nombre_sites' => '@nb_sites@ gblogblojí ,',
 	'info_non_deplacer' => 'yè mà sɛ wó...',
@@ -293,48 +242,34 @@ $GLOBALS[$GLOBALS['idx_lang']] = array(
 	'info_non_modifiable' => 'Yé sín ɖyɔ á',
 	'info_non_suppression_mot_cle' => 'ŋ jó ná súnsún gbètɛn ɔ á.',
 	'info_notes' => 'wê',
-	'info_nouveaux_message' => 'wɛn yɔyɔ',
 	'info_nouvel_article' => 'wékpá yɔyɔ',
 	'info_nouvelle_traduction' => 'Tínmɛ ɖévó:',
 	'info_numero_article' => 'Wékpá nùméló:',
 	'info_obligatoire_02' => '[dódó]', # MODIF
 	'info_option_accepter_visiteurs' => 'Mi yí gbè nú jònɔ é ná nyíkɔ lɛ ',
-	'info_option_faire_suivre' => 'Mi nɔ kpɔn wɛn lɛ ɖò kplékplé ɔ mɛ',
 	'info_option_ne_pas_accepter_visiteurs' => 'Mi gbɛ nyíkɔ jónɔ é lɔ tɔn ',
 	'info_options_avancees' => 'wàlɔ é ɖrɛn àfɔ ',
-	'info_ortho_activer' => 'mi vlɔn nú é nɔ wlán gànjí ɔ ',
-	'info_ortho_desactiver' => 'mi má vlɔn nú é nɔ wlán gànjí ɔ ',
 	'info_ou' => 'fítɛ...',
 	'info_page_interdite' => 'àlì sú',
 	'info_par_nombre_article' => '(ɖìɖèmɛ wékpá )',
 	'info_passe_trop_court' => 'gbètákɛn ɔ hwè.',
 	'info_passes_identiques' => 'gbètákɛn wè lɛ sɔgbè á.',
-	'info_pense_bete_ancien' => 'Lìntámɛ-Agúɖàgɔ xóxó mi tɔn lɛ', # MODIF
 	'info_plus_cinq_car' => 'E hú wékwín àtɔ̂n',
 	'info_plus_cinq_car_2' => '(E hú wékwín àtɔ̂n)',
 	'info_plus_trois_car' => '(E hú wékwín àtɔn)',
 	'info_popularite' => 'Tòbítù: @popularite@ ; Jōnɔ: @visites@',
-	'info_popularite_4' => 'Tòbítùn : @popularite@ ; Jōnɔ : @visites@',
 	'info_post_scriptum' => 'Gbè ní ná',
 	'info_post_scriptum_2' => 'Gbè ní ná :',
 	'info_pour' => 'gbɔn',
-	'info_preview_admin' => 'Tìtòtɔ lɛ jɛn síwú kpɔn gblogblojí ɔ hwɛ',
-	'info_preview_comite' => 'Nyɔwlántɔ lɛ jɛn síwú kpɔn gblogblojí ɔ hwɛ',
-	'info_preview_desactive' => 'wàlɔ kpíkpɔn tɔn sɔ ɖò gbɛ á',
-	'info_preview_texte' => 'wàlɔ kpíkpɔn tɔn sɔ ɖò gbɛ á',
-	'info_principaux_correspondants' => 'Xɔntɔn mìtɔn àlɔ mà yì mɛ lɛ',
+	'info_preview_texte' => 'wàlɔ kpíkpɔn tɔn sɔ ɖò gbɛ á', # MODIF
 	'info_procedez_par_etape' => 'wàlɔ ɖòkpó ɖòkpó',
 	'info_procedure_maj_version' => 'wàlɔ ɖòkpó ɖòkpó.',
 	'info_ps' => 'P.S',
 	'info_publies' => 'yè sɔ kɛn ná',
 	'info_question_accepter_visiteurs' => 'Nɛ nyí ɖɔ tìtòmɛ mi tɔn bà ɖɔ é mi ná wlí jōnɔ lɛ hɛn ɔ :',
 	'info_question_inscription_nouveaux_redacteurs' => 'Mi yí gbè nú nyɔwántɔ yɔyɔ lɛ à.', # MODIF
-	'info_question_utilisation_moteur_recherche' => 'mi jló ná zán mɔbìbàtɔ supipù tɔn à',
-	'info_qui_edite' => '@nom_auteur_modif@ a travaillé sur ce contenu il y a @date_diff@ minutes', # MODIF
 	'info_racine_site' => 'gblogblojí ɔ sín dɔ',
 	'info_recharger_page' => 'mi lɛ vɔ jlɔ wémà é lɔ ɖò cɛjú ywɛywɛmɛ.',
-	'info_recherche_auteur_a_affiner' => 'xókwìn lɛ súkpɔ ɖí"@cherche_auteur@" ; mi lɛ vɔ bà',
-	'info_recherche_auteur_ok' => 'yè mɔ nyɔwlátɔ gégé"@cherche_auteur@":',
 	'info_recherche_auteur_zero' => 'xókwìn lɛ « @cherche_auteur@ ».',
 	'info_recommencer' => 'Mi lɛ νɔ bɛ.',
 	'info_redacteur_1' => 'Nyɔwlántɔ ',
@@ -351,7 +286,6 @@ $GLOBALS[$GLOBALS['idx_lang']] = array(
 	'info_rubriques' => 'àkpáxwé',
 	'info_rubriques_02' => 'àkpáxwé lɛ',
 	'info_rubriques_trouvees' => 'àkpáxwé lɛ ɖê yè mɔ̂',
-	'info_rubriques_trouvees_dans_texte' => 'àkpáxwé lɛ ɖê yè mɔ̂ (ɖò wěmà lɛ mɛ) ',
 	'info_sans_titre' => 'Xótá ɖè á',
 	'info_selection_chemin_acces' => 'Mi cyán  àlì é byoɔ wégbó ɔ mɛ ɔ :',
 	'info_signatures' => 'Alɔɖówěmámɛ lɛ',
@@ -364,11 +298,9 @@ $GLOBALS[$GLOBALS['idx_lang']] = array(
 	'info_sites_lies_mot' => 'Gblogblojí ɖê cáɖó gbètákɛn ɔ nú ɔ ',
 	'info_sites_proxy' => 'Mi zán  proxy',
 	'info_sites_trouves' => 'gblogblojí ɖê mɔ lɛ',
-	'info_sites_trouves_dans_texte' => 'gblogblojí ɖê mɔ lɛ(ɖò wěmámɛ)',
 	'info_sous_titre' => 'xótákpɛví:',
 	'info_statut_administrateur' => 'Tìtòtɔ',
 	'info_statut_auteur' => 'Nyɔwlán sín tìtòmɛ:', # MODIF
-	'info_statut_efface' => 'súnsún',
 	'info_statut_redacteur' => 'Nyɔwlántɔ',
 	'info_statut_utilisateurs_1' => 'nɔtè kpòhùn',
 	'info_statut_utilisateurs_2' => 'mi cyán nɔtè mɛ̂ ɖò LDAP sín wěmámɛ é nú yé sɔ yéɖé xlɛ ɔ núkɔnnúkɔntɔ̂n..',
@@ -386,7 +318,6 @@ $GLOBALS[$GLOBALS['idx_lang']] = array(
 	'info_tous_articles_en_redaction' => 'Wékpá lɛ kpó  nyí wlánwlántɔ',
 	'info_tous_articles_presents' => 'Wékpá lɛ yè zéɖò àkpáxwé é lɔ̂',
 	'info_tous_les' => 'Yé bî:',
-	'info_tous_redacteurs' => 'nyɔwlántɔ lɛ bí xógbè',
 	'info_tout_site' => 'Gblògblòjí ɔ bí',
 	'info_tout_site2' => 'Yé tìnmɛ wěkpâ ɖó gbè ɖé mɛ á.',
 	'info_tout_site3' => 'Yé tìnmɛ wěkpâ ɖó gbè ɖé mɛ á',
@@ -400,7 +331,6 @@ $GLOBALS[$GLOBALS['idx_lang']] = array(
 	'info_une_rubrique' => 'àkpáxwé,',
 	'info_une_rubrique_02' => 'àkpáxwé',
 	'info_url' => 'URL :',
-	'info_url_site' => 'URL Gblògblòjí ɔ tɔn :',
 	'info_urlref' => 'àlɔwlí :',
 	'info_utilisation_spip' => 'mi síwú jɛ tìtò ɖiɖèxlɛ tɔn zán jí...',
 	'info_visites_par_mois' => 'ɖìdèxlɛ sùn ɖòkpó mɛ tɔn:',
@@ -414,15 +344,12 @@ $GLOBALS[$GLOBALS['idx_lang']] = array(
 	'item_activer_messages_avertissement' => 'mi jɛ sɛn dó jí',
 	'item_administrateur_2' => 'Tìtótɔ ',
 	'item_afficher_calendrier' => 'Mi ɖè kalánɖlyé lɛ xlɛ',
-	'item_autoriser_documents_joints' => 'Mi sɔ wémà dɔɖó wékpá wú',
-	'item_autoriser_documents_joints_rubriques' => 'Mi sɔ wémà dɔɖó àkpáxwé ɔ mɛ',
 	'item_choix_administrateurs' => 'Tìtótɔ lɛ',
 	'item_choix_generation_miniature' => 'Mi tò ɖéxlɛ lɛ cíkícíkí.',
 	'item_choix_non_generation_miniature' => 'Mi mà tò ɖéxlɛ lɛ cíkícíkí.',
 	'item_choix_redacteurs' => 'nyɔwlántɔ lɛ',
 	'item_choix_visiteurs' => 'jónɔ lɛ',
 	'item_creer_fichiers_authent' => 'Gbètáxó lɛ.htpasswd',
-	'item_limiter_recherche' => 'Tò nyíkɔ lɛ',
 	'item_login' => ' nyíkɔ ',
 	'item_mots_cles_association_articles' => 'Wékpá lɛ',
 	'item_mots_cles_association_rubriques' => 'àkpáxwé ɔ ',
@@ -431,34 +358,24 @@ $GLOBALS[$GLOBALS['idx_lang']] = array(
 	'item_non_accepter_inscriptions' => 'yí gbè nú nyíkɔ lɛ ',
 	'item_non_activer_messages_avertissement' => 'mi jɛ sɛn dó jí',
 	'item_non_afficher_calendrier' => 'Mi ɖè kalánɖlyé lɛ xlɛ wo',
-	'item_non_autoriser_documents_joints' => 'Mi sɔ wémà dɔɖó àkpáxwé ɔ mɛ',
-	'item_non_autoriser_documents_joints_rubriques' => 'Mi sɔ wémà dɔɖó àkpáxwé ɔ mɛ',
 	'item_non_creer_fichiers_authent' => 'mi má sɔ bló xótá ô',
-	'item_non_gerer_statistiques' => 'Mi mà Mi bló tìtò lɛ',
-	'item_non_limiter_recherche' => 'mi vlɔn kàn nú bìbà sɔ yí Gblògblòjí bàɖémɛ jí ',
 	'item_non_publier_articles' => 'mi má sɔ xlɛ wékpá lɛ có àzán lɛ ní wâ.',
-	'item_non_utiliser_moteur_recherche' => 'mi má zán mɔ ɔ ',
 	'item_nouvel_auteur' => 'nyɔwlántɔ yɔyɔ',
 	'item_nouvelle_rubrique' => 'àkpáxwé yɔyɔ',
 	'item_oui' => 'ɛ̂',
 	'item_publier_articles' => 'mi zé wékpá é lɔ lɛ sɔ, é ná bò tɛ nyí àzanɖébú.',
 	'item_reponse_article' => 'yígbè nú wékpá',
-	'item_utiliser_moteur_recherche' => 'mi zán xó kléwún lɛ',
 	'item_visiteur' => 'jònɔ',
 
 	// J
 	'jour_non_connu_nc' => 'n.c.',
 
 	// L
-	'lien_ajout_destinataire' => 'mi zé mɛ̂ gɔn é ná yí ɔ zé gɔn ná',
 	'lien_ajouter_auteur' => 'mi zé nyɔwlátɔ  zé gɔn ná',
-	'lien_ajouter_participant' => 'mi zé nyɔwlátɔ  zé gɔn ná',
 	'lien_email' => 'e-mailu',
 	'lien_nom_site' => 'nyíkɔ gblogblojí ɔ tɔn  :',
 	'lien_retirer_auteur' => 'mi ɖè nyɔwlátɔ sín ',
-	'lien_retrait_particpant' => 'mi ɖè nyɔwlátɔ sín ',
 	'lien_site' => 'gblogblojí',
-	'lien_supprimer_rubrique' => 'Sùnsùn àkpáxwé é lɔ',
 	'lien_tout_deplier' => 'mi vlɔn bí',
 	'lien_tout_replier' => 'mi blán bí',
 	'lien_trier_nom' => 'mi cyán nyìkɔmɛ',
@@ -484,6 +401,9 @@ $GLOBALS[$GLOBALS['idx_lang']] = array(
 	// O
 	'onglet_repartition_actuelle' => 'Hwé élɔ nú',
 
+	// R
+	'required' => '[dódó]', # MODIF
+
 	// S
 	'statut_admin_restreint' => '(tìto kléwún)', # MODIF
 
@@ -504,13 +424,10 @@ $GLOBALS[$GLOBALS['idx_lang']] = array(
 	'texte_article_virtuel_reference' => 'wékpá é lɔ.',
 	'texte_aucun_resultat_auteur' => 'xógbè lɛ "@cherche_auteur@"',
 	'texte_auteur_messagerie' => 'nyɔwlántɔ lɛ .',
-	'texte_auteur_messagerie_1' => 'gblogblojí é lɔ nɔ zɔn bɔ mi nɔ sɛ  wɛn ɖó bó nɔ lɛ yí wɛn.',
 	'texte_auteurs' => 'nyɔwlántɔ lɛ ',
 	'texte_choix_base_1' => 'mi sɔ xóxòkplégbàví mi tɔn :',
 	'texte_choix_base_2' => 'mɔ SQL nɔ hɛnxóxòkplégbàví',
 	'texte_choix_base_3' => 'mi cyían ɖê jɛ ɖéwú ɔ:',
-	'texte_commande_vider_tables_indexation' => 'mi cyían ɖê jɛ ɖéwú ɔ.',
-	'texte_compresse_ou_non' => '(E lɔ̂ yé síwú xóklpé)',
 	'texte_compte_element' => '@count@ kwín',
 	'texte_compte_elements' => '@count@ kwín',
 	'texte_connexion_mysql' => 'tòbítùntìto kléwúngbàví ɔ jɛ vɔwɛn é lɔ yé sɛ ɖó ɔ mi kɛnklɛ̂n bó ná lìnlìn mi tɔn ɖé wúSQL, kplékplé yé sɔ ɖó dò wɔ mɛ SQL.', # MODIF
@@ -522,10 +439,8 @@ $GLOBALS[$GLOBALS['idx_lang']] = array(
 	'texte_date_publication_anterieure' => 'AZAN ƉÊ YE SƆ WĚMA SƆ XLƐ Ɔ :',
 	'texte_date_publication_anterieure_nonaffichee' => 'Mi sɔ Azán ɖê yé sɔ wěmà sɔ xlɛ.',
 	'texte_date_publication_article' => 'Mi sɔ Azán ɖê yé sɔ wěmà sɔ xlɛ :',
-	'texte_descriptif_petition' => 'mi tìnmɛ xójíjlá ɔ',
 	'texte_descriptif_rapide' => 'mi tìnmɛ càcàcà',
 	'texte_effacer_base' => 'mi sùnsùn xóxòkplé sùpípù tɔn ',
-	'texte_effacer_donnees_indexation' => 'mi sùnsùn xóxòkplé indɛsù tɔn',
 	'texte_en_cours_validation' => 'wékwín é lɔ ɖò wěmámɛyé mɔ wěmà ɖé ɖò gbè é lɔ mɛ áwékwín ɖê yé mà tùn à lɛ ɔ ɖò vɔvɔmɛ. Zìn yé bó kpɔn àyì é yè b ɖó yèwú ɔ.', # MODIF
 	'texte_enrichir_mise_a_jour' => 'mi síwú zán kwín é lɔ lɛ».',
 	'texte_fichier_authent' => 'xó kléwun lɛ wěmà kléwún ɖé lɛ wɛbɔ yé nɔ zɔn bɔ xó lɛ nɔ yí àtɛjí gànmɛgànmɛmi sɔ xóxòkplégbàví mi tɔn mɔnɔ hɛnmi cyían ɖê jɛ ɖéwú ɔ', # MODIF
@@ -533,19 +448,13 @@ $GLOBALS[$GLOBALS['idx_lang']] = array(
 	'texte_informations_personnelles_2' => 'Nú mi lɛ ján bló bɔ àcɛ mi tɔn ɖò àzɔ wàwɛ tɛgbɛ ɔ mi síwú', # MODIF
 	'texte_introductif_article' => '(Có nú mi ná bɛ xó ɔ.)',
 	'texte_jeu_caractere' => 'vlàvò nú mi gòsínbò dózò nú ɖéxlɛtɔ mi tɔn  mi k pɔn àcɛ winwl tɔn E ɖò àkpáxwé ɔ mɛ Tìtòmɛ ɔ ná mi àcɛ mi ɖé sú tɔn mi Nú mi lɛ ján bló bɔ àcɛ mi tɔn ɖò àzɔ wàwɛ tɛgbɛ ɔ mi síwú(balise <tt>#CHARSET</tt>).',
-	'texte_jeu_caractere_2' => 'vlàvò nú mi gòsínbò dózò nú ɖéxlɛtɔ mi tɔn  mi k pɔn àcɛ winwl tɔn E ɖò àkpáxwé ɔ mɛ Tìtòmɛ ɔ ná mi àcɛ mi ɖé sú tɔn mi Nú mi lɛ ján bló bɔ àcɛ mi tɔn ɖò àzɔ wàwɛ tɛgbɛ ɔ mi síwú',
-	'texte_lien_hypertexte' => '(nɛ nyí ɖɔ wɛn é lɔ kò yí àtɛ ɔ jí ɖá yí ɔ mi xlɛ nɔtɛn  URL.)',
 	'texte_login_ldap_1' => 'vlàvò nú mi gòsínbò dózò nú ɖéxlɛtɔ mi tɔn  mi k pɔn àcɛ winwl tɔn E ɖò àkpáxwé ɔ mɛ Tìtòmɛ ɔ ná mi àcɛ mi ɖé sú tɔn mi Nú mi lɛ ján bló bɔ àcɛ mi tɔn ɖò àzɔ wàwɛ tɛgbɛ ɔ mi síwú',
 	'texte_login_precaution' => 'vlàvò nú mi gòsínbò dózò nú ɖéxlɛtɔ mi tɔn  mi k pɔn àcɛ winwl tɔn E ɖò àkpáxwé ɔ mɛ Tìtòmɛ ɔ ná mi àcɛ mi ɖé sú tɔn mi Nú mi lɛ ján bló bɔ àcɛ mi tɔn ɖò àzɔ wàwɛ tɛgbɛ ɔ mi síwú...',
-	'texte_message_edit' => 'Gbêgbè yé wlán wěmà ɔMi sɔ Azán ɖê yé sɔ wěmà sɔ xlɛàlɔwlí ɖévó lɛ ɖê gòsín gblogblojí é lɔ ján mi tìnmɛ càcàcàxójíjlá ɔmi sɔ ɖidé ɖó wěmà lɛ mɛsùpípù tɔn ',
 	'texte_mise_a_niveau_base_1' => 'wɛn wékpá tɔn yé sɔ xlɛàlɔwlí yɔyɔ lɛ ná jɛ àtɛ ɔ jími ná sɔ yé xlɛ àzɔn ɖókpó',
 	'texte_modifier_article' => 'ɖyɔ wékpá ɔ:',
-	'texte_moteur_recherche_active' => 'vlàvò nú mi gòsínbò dózò nú ɖéxlɛtɔ mi tɔn  mi k pɔn àcɛ winwl tɔn E ɖò àkpáxwé ɔ mɛ Tìtòmɛ ɔ ná mi àcɛ mi ɖé sú tɔn mi Nú mi lɛ ján bló bɔ àcɛ mi tɔn ɖò àzɔ wàwɛ tɛgbɛ ɔ mi síwúCó nú mi ná bɛ xó ɔ nɛ nyí ɖɔ wɛn é lɔ kò yí àtɛ ɔ jí ɖá yí ɔ mi xlɛ nɔtɛn àlɔwlí yɔyɔ lɛ ná jɛ àtɛ ɔ jími ná sɔ yé xlɛ àzɔn ɖókpó',
-	'texte_moteur_recherche_non_active' => 'mɔ̂ ɖò àzɔ wà wɛ á.',
 	'texte_multilinguisme' => 'vlàvò nú mi gòsínbò dózò nú ɖéxlɛtɔ mi tɔn  mi k pɔn àcɛ winwl tɔn E ɖò àkpáxwé ɔ mɛ Tìtòmɛ ɔ ná mi àcɛ mi ɖé sú tɔn mi Nú mi lɛ ján bló bɔ àcɛ mi tɔn ɖò àzɔ wàwɛ tɛgbɛ ɔ mi síwúCó nú mi ná bɛ xó ɔ nɛ nyí ɖɔ wɛn é lɔ kò yí àtɛ ɔ jí ɖá yí ɔ mi xlɛ nɔtɛn ', # MODIF
 	'texte_multilinguisme_trad' => 'wɛn wékpá tɔn yé sɔ xlɛmi jláɖyɔ wékpá ɔmɔ̂ ɖò àzɔ wà wɛ á.', # MODIF
 	'texte_non_compresse' => 'xókplé(mɔ mi tɔn sìwú yí wàlɔ é nɛ lɛ á)',
-	'texte_nouveau_message' => 'wɛn yɔyɔ',
 	'texte_nouvelle_version_spip_1' => 'wàlɔ sùpípù ɖévó wɛ mi sɔ.',
 	'texte_nouvelle_version_spip_2' => 'Có nú mi ná bɛ xó ɔ nɛ nyí ɖɔ wɛn é lɔ kò yí àtɛ ɔ jí ɖá yí ɔ mi xlɛ nɔtɛn àlɔwlí yɔyɔ lɛ ná jɛ àtɛ ɔ jími ná sɔ yé xlɛ àzɔn ɖókpówɛn wékpá tɔn yé sɔ xlɛmi jláɖyɔ wékpá ɔmɔ̂ ɖò àzɔ wà wɛ áxókplémɔ mi tɔn sìwú yí wàlɔ é nɛ lɛ ámi hɛn mi ná zán wàlɔ càcàcà ɔ ámi ɖé sú mi bló jɛ xá myɔ  wékwín yɔyɔ...)', # MODIF
 	'texte_operation_echec' => 'mi lɛ vɔ yí wékpá ɖé wá ɔ jí mi lɛ vɔ kpɔn xó é xwétɔ̂ sɛɖó ɔ.',
@@ -557,7 +466,6 @@ $GLOBALS[$GLOBALS['idx_lang']] = array(
 	'texte_publication_articles_post_dates' => 'Wàlɔtɛ sùpípù kàsíwú bló wémà ɖê jló ná sɔɖó àtɛ jí hwè ɖé vó nú ɔ?',
 	'texte_rappel_selection_champs' => '[Mi má wɔn bó sɔ kɛn nú tɛnmɛ ó.]',
 	'texte_recalcul_page' => 'Mi wɔn wékpá ɖòkpó sín àkɔwúntà bló mi ɖè.Mi lɛ vɔ bó zín .',
-	'texte_recapitiule_liste_documents' => 'wékpá nɔ bló àkɔwúntà wémà é ɖò àkpéxwé lɛ̂ mɛ.',
 	'texte_recuperer_base' => 'mi bló xóxòkplé ɔ ɖó',
 	'texte_reference_mais_redirige' => 'wémà é lɔ sùpípù mɛ wɛ é mɔ àcɛ ɖé àmɔ nɔtɛn ɖévɔ mɛ wɛ é xwè',
 	'texte_requetes_echouent' => 'Tìtòmɛ Sùpípù tɔn sɔ gbɔn uZine jíEtɛ wɛ nyí sùpípùWěmàxòkplé sùpípù tɔntɛmɛbìbá  - blòɖóTìtòmɛ é nɔ zɔn bɔ yè nɔ ɖè nɛ ɖò gblogblòjí E zɛ kwín àtɔn  wúàcɛ yé nɔ ná nɔ jɛɖóNú mi wlán wěmà mi tɔn fó ɔ mi síwú sɔɖó àtɛ jí Wàlɔtɛ sùpípù kàsíwú bló wémà ɖê jló ná sɔɖó àtɛ jí hwè ɖé vó nú ɔMi wɔn wékpá ɖòkpó sín àkɔwúntà bló mi ɖè.Mi lɛ vɔ bó zín bó sɔ kɛn nú tɛnmɛ ówékpá nɔ bló àkɔwúntà wémà é ɖò àkpéxwé lɛ̂ mɛ', # MODIF
@@ -570,7 +478,6 @@ $GLOBALS[$GLOBALS['idx_lang']] = array(
 	'texte_suppression_fichiers' => 'tɛmɛbìbá  - blòɖóTìtòmɛ é nɔ zɔn bɔ yè nɔ ɖè nɛ ɖò gblogblòjí E zɛ kwín àtɔn  wúàcɛ yé nɔ ná nɔ jɛɖóNú mi wlán wěmà mi tɔn fó ɔ mi síwú sɔɖó àtɛ jí Wàlɔtɛ sùpípù kàsíwú bló wémà ɖê jló ná sɔɖó àtɛ jí hwè ɖé vó nú ɔMi wɔn wékpá ɖòkpó sín àkɔwúntà bló mi ɖè.Mi lɛ vɔ bó zín bó sɔ kɛn nú tɛnmɛ ó',
 	'texte_sur_titre' => 'xótájí',
 	'texte_table_ok' => 'wàlɔ̂ sɔ gbè.',
-	'texte_tables_indexation_vides' => 'wàlɔ̂ lɛ jɛ vɔ.',
 	'texte_tentative_recuperation' => 'tɛnkpɔn bíblóɖó tɔn',
 	'texte_tenter_reparation' => 'tɛnkpɔn bíblóɖó tɔn',
 	'texte_test_proxy' => 'tɛnkpɔn  proxy,E zɛ kwín àtɔn  wúàcɛ yé nɔ ná nɔ jɛɖóNú mi wlán wěmà mi tɔn fó ɔ mi síwú sɔɖó àtɛ jí  .',
@@ -578,13 +485,8 @@ $GLOBALS[$GLOBALS['idx_lang']] = array(
 	'texte_titre_obligatoire' => 'xótá[dódó]',
 	'texte_travail_article' => '@nom_auteur_modif@ é wàzɔ ɖó wékpá é lɔ wú @date_diff@ cɛjú',
 	'texte_travail_collaboratif' => 'Sùpípù ɔ tìtómɛ nù jíjlá tɔn ɖê minirézo kéjé bó lɛ vlɔnkán nú bíbló gblògblòjí uZine tɔn ɔ. Mì sɔ kɛ mí ɖò àcɛ wàlɔ GPl tɔn mɛ. Mī zé bò zán bó dó bló gblògblòjí lɛ̂ ná : é síwú nyí mì tɔn ɖé sú kàbí gbɛtá ɖé tɔn, kàbí tòxóɖɔgbɛ ɖé tɔn, àló àjɔwíwá wú.Gblògblòjí é lɔ̂, é wɛ nyí  Wěmàxòkplé sùpípù tɔn ɖò tájí. Mí ná lɛ mɔ àlɔwlí gégé ɖê ná ɖɔn mî yì gblògblòjí ɖê jí kplékplé lɛ̂ nɔ tîn ɖè ɔ ',
-	'texte_trop_resultats_auteurs' => 'xógbè súkpɔ "@cherche_auteur@" ; mi lɛ vɔ bà',
-	'texte_unpack' => 'mi ɖon wàlɔ yɔyɔ wá',
-	'texte_utilisation_moteur_syndiques' => 'Sùpípù ɔ tìtómɛ nù jíjlá tɔn ɖê minirézo kéjé bó lɛ vlɔnkán nú bíbló gblògblòjí uZine tɔn ɔ. Mì sɔ kɛ mí ɖò àcɛ wàlɔ GPl tɔn mɛ. Mī zé bò zán bó dó bló gblògblòjí lɛ̂ ná : é síwú nyí mì tɔn ɖé sú kàbí gbɛtá ɖé tɔn, kàbí tòxóɖɔgbɛ ɖé tɔn, àló àjɔwíwá wú.Gblògblòjí é lɔ̂, é wɛ nyí  Wěmàxòkplé sùpípù tɔn ɖò tájí. Mí ná lɛ mɔ àlɔwlí gégé ɖê ná ɖɔn mî yì gblògblòjí ɖê jí kplékplé lɛ̂ nɔ tîn ɖè ɔ Tìtòmɛ Sùpípù tɔn sɔ gbɔn uZine jíEtɛ wɛ nyí sùpípùWěmàxòkplé sùpípù tɔntɛmɛbìbá  - blòɖóTìtòmɛ é nɔ zɔn bɔ yè nɔ ɖè nɛ ɖò gblogblòjí E zɛ kwín àtɔn  wúàcɛ yé nɔ ná nɔ jɛɖó', # MODIF
-	'texte_utilisation_moteur_syndiques_2' => 'wàlɔ é lɔ nɔ zɔn bɔ sùpípù nɔ .',
 	'texte_vide' => 'jɛ vɔ',
 	'texte_vider_cache' => 'gbàv i ɔ jɛ vɔ',
-	'titre_admin_effacer' => 'wàlɔ zɔ',
 	'titre_admin_tech' => 'wàlɔ zɔ',
 	'titre_admin_vider' => 'wàlɔ zɔ',
 	'titre_cadre_afficher_article' => 'xlɛ wékpá lɛ',
@@ -604,32 +506,19 @@ $GLOBALS[$GLOBALS['idx_lang']] = array(
 	'titre_naviguer_dans_le_site' => 'kéjénúmɛ ɖò gblogblo ɔ jí ...',
 	'titre_nouvelle_rubrique' => 'àkpáxwé yɔyɔ',
 	'titre_numero_rubrique' => 'númɛló àkpáxwé tɔn :',
-	'titre_page_admin_effacer' => 'bìblóɖó: sùnsùn xóxòkplé ɔ',
 	'titre_page_articles_edit' => 'ɖyɔ : @titre@',
 	'titre_page_articles_page' => 'wékpá lɛ',
 	'titre_page_articles_tous' => 'gblogblojí  ɔ  bí ',
-	'titre_page_auteurs' => 'Jónɔ lɛ',
 	'titre_page_calendrier' => 'kàlanɖlyé@nom_mois@ @annee@',
 	'titre_page_config_contenu' => 'Tìtò gblogblojí  ɔ  tɔn',
-	'titre_page_config_fonctions' => 'Tìtò gblogblojí  ɔ  tɔn',
-	'titre_page_configuration' => 'Tìtò gblogblojí  ɔ  tɔn',
-	'titre_page_controle_petition' => 'Bɔ núkún nú xàjíjlá lɛ',
 	'titre_page_delete_all' => 'Sùnsùn bó gbìdí bí',
-	'titre_page_documents_liste' => 'wěmà àkpáxwé lɛ tɔn ',
-	'titre_page_index' => 'tɛnkánɖóvò',
-	'titre_page_message_edit' => 'wlán wɛn ',
-	'titre_page_messagerie' => 'wɛngbàví',
 	'titre_page_recherche' => 'xógbè é tɔn ɖò nú bíbà ɔ mɛ ɔ @recherche@',
 	'titre_page_statistiques_referers' => 'àkɔŋtá ',
 	'titre_page_upgrade' => 'mi vɛ jɔwú nú sùpípù ɔ ',
 	'titre_publication_articles_post_dates' => 'ɖéxlɛ wékpá é ná wà lɛ tɔn',
-	'titre_referencer_site' => 'àcɛ yíyí ɖò gblogblojí :',
-	'titre_rendez_vous' => 'gàmɛ ɖóɖó :',
 	'titre_reparation' => 'Bìblòɖó',
 	'titre_suivi_petition' => 'Bɔ núkún ɖó xójíjlá lɛ jí',
-	'trad_article_inexistant' => 'númɛló ɖé sɔgbè ɖó wépká é lɔ á.',
 	'trad_article_traduction' => 'wàlɔ wépká é lɔ tɔn lɛ bí',
-	'trad_deja_traduit' => 'wépká é lɔ kò nyí tìnmɛ wékpá ɖévó tɔn.',
 	'trad_delier' => 'yé má cá wépká é lɔ ɖó tìnmɛ é lɔ wú ó', # MODIF
 	'trad_lier' => 'kò nyí tìnmɛ wékpá ɖévó tɔn :',
 	'trad_new' => 'Lɛ wlán tìnmɛ wékpá ɖévó tɔn' # MODIF
