@@ -3,7 +3,9 @@
 // extrait automatiquement de http://trad.spip.net/tradlang_module/ecrire_?lang_cible=he
 // ** ne pas modifier le fichier **
 
-if (!defined('_ECRIRE_INC_VERSION')) return;
+if (!defined('_ECRIRE_INC_VERSION')) {
+	return;
+}
 
 $GLOBALS[$GLOBALS['idx_lang']] = array(
 
@@ -163,8 +165,6 @@ $GLOBALS[$GLOBALS['idx_lang']] = array(
 	'info_1_article' => 'מאמר 1',
 	'info_activer_cookie' => 'אתה יכול להפעיל <b> עוגיית התכתבות</b>, אשר יאפשר לך
  לעבור בקלות מן האתר הציבורי לאתר הפרטי.',
-	'info_admin_gere_rubriques' => 'המנהל הזה מנהל את המדורים הבאים:',
-	'info_admin_gere_toutes_rubriques' => 'המנהל הזה מנהל את <b>כל המדורים</b>.', # MODIF
 	'info_administrateur' => 'מנהל',
 	'info_administrateur_1' => 'מנהל',
 	'info_administrateur_2' => 'של האתר (<i>use with caution</i>)',
@@ -294,7 +294,7 @@ $GLOBALS[$GLOBALS['idx_lang']] = array(
 	'info_post_scriptum' => 'פוסטסקריפט',
 	'info_post_scriptum_2' => ':פוסטסקריפט',
 	'info_pour' => 'ל',
-	'info_preview_texte' => 'אפשר לבקר את האתר בהקשפה מוקדמת כאילו כל המאמרים והמבזקים התפרסמו (עם לפחות הסטטוס "מוצע"). האם אתה רוצה להגיש אפשרות זו למנהלים בלבד, לכל מחברים או לכולם?',
+	'info_preview_texte' => 'אפשר לבקר את האתר בהקשפה מוקדמת כאילו כל המאמרים והמבזקים התפרסמו (עם לפחות הסטטוס "מוצע"). האם אתה רוצה להגיש אפשרות זו למנהלים בלבד, לכל מחברים או לכולם?', # MODIF
 	'info_procedez_par_etape' => 'אנא המשך צעד אחר צעד',
 	'info_ps' => 'נ.ב',
 	'info_publier' => 'לפרסם',
