@@ -3,7 +3,9 @@
 // extrait automatiquement de http://trad.spip.net/tradlang_module/ecrire_?lang_cible=id
 // ** ne pas modifier le fichier **
 
-if (!defined('_ECRIRE_INC_VERSION')) return;
+if (!defined('_ECRIRE_INC_VERSION')) {
+	return;
+}
 
 $GLOBALS[$GLOBALS['idx_lang']] = array(
 
@@ -23,75 +25,43 @@ $GLOBALS[$GLOBALS['idx_lang']] = array(
 	'avis_connexion_ldap_echec_2' => 'Kembali ke halaman sebelumnya, dan verifikasi informasi yang anda telah berikan.',
 	'avis_connexion_ldap_echec_3' => 'Alternatif lainnya, jangan gunakan dukungan LDAP untuk mengimpor pengguna.',
 	'avis_deplacement_rubrique' => 'Peringatan! Bagian ini mengandung @contient_breves@ berita@scb@: jika anda memindahkannya, silakan cek kotak ini untuk konfirmasi.',
-	'avis_destinataire_obligatoire' => 'Anda harus memilih satu orang penerima sebelum mengirimkan pesan ini.',
 	'avis_erreur_connexion_mysql' => 'Kesalahan koneksi SQL',
-	'avis_erreur_version_archive' => '<b>Peringatan! Berkas @archive@ berkaitan dengan
-    sebuah versi SPIP yang lain dengan yang anda
-    miliki.</b> Anda akan mengalami sejumlah
-    kesulitan: risiko untuk merusak database anda,
-    kejanggalan fungsional situs anda, dll. Jangan
-    kirim permohonan impor ini.<p>Untuk informasi
-    lebih lanjut, silakan lihat <a href="@spipnet@">
-                                dokumentasi SPIP</a>.', # MODIF
 	'avis_espace_interdit' => '<b>Area terlarang</b><p>SPIP telah diinstal.',
 	'avis_lecture_noms_bases_1' => 'Sistem instalasi tidak dapat membaca nama-nama database yang terinstal.',
 	'avis_lecture_noms_bases_2' => 'Bisa jadi tidak ada database yang tersedia, atau fitur yang mengizinkan penampilan daftar database dinonaktifkan
   dengan alasan keamanan (yang sering ditemui pada banyak hosting).',
 	'avis_lecture_noms_bases_3' => 'Jika alternatif kedua benar, sangat mungkin sebuah database dinamai sama dengan log masuk anda:',
-	'avis_non_acces_message' => 'Anda tidak memiliki akses ke pesan ini.',
 	'avis_non_acces_page' => 'Anda tidak memiliki akses ke halaman ini.',
 	'avis_operation_echec' => 'Operasi gagal.',
 	'avis_operation_impossible' => 'Operasi tidak mungkin dijalankn',
-	'avis_probleme_archive' => 'Kesalahan membaca pada berkas @archive@',
 	'avis_suppression_base' => 'PERINGATAN, data yang dihapus tidak dapat dikembalikan lagi',
-	'avis_version_mysql' => 'Versi SQL anda (@version_mysql@) tidak mengizinkan perbaikan otomatis tabel-tabel database.',
 
 	// B
 	'bouton_acces_ldap' => 'Tambah sebuah akses ke LDAP >>',
 	'bouton_ajouter' => 'Tambah',
-	'bouton_ajouter_participant' => 'TAMBAH SEORANG PESERTA:',
-	'bouton_annonce' => 'PENGUMUMAN',
 	'bouton_annuler' => 'Batal',
-	'bouton_checkbox_envoi_message' => 'kemungkinan untuk mengirimkan sebuah pesan',
-	'bouton_checkbox_indiquer_site' => 'Anda harus mengisi nama untuk sebuah situs web',
-	'bouton_checkbox_signature_unique_email' => 'hanya satu tanda tangan per alamat e-mail',
-	'bouton_checkbox_signature_unique_site' => 'hanya satu tanda tangan per situs web',
 	'bouton_demande_publication' => 'Permohonan publikasi artikel ini',
 	'bouton_desactive_tout' => 'Non aktifkan semua',
-	'bouton_effacer_index' => 'Hapus indeksasi',
 	'bouton_effacer_tout' => 'Hapus SEMUA',
-	'bouton_envoi_message_02' => 'KIRIM SEBUAH PESAN',
 	'bouton_envoyer_message' => 'Pesan terakhir: kirim',
 	'bouton_modifier' => 'Modifikasi',
-	'bouton_pense_bete' => 'MEMO PRIBADI',
-	'bouton_radio_activer_messagerie' => 'Aktifkan sistem pesan intern',
-	'bouton_radio_activer_messagerie_interne' => 'Aktifkan sistem pesan intern',
-	'bouton_radio_activer_petition' => 'Aktifkan petisi',
 	'bouton_radio_afficher' => 'Tampilkan',
 	'bouton_radio_apparaitre_liste_redacteurs_connectes' => 'Muncul di daftar editor-editor yang terkoneksi',
-	'bouton_radio_desactiver_messagerie' => 'Non aktifkan sistem pesan',
 	'bouton_radio_envoi_annonces_adresse' => 'Kirim pengumuman ke alamat:',
 	'bouton_radio_envoi_liste_nouveautes' => 'Kirim daftar berita terbaru',
 	'bouton_radio_non_apparaitre_liste_redacteurs_connectes' => 'Jangan muncul di daftar editor-editor yang terkoneksi',
 	'bouton_radio_non_envoi_annonces_editoriales' => 'Jangan kirim pengumuman editorial apapun juga',
-	'bouton_radio_pas_petition' => 'Tidak ada petisi',
-	'bouton_radio_petition_activee' => 'Petisi diaktifkan',
-	'bouton_radio_supprimer_petition' => 'Hapus petisi',
 	'bouton_redirection' => 'MENGALIHKAN TUJUAN	',
 	'bouton_relancer_installation' => 'Menjalankan instalasi kembali',
 	'bouton_suivant' => 'Selanjutnya',
 	'bouton_tenter_recuperation' => 'Usaha perbaikan',
 	'bouton_test_proxy' => 'Tes proxy',
 	'bouton_vider_cache' => 'Kosongkan cache',
-	'bouton_voir_message' => 'Lihat pesan sebelum divalidasi',
 
 	// C
-	'cache_mode_compresse' => 'Berkas-berkas cache disimpan dalam bentuk kompresi.',
-	'cache_mode_non_compresse' => 'Berkas-berkas cache ditulis dalam bentuk tidak terkompresi.',
 	'cache_modifiable_webmestre' => 'Parameter ini dapat dimodifikasi oleh webmaster.',
 	'calendrier_synchro' => 'Jika anda menggunakan aplikasi kalender yang kompatibel dengan <b>iCal</b>, anda dapat mensinkronisasikannya dengan informasi situs ini.',
 	'connexion_ldap' => 'Koneksi:',
-	'copier_en_local' => 'Kopi ke situs lokal',
 
 	// D
 	'date_mot_heures' => 'H',
@@ -115,7 +85,6 @@ $GLOBALS[$GLOBALS['idx_lang']] = array(
 	'entree_login' => 'Log masuk anda',
 	'entree_login_connexion_1' => 'Log masuk koneksi',
 	'entree_login_connexion_2' => '(Kadang kala sesuai dengan log masuk akses FTP anda dan bisa jadi juga dibiarkan tidak terisi)',
-	'entree_login_ldap' => 'Log masuk awal LDAP',
 	'entree_mot_passe' => 'Kata sandi anda',
 	'entree_mot_passe_1' => 'Kata sandi koneksi',
 	'entree_mot_passe_2' => '(Kadang kala sesuai dengan kata sandi akses FTP anda dan bisa jadi juga dibiarkan tidak terisi)',
@@ -142,7 +111,7 @@ $GLOBALS[$GLOBALS['idx_lang']] = array(
 	'ical_info2' => 'Untuk informasi lebih lanjut, jangan segan-segan untuk mengunjungi <a href="@spipnet@">dokumentasi SPIP</a>.', # MODIF
 	'ical_info_calendrier' => 'Dua kalender berada di tangan anda siap untuk dipakai. Yang pertama adalah peta situs yang menampilkan semua artikel yang dipublikasi. Yang kedua berisikan pengumuman editorial sekaligus pesan-pesan pribadi terbaru anda: semuanya dapat disimpan berkat kunci pribadi yang bisa anda modifikasi setiap saat dengan jalan memperbaharui kata sandi.',
 	'ical_methode_http' => 'Mengunduh',
-	'ical_methode_webcal' => 'Sinkronisasi (webcal://)',
+	'ical_methode_webcal' => 'Sinkronisasi (webcal://)', # MODIF
 	'ical_texte_js' => 'Sebuah kode javascript mengizinkan anda untuk menampilkan secara mudah dan di setiap situs yang anda miliki, semua artikel terbaru yang dipublikasikan di situs ini.',
 	'ical_texte_prive' => 'Kalender ini, yang sifatnya pribadi sekali, menginformasikan anda seluruh aktivitas editorial pribadi situs ini (tugas-tugas, janji-janji pribadi, artikel-artikel dan berita-berita yang dikirimkan...).',
 	'ical_texte_public' => 'Kalender ini memperbolehkan anda mengikuti aktivitas umum situs ini (artikel-artikel dan berita-berita yang dipublikasi).',
@@ -159,9 +128,7 @@ $GLOBALS[$GLOBALS['idx_lang']] = array(
 	'icone_creer_auteur' => 'Buat seorang penulis baru dan asosiasikan dia dengan artikel ini',
 	'icone_creer_mot_cle' => 'Buat sebuah kata kunci baru dan tautkan ia ke artikel ini',
 	'icone_creer_rubrique_2' => 'Buat sebuah bagian baru',
-	'icone_envoyer_message' => 'Kirim pesan ini',
 	'icone_modifier_article' => 'Modifikasi artikel ini',
-	'icone_modifier_message' => 'Modifikasi pesan ini',
 	'icone_modifier_rubrique' => 'Modifikasi bagian ini',
 	'icone_retour' => 'Kembali',
 	'icone_retour_article' => 'Kembali ke artikel',
@@ -171,11 +138,8 @@ $GLOBALS[$GLOBALS['idx_lang']] = array(
 	'icone_valider_signature' => 'Validasi tanda tangan ini',
 	'image_administrer_rubrique' => 'Anda dapat mengelola bagian ini',
 	'info_1_article' => '1 artikel',
-	'info_1_site' => '1 situs',
 	'info_activer_cookie' => 'Anda apat mengaktifkan <b>cookie administrasi</b>, yang memperbolehkan anda
  untuk berpindah-pindah dengan mudah antara situs umum dan area pribadi.',
-	'info_admin_gere_rubriques' => 'Administrator ini mengelola bagian-bagian berikut:',
-	'info_admin_gere_toutes_rubriques' => 'Administrator ini mengelola <b>semua bagian</b>.', # MODIF
 	'info_administrateur' => 'Administrator',
 	'info_administrateur_1' => 'Administrator',
 	'info_administrateur_2' => 'situs (<i>gunakan dengan penuh kehati-hatian</i>)',
@@ -185,16 +149,13 @@ $GLOBALS[$GLOBALS['idx_lang']] = array(
 	'info_administrer_rubrique' => 'Anda dapat mengelola bagian ini',
 	'info_adresse' => 'ke alamat:',
 	'info_adresse_url' => 'URL situs umum anda',
-	'info_afficher_visites' => 'Tampilkan kunjungan untuk:',
 	'info_aide_en_ligne' => 'Bantuan Online SPIP',
 	'info_ajout_image' => 'Ketika anda menambahkan gambar sebagai lampiran pada sebuah artikel,
 		SPIP dapat secara otomatis membuat gambar kecil dari
 		gambar yang dimasukkan. Ini bermanfaat ,sebagai contoh, untuk membuat
 		sebuah galeri gambar atau portfolio.',
-	'info_ajout_participant' => 'Peserta berikut telah ditambahkan:',
 	'info_ajouter_rubrique' => 'Tambah sebuah bagian untuk dikelola:',
 	'info_annonce_nouveautes' => 'Pengumuman-pengumuman berita terbaru',
-	'info_anterieur' => 'sebelumnya',
 	'info_article' => 'artikel',
 	'info_article_2' => 'artikel',
 	'info_article_a_paraitre' => 'Artikel-artikel bertanggal yang akan dipublikasikan',
@@ -202,10 +163,8 @@ $GLOBALS[$GLOBALS['idx_lang']] = array(
 	'info_articles_2' => 'Artikel',
 	'info_articles_auteur' => 'Artikel-artikel penulis ini',
 	'info_articles_trouves' => 'Artikel ditemukan',
-	'info_articles_trouves_dans_texte' => 'Artikel ditemukan (dalam teks)',
 	'info_attente_validation' => 'Validasi tertunda artikel-artikel anda',
 	'info_aujourdhui' => 'hari ini:',
-	'info_auteur_message' => 'PENGIRIM PESAN:',
 	'info_auteurs' => 'Penulis',
 	'info_auteurs_par_tri' => 'Penulis@partri@',
 	'info_auteurs_trouves' => 'Penulis ditemukan',
@@ -238,15 +197,12 @@ $GLOBALS[$GLOBALS['idx_lang']] = array(
 	'info_date_publication_anterieure' => 'Tanggal publikasi sebelumnya:',
 	'info_date_referencement' => 'TANGGAL REFERENSI SITUS INI:',
 	'info_derniere_etape' => 'Langkah terakhir: <b>Selesai!',
-	'info_derniers_articles_publies' => 'Artikel-artikel terakhir anda yang dipublikasi',
-	'info_desactiver_messagerie_personnelle' => 'Anda dapat mengaktifkan atau menonaktifkan sistem pesan pribadi anda di situs ini.',
 	'info_descriptif' => 'Deskripsi:',
 	'info_discussion_cours' => 'Diskusi-diskusi yang sedang berlangsung',
 	'info_ecrire_article' => 'Sebelum dapat menulis artikel, anda harus membuat paling tidak satu bagian.',
 	'info_email_envoi' => 'Alamat e-mail pengirim (opsional)',
 	'info_email_envoi_txt' => 'Masukkan alamat e-mail pengirim yang digunakan untuk mengirim e-mail (secara standar, alamat penerima digunakan sebagai alamat pengirim) :',
 	'info_email_webmestre' => 'Alamat e-mail webmaster (opsional)', # MODIF
-	'info_entrer_code_alphabet' => 'Masukkan kode set karakter yang akan digunakan:',
 	'info_envoi_email_automatique' => 'Pengiriman otomatis',
 	'info_envoyer_maintenant' => 'Kirim sekarang',
 	'info_etape_suivante' => 'Lanjut ke langkah berikutnya',
@@ -258,28 +214,20 @@ $GLOBALS[$GLOBALS['idx_lang']] = array(
   sebagai contoh permohonan publikasi dan validasi artikel.',
 	'info_fichiers_authent' => 'Berkas ototentikasi ".htpasswd"',
 	'info_forums_abo_invites' => 'Situs anda berisikan forum-forum berlangganan; pengunjung dapat mendaftarkan diri pada forum-forum tersebut di situs umum.',
-	'info_gauche_admin_effacer' => '<b>Hanya administrator yang memiliki akses ke halaman ini.</b><p> Halaman ini memberikan akses ke berbagai tugas pemeliharaan teknis. Beberapa di antaranya memerlukan proses ototentikasi tersendiri yang membutuhkan akses FTP ke situs web.</p>', # MODIF
 	'info_gauche_admin_tech' => '<b>Hanya administrator yang memiliki akses ke halaman ini.</b><p> Halaman ini memberikan akses ke berbagai tugas pemeliharaan teknis. Beberapa di antaranya memerlukan proses ototentikasi tersendiri yang membutuhkan akses FTP ke situs web.</p>', # MODIF
 	'info_gauche_admin_vider' => '<b>Hanya administrator yang memiliki akses ke halaman ini.</b><p> Halaman ini memberikan akses ke berbagai tugas pemeliharaan teknis. Beberapa di antaranya memerlukan proses ototentikasi tersendiri yang membutuhkan akses FTP ke situs web.</p>', # MODIF
 	'info_gauche_auteurs' => 'Anda akan menemukan seluruh penulis situs di sini.
  Status dari setiap penulis ditunjukkan oleh warna icon (administrator = hijau; editor = kuning).',
 	'info_gauche_auteurs_exterieurs' => 'Penulis eksternal, tanpa akses ke situs, ditunjukkan oleh icon biru; penulis yang dihapus oleh icon warna keranjang sampah.', # MODIF
 	'info_gauche_messagerie' => 'Sistem pesan mengizinkan anda bertukar pesan dengan sesama editor, untuk menyimpan memo (untuk keperluan pribadi anda) atau untuk menampilkan pengumuman di halaman depan area pribadi (jika anda seorang administrator).',
-	'info_gauche_numero_auteur' => 'NOMOR PENULIS:',
 	'info_gauche_statistiques_referers' => 'Halaman ini menampilkan daftar <i>pereferensi</I>, yakni situs-situs yang memuat tautan ke situs anda, hanya untuk kemarin dan hari ini: sesungguhnya daftar ini diperbaharui setiap 24 jam.',
 	'info_gauche_visiteurs_enregistres' => 'Anda akan menemukan di sini para pengunjung
 	terdaftar di area umum situs (forum-forum berlangganan).',
 	'info_generation_miniatures_images' => 'Membuat gambar-gambar kecil',
-	'info_gerer_trad' => 'Aktifkan tautan penerjemahan?',
 	'info_hebergeur_desactiver_envoi_email' => 'Sejumlah hosting menonaktifkan pengiriman e-mail
   otomatis di server mereka. Dalam hal ini fitur-fitur SPIP berikut tidak
   dapat diimplementasikan.',
 	'info_hier' => 'kemarin:',
-	'info_historique_activer' => 'Aktifkan pelacakan revisi',
-	'info_historique_affiche' => 'Tampilkan versi ini',
-	'info_historique_comparaison' => 'bandingkan',
-	'info_historique_desactiver' => 'Non aktifkan pelacakan revisi',
-	'info_historique_texte' => 'Pelacakan revisi mengizinkan anda untuk melihat perubahan dan penambahan yang dibuat pada sebuah artikel dan menampilkan perbedaan di antara versi-versi yang ada.',
 	'info_identification_publique' => 'Identitas umum anda...',
 	'info_image_process' => 'Pilih metode terbaik untuk membuat gambar kecil dengan mengklik gambar yang terkait.',
 	'info_image_process2' => '<b>Catatan:</b> <i>Jika anda tidak dapat melihat gambar, berarti server anda tidak dikonfigurasi untuk menggunakan peralatan yang ada. Jika anda ingin menggunakan fitur-fitur ini, hubungi bagian teknis penyedia hosting anda dan minta ekstensi «GD» atau «Imagick» diinstal.</i>', # MODIF
@@ -297,8 +245,6 @@ $GLOBALS[$GLOBALS['idx_lang']] = array(
 	'info_login_trop_court' => 'Log masuk terlalu pendek.',
 	'info_maximum' => 'maksimum:',
 	'info_meme_rubrique' => 'Dalam bagian yang sama',
-	'info_message' => 'Pesan dari',
-	'info_message_efface' => 'PESAN DIHAPUS',
 	'info_message_en_redaction' => 'Pesan-pesan anda dalam proses',
 	'info_message_technique' => 'Pesan teknis:',
 	'info_messagerie_interne' => 'Sistem pesan internal',
@@ -311,20 +257,15 @@ $GLOBALS[$GLOBALS['idx_lang']] = array(
 	'info_modifier_rubrique' => 'Modifikasi bagian:',
 	'info_modifier_titre' => 'Modifikasi: @titre@',
 	'info_mon_site_spip' => 'Situs SPIP saya',
-	'info_mot_sans_groupe' => '(Kata-kata kunci tanpa kelompok...)',
-	'info_moteur_recherche' => 'Mesin pencari terintegrasi',
 	'info_moyenne' => 'rata-rata:',
-	'info_multi_articles' => 'Aktifkan menu bahasa untuk artikel?',
 	'info_multi_cet_article' => 'Bahasa artikel ini:',
 	'info_multi_langues_choisies' => 'Silakan pilih di bawah bahasa yang tersedia untuk editor situs anda.
   Bahasa-bahasa yang telah digunakan oleh situs anda (di daftar paling atas) tidak dapat dinonaktifkan.',
-	'info_multi_rubriques' => 'Aktifkan menu bahasa untuk bagian?',
 	'info_multi_secteurs' => '... hanya untuk bagian-bagian yang berlokasi di root?',
 	'info_nom' => 'Nama',
 	'info_nom_destinataire' => 'Nama penerima',
 	'info_nom_site' => 'Nama situs anda',
 	'info_nombre_articles' => '@nb_articles@ artikel,',
-	'info_nombre_partcipants' => 'PESERTA DISKUSI:',
 	'info_nombre_rubriques' => '@nb_rubriques@ bagian,',
 	'info_nombre_sites' => '@nb_sites@ situs,',
 	'info_non_deplacer' => 'Jangan pindahkan...',
@@ -334,17 +275,13 @@ $GLOBALS[$GLOBALS['idx_lang']] = array(
 	'info_non_modifiable' => 'tidak dapat dimodifikasi',
 	'info_non_suppression_mot_cle' => 'Saya tidak ingin menghapus kata kunci ini.',
 	'info_notes' => 'Catatan kaki',
-	'info_nouveaux_message' => 'Pesan-pesan baru',
 	'info_nouvel_article' => 'Artikel baru',
 	'info_nouvelle_traduction' => 'Terjemahan baru:',
 	'info_numero_article' => 'NOMOR ARTIKEL:',
 	'info_obligatoire_02' => '[Dibutuhkan]', # MODIF
 	'info_option_accepter_visiteurs' => 'Izinkan registrasi pengunjung dari situs umum',
-	'info_option_faire_suivre' => 'Teruskan pesan forum ke penulis artikel',
 	'info_option_ne_pas_accepter_visiteurs' => 'Tolak registrasi pengunjung',
 	'info_options_avancees' => 'OPSI-OPSI LANJUTAN',
-	'info_ortho_activer' => 'Aktifkan pemeriksa ejaan.',
-	'info_ortho_desactiver' => 'Non aktifkan pemeriksa ejaan.',
 	'info_ou' => 'atau...',
 	'info_page_interdite' => 'Halaman terlarang',
 	'info_par_nom' => 'berdasarkan nama',
@@ -353,20 +290,14 @@ $GLOBALS[$GLOBALS['idx_lang']] = array(
 	'info_par_tri' => '(Oleh @tri@)',
 	'info_passe_trop_court' => 'Kata sandi terlalu pendek.',
 	'info_passes_identiques' => 'Dua kata sandi tidak identik.',
-	'info_pense_bete_ancien' => 'Memo-memo lama anda', # MODIF
 	'info_plus_cinq_car' => 'lebih dari 5 karakter',
 	'info_plus_cinq_car_2' => '(Lebih dari 5 karakter)',
 	'info_plus_trois_car' => '(Lebih dari 3 karakter)',
 	'info_popularite' => 'popularitas: @popularite@; kunjungan: @visites@',
-	'info_popularite_4' => 'popularitas: @popularite@; kunjungan: @visites@',
 	'info_post_scriptum' => 'Postscript',
 	'info_post_scriptum_2' => 'Postscript:',
 	'info_pour' => 'untuk',
-	'info_preview_admin' => 'Hanya administrator yang memiliki akses ke mode preview',
-	'info_preview_comite' => 'Semua penulis memiliki akses ke mode preview',
-	'info_preview_desactive' => 'Mode preview dinonaktifkan',
-	'info_preview_texte' => 'Ada kemungkinan melihat situs terlebih dahulu seolah-olah semua artikel dan berita (yang paling tidak memiliki status "terkirim") telah dipublikasi. Apakah mode preview ini sebaiknya dibatasi hanya kepada administrator, terbuka untuk semua penulis atau dinonaktifkan selama-lamanya?',
-	'info_principaux_correspondants' => 'Korespondensi utama anda',
+	'info_preview_texte' => 'Ada kemungkinan melihat situs terlebih dahulu seolah-olah semua artikel dan berita (yang paling tidak memiliki status "terkirim") telah dipublikasi. Apakah mode preview ini sebaiknya dibatasi hanya kepada administrator, terbuka untuk semua penulis atau dinonaktifkan selama-lamanya?', # MODIF
 	'info_procedez_par_etape' => 'silakan dilanjutkan langkah demi langkah',
 	'info_procedure_maj_version' => 'prosedur pembaharuan hendaknya dijalankan untuk
 	mengadaptasi database degan versi terbaru SPIP.',
@@ -384,13 +315,9 @@ $GLOBALS[$GLOBALS['idx_lang']] = array(
   hosting menonaktifkan pengiriman e-mail di server mereka:
   dalam hal ini ini registrasi terotomasi tidak dapat
   diimplementasikan.', # MODIF
-	'info_question_utilisation_moteur_recherche' => 'Apakah anda ingin mengunakan mesin pencari yang terintegrasi dengan SPIP?
-	(Menonaktifkannya akan meningkatkan kinerja sistem.)',
 	'info_qui_edite' => '@nom_auteur_modif@ a travaillé sur ce contenu il y a @date_diff@ minutes', # MODIF
 	'info_racine_site' => 'Root situs',
 	'info_recharger_page' => 'Silakan buka kembali halaman ini beberapa saat lagi.',
-	'info_recherche_auteur_a_affiner' => 'Terlalu banyaj hasil untuk "@cherche_auteur@"; silakan perbaiki pencarian anda.',
-	'info_recherche_auteur_ok' => 'Sejumlah editor ditemukan untuk "@cherche_auteur@":',
 	'info_recherche_auteur_zero' => 'Tidak ada hasil untuk "@cherche_auteur@".',
 	'info_recommencer' => 'Silakan coba lagi.',
 	'info_redacteur_1' => 'Redaktur',
@@ -407,7 +334,6 @@ $GLOBALS[$GLOBALS['idx_lang']] = array(
 	'info_rubriques' => 'Bagian',
 	'info_rubriques_02' => 'bagian',
 	'info_rubriques_trouvees' => 'Bagian ditemukan',
-	'info_rubriques_trouvees_dans_texte' => 'Bagian ditemukan (dalam teks)',
 	'info_sans_titre' => 'Tidak berjudul',
 	'info_selection_chemin_acces' => '<b>Pilih</b> di bawah path akses dalam direktori:',
 	'info_signatures' => 'tanda tangan',
@@ -420,13 +346,11 @@ $GLOBALS[$GLOBALS['idx_lang']] = array(
 	'info_sites_lies_mot' => 'Situs-situs referensi yang terasosiasi dengan kata kunci ini',
 	'info_sites_proxy' => 'Menggunakan proxy',
 	'info_sites_trouves' => 'Situs ditemukan',
-	'info_sites_trouves_dans_texte' => 'Situs ditemukan (dalam teks)',
 	'info_sous_titre' => 'Sub judul:',
 	'info_statut_administrateur' => 'Administrator',
 	'info_statut_auteur' => 'Status penulis ini:', # MODIF
 	'info_statut_auteur_a_confirmer' => 'Pendaftaran yang perlu dikonfirmasi',
 	'info_statut_auteur_autre' => 'Status lainnya:',
-	'info_statut_efface' => 'Dihapus',
 	'info_statut_redacteur' => 'Editor',
 	'info_statut_utilisateurs_1' => 'Status standar para pengguna yang diimpor',
 	'info_statut_utilisateurs_2' => 'Pilih status yang diberikan kepada orang-orang yang terdapat di direktori LDAP ketika terkoneksi pertama kali. Nanti anda dapat memodifikasi status tersebut untuk setiap penulis berdasarkan kasus per kasus.',
@@ -447,7 +371,6 @@ $GLOBALS[$GLOBALS['idx_lang']] = array(
 	'info_tous_articles_en_redaction' => 'Semua artikel dalam proses',
 	'info_tous_articles_presents' => 'Semua artikel yang dipublikasi dalam bagian ini',
 	'info_tous_les' => 'setiap:',
-	'info_tous_redacteurs' => 'Pengumuman kepada semua editor',
 	'info_tout_site' => 'Seluruh situs',
 	'info_tout_site2' => 'Artikel-artikel belum diterjemahkan ke dalam bahasa ini.',
 	'info_tout_site3' => 'Artikel telah diterjemahkan ke dalam bahasa ini, tapi sejumlah modifikasi telah dibuat untuk artikel referensi. Oleh karenanya terjemahan memerlukan pembaharuan.',
@@ -462,7 +385,6 @@ dalam warna yang menunjukkan statusnya:',
 	'info_une_rubrique' => 'sebuah bagian,',
 	'info_une_rubrique_02' => '1 bagian',
 	'info_url' => 'URL:',
-	'info_url_site' => 'URL SITUS:',
 	'info_urlref' => 'Tautan web:',
 	'info_utilisation_spip' => 'SPIP siap untuk digunakan...',
 	'info_visites_par_mois' => 'Tampilan bulanan:',
@@ -480,8 +402,6 @@ dalam warna yang menunjukkan statusnya:',
 	'item_activer_messages_avertissement' => 'Aktifkan pesan-pesan peringatan',
 	'item_administrateur_2' => 'administrator',
 	'item_afficher_calendrier' => 'Tampilkan dalam kalender',
-	'item_autoriser_documents_joints' => 'Otorisasi dokumen yang terlampir di artikel',
-	'item_autoriser_documents_joints_rubriques' => 'Otorisasi dokumen dalam bagian',
 	'item_autoriser_syndication_integrale' => 'Ikut sertakan semua artikel dalam berkas sindikasi',
 	'item_choix_administrateurs' => 'administrator',
 	'item_choix_generation_miniature' => 'Buat gambar-gambar kecil secara otomatis.',
@@ -489,7 +409,6 @@ dalam warna yang menunjukkan statusnya:',
 	'item_choix_redacteurs' => 'editor',
 	'item_choix_visiteurs' => 'pengunjung situs umum',
 	'item_creer_fichiers_authent' => 'Buat berkas .htpasswd',
-	'item_limiter_recherche' => 'Batasi pencarian pada informasi yang terdapat di situs anda',
 	'item_login' => 'Log masuk',
 	'item_mots_cles_association_articles' => 'artikel',
 	'item_mots_cles_association_rubriques' => 'bagian',
@@ -498,35 +417,25 @@ dalam warna yang menunjukkan statusnya:',
 	'item_non_accepter_inscriptions' => 'Jangan izinkan pendaftaran',
 	'item_non_activer_messages_avertissement' => 'Tidak ada pesan-pesan kesalahan',
 	'item_non_afficher_calendrier' => 'Jangan tampilkan dalam kalender',
-	'item_non_autoriser_documents_joints' => 'Jangan otorisasi dokumen dalam artikel',
-	'item_non_autoriser_documents_joints_rubriques' => 'Jangan otorisasi dokumen dalam bagian',
 	'item_non_autoriser_syndication_integrale' => 'Kirim ringkasan saja',
 	'item_non_creer_fichiers_authent' => 'Jangan buat berkas-berkas ini',
-	'item_non_gerer_statistiques' => 'Jangan kelola statistik',
-	'item_non_limiter_recherche' => 'Perluas pencarian isi dari situs-situs referensi',
 	'item_non_publier_articles' => 'Jangan publikasi artikel sebelum tanggal publikasinya.',
-	'item_non_utiliser_moteur_recherche' => 'Jangan gunakan sistem',
 	'item_nouvel_auteur' => 'Penulis baru',
 	'item_nouvelle_rubrique' => 'Bagian baru',
 	'item_oui' => 'Ya',
 	'item_publier_articles' => 'Publikasi artikel tanpa menghiraukan tanggal publikasinya.',
 	'item_reponse_article' => 'Balasan pada artikel',
-	'item_utiliser_moteur_recherche' => 'Gunakan mesin pencari',
 	'item_visiteur' => 'pengunjung',
 
 	// J
 	'jour_non_connu_nc' => 'tidak dikenal',
 
 	// L
-	'lien_ajout_destinataire' => 'Tambahkan penerima ini',
 	'lien_ajouter_auteur' => 'Tambahkan penulis ini',
-	'lien_ajouter_participant' => 'Tambahkan seorang peserta',
 	'lien_email' => 'e-mail',
 	'lien_nom_site' => 'NAMA SITUS:',
 	'lien_retirer_auteur' => 'Hapus penulis',
-	'lien_retrait_particpant' => 'Hapus peserta ini',
 	'lien_site' => 'situs',
-	'lien_supprimer_rubrique' => 'hapus bagian ini',
 	'lien_tout_deplier' => 'Buka semuanya',
 	'lien_tout_replier' => 'Tutup semuanya',
 	'lien_tout_supprimer' => 'Hapus semua',
@@ -563,6 +472,7 @@ dalam warna yang menunjukkan statusnya:',
 
 	// R
 	'repertoire_plugins' => 'Directori:',
+	'required' => '[Dibutuhkan]', # MODIF
 
 	// S
 	'statut_admin_restreint' => '(admin terbatas)', # MODIF
@@ -587,16 +497,11 @@ menginstal kembali SPIP untuk membuat database baru dan akses administrator pert
 	'texte_article_virtuel_reference' => '<b>Artikel maya:</b> artikel referensi di situs SPIP anda, yang dialihkan ke lain URL. Untuk menghapus pengalihan, hapuslah URL di atas.',
 	'texte_aucun_resultat_auteur' => 'Tidak ada hasil untuk "@cherche_auteur@".',
 	'texte_auteur_messagerie' => 'Situs ini dapat memonitor secara terus-menerus daftar editor-editor yang terkoneksi, yang mengizinkan anda untuk bertukar pesan secara langsung. Anda dapat memilih untuk tidak muncul dalam daftar ini (yang membuat anda kemudian, "tak terlihat" di hadapan pengguna lainnya).',
-	'texte_auteur_messagerie_1' => 'Situs ini mengizinkan anda untuk bertukar pesan dan membuat forum diskusi pribadi di antara pengunjung situs. Anda dapat memilih untuk tidak berpartisipasi dalam pertukaran ini.',
 	'texte_auteurs' => 'PENULIS',
 	'texte_choix_base_1' => 'Pilih database anda:',
 	'texte_choix_base_2' => 'Server SQL berisikan sejumlah database.',
 	'texte_choix_base_3' => '<b>Pilih</B> di bawah salah satu yang diberikan hosting anda kepada anda:',
 	'texte_choix_table_prefix' => 'Prefiks untuk tabel:',
-	'texte_commande_vider_tables_indexation' => 'Gunakan perintah ini untuk mengosongkan tabel terindeksasi
-			yang digunakan oleh mesin pencari SPIP. Ini akan memberi anda
-			sejumlah ruangan di disk.',
-	'texte_compresse_ou_non' => '(yang ini dapat dikompres atau tidak)',
 	'texte_compte_element' => '@count@ elemen',
 	'texte_compte_elements' => '@count@ elemen',
 	'texte_connexion_mysql' => 'Merujuk kepada informasi yang diberikan hosting anda kepada anda: mereka seharusnya memberikan anda, jika hosting anda mendukung SQL, kode koneksi ke server SQL.', # MODIF
@@ -612,10 +517,8 @@ menginstal kembali SPIP untuk membuat database baru dan akses administrator pert
 	'texte_date_publication_anterieure' => 'Tanggal publikasi awal:',
 	'texte_date_publication_anterieure_nonaffichee' => 'Sembunyikan data publikasi awal.',
 	'texte_date_publication_article' => 'TANGGAL PUBLIKASI ONLINE:',
-	'texte_descriptif_petition' => 'Deskripsi petisi',
 	'texte_descriptif_rapide' => 'Deskripsi singkat',
 	'texte_effacer_base' => 'Hapus database SPIP',
-	'texte_effacer_donnees_indexation' => 'Hapus data terindeksasi',
 	'texte_en_cours_validation' => 'Artikel-artikel dan berita-berita berikut dikirim untuk publikasi. Jangan segan-segan memberikan opini anda melalui forum yang terlampir di dalamnya.', # MODIF
 	'texte_enrichir_mise_a_jour' => 'Anda dapat memperkaya tampilan teks anda dengan menggunakan «jalan pintas typografis».',
 	'texte_fichier_authent' => '<b>Haruskah SPIP membuat berkas <tt>.htpasswd</tt>
@@ -630,29 +533,17 @@ menginstal kembali SPIP untuk membuat database baru dan akses administrator pert
 	'texte_informations_personnelles_2' => '(Catatan: jika ini adalah instalasi kembali, dan akses anda masih berlaku, anda dapat', # MODIF
 	'texte_introductif_article' => '(Teks Pengantar artikel.)',
 	'texte_jeu_caractere' => 'Anda disarankan menggunakan aksara universal (<tt>utf-8</tt>) di situs anda. Ini memungkinkan untuk menampilkan teks dalam segala bahsa. Browser modern tidak akan mengalami kesulitan dalam menangani set karakter ini.',
-	'texte_jeu_caractere_2' => 'Catatan: Pengaturan ini tidak akan mengubah teks yang sudah disimpan dalam database.',
 	'texte_jeu_caractere_3' => 'Situs anda saat ini menggunakan set karakter ini:',
 	'texte_jeu_caractere_4' => 'Jika itu tidak berkaitan dengan situasi yang anda miliki dengan data anda (sebagai contoh, setelah pemulihan database anda dari backup), atau jika <em>anda mengkonfigurasi situs ini</em> dan berkeinginan menggunakan set karakter yang berbeda, silakan tunjukkan set karakter di sini:',
-	'texte_jeu_caractere_conversion' => 'Catatan: Anda dapat memutuskan untuk mengubah semua teks (artickel, berita, forum, dll.) situs anda dan semua set karakter ke <tt>utf-8</tt>. Untuk melakukan ini, silakan kunjungi <a href="@url@">halaman konversi UTF-8</a>.',
-	'texte_lien_hypertexte' => '(Jika pesan anda merujuk pada sebuah artikel yang dipublikasi di Web, atau ke halaman yang berisikan informasi lebih banyak, silakan memasukkan judul halaman dan URL nya di sini.)',
 	'texte_login_ldap_1' => '(Biarkan kosong untuk akses anonim atau masukkan path lengkap, sebagai contoh «<tt>uid=smith, ou=users, dc=my-domain, dc=com</tt>».)',
 	'texte_login_precaution' => 'Peringatan! Ini adalah log masuk yang anda gunakan untuk terkoneksi sekarang.
 	Gunakan formulir ini dengan hati-hati...',
-	'texte_message_edit' => 'Peringatan: pesan ini dapat dimodifikasi oleh semua administrator situs, dan muncul di hadapan semua editor. Gunakan pengumuman hanya untuk menekankan pentingnya sebuah kejadian dalam siklus hidup situs.',
 	'texte_mise_a_niveau_base_1' => 'Anda harus memperbaharui berkas-berkas SPIP.
 	Sekarang anda harus memperbaharui database situs.',
 	'texte_modifier_article' => 'Modifikasi artikel:',
-	'texte_moteur_recherche_active' => '<b>Mesin pencari diaktifkan.</b> Gunakan perintah ini
-		jika anda ingin mengeksekusi indeksasi ulang (setelah pemulihan
-		sebuah backup sebagai contohnya). Anda seharusnya memperhatikan bahwa
-		dokumen yang dimodifikasi secara normal (dari tatap muka SPIP) akan diindeks
-		kembali secara otomatis: oleh karenanya perintah ini hanya berlaku dalam
-		situasi tertentu saja.',
-	'texte_moteur_recherche_non_active' => 'Mesin pencari tidak diaktifkan.',
 	'texte_multilinguisme' => 'Jika anda ingin mengelola artikel-artikel dalam beberapa bahasa, dengan navigasi yang kompleks, anda dapat menambah sebuah menu pemilih bahasa di artikel dan/atau bagian, sesuai dengan organisasi dari situs anda.', # MODIF
 	'texte_multilinguisme_trad' => 'Selain itu, anda juga dapat mengaktifkan sistem manajemen tautan di antara terjemahan yang berbeda dari sebuah artikel.', # MODIF
 	'texte_non_compresse' => '<i>tidak dikompresi</i> (server anda tidak mendukung fitur ini)',
-	'texte_nouveau_message' => 'Pesan baru',
 	'texte_nouvelle_version_spip_1' => 'Anda baru saja menginstal versi terbaru SPIP.',
 	'texte_nouvelle_version_spip_2' => 'Versi terbaru ini membutuhkan pembaharuan secara menyeluruh daripada biasanya. Jika anda adalah webmaster situs ini, silakan hapus berkas @connect@ dan jalankan kembali instalasi untuk memperbaharui paramater-parameter koneksi database anda. <p>(Catatan: Jika anda lupa paramater-parameter koneksi database anda, silakan lihat berkas @connect@ sebelum menghapusnya!)</p>', # MODIF
 	'texte_operation_echec' => 'Kembali ke halaman sebelumnya, pilih database lain atau buat yang baru. Verifikasi informasi yang diberikan oleh hosting anda.',
@@ -672,7 +563,6 @@ menginstal kembali SPIP untuk membuat database baru dan akses administrator pert
 	'texte_rappel_selection_champs' => '[Ingat untuk memilih kolom ini dengan benar.]',
 	'texte_recalcul_page' => 'Jika anda hanya ingin
 memperbaharui satu halaman, anda sebaiknya melakukannya dari area umum dan gunakan tombol « perbaharui ».',
-	'texte_recapitiule_liste_documents' => 'Halaman ini menampilkan daftar dari dokumen-dokumen yang anda tempatkan di bagian-bagian. Untuk memodifikasi informasi setiap dokumen, ikuti tautan ke halaman bagiannya.',
 	'texte_recuperer_base' => 'Perbaiki database',
 	'texte_reference_mais_redirige' => 'artikel referensi di situs SPIP anda, tapi mengarah ke URL lain.',
 	'texte_requetes_echouent' => '<b>Wetika sejumlah query SQL gagal
@@ -703,7 +593,6 @@ dalam cache SPIP. Ini mengizinkan anda, antara lain, untuk memaksa semua halaman
 anda memasukkan modifikasi yang penting di grafik atau struktur situs.',
 	'texte_sur_titre' => 'Judul atas',
 	'texte_table_ok' => ': tabel ini OK.',
-	'texte_tables_indexation_vides' => 'Tabel terindeksasi mesin kosong.',
 	'texte_tentative_recuperation' => 'Usaha perbaikan',
 	'texte_tenter_reparation' => 'Usaha untuk memperbaiki database.',
 	'texte_test_proxy' => 'Untuk mencoba proxy ini, masukkan alamat sebuah situs web di sini
@@ -713,13 +602,8 @@ anda memasukkan modifikasi yang penting di grafik atau struktur situs.',
 	'texte_travail_article' => '@nom_auteur_modif@ telah bekerja di artikel ini @date_diff@ menit yang lalu',
 	'texte_travail_collaboratif' => 'Jika beberapa editor sering bekerja sama dalam artikel yang sama, sistem dapat menandai artikel-artikel yang saat itu sedang «dibuka» guna menghindari konflik saat diedit.
   Opsi ini dinonaktifkan secara standar untuk menghindri pesan-pesan peringatan yang tidak perlu.',
-	'texte_trop_resultats_auteurs' => 'Terlalu banyak hasil untuk "@cherche_auteur@"; silakan perbaiki pencarian anda.',
-	'texte_unpack' => 'mengunduh versi terakhir',
-	'texte_utilisation_moteur_syndiques' => 'Ketika anda menggunakan mesin pencari SPIP, anda dapat melakukan pencarian di situs dan artikel yang tersindikasi dala dua cara yang berbeda. <br />- Cara termudah adalah mencari hanya di judul dan deskripsi artikel. <br />- Kedua, cara yang lebih bagus, selain di atas juga mencari dalam teks situs-situs referensi. Jika anda mereferensi sebuah situs, SPIP akan melakukan pencarian di teks situs tersebut.', # MODIF
-	'texte_utilisation_moteur_syndiques_2' => 'Metode ini memaksa SPIP untuk mengunjungi situs-situs referensi secara teratur, yang mungkin dapat menurunkan kinerja situs anda.',
 	'texte_vide' => 'kosong',
 	'texte_vider_cache' => 'Kosongkan cache',
-	'titre_admin_effacer' => 'Pemeliharaan teknis',
 	'titre_admin_tech' => 'Pemeliharaan teknis',
 	'titre_admin_vider' => 'Pemeliharaan teknis',
 	'titre_cadre_afficher_article' => 'Tampilkan artikel:',
@@ -739,47 +623,26 @@ anda memasukkan modifikasi yang penting di grafik atau struktur situs.',
 	'titre_naviguer_dans_le_site' => 'Jelajah situs...',
 	'titre_nouvelle_rubrique' => 'Bagian baru',
 	'titre_numero_rubrique' => 'NOMOR BAGIAN:',
-	'titre_page_admin_effacer' => 'Pemeliharaan teknis: mengahpus database',
 	'titre_page_articles_edit' => 'Modifikasi: @titre@',
 	'titre_page_articles_page' => 'Artikel',
 	'titre_page_articles_tous' => 'Seluruh situs',
-	'titre_page_auteurs' => 'Pengunjung',
 	'titre_page_calendrier' => 'Kalender @nom_mois@ @annee@',
 	'titre_page_config_contenu' => 'Konfigurasi situs',
-	'titre_page_config_fonctions' => 'Konfigurasi situs',
-	'titre_page_configuration' => 'Konfigurasi situs',
-	'titre_page_controle_petition' => 'Tindak lanjut petisi',
 	'titre_page_delete_all' => 'penghapusan menyeluruh dan tidak dapat dikembalikan lagi',
-	'titre_page_documents_liste' => 'Lampiran',
-	'titre_page_index' => 'Area pribadi anda',
-	'titre_page_message_edit' => 'Tulis sebuah pesan',
-	'titre_page_messagerie' => 'Sistem pesan anda',
 	'titre_page_recherche' => 'Hasil pencarian @recherche@',
 	'titre_page_statistiques_referers' => 'Statistik (tautan masuk)',
 	'titre_page_upgrade' => 'Pembaharuan SPIP',
 	'titre_publication_articles_post_dates' => 'Publikasi artikel terjadwal',
-	'titre_referencer_site' => 'Referensi situs:',
-	'titre_rendez_vous' => 'JANJI:',
 	'titre_reparation' => 'Perbaikan',
 	'titre_suivi_petition' => 'Tindak lanjut petisi',
 	'tls_ldap' => 'Pengamanan layer transportasi:',
-	'trad_article_inexistant' => 'Tidak ada artikel dengan nomor ini',
 	'trad_article_traduction' => 'Semua versi artikel ini:',
-	'trad_deja_traduit' => 'Artikel ini adalah terjemahan dari artikel yang sekarang.',
 	'trad_delier' => 'Berhenti menautkan artikel ini ke terjemahannya', # MODIF
 	'trad_lier' => 'Artikel ini adalah terjemahan dari artikel nomor:',
 	'trad_new' => 'Tulis terjemahan baru untuk artikel ini', # MODIF
 
 	// U
-	'utf8_convert_attendez' => 'Tunggu beberapa saat dan perbaharui halaman ini.',
-	'utf8_convert_avertissement' => 'Anda akan mengubah isi database anda (artikel, berita, dll) dari set karakter <b>@orig@</b> ke set karakter <b>@charset@</b>.',
-	'utf8_convert_backup' => 'Jangan lupa membuat backup lengkap situs anda terlebih dahulu. Anda juga perlu memeriksa bahawa templat dan bahasa anda kompatibel dengan @charset@.',
-	'utf8_convert_erreur_deja' => 'Situs anda sudah dalam @charset@, tidak ada yang perlu diubah.',
 	'utf8_convert_erreur_orig' => 'Kesalahan: set karakter @charset@ tidak didukung.',
-	'utf8_convert_termine' => 'Selesai!',
-	'utf8_convert_timeout' => '<b>Penting:</b> Jika server menunjukkan <i>timeout</i>, silakan perbaharui halaman di mana anda memperoleh pesan «Selesai!».',
-	'utf8_convert_verifier' => 'Anda sekarang harus mengosongkan cache situs dan periksa apakah semuanya baik-baik saja di halaman-halaman umum situs. Jika anda mengalami sebuah permasalahan besar, sebuah backup data asli anda (dalam format SQL) telah dibuat di direktori @rep@.',
-	'utf8_convertir_votre_site' => 'Ubah situs anda ke utf-8',
 
 	// V
 	'version' => 'Versi:'
