@@ -3,7 +3,9 @@
 // extrait automatiquement de http://trad.spip.net/tradlang_module/ecrire_?lang_cible=it
 // ** ne pas modifier le fichier **
 
-if (!defined('_ECRIRE_INC_VERSION')) return;
+if (!defined('_ECRIRE_INC_VERSION')) {
+	return;
+}
 
 $GLOBALS[$GLOBALS['idx_lang']] = array(
 
@@ -203,9 +205,6 @@ Se non conosci queste informazioni, richiedile all’amministratore del sistema
 di passare facilmente dal sito pubblico all’interfaccia privata.',
 	'info_activer_menu_developpement' => 'Mostra il menù Sviluppo',
 	'info_admin_etre_webmestre' => 'Concedimi i privilegi di webmaster',
-	'info_admin_gere_rubriques' => 'Questo amministratore gestisce le seguenti rubriche:',
-	'info_admin_gere_toutes_rubriques' => 'Questo amministratore gestisce <b>tutte le rubriche</b>.',
-	'info_admin_gere_toutes_rubriques_2' => 'Io modifico <b>tutte le rubriche</b>',
 	'info_admin_je_suis_webmestre' => 'Sono <b>webmaster</b>',
 	'info_admin_statuer_webmestre' => 'Dai a questo amministratore i privilegi di webmaster',
 	'info_admin_webmestre' => 'Questo amministratore è un <b>webmaster</b>',
@@ -241,6 +240,7 @@ immagini inserite. Ciò permette ad esempio di creare in automatico una galleria
 	'info_aucun_message' => 'Nessun messaggio',
 	'info_aucun_rubrique' => 'Nessuna rubrica',
 	'info_aujourdhui' => 'oggi: ',
+	'info_auteur_gere_toutes_rubriques_2' => 'Io modifico <b>tutte le rubriche</b>', # MODIF
 	'info_auteurs' => 'Gli autori',
 	'info_auteurs_par_tri' => 'Autori@partri@',
 	'info_auteurs_trouves' => 'Autori trovati',
@@ -403,7 +403,7 @@ le informazioni contenute nel database sono probabilmente andate perse.<br />{{R
 	'info_post_scriptum' => 'Post Scriptum',
 	'info_post_scriptum_2' => 'Post Scriptum:',
 	'info_pour' => 'per',
-	'info_preview_texte' => 'È possibile visualizzare un’anteprima del sito comprendente anche gli articoli e le brevi "proposti" per la pubblicazione. Questa funzionalità può essere disattivata, consentita solo agli amministratori o a tutti i redattori.',
+	'info_preview_texte' => 'È possibile visualizzare un’anteprima del sito comprendente anche gli articoli e le brevi "proposti" per la pubblicazione. Questa funzionalità può essere disattivata, consentita solo agli amministratori o a tutti i redattori.', # MODIF
 	'info_procedez_par_etape' => 'procedere passo dopo passo',
 	'info_procedure_maj_version' => 'è necessario avviare la procedura di aggiornamento per adattare
 il database alla nuova versione di SPIP.',
@@ -571,7 +571,7 @@ Le traduzioni sono associate all’originale,
 	'label_choix_langue' => 'Seleziona la tua lingua',
 	'label_nom_fichier_connect' => 'Indica il nome per questo server',
 	'label_slogan_site' => 'Slogan del sito',
-	'label_taille_ecran' => 'Larghezza dello schermo',
+	'label_taille_ecran' => 'Larghezza dello schermo', # MODIF
 	'label_texte_et_icones_navigation' => 'Menù di naviagazione',
 	'label_texte_et_icones_page' => 'Visualizzazione nella pagina',
 	'ldap_correspondance' => 'mappa del campo @champ@',
@@ -611,7 +611,7 @@ Le traduzioni sono associate all’originale,
 	'mois_non_connu' => 'sconosciuto',
 
 	// N
-	'nouvelle_version_spip' => 'La versione @version@ di SPIP è disponibile',
+	'nouvelle_version_spip' => 'La versione @version@ di SPIP è disponibile', # MODIF
 
 	// O
 	'onglet_contenu' => 'Contenuto',
@@ -660,7 +660,7 @@ Le traduzioni sono associate all’originale,
 	'plugin_info_upgrade_ok' => 'Aggiornamento avvenuto',
 	'plugin_librairies_installees' => 'Librerie installate',
 	'plugin_necessite_lib' => 'Questa estensione richiede la libreria @lib@',
-	'plugin_necessite_plugin' => 'Necessita l’estensione @plugin@ con almeno la versione @version@.',
+	'plugin_necessite_plugin' => 'Necessita l’estensione @plugin@ con la versione @version@.',
 	'plugin_necessite_plugin_sans_version' => 'Necessita del plugin @plugin@',
 	'plugin_necessite_spip' => 'Necessita SPIP con almeno la versione @version@.',
 	'plugin_source' => 'origine: ',
@@ -694,7 +694,7 @@ Le traduzioni sono associate all’originale,
 
 	// Q
 	'queue_executer_maintenant' => 'Esegui adesso',
-	'queue_info_purger' => 'È possibile eliminare tutti i lavori in sospeso e reinizializzare lista con delle elaborazioni periodiche',
+	'queue_info_purger' => 'È possibile eliminare tutti i lavori in sospeso e reinizializzare lista con delle elaborazioni periodiche', # MODIF
 	'queue_nb_jobs_in_queue' => '@nb@ processi in coda',
 	'queue_next_job_in_nb_sec' => 'Prossimo processo in @nb@ s',
 	'queue_no_job_in_queue' => 'Nessun processo appeso',
