@@ -3,7 +3,9 @@
 // extrait automatiquement de http://trad.spip.net/tradlang_module/ecrire_?lang_cible=it_fem
 // ** ne pas modifier le fichier **
 
-if (!defined('_ECRIRE_INC_VERSION')) return;
+if (!defined('_ECRIRE_INC_VERSION')) {
+	return;
+}
 
 $GLOBALS[$GLOBALS['idx_lang']] = array(
 
@@ -184,8 +186,6 @@ Se non conosci queste informazioni, richiedile all’amministratrice del sistema
 	'info_1_article' => '1 articolo',
 	'info_activer_cookie' => 'Se vuoi puoi attivare un <b>cookie di corrispondenza</b>, che ti permetterà
 di passare facilmente dal sito pubblico all’interfaccia privata.',
-	'info_admin_gere_rubriques' => 'Questa amministratrice gestisce le seguenti rubriche:',
-	'info_admin_gere_toutes_rubriques' => 'Questa amministratrice gestisce <b>tutte le rubriche</b>.',
 	'info_administrateur' => 'Amministratrice',
 	'info_administrateur_1' => 'Amministratrice',
 	'info_administrateur_2' => 'del sito (<i>da utilizzare con prudenza</i>)',
@@ -350,7 +350,7 @@ le informazioni contenute nel database sono probabilmente andate perse.<br />{{R
 	'info_post_scriptum' => 'Post Scriptum',
 	'info_post_scriptum_2' => 'Post Scriptum:',
 	'info_pour' => 'per',
-	'info_preview_texte' => 'È possibile visualizzare un’anteprima del sito comprendente anche gli articoli e le brevi "proposti" per la pubblicazione. Questa funzionalità può essere disattivata, consentita solo alle amministratrici o a tutte le redattrici.',
+	'info_preview_texte' => 'È possibile visualizzare un’anteprima del sito comprendente anche gli articoli e le brevi "proposti" per la pubblicazione. Questa funzionalità può essere disattivata, consentita solo alle amministratrici o a tutte le redattrici.', # MODIF
 	'info_procedez_par_etape' => 'procedere passo dopo passo',
 	'info_procedure_maj_version' => 'è necessario avviare la procedura di aggiornamento per adattare
 il database alla nuova versione di SPIP.',
@@ -567,7 +567,7 @@ Le traduzioni sono associate all’originale,
 	'plugin_info_telecharger' => 'da scaricare da @url@ e da installare in @rep@',
 	'plugin_librairies_installees' => 'Librerie installate',
 	'plugin_necessite_lib' => 'Questo plug-in richiede la libreria @lib@',
-	'plugin_necessite_plugin' => 'Necessita il plug-in @plugin@ con almeno la versione @version@.',
+	'plugin_necessite_plugin' => 'Necessita il plug-in @plugin@ con almeno la versione @version@.', # MODIF
 	'plugin_necessite_spip' => 'Necessita SPIP con almeno la versione @version@.',
 	'plugin_source' => 'origine: ',
 	'plugin_titre_automatique' => 'Installazione automatica',
