@@ -3,7 +3,9 @@
 // extrait automatiquement de http://trad.spip.net/tradlang_module/ecrire_?lang_cible=ja
 // ** ne pas modifier le fichier **
 
-if (!defined('_ECRIRE_INC_VERSION')) return;
+if (!defined('_ECRIRE_INC_VERSION')) {
+	return;
+}
 
 $GLOBALS[$GLOBALS['idx_lang']] = array(
 
@@ -23,68 +25,38 @@ $GLOBALS[$GLOBALS['idx_lang']] = array(
 	'avis_connexion_ldap_echec_2' => '前のページに戻って、与えられている情報を確認してください。',
 	'avis_connexion_ldap_echec_3' => '交代でLDAPサポートをユーザのインポートのために利用しないでください。',
 	'avis_deplacement_rubrique' => '注意！ この項目は、 @contient_breves@　件のニュースを含んでいます: それを移動する場合は、確認のためこのボックスにチェックを入れてください。',
-	'avis_destinataire_obligatoire' => 'メッセージを送信するには、受取人を選択してください。',
 	'avis_erreur_connexion_mysql' => 'SQL接続のエラーです。',
-	'avis_erreur_version_archive' => '<b>注意！ @archive@ ファイルは
-あなたのお手元のSPIPとは異なるバージョンのSPIPに対応するものです。</b>このままですと、データベースの破壊や
-いくつかのサイトに関する機能不全といった
-深刻な問題に行き当たることになります。
-このインポートはリクエストしないでください。<p>詳細は、
-<a href="@spipnet@">
-SPIPドキュメント</a>をご覧ください。</p>', # MODIF
 	'avis_espace_interdit' => '<b>許されないエリア</b><p>SPIPが既にインストールされています。',
 	'avis_lecture_noms_bases_1' => 'インストールプログラムは、インストールされたデータベースの名前を読むことが出来ませんでした。',
 	'avis_lecture_noms_bases_2' => 'ベースが有効でないか、ベースリストを許可する機能がアクティブではありませんでした。
 これはセキュリティ上の理由によります（多くのホスティングによくみられるものです）。',
 	'avis_lecture_noms_bases_3' => '二つ目の選択において、あなたのログイン名を含むデータベースが利用可能なようです :',
-	'avis_non_acces_message' => 'このメッセージにはアクセスしていません。',
 	'avis_non_acces_page' => 'このページにはアクセスしていません。',
 	'avis_operation_echec' => '操作に失敗しました。',
-	'avis_probleme_archive' => '@archive@ ファイルの読み込みに問題があります。',
 	'avis_suppression_base' => '注意！データ消去します。復旧出来ません。',
-	'avis_version_mysql' => 'あなたのSQLのバージョン  （@version_mysql@） は、データベーステーブルの自動修復が不可能です。',
 
 	// B
 	'bouton_acces_ldap' => 'LDAPへのアクセスを追加 >>',
 	'bouton_ajouter' => '追加する',
-	'bouton_ajouter_participant' => '関係するものを追加:',
-	'bouton_annonce' => 'アナウンス',
-	'bouton_checkbox_envoi_message' => 'メッセージが送れるようにする',
-	'bouton_checkbox_indiquer_site' => 'ウェブサイトを必須入力にする',
-	'bouton_checkbox_signature_unique_email' => 'メールアドレス１つにつき、１署名まで',
-	'bouton_checkbox_signature_unique_site' => 'ウェブサイト１つにつき、１署名まで',
 	'bouton_demande_publication' => 'この記事の公開を要求する',
 	'bouton_desactive_tout' => 'すべて無効',
-	'bouton_effacer_index' => 'インデックスの削除',
 	'bouton_effacer_tout' => 'すべての削除',
-	'bouton_envoi_message_02' => 'メッセージを送る',
 	'bouton_envoyer_message' => '最後のメッセージ: 送る',
 	'bouton_modifier' => '修正',
-	'bouton_pense_bete' => '個人的なメモ',
-	'bouton_radio_activer_messagerie' => '内部でのメッセージ交換を可能にする',
-	'bouton_radio_activer_messagerie_interne' => '内部でのメッセージ交換を可能にする',
-	'bouton_radio_activer_petition' => '署名機能を使う',
 	'bouton_radio_afficher' => '表示',
 	'bouton_radio_apparaitre_liste_redacteurs_connectes' => '接続中に接続中エディターのリストに表示',
-	'bouton_radio_desactiver_messagerie' => 'メッセージ交換を不能にする',
 	'bouton_radio_envoi_annonces_adresse' => 'アナウンスを送信するアドレス:',
 	'bouton_radio_envoi_liste_nouveautes' => '最新のニュースリストを送る',
 	'bouton_radio_non_apparaitre_liste_redacteurs_connectes' => '接続中のエディターズのリストに表示しない',
 	'bouton_radio_non_envoi_annonces_editoriales' => '編集の発表を送らない',
-	'bouton_radio_pas_petition' => '署名機能なし',
-	'bouton_radio_petition_activee' => '署名機能を使用中',
-	'bouton_radio_supprimer_petition' => '署名機能を無効にする',
 	'bouton_redirection' => 'リダイレクト',
 	'bouton_relancer_installation' => 'インストレーションを再起動',
 	'bouton_suivant' => '次',
 	'bouton_tenter_recuperation' => '修復を試みる',
 	'bouton_test_proxy' => 'プロキシーをテスト',
 	'bouton_vider_cache' => 'システムキャッシュを空にする',
-	'bouton_voir_message' => '承認前にメッセージを再度表示する',
 
 	// C
-	'cache_mode_compresse' => 'キャッシュファイルは圧縮して保存されました。',
-	'cache_mode_non_compresse' => 'キャッシュファイルは未圧縮で保存されました。',
 	'cache_modifiable_webmestre' => 'これらのパラメータはwebmasterによって修正できます。',
 	'calendrier_synchro' => '<b>iCal</b>と互換性のある日記アプリケーションを使っているなら、それとこのサイトの情報を同調（シンクロ）することが出来ます。',
 
@@ -110,7 +82,6 @@ SPIPドキュメント</a>をご覧ください。</p>', # MODIF
 	'entree_login' => 'あなたのログインID',
 	'entree_login_connexion_1' => '接続するログインID',
 	'entree_login_connexion_2' => '(あなたのFTP用のログインIDと同じときもあれば空欄のときもあります)',
-	'entree_login_ldap' => '最初のLDAPのログインID',
 	'entree_mot_passe' => 'パスワード',
 	'entree_mot_passe_1' => '接続パスワード',
 	'entree_mot_passe_2' => '(あなたのFTP用のパスワードと同じときもあれば空欄のときもあります)',
@@ -131,7 +102,7 @@ SPIPドキュメント</a>をご覧ください。</p>', # MODIF
 	'ical_info2' => 'さらに情報が欲しい場合、躊躇せずに、<a href="@spipnet@">SPIP’sドキュメント</a>を訪れてください。', # MODIF
 	'ical_info_calendrier' => 'あなたは２種類のカレンダーが自由に使えます。１つめはすべての公開された記事を示すサイトマップです。２つめは編集中のアナウンスに加え、あなたの最新のプライベートメッセージも含んでいます: URL中に含まれる個人のキーはあなたの為に確保してあり、あなたのパスワードを新しくすることでいつでも変更することができます。',
 	'ical_methode_http' => 'ダウンロードする',
-	'ical_methode_webcal' => '同調（シンクロ）する (webcal://)',
+	'ical_methode_webcal' => '同調（シンクロ）する (webcal://)', # MODIF
 	'ical_texte_js' => 'このサイトで出版された最新記事を、あなたの管理しているどんなサイトでもとても簡単に、たった１行のjavascriptで表示することが出来ます。',
 	'ical_texte_prive' => 'このカレンダーは完全に個人用で、このサイトのあなたのプライベートの編集活動を知らせます（仕事、個人的な約束、提出された記事とニュース...）。',
 	'ical_texte_public' => 'このカレンダーは、あなたがこのサイト（公開された記事とニュース）のパブリックな活動を理解するのを手伝います。',
@@ -147,9 +118,7 @@ SPIPドキュメント</a>をご覧ください。</p>', # MODIF
 	'icone_creer_auteur' => '新しい著者を作って、彼をこの記事に参加させる。',
 	'icone_creer_mot_cle' => '新しいキーワードと、この記事へのリンクを作る',
 	'icone_creer_rubrique_2' => '新しいセクションを作る',
-	'icone_envoyer_message' => 'このメッセージを送る',
 	'icone_modifier_article' => 'この記事を修正',
-	'icone_modifier_message' => 'このメッセージを修正',
 	'icone_modifier_rubrique' => 'このセクションを修正',
 	'icone_retour' => '戻る',
 	'icone_retour_article' => '記事に戻る',
@@ -159,11 +128,8 @@ SPIPドキュメント</a>をご覧ください。</p>', # MODIF
 	'icone_valider_signature' => 'この署名を確認',
 	'image_administrer_rubrique' => 'あなたはこのセクションを管理することができる',
 	'info_1_article' => '１記事',
-	'info_1_site' => '1 サイト',
 	'info_activer_cookie' => '<b>管理者用クッキー</b>を使うことが出来ます。 それによって
 パブリックなサイトとプライベートエリアの切替が簡単に出来ます。',
-	'info_admin_gere_rubriques' => 'この管理者は下記のセクションを管理:',
-	'info_admin_gere_toutes_rubriques' => 'この管理者は<b>すべてのセクション</b>を管理。', # MODIF
 	'info_administrateur' => '管理者',
 	'info_administrateur_1' => '管理者',
 	'info_administrateur_2' => 'サイトについて（<i>注意して使って</i>）',
@@ -173,16 +139,13 @@ SPIPドキュメント</a>をご覧ください。</p>', # MODIF
 	'info_administrer_rubrique' => 'あなたはこのセクションを管理することができる',
 	'info_adresse' => 'そのアドレスへ:',
 	'info_adresse_url' => 'あなたの公開サイトのURL',
-	'info_afficher_visites' => '訪問者の表示:',
 	'info_aide_en_ligne' => 'SPIPオンラインヘルプ',
 	'info_ajout_image' => '記事に添付書類として画像イメージを付け加えるとき、
   SPIPは自動的にヴィニェット＜半身像・ロゴなど＞（サムネイル）を
   挿入された画像から作成します。 これにより例えば
   ギャラリーやポートフォリオの自動作成を可能にします。',
-	'info_ajout_participant' => '次の関係者は加えられた:',
 	'info_ajouter_rubrique' => '管理する他のセクションを追加:',
 	'info_annonce_nouveautes' => '最新のニュースアナウンス',
-	'info_anterieur' => '前候補',
 	'info_article' => '記事',
 	'info_article_2' => '記事',
 	'info_article_a_paraitre' => '公開されている記事の投稿日付',
@@ -190,10 +153,8 @@ SPIPドキュメント</a>をご覧ください。</p>', # MODIF
 	'info_articles_2' => '記事',
 	'info_articles_auteur' => 'この著者の記事',
 	'info_articles_trouves' => '記事が見つかりました',
-	'info_articles_trouves_dans_texte' => '記事が見つかりました（文中）',
 	'info_attente_validation' => '適性検査前のあなたの記事',
 	'info_aujourdhui' => '今日：',
-	'info_auteur_message' => '差出人:',
 	'info_auteurs' => '著者たち',
 	'info_auteurs_par_tri' => '著者@partri@',
 	'info_auteurs_trouves' => '見つかった著者たち',
@@ -226,15 +187,12 @@ SPIPドキュメント</a>をご覧ください。</p>', # MODIF
 	'info_date_publication_anterieure' => '公表時の日付:',
 	'info_date_referencement' => 'このサイトを参照した日付 :',
 	'info_derniere_etape' => '最後のステップ: <b>終わりました！',
-	'info_derniers_articles_publies' => 'あなたの最近公開された記事',
-	'info_desactiver_messagerie_personnelle' => 'あなたはこのサイト上で個人的なメッセージ交換を、するかしないか決められます。',
 	'info_descriptif' => '記述:',
 	'info_discussion_cours' => '進行中の討論',
 	'info_ecrire_article' => '記事を書く前に、あなたは最低１つのセクションを作らなければなりません。',
 	'info_email_envoi' => '送り主のe-mailアドレス（任意）',
 	'info_email_envoi_txt' => 'e-mailを送るのに使っている送り主のe-mailアドレスを入力してください（デフォルトで、受信者のアドレスは送信者のアドレスが入力してあります :',
 	'info_email_webmestre' => 'ウェブマスターのe-mailアドレス（任意）', # MODIF
-	'info_entrer_code_alphabet' => '使っている文字セットのコードを入力してください:',
 	'info_envoi_email_automatique' => 'メールを自動送信',
 	'info_envoyer_maintenant' => '今送る',
 	'info_etape_suivante' => '次のステップに進む',
@@ -244,25 +202,17 @@ SPIPドキュメント</a>をご覧ください。</p>', # MODIF
 	'info_facilite_suivi_activite' => 'サイトでの編集活動のお手伝いのために、SPIPは記事公開要求、適性検査の結果など、メールで自動送信することが出来ます。（例えばメーリングリストなど）',
 	'info_fichiers_authent' => '認証ファイル ".htpasswd"',
 	'info_forums_abo_invites' => 'あなたのサイトはサブスクリプションのための掲示板を持っています; 訪問者達はパブリックなサイトでそれらのために登録するかもしれません。',
-	'info_gauche_admin_effacer' => '<b>管理者のみがこのページにアクセス出来る。</b><p> そのページはさまざまな技術的メンテナンスのための手順を提供します。いくらかの手順では同WEBサイトへのFTPアクセスによる特別な認証手順が必要です。</p>', # MODIF
 	'info_gauche_admin_tech' => '<b>管理者のみがこのページにアクセス出来る。</b><p> そのページはさまざまな技術的メンテナンスのための手順を提供します。いくらかの手順では同WEBサイトへのFTPアクセスによる特別な認証手順が必要です。</p>', # MODIF
 	'info_gauche_admin_vider' => '<b>このページは管理者のみアクセス出来ます。</b><p> このページはいろいろなメンテナンスの手順を提供します。いくつかの手順は同WEBサイトへのアクセスによる特別な認証を必要とします。</p>', # MODIF
 	'info_gauche_auteurs' => 'あなたはサイトの著者たちすべてをここで見つけることができます。
  それぞれの状態はアイコンの色によって示されています（管理者 = 緑; エディター = 黄色）。',
 	'info_gauche_auteurs_exterieurs' => '外部の著者たち、サイトへのどんなアクセスもない、は青いアイコンで示されています; また、削除された著者たちはゴミ箱です。', # MODIF
 	'info_gauche_messagerie' => 'メッセージ交換はエディター同士でのメッセージの交換を可能にします、保護されたメモ（あなたの私用向け）または、プライベートエリアのホームページのアナウンスを示す（あなたが管理者の場合）。',
-	'info_gauche_numero_auteur' => '著者番号',
 	'info_gauche_statistiques_referers' => 'このページは<i>referrers</i>のリストを表示します。つまり昨日と今日の間、あなたのサイトへのリンクを含んだサイト：実際にこのリストは２４時間ごとに初期化されています。',
 	'info_gauche_visiteurs_enregistres' => 'ここでサイトのパブリックなエリアで登録された訪問者たちを探せるでしょう（寄付による掲示板）。',
 	'info_generation_miniatures_images' => '画像のサムネイルを生成',
-	'info_gerer_trad' => '翻訳版同士リンクし合いますか？',
 	'info_hebergeur_desactiver_envoi_email' => '若干のホストでは、それらサーバー上から自動的にメールを送ることが出来ません。そういう場合、SPIPの次の機能は実施できません。',
 	'info_hier' => '昨日：',
-	'info_historique_activer' => 'リビジョン（修正点）の表示を有効にする',
-	'info_historique_affiche' => 'このバージョンを表示',
-	'info_historique_comparaison' => '比較',
-	'info_historique_desactiver' => 'リビジョン（改訂）の表示を無効化する',
-	'info_historique_texte' => '改訂（リビジョン）の追跡で、あなたが記事のすべての変更を記録・追跡することが可能になります。前後バージョンとの記事の変更点を表示することができます。',
 	'info_identification_publique' => 'あなたの公開ID...',
 	'info_image_process' => 'ミニチュアを作る最も良い方法を、対応する写真の上を、クリックして選んでください。',
 	'info_image_process2' => '<b>付記</b> <i>もし画像を見ることが出来なかったら、あなたのサーバーではソフトが使えるように設定してありません。もしあなたがそれらの機能を使いたいなら、プロバイダの技術サポートに«GD»か«Imagick»拡張をインストールしてもらって下さい。</i>', # MODIF
@@ -280,8 +230,6 @@ SPIPドキュメント</a>をご覧ください。</p>', # MODIF
 	'info_login_trop_court' => 'ログインIDが短すぎます。',
 	'info_maximum' => '最大:',
 	'info_meme_rubrique' => '同じセクションで',
-	'info_message' => 'メッセージ from',
-	'info_message_efface' => 'メッセージは削除された',
 	'info_message_en_redaction' => '進行中のあなたのメッセージ',
 	'info_message_technique' => '技術的なメッセージ:',
 	'info_messagerie_interne' => '内部のメッセージ交換',
@@ -293,19 +241,14 @@ SPIPドキュメント</a>をご覧ください。</p>', # MODIF
 	'info_modifier_rubrique' => '修正するセクション:',
 	'info_modifier_titre' => '修正: @titre@',
 	'info_mon_site_spip' => '私のSPIPのサイト',
-	'info_mot_sans_groupe' => '(グループを除いたキーワード...)',
-	'info_moteur_recherche' => '検索エンジンを結合した',
 	'info_moyenne' => '平均：',
-	'info_multi_articles' => '記事用に言語選択メニューを有効にしますか？',
 	'info_multi_cet_article' => 'この記事の言語：',
 	'info_multi_langues_choisies' => 'あなたのサイトのエディターが利用できる言語を下で選んでください。もうすでにあなたのサイト内で（リストの上で）使われている言語は無効に出来ません。',
-	'info_multi_rubriques' => 'セクション用にに言語選択メニューを有効にしますか？',
 	'info_multi_secteurs' => '... ルート（一番上のフォルダ）にあるセクションだけ有効にしますか？',
 	'info_nom' => '名前',
 	'info_nom_destinataire' => '受取人の名前',
 	'info_nom_site' => 'ＨＰの名前',
 	'info_nombre_articles' => '@nb_articles@ 記事、',
-	'info_nombre_partcipants' => '討論の参加者:',
 	'info_nombre_rubriques' => '@nb_rubriques@ セクション、',
 	'info_nombre_sites' => '@nb_sites@サイト、',
 	'info_non_deplacer' => '動かさないで...',
@@ -315,36 +258,26 @@ SPIPドキュメント</a>をご覧ください。</p>', # MODIF
 	'info_non_modifiable' => '変更できない',
 	'info_non_suppression_mot_cle' => '私はこのキーワードを削除することを望みません。',
 	'info_notes' => '補足',
-	'info_nouveaux_message' => '新しいメッセージ',
 	'info_nouvel_article' => '新しい記事',
 	'info_nouvelle_traduction' => '新しい翻訳:',
 	'info_numero_article' => '記事番号:',
 	'info_obligatoire_02' => '[要求した]', # MODIF
 	'info_option_accepter_visiteurs' => 'パブリックなサイトからの訪問者の登録を許可',
-	'info_option_faire_suivre' => '記事の著者たちへ掲示板のメッセージを送る',
 	'info_option_ne_pas_accepter_visiteurs' => '訪問者の登録を断る',
 	'info_options_avancees' => '拡張オプション',
-	'info_ortho_activer' => 'スペルチェッカーを有効にする',
-	'info_ortho_desactiver' => 'スペルチェッカーを無効にする。',
 	'info_ou' => '又は...',
 	'info_page_interdite' => '禁じられたページ',
 	'info_par_nombre_article' => '(記事の数によって)',
 	'info_passe_trop_court' => 'パスワードが短すぎます。',
 	'info_passes_identiques' => 'その二つのパスワードは同一でない。',
-	'info_pense_bete_ancien' => 'あなたの古いメモ類', # MODIF
 	'info_plus_cinq_car' => '６文字以上',
 	'info_plus_cinq_car_2' => '(６文字以上)',
 	'info_plus_trois_car' => '(４文字以上)',
 	'info_popularite' => '人気度: @popularite@; 訪問者: @visites@',
-	'info_popularite_4' => '人気度: @popularite@; 訪問者: @visites@',
 	'info_post_scriptum' => 'Postscript',
 	'info_post_scriptum_2' => 'Postscript:',
 	'info_pour' => 'for',
-	'info_preview_admin' => '管理者のみ、プレビューモードへアクセス出来る',
-	'info_preview_comite' => 'すべての編集者がプレビューモードへアクセス出来る',
-	'info_preview_desactive' => 'プレビューモードは使用不能',
-	'info_preview_texte' => '（少なくとも"提出中"状態の）すべての記事とニュースを公表した時どのように見えるか試しに見ることが出来ます。このプレビューモードは管理人だけに限定するか、すべての編集者に開放するか、完全に無効にすることが出来ます。',
-	'info_principaux_correspondants' => 'あなたの主な通信者',
+	'info_preview_texte' => '（少なくとも"提出中"状態の）すべての記事とニュースを公表した時どのように見えるか試しに見ることが出来ます。このプレビューモードは管理人だけに限定するか、すべての編集者に開放するか、完全に無効にすることが出来ます。', # MODIF
 	'info_procedez_par_etape' => 'どうかステップbyステップで進んでください',
 	'info_procedure_maj_version' => '新しいバージョンのSPIPに順応させるために、データベースをアップグレードするべきです。',
 	'info_ps' => 'P.S.',
@@ -352,13 +285,8 @@ SPIPドキュメント</a>をご覧ください。</p>', # MODIF
 	'info_publies' => 'オンラインに公開されたあなたの記事',
 	'info_question_accepter_visiteurs' => 'もしあなたのサイトのテンプレートが、プライベートエリアに入らないで登録する訪問者たちを許すなら、次のオプションを有効にしてください:',
 	'info_question_inscription_nouveaux_redacteurs' => '公開されているサイトで新しいエディターの登録を募りますか？　許可した場合、訪問者たちはフォームから自動で登録でき、プライベートエリアにアクセスし自分の記事を提出できます。 <blockquote><i>登録作業中に、ユーザーは自動的に送信されるプライベートエリアへのIDとパスワードを記したe-mailを受け取ります。若干のホストでは、それらサーバー上からメールが送れない場合があります：そういう場合、自動登録を実施できません。', # MODIF
-	'info_question_utilisation_moteur_recherche' => 'SPIPに結合された検索エンジンを使いたいですか?
- (無効にするとシステムが早くなります。)',
-	'info_qui_edite' => '@nom_auteur_modif@ a travaillé sur ce contenu il y a @date_diff@ minutes', # MODIF
 	'info_racine_site' => 'サイトのルート',
 	'info_recharger_page' => 'ちょっとしてからこのページを再読込してください。',
-	'info_recherche_auteur_a_affiner' => '"@cherche_auteur@"の検索結果が多すぎます; もうちょっとキーワードをひねって検索して下さい。',
-	'info_recherche_auteur_ok' => '"@cherche_auteur@"に対するエディターが幾人か見つかりました:',
 	'info_recherche_auteur_zero' => '"@cherche_auteur@"は何も見つかりませんでした。',
 	'info_recommencer' => 'もう一度挑戦してみて下さい。',
 	'info_redacteur_1' => '編集者',
@@ -375,7 +303,6 @@ SPIPドキュメント</a>をご覧ください。</p>', # MODIF
 	'info_rubriques' => 'セクション',
 	'info_rubriques_02' => 'セクション',
 	'info_rubriques_trouvees' => '見つかったセクション',
-	'info_rubriques_trouvees_dans_texte' => '見つかったセクション（文中）',
 	'info_sans_titre' => '無名',
 	'info_selection_chemin_acces' => '<b>下を選択</b> ディレクトリのアクセスパス:',
 	'info_signatures' => '署名',
@@ -388,12 +315,10 @@ SPIPドキュメント</a>をご覧ください。</p>', # MODIF
 	'info_sites_lies_mot' => '参照されたサイトをこのキーワードと関連付ける',
 	'info_sites_proxy' => 'プロキシを使う',
 	'info_sites_trouves' => '見つかったサイト',
-	'info_sites_trouves_dans_texte' => '見つかったサイト（文中）',
 	'info_sous_titre' => 'サブタイトル:',
 	'info_statut_administrateur' => '管理者',
 	'info_statut_auteur' => 'この著者の状態:', # MODIF
 	'info_statut_auteur_autre' => 'その他の状態:',
-	'info_statut_efface' => '削除',
 	'info_statut_redacteur' => 'エディター',
 	'info_statut_utilisateurs_1' => '読み込まれたユーザーの標準の状態',
 	'info_statut_utilisateurs_2' => '始めて接続したときにLDAPディレクトリに存在・属している人たちの状態を選択してください。後で、それぞれの著者ごとにケースバイケースで値を変更できます。',
@@ -411,7 +336,6 @@ SPIPドキュメント</a>をご覧ください。</p>', # MODIF
 	'info_tous_articles_en_redaction' => '進行中のすべての記事',
 	'info_tous_articles_presents' => 'このセクションに出版したすべての記事',
 	'info_tous_les' => 'すべて:',
-	'info_tous_redacteurs' => 'すべてのエディターへのアナウンス',
 	'info_tout_site' => '全サイト',
 	'info_tout_site2' => '記事はこの言語へ翻訳されていません。',
 	'info_tout_site3' => '記事はこの言語へ翻訳されていますが、いくつかの別言語版に、その後入力がなされました。翻訳のアップデートを要求します。',
@@ -426,7 +350,6 @@ SPIPドキュメント</a>をご覧ください。</p>', # MODIF
 	'info_une_rubrique' => '１つのセクション、',
 	'info_une_rubrique_02' => '１セクション',
 	'info_url' => 'URL:',
-	'info_url_site' => 'サイトのURL:',
 	'info_urlref' => 'リンク:',
 	'info_utilisation_spip' => 'SPIPが使えるように準備中...',
 	'info_visites_par_mois' => '月単位で表示:',
@@ -443,15 +366,12 @@ SPIPドキュメント</a>をご覧ください。</p>', # MODIF
 	'item_activer_messages_avertissement' => '警告メッセージを作動させる',
 	'item_administrateur_2' => '管理者',
 	'item_afficher_calendrier' => 'カレンダーに表示',
-	'item_autoriser_documents_joints' => 'ドキュメントが記事に結びつくのを許可する',
-	'item_autoriser_documents_joints_rubriques' => 'セクション内のドキュメントを許可する',
 	'item_choix_administrateurs' => '管理者たち',
 	'item_choix_generation_miniature' => '自動的に画像のサムネイルを作る。',
 	'item_choix_non_generation_miniature' => '画像のサムネイルを作らない。',
 	'item_choix_redacteurs' => 'エディターズ',
 	'item_choix_visiteurs' => 'パブリックなサイトの訪問者',
 	'item_creer_fichiers_authent' => '.htpasswdファイルを作る',
-	'item_limiter_recherche' => 'あなたのサイトに含まれている情報に検索を制限する',
 	'item_login' => 'ログインID',
 	'item_mots_cles_association_articles' => '記事',
 	'item_mots_cles_association_rubriques' => 'セクション',
@@ -460,34 +380,24 @@ SPIPドキュメント</a>をご覧ください。</p>', # MODIF
 	'item_non_accepter_inscriptions' => '登録を許可しない',
 	'item_non_activer_messages_avertissement' => '警告メッセージを表示しない',
 	'item_non_afficher_calendrier' => 'カレンダー上に表示しない',
-	'item_non_autoriser_documents_joints' => '記事内のドキュメントを許可しない',
-	'item_non_autoriser_documents_joints_rubriques' => 'セクション内のドキュメントを許可しない',
 	'item_non_creer_fichiers_authent' => 'それらファイルを作らない',
-	'item_non_gerer_statistiques' => '統計を管理しない',
-	'item_non_limiter_recherche' => '参照しているサイトの内容へ検索を拡張する',
 	'item_non_publier_articles' => 'それらの公開日付前に記事を公表しない。',
-	'item_non_utiliser_moteur_recherche' => 'エンジンを使わない',
 	'item_nouvel_auteur' => '新しい著者',
 	'item_nouvelle_rubrique' => '新しいセクション',
 	'item_oui' => 'はい',
 	'item_publier_articles' => 'それらの発表日時を無視して記事を公表する。',
 	'item_reponse_article' => '記事に返信',
-	'item_utiliser_moteur_recherche' => '検索エンジンを使う',
 	'item_visiteur' => '訪問者',
 
 	// J
 	'jour_non_connu_nc' => '未定義',
 
 	// L
-	'lien_ajout_destinataire' => 'この受取人を追加',
 	'lien_ajouter_auteur' => 'この著者を追加',
-	'lien_ajouter_participant' => '関係者を追加',
 	'lien_email' => 'e-mail',
 	'lien_nom_site' => 'サイトの名前:',
 	'lien_retirer_auteur' => '著者を削除',
-	'lien_retrait_particpant' => 'この関係者を削除',
 	'lien_site' => 'サイト',
-	'lien_supprimer_rubrique' => 'このセクションを削除',
 	'lien_tout_deplier' => 'すべて拡張',
 	'lien_tout_replier' => 'すべて壊す',
 	'lien_trier_nom' => '名前でソート',
@@ -513,6 +423,9 @@ SPIPドキュメント</a>をご覧ください。</p>', # MODIF
 	// O
 	'onglet_repartition_actuelle' => '今',
 
+	// R
+	'required' => '[要求した]', # MODIF
+
 	// S
 	'statut_admin_restreint' => '(限定された管理者)', # MODIF
 
@@ -534,13 +447,10 @@ SPIPドキュメント</a>をご覧ください。</p>', # MODIF
 	'texte_article_virtuel_reference' => '<b>仮想記事:</b> あなたのSPIPサイト内の記事を参照しているが、ほかのURLへとリダイレクトしている。リダイレクションを削除するには上のURLを削除して下さい。',
 	'texte_aucun_resultat_auteur' => '"@cherche_auteur@"は見つかりませんでした。',
 	'texte_auteur_messagerie' => 'このサイトはリアルタイムでメッセージ交換できるように、接続中のエディターのリストを絶えず表示することが出来ます。このリストに表れないようにも出来ます。(そうすると、他の著者たちには" 見えません ")。',
-	'texte_auteur_messagerie_1' => 'このサイトはメッセージ交換やサイトの参加者と関係者用の掲示板を作ることができます。あなたはこの交換に参加しないようにも設定出来ます。',
 	'texte_auteurs' => '著者たち',
 	'texte_choix_base_1' => 'あなたのデータベースの選択:',
 	'texte_choix_base_2' => 'SQLサーバーはいくつかのデータベースを含んでいます。',
 	'texte_choix_base_3' => 'あなたのホストがあなたに割り当てたものを<b>下から１つ選んで下さい</b>:',
-	'texte_commande_vider_tables_indexation' => 'この手順を使うとSPIPに結合された検索エンジンが使っているインデックステーブルが空になります。いくらかのディスクが空くことでしょう。',
-	'texte_compresse_ou_non' => '(これが圧縮できなかったか、違う)',
 	'texte_compte_element' => '@count@ 要素',
 	'texte_compte_elements' => '@count@ 要素',
 	'texte_connexion_mysql' => 'あなたのホストからあなたに提供されている情報を参照して下さい: もしあなたのホストがSQL、SQLサーバーへの接続コードをサポートするなら、それはあなたを与えるべきです。', # MODIF
@@ -552,10 +462,8 @@ SPIPドキュメント</a>をご覧ください。</p>', # MODIF
 	'texte_date_publication_anterieure' => '公開前の日付:',
 	'texte_date_publication_anterieure_nonaffichee' => '公表前の日時を隠す。',
 	'texte_date_publication_article' => 'オンラインに公表された日時:',
-	'texte_descriptif_petition' => '署名内容の説明',
 	'texte_descriptif_rapide' => '短い記述',
 	'texte_effacer_base' => 'SPIPデータベースを削除',
-	'texte_effacer_donnees_indexation' => 'インデックスデータを削除',
 	'texte_en_cours_validation' => '次の記事およびニュースは公表するために送られました。それらの掲示板を通してあなたの意見を述べることを、どうぞためらわないでください。', # MODIF
 	'texte_enrichir_mise_a_jour' => 'あなたは、«印刷上のショートカット»を使うことによってあなたの文章のレイアウトを豊かにすることができます。',
 	'texte_fichier_authent' => '<b>SPIPは<tt>.ecrire/data/</tt>フォルダ内に<tt>.htpasswd</tt>ファイルと<tt>.htpasswd-admin</tt>ファイルを作るべきですか？</b><p>それらのファイルであなたのサイトの他の部分で、著者たちと管理者に限定したアクセスを使うことが出来ます。（例えば、外部の統計プログラムとか）。</p><p>
@@ -564,21 +472,15 @@ SPIPドキュメント</a>をご覧ください。</p>', # MODIF
 	'texte_informations_personnelles_2' => '(メモ: もしそれが再インストールであり、そしてあなたのアクセスがまだ機能しているなら、あなたは', # MODIF
 	'texte_introductif_article' => '（記事の紹介文章。）',
 	'texte_jeu_caractere' => 'このオプションはあなたのサイトがローマ字（«western»）とその派生物以外の文字セット（日本語など）を表示する場合に使用すると便利です。そういう場合、自分にあった文字コード（文字の設定）に変えなければいけません。とにかく、私たちは正しいのを探すために違うのを試してみることを勧めします。もしこの設定を変更したなら、忘れずに<tt>#CHARSET</tt>タグにあわせて公開しているサイトを変更してください。',
-	'texte_jeu_caractere_2' => 'この設定はさかのぼって有効にはなりません。したがって、この設定を変更した後、文章が文字化けする可能性があります。いずれにしても、あなたはいつでも前の設定に戻すことが出来ます。',
-	'texte_lien_hypertexte' => '（もしあなたのメッセージがウェブに公開されている記事か、さらなる情報を提供しているページへリンクしている場合、ここにページのタイトルとURLを入力してください。）',
 	'texte_login_ldap_1' => '（匿名アクセスのために空状態にしておくか、完全なパスを入力、例えば、«<tt>uid=smith, ou=users, dc=my-domain, dc=com</tt>»。）',
 	'texte_login_precaution' => '警告! これは今あなたが接続しているログインIDです。
  注意してこのフォームを使ってください...',
-	'texte_message_edit' => '警告：このメッセージはすべてのサイト管理者によって変更することができます、そしてすべてのエディターに表示されます。サイト生活での重要な出来事を強調するときのみ、アナウンスを使ってください。',
 	'texte_mise_a_niveau_base_1' => 'あなたはちょうど今SPIPのファイルを更新しました
  今あなたはサイトのデータベースも更新しなければなりません。',
 	'texte_modifier_article' => '修正する記事:',
-	'texte_moteur_recherche_active' => '<b>検索エンジンは有効になっています。</b>すばやく再度インデックスしたいならこれを実行してください（例えばバックアップを復元した後など）。気をつけてください、（SPIPのインターフェースから）普通に変更されたドキュメントは再度自動的にインデックスされています。：そのためこのコマンドは特別な事情があるときだけ有用です。',
-	'texte_moteur_recherche_non_active' => '検索エンジンが無効です。',
 	'texte_multilinguisme' => 'もし記事をいくつかの言語で管理したいなら、完全なナビゲーション インターフェースによって、あなたのサイトの組織の記事と、セクションに言語選択メニューを追加できます。', # MODIF
 	'texte_multilinguisme_trad' => '同じく、あなたは１つの記事の、違う翻訳版間のリンク管理システムを有効にできます。', # MODIF
 	'texte_non_compresse' => '<i>未圧縮</i>（あなたのサーバーでこの機能は使えません）',
-	'texte_nouveau_message' => '新しいメッセージ',
 	'texte_nouvelle_version_spip_1' => 'たった今SPIPの新しいバージョンがインストールされました。',
 	'texte_nouvelle_version_spip_2' => 'この新しいバージョンはこまめに更新（アップデート）することが必要となります。もしこのサイトの管理者なら、<tt>ecrire</tt>ディレクトリの<tt>inc_connect.php3</tt>ファイルを削除して、あなたのデータベースとの接続の仕方などを変更するためインストールを再度実施してください。<p>（付記：もし接続用の情報などを忘れているのなら、<tt>inc_connect.php3</tt>を"削除する前に"見ておいてください。）</p>', # MODIF
 	'texte_operation_echec' => '前のページに戻って、他のデータベースを選択するか、新しいのを作ってください。あなたのホストに提供された情報を確認してみてください。',
@@ -590,7 +492,6 @@ SPIPドキュメント</a>をご覧ください。</p>', # MODIF
 	'texte_publication_articles_post_dates' => '出版用に未来の日付が設定された記事に対するSPIPの対応を決めて下さい。',
 	'texte_rappel_selection_champs' => '[忘れずにこの部分をきちんと選択してください。]',
 	'texte_recalcul_page' => 'もしあなたが１つのページだけリフレッシュしたい場合、公開エリアで« リフレッシュ »ボタンを使った方が良いです。',
-	'texte_recapitiule_liste_documents' => 'このページはセクション内に置いてあるドキュメントのリストのまとめです。それぞれのドキュメントの情報を変更するには、次の（置いてあるセクションへリンクしている）リンクをクリックしてください。',
 	'texte_recuperer_base' => 'データベースを復元',
 	'texte_reference_mais_redirige' => 'あなたのSPIPサイト内の記事を参照しているけれど、他のURLへとリダイレクションしている。',
 	'texte_requetes_echouent' => '<b>いくらかのSQLの要求（クエリー）がシステム的に何も理由を表さず失敗したとき、データベース自体が壊れている可能性があります。</b><p>SQLは偶然壊れたとき、また使えるようにテーブルの機能を修復します。ここで、あなたはこの修復に挑戦できます; 失敗した場合、あなたは画面の複製をとっておくべきです。何が悪かったのかが書いてあるかもしれません。</p><p>もし問題が残っているなら、あなたのホストと連絡をとってください。</p>', # MODIF
@@ -611,7 +512,6 @@ SPIPドキュメント</a>をご覧ください。</p>', # MODIF
 	'texte_suppression_fichiers' => 'これを使うとSPIPのすべてのキャッシュファイルが削除されます。これを許可すると、特にサイトの構造や画像の重要な変更を入力している場合に備えて、すべてのページのリフレッシュを強制します。',
 	'texte_sur_titre' => 'トップタイトル',
 	'texte_table_ok' => ': このテーブルはOK。',
-	'texte_tables_indexation_vides' => '空のエンジンのテーブルをインデックス',
 	'texte_tentative_recuperation' => '復元を試みる',
 	'texte_tenter_reparation' => 'データベースの復元を試みる',
 	'texte_test_proxy' => 'このプロキシを試すために、ここにあなたがテストしてみたいウェブサイトのアドレスを入力してください。',
@@ -619,13 +519,8 @@ SPIPドキュメント</a>をご覧ください。</p>', # MODIF
 	'texte_titre_obligatoire' => '<b>タイトル</b> [必須]',
 	'texte_travail_article' => '@nom_auteur_modif@は、@date_diff@分前、この記事で働いていた',
 	'texte_travail_collaboratif' => '同じ記事上で数人のエディターが頻繁に働くと、システムは記事が同時に修正されるのを防ぐために最近«開かれた»と表示することができます。このオプションはたくさん警告メッセージが表示されるのを防ぐため、初めは無効になっています。',
-	'texte_trop_resultats_auteurs' => '"@cherche_auteur@"に対する結果が多すぎます; キーワードをひねって検索してください。',
-	'texte_unpack' => '最新バージョンをダウンロード',
-	'texte_utilisation_moteur_syndiques' => 'あなたがSPIPに結合された検索エンジンを使うとき、サイト上と供給（シンジケート）されている記事を違った態度で検索することができます。<br /><img src=\'puce.gif\' />最も簡単なのは記事のタイトルと記述だけを検索することです。<br /><img src=\'puce.gif\' />もっと強力な２番目の方法は、同じように参照されているサイト内の文も検索できます。もしあなたがサイトを参照するなら、SPIPはサイトの文自体の検索を行うでしょう。', # MODIF
-	'texte_utilisation_moteur_syndiques_2' => 'この方法は定期的に参照しているサイトへ訪問することを強います。あなた自身のサイトに少々負担を掛けます。',
 	'texte_vide' => '空にする',
 	'texte_vider_cache' => 'キャッシュを空にする',
-	'titre_admin_effacer' => '技術的なメンテナンス',
 	'titre_admin_tech' => '技術的なメンテナンス',
 	'titre_admin_vider' => '技術的なメンテナンス',
 	'titre_cadre_afficher_article' => '記事の表示:',
@@ -645,40 +540,25 @@ SPIPドキュメント</a>をご覧ください。</p>', # MODIF
 	'titre_naviguer_dans_le_site' => 'このサイトをブラウザする...',
 	'titre_nouvelle_rubrique' => '新しいセクション',
 	'titre_numero_rubrique' => 'セクション番号:',
-	'titre_page_admin_effacer' => '技術的なメンテナンス: データベースを削除しています',
 	'titre_page_articles_edit' => '変更: @titre@',
 	'titre_page_articles_page' => '記事',
 	'titre_page_articles_tous' => '全てのサイト',
-	'titre_page_auteurs' => '訪問者たち',
 	'titre_page_calendrier' => 'カレンダー @nom_mois@ @annee@',
 	'titre_page_config_contenu' => 'サイトの設定',
-	'titre_page_config_fonctions' => 'サイトの設定',
-	'titre_page_configuration' => 'サイトの設定',
-	'titre_page_controle_petition' => '署名の把握',
 	'titre_page_delete_all' => '撤回できない、ページ全体の削除',
-	'titre_page_documents_liste' => '付属した文章',
-	'titre_page_index' => 'あなたのプライベートエリア',
-	'titre_page_message_edit' => 'メッセージを書く',
-	'titre_page_messagerie' => 'あなたのメッセージング',
 	'titre_page_recherche' => '検索語 @recherche@ による検索結果',
 	'titre_page_statistiques_referers' => '統計（入ってくるリンク）',
 	'titre_page_upgrade' => 'SPIPアップグレード',
 	'titre_publication_articles_post_dates' => '記事の投稿時間の公開',
-	'titre_referencer_site' => 'サイトの参照:',
-	'titre_rendez_vous' => '約束:',
 	'titre_reparation' => '修理',
 	'titre_suivi_petition' => '署名の把握',
-	'trad_article_inexistant' => 'この番号には記事はありません',
 	'trad_article_traduction' => '記事のすべてのバージョン:',
-	'trad_deja_traduit' => 'この記事は、それ自身現在の記事の翻訳です。',
 	'trad_delier' => 'この記事をその翻訳に関連付けないで下さい。', # MODIF
 	'trad_lier' => 'この記事はこの記事番号の翻訳です:',
 	'trad_new' => 'この記事の新しい翻訳を書く', # MODIF
 
 	// U
 	'utf8_convert_erreur_orig' => 'エラー: その文字セット　@charset@　は、対応していません。',
-	'utf8_convert_termine' => '完了しました!!',
-	'utf8_convertir_votre_site' => 'あなたのサイトをutf-8に変換します。',
 
 	// V
 	'version' => 'バージョン:'
