@@ -3,7 +3,9 @@
 // extrait automatiquement de http://trad.spip.net/tradlang_module/ecrire_?lang_cible=km
 // ** ne pas modifier le fichier **
 
-if (!defined('_ECRIRE_INC_VERSION')) return;
+if (!defined('_ECRIRE_INC_VERSION')) {
+	return;
+}
 
 $GLOBALS[$GLOBALS['idx_lang']] = array(
 
@@ -149,8 +151,6 @@ $GLOBALS[$GLOBALS['idx_lang']] = array(
 	'image_administrer_rubrique' => 'អ្នក​អាច​គ្រប់គ្រង​ផ្នែក​នេះ',
 	'info_1_article' => 'អត្ថបទ ១',
 	'info_activer_cookie' => 'អ្នអ្នក អាចធ្វើអោយសកម្ម មួយ <b>ខូកឃីឆ្លងឆ្លើយ</b>, វា នឹងអនុញ្ញាតអ្នក ងាយដើរ ពីសៃថ៍សាធារណះ ទៅសៃថ៍ឯកជន។',
-	'info_admin_gere_rubriques' => 'អ្នកគ្រប់គ្រង​នេះ​ចាត់ចែង​ផ្នែក​ដូច​ខាងក្រោម ៖',
-	'info_admin_gere_toutes_rubriques' => 'អ្នកអភិបាលនេះ គ្រប់គ្រង <b>គ្រប់ផ្នែក</b>។', # MODIF
 	'info_administrateur' => 'អ្នកគ្រប់គ្រង',
 	'info_administrateur_1' => 'អ្នកគ្រប់គ្រង',
 	'info_administrateur_2' => 'នៃសៃថ៍ (<i>ប្រើប្រាស់ ដោយប្រយត្ន</i>)',
@@ -307,7 +307,7 @@ $GLOBALS[$GLOBALS['idx_lang']] = array(
 	'info_post_scriptum' => 'បដ្ឋនាលិខិត',
 	'info_post_scriptum_2' => 'បដ្ឋនាលិខិត',
 	'info_pour' => 'សំរាប់',
-	'info_preview_texte' => 'គ្មានអាចមើលមុន សៃថ៍ ដូចដែលគ្រប់អត្ថបទ និងខ្ទង់ដំណឹង (ដែលមានយ៉ាងតិច ស្ថានភាព "បានដាក់ស្នើ") ត្រូវបានបោះផ្សាយហើយ។ បែបមើលមុននេះ គួរត្រូវបានអនុញ្ញាត សំរាប់ពួកអ្នកអភិបាល, បើក សំរាប់គ្រប់អ្នកនិពន្ធ, ឬ គ្មានអនុញ្ញាតទាំងស្រុង?',
+	'info_preview_texte' => 'គ្មានអាចមើលមុន សៃថ៍ ដូចដែលគ្រប់អត្ថបទ និងខ្ទង់ដំណឹង (ដែលមានយ៉ាងតិច ស្ថានភាព "បានដាក់ស្នើ") ត្រូវបានបោះផ្សាយហើយ។ បែបមើលមុននេះ គួរត្រូវបានអនុញ្ញាត សំរាប់ពួកអ្នកអភិបាល, បើក សំរាប់គ្រប់អ្នកនិពន្ធ, ឬ គ្មានអនុញ្ញាតទាំងស្រុង?', # MODIF
 	'info_procedez_par_etape' => 'សូម​ដំណើរការ​មួយ​ជំហាន​ម្ដងៗ',
 	'info_procedure_maj_version' => 'គួរ​បើក​ដំណើរការ​នីតិវិធី​កែ​លំអ​ដើម្បី​សម្រួល​ដល់​ការ​ប្រើប្រាស់​ទិន្នន័យ​ទៅ​ក្នុង​វើ​សឹ​ន (version) របស់ SPIP',
 	'info_proxy_ok' => 'ការ​ពិនិត្យ​លើ​វើ​សឹ​ន​ថ្មី​ទទួល​បាន​ជោគជ័យ​។',
@@ -316,7 +316,6 @@ $GLOBALS[$GLOBALS['idx_lang']] = array(
 	'info_publies' => 'រាល់អត្ថបទ របស់អ្នក ត្រូវបានបោះផ្សាយ លើអិនរើណែត',
 	'info_question_accepter_visiteurs' => 'ប្រសិនបើ​ទម្រង់​វ៉ិ​ប​សាយ​របស់​លោក​អ្នក​អនុញ្ញាត​ឱ្យ​អ្នក​ទស្សនា​ចុះ​ឈ្មោះ​ដោយ​មិន​ចាំបាច់​ចូល​ទៅ​ក្នុង​ផ្នែក​ឯកជន សូម​បើកមុខ​ងារ​ជំរើស​ខាងក្រោមៈ',
 	'info_question_inscription_nouveaux_redacteurs' => 'តើ​លោក​អ្នក​ត្រូវការ​អនុញ្ញាត​ឱ្យ​អ្នក​សរសេរ​អត្ថបទ​ថ្មី​ចុះ​ឈ្មោះ​ពី​វ៉ិ​ប​សាយ​សាធារណៈ​ដែល​ឬទេ​? ប្រសិនបើ​លោក​អ្នក​យល់ព្រម អ្នក​ទស្សនា​នឹង​អាច​ចុះ​ឈ្មោះ​ដោយ​ប្រើប្រាស់​ទម្រង់​ស្វ័យប្រវត្ដិ​មួយ ហើយ​បន្ទាប់​មក​ចូល​ក្នុង​ផ្នែក​ឯកជន​ដើម្បី​បញ្ចូល​អត្ថបទ​ផ្ទា់ល់​របស់​ពួក​គេ​។ <blockquote> ក្នុង​ពេល​ដំណើរការ​ចុះ​ឈ្មោះ អ្នក​ប្រើប្រាស់​ទទួល​បាន​អ៊ី​ម៉ែ​ល​ស្វ័យប្រវត្ដិ​ដែល​ផ្ដល់​ជូន​ពួក​គេ​នូវ​លេខ​កូដ​ចូល​ទៅ​ក្នុង​ផ្នែក​ឯកជន​។ ក្រុមហ៊ុន​ផ្ដល់​សេវា​មួយ​ចំនួន​មិន​អនុញ្ញាត​ចំពោះ​ការ​ផ្ញើ​អ៊ី​ម៉ែ​ល​ម៉ាស៊ីន​មេ (servers)​របស់​ពួក​គេ​ទេ ៖ ក្នុង​ករណី​នោះ ការ​ចុះ​ឈ្មោះ​ដោយ​ស្វ័យប្រវត្ដិ​គឺ​មិន​អាច​អនុវត្ដ​បាន​ទេ​។', # MODIF
-	'info_qui_edite' => '@nom_auteur_modif@ a travaillé sur ce contenu il y a @date_diff@ minutes', # MODIF
 	'info_racine_site' => 'ឫស នៃវ៉ែបសៃថ៍',
 	'info_recharger_page' => 'សូម​បញ្ចូល​ទំព័រ​នេះ​ជា​ថ្មី​ម្ដងទៀត​នៅ​មួយសន្ទុះ​ក្រោយ',
 	'info_recherche_auteur_zero' => 'គ្មាន​លទ្ធផល​ទេ​សំរាប់ \\"@cherche_auteur@\\".',
