@@ -3,7 +3,9 @@
 // extrait automatiquement de http://trad.spip.net/tradlang_module/ecrire_?lang_cible=my
 // ** ne pas modifier le fichier **
 
-if (!defined('_ECRIRE_INC_VERSION')) return;
+if (!defined('_ECRIRE_INC_VERSION')) {
+	return;
+}
 
 $GLOBALS[$GLOBALS['idx_lang']] = array(
 
@@ -135,8 +137,6 @@ $GLOBALS[$GLOBALS['idx_lang']] = array(
 	'image_administrer_rubrique' => 'ဤကဏ္ဍကို သင်စီမံနိုင်သည်',
 	'info_1_article' => '၁ ဆောင်းပါး',
 	'info_activer_cookie' => 'ကိုယ်ပိုင်နေရာနှင့် အများသုံးဝက်ဘ်ဆိုက်ကြားသို့ အလွယ်တကူကူးနိုင်ရန် သင့်ကိုခွင့်ပြုထားသော  <b>ကြီးကြပ်သူကွတ်ကီး</b>တခုကို သင်အသက်သွင်းနိုင်သည်',
-	'info_admin_gere_rubriques' => 'ဤကြီးကြပ်သူသည် အောက်ပါကဏ္ဍများကို စီမံသည်',
-	'info_admin_gere_toutes_rubriques' => 'ဤဝက်ဘ်ဆိုက် ကြီးကြပ်သူသည်<b>ကဏ္ဍအားလုံး</b>ကို စီမံခန့်ခွဲသည်', # MODIF
 	'info_administrateur' => 'ကြီးကြပ်သူ',
 	'info_administrateur_1' => 'ကြီးကြပ်သူ',
 	'info_administrateur_2' => 'ဝက်ဆိုက်၏ (<i>သတိပေးချက်နှင့်အသုံးပြုပါ</i>)',
@@ -279,7 +279,7 @@ $GLOBALS[$GLOBALS['idx_lang']] = array(
 	'info_post_scriptum' => 'ပို့စခရစ် (ပရိုဂရမ်ဘာသာစကား)',
 	'info_post_scriptum_2' => 'ပို့စခရစ် (ပရိုဂရမ်ဘာသာစကား)',
 	'info_pour' => 'အတွက်',
-	'info_preview_texte' => 'ဤဆိုက်ပေါ်ရှိ ဆောင်းပါးများ၊ သတင်းများ အားလုံးကို ကြည့်ရှုနိုင်ပါသည် (ထုတ်ဝေရန် တင်သွင်းပြီး၊ ထုတ်ဝေပြီးသား ဆိုရင်)။ ဤသို့ကြည့်ရှုခွင့်ကို စီမံကြီးကြပ်သူများ အ​တွက်သီးသန့် ဖြစ်စေလိုပါသလား (သို့) စာရေးသူများ အားလုံးကို ခွင့်ပြုလိုပါသလား (သို့) လုံးဝဥတုံ ပိတ်ထားချင်သလား?',
+	'info_preview_texte' => 'ဤဆိုက်ပေါ်ရှိ ဆောင်းပါးများ၊ သတင်းများ အားလုံးကို ကြည့်ရှုနိုင်ပါသည် (ထုတ်ဝေရန် တင်သွင်းပြီး၊ ထုတ်ဝေပြီးသား ဆိုရင်)။ ဤသို့ကြည့်ရှုခွင့်ကို စီမံကြီးကြပ်သူများ အ​တွက်သီးသန့် ဖြစ်စေလိုပါသလား (သို့) စာရေးသူများ အားလုံးကို ခွင့်ပြုလိုပါသလား (သို့) လုံးဝဥတုံ ပိတ်ထားချင်သလား?', # MODIF
 	'info_procedez_par_etape' => 'အဆင့်လိုက်စတင်လုပ်ဆောင်ပါ',
 	'info_procedure_maj_version' => 'အဆင့်မြှင့်တင် လုပ်ဆောင်မှုသည် SPIP၏ သိုလှောင်မှု မူကွဲအသစ်နှင့် ကိုက်ညီရန် လိုအပ်သည်',
 	'info_proxy_ok' => 'proxy စမ်းသပ်မှုအောင်မြင်သည်',
