@@ -3,7 +3,9 @@
 // extrait automatiquement de http://trad.spip.net/tradlang_module/ecrire_?lang_cible=oc_lnc
 // ** ne pas modifier le fichier **
 
-if (!defined('_ECRIRE_INC_VERSION')) return;
+if (!defined('_ECRIRE_INC_VERSION')) {
+	return;
+}
 
 $GLOBALS[$GLOBALS['idx_lang']] = array(
 
@@ -23,66 +25,40 @@ $GLOBALS[$GLOBALS['idx_lang']] = array(
 	'avis_connexion_ldap_echec_2' => 'Tornatz a la pagina anteriora, e verificatz las informacions qu’avètz fornidas. ',
 	'avis_connexion_ldap_echec_3' => 'Alternativament, utilizetz pas lo supòrt LDAP per importar d’utilizaires.',
 	'avis_deplacement_rubrique' => 'Atention! Aquela rubrica conten @contient_breves@ brèvas@scb@: se la desplaçatz, voldretz ben oscar aquela casa de confirmacion.',
-	'avis_destinataire_obligatoire' => 'Devètz indicar un destinatari abans de mandar aquel messatge.',
 	'avis_erreur_connexion_mysql' => 'Error de connexion SQL',
-	'avis_erreur_version_archive' => '<b>Atencion! Lo fichièr @archive@ correspond a una autra version d’SPIP que la qu’avètz installada.</b> Anatz cap a de dificultats grandassas: risca de destruccion de vòstra basa de donadas, disfoncionaments divèrses del sit, etc. Validetz pas aquela demanda d’importacion.<p> Per mai d’informacions, vejatz
-<a href="@spipnet@">
-la documentacion d’SPIP</a>.', # MODIF
 	'avis_espace_interdit' => '<b>Espaci proïbit</b><div>SPIP es ja installat.</div>',
 	'avis_lecture_noms_bases_1' => 'Lo programa d’installacion a pas pogut legir los noms de las basas de donadas installadas.',
 	'avis_lecture_noms_bases_2' => 'Siá cap de basa es pas disponibla, siá la foncion que permet d’entierar las basas es estada desactivada per de rasons de seguretat (aquò’s lo cas en cò de mai d’un albergador).',
 	'avis_lecture_noms_bases_3' => 'Dins la segonda alternativa, es probable qu’una basa que pòrta lo vòstre nom de login siá utilizabla:',
-	'avis_non_acces_message' => 'Podètz pas accedir a aquel messatge.',
 	'avis_non_acces_page' => 'Podètz pas accedir a aquela pagina.',
 	'avis_operation_echec' => 'L’operacion a abocat.',
 	'avis_operation_impossible' => 'Operacion impossibla',
-	'avis_probleme_archive' => 'Problèma de lectura del fichièr @archive@',
 	'avis_suppression_base' => 'ATENCION, suprimir las donadas es irreversible',
-	'avis_version_mysql' => 'Vòstre servidor SQL (@version_mysql@) permet pas l’autoreparacion de las taulas de la basa.',
 
 	// B
 	'bouton_acces_ldap' => 'Apondre l’accès a LDAP >>',
 	'bouton_ajouter' => 'Apondre',
-	'bouton_ajouter_participant' => 'APONDRE UN PARTICIPANT:',
-	'bouton_annonce' => 'ANONCI',
 	'bouton_annuler' => 'Anullar',
-	'bouton_checkbox_envoi_message' => 'possibilitat de mandar un messatge',
-	'bouton_checkbox_indiquer_site' => 'indicar obligatòriament un sit web',
-	'bouton_checkbox_signature_unique_email' => 'sonque una signatura per adreiça e-mail',
-	'bouton_checkbox_signature_unique_site' => 'sonque una signatura per sit web',
 	'bouton_demande_publication' => 'Demandar la publicacion d’aqueste article',
 	'bouton_desactive_tout' => 'Desactivar tot',
 	'bouton_desinstaller' => 'Desinstallar',
-	'bouton_effacer_index' => 'Escafar los indèxes',
 	'bouton_effacer_tout' => 'O escafar tot',
-	'bouton_envoi_message_02' => 'MANDAR UN MESSATGE',
 	'bouton_envoyer_message' => 'Messatge definitiu: mandar',
 	'bouton_modifier' => 'Modificar',
-	'bouton_pense_bete' => 'MEMENTO (D’USATGE PERSONAL)',
-	'bouton_radio_activer_messagerie' => 'Activar la messatjariá intèrna',
-	'bouton_radio_activer_messagerie_interne' => 'Activar la messatjariá intèrna',
-	'bouton_radio_activer_petition' => 'Activar la peticion',
 	'bouton_radio_afficher' => 'Afichar',
 	'bouton_radio_apparaitre_liste_redacteurs_connectes' => 'Afichar dins la tièra dels redactors connectats',
-	'bouton_radio_desactiver_messagerie' => 'Desactivar la messatjariá',
 	'bouton_radio_envoi_annonces_adresse' => 'Mandar los anoncis a l’adreiça:',
 	'bouton_radio_envoi_liste_nouveautes' => 'Mandar la tièra de las novetats',
 	'bouton_radio_non_apparaitre_liste_redacteurs_connectes' => 'Aparéisser pas dins la tièra dels redactors',
 	'bouton_radio_non_envoi_annonces_editoriales' => 'Mandar pas d’anoncis editorials',
-	'bouton_radio_pas_petition' => 'Pas cap de peticion',
-	'bouton_radio_petition_activee' => 'Peticion activada',
-	'bouton_radio_supprimer_petition' => 'Suprimir la peticion',
 	'bouton_redirection' => 'TORNAR DIRIGIR',
 	'bouton_relancer_installation' => 'Tornar lançar l’installacion',
 	'bouton_suivant' => 'Seguent',
 	'bouton_tenter_recuperation' => 'Ensajar de reparar',
 	'bouton_test_proxy' => 'Ensajar lo proxy',
 	'bouton_vider_cache' => 'Vojar l’escondedor',
-	'bouton_voir_message' => 'Veire aquel messatge abans de lo validar',
 
 	// C
-	'cache_mode_compresse' => 'Los fichièrs de l’escondedor son registrats en mòde comprimit.',
-	'cache_mode_non_compresse' => 'Los fichièrs de l’escondedor son registrats en mòde non comprimit.',
 	'cache_modifiable_webmestre' => 'Lo webmèstre del sit pòt modificar aqueste paramètre.',
 	'calendrier_synchro' => 'S’utilizatz un logicial d’agenda compatible <b>iCal</b>, lo podètz sincronizar amb las informacions d’aqueste sit.',
 	'config_activer_champs' => 'Activar los camps seguents',
@@ -94,7 +70,6 @@ la documentacion d’SPIP</a>.', # MODIF
 	'config_info_redirection' => 'En activar aquela opcion, vous poirretz crear d’articles virtuals, que son de referéncias a d’articles publicats sus d’autres sits o fòra  SPIP.',
 	'config_redirection' => 'Articles virtuals',
 	'connexion_ldap' => 'Conexion :',
-	'copier_en_local' => 'Copiar en local',
 
 	// D
 	'date_mot_heures' => 'oras',
@@ -120,7 +95,6 @@ L’administrator del sistèma o de la ret vos deu poder fornir
 	'entree_login' => 'Lo vòstre login',
 	'entree_login_connexion_1' => 'Lo login de connexion',
 	'entree_login_connexion_2' => '(Correspond de còps al vòstre login d’accès a l’FTP; de còps se daissa vuèg)',
-	'entree_login_ldap' => 'Login LDAP inicial',
 	'entree_mot_passe' => 'Vòstre mot de santa Clara',
 	'entree_mot_passe_1' => 'Mot de santa Clara per la connexion',
 	'entree_mot_passe_2' => '(Correspond de còps a vòstre mot de santa Clara per l’FTP; de còps se daissa vuèg)',
@@ -147,7 +121,7 @@ L’administrator del sistèma o de la ret vos deu poder fornir
 	'ical_info2' => 'Per téner mai d’informacions subre aquelas tecnicas, esitetz pas de consultar <a href="@spipnet@">la documentacion d’SPIP</a>.', # MODIF
 	'ical_info_calendrier' => 'I a dos calendièrs a la vòstra disposicion. Lo primièr es un plan del sit qu’anóncia totes los articles publicats. Lo segond conten los anoncis editorials en mai de vòstres darrièrs messatges privats: vos es reservat gràcias a una clau personala, que la podètz modificar en tot moment en renovant vòstre mot de santa Clara. ',
 	'ical_methode_http' => 'Telecargament',
-	'ical_methode_webcal' => 'Sincronizacion (webcal://)',
+	'ical_methode_webcal' => 'Sincronizacion (webcal://)', # MODIF
 	'ical_texte_js' => 'Los articles publicats en aquel sit se pòdon afichar aisit, dins totes los sits vòstres, en far servir una linha javascript. ',
 	'ical_texte_prive' => 'Aquel calendièr, d’us estrictament personal, vos informa de l’activitat editoriala privada d’aquel sit (òbras e rendètz-vos personals, articles e brèvas prepausats...).',
 	'ical_texte_public' => 'Aquel calendièr vos permet de seguir l’activitat publica d’aquel sit (articles e brèvas publicats).',
@@ -163,12 +137,8 @@ L’administrator del sistèma o de la ret vos deu poder fornir
 	'icone_calendrier' => 'Calendièr',
 	'icone_creer_auteur' => 'Crear un autor nòu e l’associar a aquel article',
 	'icone_creer_mot_cle' => 'Crear un mot clau nòu e lo ligar a aquel article',
-	'icone_creer_mot_cle_rubrique' => 'Crear un mot-clau nòu e lo ligar a aquela rubrica',
-	'icone_creer_mot_cle_site' => 'Crear un mot-clau nòu e lo ligar a aquel sit',
 	'icone_creer_rubrique_2' => 'Crear una rubrica nòva',
-	'icone_envoyer_message' => 'Mandar aquel messatge',
 	'icone_modifier_article' => 'Modificar aquel article',
-	'icone_modifier_message' => 'Modificar aquel messatge',
 	'icone_modifier_rubrique' => 'Modificar aquela rubrica',
 	'icone_retour' => 'Tornar',
 	'icone_retour_article' => 'Tornar a l’article',
@@ -178,10 +148,7 @@ L’administrator del sistèma o de la ret vos deu poder fornir
 	'icone_valider_signature' => 'Validar aquela signatura',
 	'image_administrer_rubrique' => 'Podètz administrar aquela rubrica',
 	'info_1_article' => '1 article',
-	'info_1_site' => '1 sit',
 	'info_activer_cookie' => 'Podètz activar un <b>cookie de correspondéncia</b>; aquò vos permetrà de passar aisit del sit public al sit privat.',
-	'info_admin_gere_rubriques' => 'Aquel administrator gerís las rubricas seguentas :',
-	'info_admin_gere_toutes_rubriques' => 'Aquel administrator gerís <b>totas las rubricas</b>.', # MODIF
 	'info_administrateur' => 'Administrator',
 	'info_administrateur_1' => 'Administrator',
 	'info_administrateur_2' => 'del sit(<i>d’utilizar amb precaucion</i>)',
@@ -191,13 +158,10 @@ L’administrator del sistèma o de la ret vos deu poder fornir
 	'info_administrer_rubrique' => 'Podètz administrar aquela rubrica',
 	'info_adresse' => 'a l’adreiça:',
 	'info_adresse_url' => 'Adreiça (URL) del sit public',
-	'info_afficher_visites' => 'Afichar las vesitas per:',
 	'info_aide_en_ligne' => 'Ajuda en linha SPIP',
 	'info_ajout_image' => 'Quand apondètz d’imatges coma estacaments jonches a un article, SPIP pòt crear automaticament per vos de vinhetas (miniaturas) dels imatges inserits. Aquò permet per exemple de crear automaticament una galariá o un pòrtfòlio.',
-	'info_ajout_participant' => 'Lo participant seguent es apondut :',
 	'info_ajouter_rubrique' => 'Apondre una autra rubrica d’administrar:',
 	'info_annonce_nouveautes' => 'Anonci de las novetats',
-	'info_anterieur' => 'anteriora',
 	'info_article' => 'article',
 	'info_article_2' => 'articles',
 	'info_article_a_paraitre' => 'Los articles pòstdatats per paréisser',
@@ -205,10 +169,8 @@ L’administrator del sistèma o de la ret vos deu poder fornir
 	'info_articles_2' => 'Articles',
 	'info_articles_auteur' => 'Los articles d’aquel autor',
 	'info_articles_trouves' => 'Articles trobats',
-	'info_articles_trouves_dans_texte' => 'Articles trobats (dins lo tèxt)',
 	'info_attente_validation' => 'Vòstres articles en espèra de validacion',
 	'info_aujourdhui' => 'uèi :',
-	'info_auteur_message' => 'AUTOR DEL MESSATGE:',
 	'info_auteurs' => 'Los autors',
 	'info_auteurs_par_tri' => 'autors@partri@',
 	'info_auteurs_trouves' => 'Autors trobats',
@@ -241,8 +203,6 @@ L’administrator del sistèma o de la ret vos deu poder fornir
 	'info_date_publication_anterieure' => 'Data de redaccion anteriora:',
 	'info_date_referencement' => 'DATA DE REFERÉNCIAMENT D’AQUEL SIT:',
 	'info_derniere_etape' => 'Es acabat!',
-	'info_derniers_articles_publies' => 'Vòstres darrièrs articles publicats en linha',
-	'info_desactiver_messagerie_personnelle' => 'Podètz activar o desactivar vòstra messatjariá personala sus aquel sit.',
 	'info_descriptif' => 'Descriptiu :',
 	'info_desinstaller_plugin' => 'suprimís las donadas et desactiva l’ajuston ',
 	'info_discussion_cours' => 'Discussions en cors',
@@ -250,7 +210,6 @@ L’administrator del sistèma o de la ret vos deu poder fornir
 	'info_email_envoi' => 'Adreiça e-mail de mandadís (opcional)',
 	'info_email_envoi_txt' => 'Indicatz aicí l’adreiça d’utilizar per enviar los e-mails (a fauta d’aquò, s’utilizarà l’adreiça destinatari coma adreiça de mandadís):',
 	'info_email_webmestre' => 'Adreiça e-mail del responsable del sit (opcional)', # MODIF
-	'info_entrer_code_alphabet' => 'Picatz lo còde de l’alfabet d’utilizar:',
 	'info_envoi_email_automatique' => 'Mandadís d’e-mails automatics',
 	'info_envoyer_maintenant' => 'Mandar ara',
 	'info_etape_suivante' => 'Passar a l’estapa seguenta',
@@ -260,27 +219,19 @@ L’administrator del sistèma o de la ret vos deu poder fornir
 	'info_facilite_suivi_activite' => 'Per facilitar lo seguit de l’activitat editoriala del sit, SPIP vos pòt fornir per e-mail, per exemple a una lista de corrièr dels redactors, l’anonci de las demandas de publicacion e de las validacions d’articles.',
 	'info_fichiers_authent' => 'Fichièrs d’autentificacion « .htpasswd »',
 	'info_forums_abo_invites' => 'Vòstre sit web porgís de forums pels abonats; dins lo sit public los vesitaires son convidats a se registrar.',
-	'info_gauche_admin_effacer' => '<b>A aquela pagina, sonque los responsables del sit i pòdon accedir.</b><p> Permet de trobar las diferentas foncions de mantenença tecnica. D’unas que i a implican un procès d’autentificacion especific, que necessita un accès FTP al sit web.</p>', # MODIF
 	'info_gauche_admin_tech' => '<b>A aquela pagina, sonque los responsables del sit i pòdon accedir.</b><p> Permet de trobar las diferentas foncions de mantenença tecnica. D’unas que i a implican un procès d’autentificacion especific, que necessita un accès FTP al sit web.</p>', # MODIF
 	'info_gauche_admin_vider' => '<b>A aquela pagina, sonque los responsables del sit i pòdon accedir.</b><p> Permet de trobar las diferentas foncions de mantenença tecnica. D’unas que i a implican un procès d’autentificacion especific, que necessita un accès FTP al sit web.</p>', # MODIF
 	'info_gauche_auteurs' => 'Trobaretz aicí totes los autors del sit. La color de las icònas n’indica l’estatut (administrator = verd; redactor = jaune).',
 	'info_gauche_auteurs_exterieurs' => 'Los autors exteriors, sens accès al sit, son indicats per una icòna blava; los autors escafats per un bordilhièr.', # MODIF
 	'info_gauche_messagerie' => 'La messatjariá vos permet d’escambiar de messatges entre redactors, de servar de mementos (per vòstre usatge personal) o d’afichar d’anoncis sus la pagina d’acuèlh de l’espaci privat (se sètz administrator/tritz).',
-	'info_gauche_numero_auteur' => 'AUTOR NUMÈRO',
 	'info_gauche_statistiques_referers' => 'Aquela pagina presenta la lista dels <i>referidors</i>, valent a dire dels sits que contenon de ligams menant cap a vòstre quite sit, mas unicament per ièr e uèi: aquela lista s’actualiza cada 24 oras.',
 	'info_gauche_visiteurs_enregistres' => 'Trobaretz aquí los vesitaires registrats
  dins l’espaci public del sit (forums amb abonament).',
 	'info_generation_miniatures_images' => 'Congreacion de miniaturas dels imatges',
-	'info_gerer_trad' => 'Gerir los ligams de revirada?',
 	'info_hebergeur_desactiver_envoi_email' => 'D’unes albergadors desactivan lo mandadís automatic
  d’e-mails dempuèi lors servidors. En aquel cas, las foncionalitats seguentas
  d’SPIP foncionaràn pas.',
 	'info_hier' => 'ièr:',
-	'info_historique_activer' => 'Activar lo seguiment de las revisions',
-	'info_historique_affiche' => 'Afichar aquela version',
-	'info_historique_comparaison' => 'comparason',
-	'info_historique_desactiver' => 'Desactivar lo seguiment de las revisions',
-	'info_historique_texte' => 'Lo seguiment de las revisions permet de servar un istoric de totas las modificacions que s’es portat al contengut d’un article, e d’afichar las diferéncias entre las versions successivas.',
 	'info_identification_publique' => 'Vòstra identitat publica...',
 	'info_image_process' => 'Volgatz seleccionar lo melhor metòde de fabricacion de las vinhetas en clicar sus l’imatge correspondent.',
 	'info_image_process2' => '<b>N.B.</b> <i>Se cap d’imatge apareis pas, aladonc lo servidor qu’albèrga vòstre sit l’an pas configurat per utilizar d’aisinas talas. Se desiratz d’utilizar aquelas foncions, contactatz lo responsable tecnic e demandatz las extensions «GD» o «Imagick».</i>', # MODIF
@@ -299,8 +250,6 @@ L’administrator del sistèma o de la ret vos deu poder fornir
 	'info_logos' => 'Los lògos',
 	'info_maximum' => 'maximum:',
 	'info_meme_rubrique' => 'Dins la meteissa rubrica',
-	'info_message' => 'Messatge del',
-	'info_message_efface' => 'MESSATGE ESCAFAT',
 	'info_message_en_redaction' => 'Vòstres messatges en cors de redaccion',
 	'info_message_technique' => 'Messatge tecnic:',
 	'info_messagerie_interne' => 'Messatjariá intèrna',
@@ -313,20 +262,15 @@ L’administrator del sistèma o de la ret vos deu poder fornir
 	'info_modifier_rubrique' => 'Modificar la rubrica:',
 	'info_modifier_titre' => 'Modificar: @titre@',
 	'info_mon_site_spip' => 'Mon sit SPIP',
-	'info_mot_sans_groupe' => '(Mots fòra grop...)',
-	'info_moteur_recherche' => 'Cercador integrat',
 	'info_moyenne' => 'mejana:',
-	'info_multi_articles' => 'Activar lo menut de lenga pels articles?',
 	'info_multi_cet_article' => 'Lenga d’aqueste article:',
 	'info_multi_langues_choisies' => 'Volgatz seleccionar çai sota las lengas que son a posita dels redactors de vòstre sit.
   Las lengas ja emplegadas dins vòstre sit (afichadas primièras) se pòdon pas desactivar.',
-	'info_multi_rubriques' => 'Activar lo menut de lenga per las rubricas?',
 	'info_multi_secteurs' => '... sonque per las rubricas a la raiç del sit?',
 	'info_nom' => 'Nom',
 	'info_nom_destinataire' => 'Nom del destinatari',
 	'info_nom_site' => 'Nom del vòstre sit',
 	'info_nombre_articles' => '@nb_articles@ articles,',
-	'info_nombre_partcipants' => 'PARTICIPANTS A LA DISCUSSION:',
 	'info_nombre_rubriques' => '@nb_rubriques@ rubricas,',
 	'info_nombre_sites' => '@nb_sites@ sits,',
 	'info_non_deplacer' => 'De desplaçar pas...',
@@ -336,17 +280,13 @@ L’administrator del sistèma o de la ret vos deu poder fornir
 	'info_non_modifiable' => 'se pòt pas modificar',
 	'info_non_suppression_mot_cle' => 'vòli pas suprimir aquel mot clau.',
 	'info_notes' => 'Nòtas',
-	'info_nouveaux_message' => 'Messatges nòus',
 	'info_nouvel_article' => 'Article nòu',
 	'info_nouvelle_traduction' => 'Revirada nòva:',
 	'info_numero_article' => 'ARTICLE NUMÈRO:',
 	'info_obligatoire_02' => '[Obligatòri]', # MODIF
 	'info_option_accepter_visiteurs' => 'Acceptar l’inscripcion dels vesitaires del sit public',
-	'info_option_faire_suivre' => 'Far seguir los messatges dels forums als autors dels articles',
 	'info_option_ne_pas_accepter_visiteurs' => 'Refusar l’inscripcion de vesitaires',
 	'info_options_avancees' => 'OPCIONS AVANÇADAS',
-	'info_ortho_activer' => 'Activar lo verificador d’ortografia',
-	'info_ortho_desactiver' => 'Desactivar lo verificador d’ortografia',
 	'info_ou' => 'o... ',
 	'info_page_interdite' => 'Pagina proïbida',
 	'info_par_nom' => 'per nom',
@@ -355,20 +295,14 @@ L’administrator del sistèma o de la ret vos deu poder fornir
 	'info_par_tri' => '’(per @tri@)’',
 	'info_passe_trop_court' => 'Mot de santa Clara tròp cort.',
 	'info_passes_identiques' => 'Los dos mots de santa Clara son pas identics.',
-	'info_pense_bete_ancien' => 'Vòstres mementos ancians ', # MODIF
 	'info_plus_cinq_car' => 'mai de 5 caractèrs',
 	'info_plus_cinq_car_2' => '(mai de 5 caractèrs)',
 	'info_plus_trois_car' => '(mai de 3 caractèrs)',
 	'info_popularite' => 'popularitat: @popularite@; vesitas: @visites@',
-	'info_popularite_4' => 'popularitat: @popularite@; vesitas: @visites@',
 	'info_post_scriptum' => 'Post-scriptum',
 	'info_post_scriptum_2' => 'Post-scriptum:',
 	'info_pour' => 'per',
-	'info_preview_admin' => 'Solament los administrators pòdon previsualizar lo sit',
-	'info_preview_comite' => 'Totes los redactors pòdon previsualizar lo sit',
-	'info_preview_desactive' => 'La previsualizacion es del tot desactivada',
-	'info_preview_texte' => 'Es possible de previsualizar lo sit coma s’avián publicat totes los articles e brèvas (que tenon almens l’estatut "prepausat"). La cal dobrir, aquela possibilitat, als administrators sonque, a totes los redactors, o pas a degun?',
-	'info_principaux_correspondants' => 'Vòstres correspondents principals',
+	'info_preview_texte' => 'Es possible de previsualizar lo sit coma s’avián publicat totes los articles e brèvas (que tenon almens l’estatut "prepausat"). La cal dobrir, aquela possibilitat, als administrators sonque, a totes los redactors, o pas a degun?', # MODIF
 	'info_procedez_par_etape' => 'procedissètz estapa per estapa',
 	'info_procedure_maj_version' => 'Cal lançar la procedura d’actualizacion per adaptar
  la basa de donadas a la version novèla d’SPIP.',
@@ -384,12 +318,9 @@ L’administrator del sistèma o de la ret vos deu poder fornir
  que lor baila un còde d’accès al sit privat.
 D’unes albergadors autorizan pas lo mandadís d’e-mails dempuèi lors servidors: en aquel cas, l’inscripcion automatica es
  impossibla.', # MODIF
-	'info_question_utilisation_moteur_recherche' => 'Desiratz d’utilizar lo cercador integrat a SPIP? (lo desactivar abriva lo foncionament del sistèma.)',
 	'info_qui_edite' => '@nom_auteur_modif@ a travaillé sur ce contenu il y a @date_diff@ minutes', # MODIF
 	'info_racine_site' => 'Raiç del sit',
 	'info_recharger_page' => 'Volgatz tornar cargar aquela pagina dins un momenton.',
-	'info_recherche_auteur_a_affiner' => 'Tròp de resultats per "@cherche_auteur@"; volgatz afinar la cèrca.',
-	'info_recherche_auteur_ok' => 'Mai d’un redactor trobat per "@cherche_auteur@":',
 	'info_recherche_auteur_zero' => '<b>Pas cap de resultat trobat per « @cherche_auteur@ ».',
 	'info_recommencer' => 'Volgatz tornar començar.',
 	'info_redacteur_1' => 'Redactor',
@@ -406,7 +337,6 @@ D’unes albergadors autorizan pas lo mandadís d’e-mails dempuèi lors servid
 	'info_rubriques' => 'Rubricas',
 	'info_rubriques_02' => 'rubricas',
 	'info_rubriques_trouvees' => 'Rubricas trobadas',
-	'info_rubriques_trouvees_dans_texte' => 'Rubricas trobadas (dins lo tèxt)',
 	'info_sans_titre' => 'Sens títol',
 	'info_selection_chemin_acces' => '<b>Seleccionatz</b> çai sota lo camin d’accès dins l’annuari:',
 	'info_signatures' => 'signaturas',
@@ -419,13 +349,11 @@ D’unes albergadors autorizan pas lo mandadís d’e-mails dempuèi lors servid
 	'info_sites_lies_mot' => 'Los sits referenciats ligats a aquel mot clau',
 	'info_sites_proxy' => 'Utilizar un proxy',
 	'info_sites_trouves' => 'Sits trobats',
-	'info_sites_trouves_dans_texte' => 'Sits trobats (dins lo tèxt)',
 	'info_sous_titre' => 'Sostítol:',
 	'info_statut_administrateur' => 'Administrator',
 	'info_statut_auteur' => 'Estatut d’aquel autor:', # MODIF
 	'info_statut_auteur_a_confirmer' => 'Inscripcion de confirmar',
 	'info_statut_auteur_autre' => 'Autre estatut :',
-	'info_statut_efface' => 'Escafat',
 	'info_statut_redacteur' => 'Redactor',
 	'info_statut_utilisateurs_1' => 'Estatut predefinit dels utilizaires importats',
 	'info_statut_utilisateurs_2' => 'Causissètz l’estatut d’atribuir a las personas presentas dins l’annuari LDAP quora se connèctan pel primièr còp. Poiretz puèi modificar aquel estatut per cada autor un cas per un.',
@@ -446,7 +374,6 @@ D’unes albergadors autorizan pas lo mandadís d’e-mails dempuèi lors servid
 	'info_tous_articles_en_redaction' => 'Totes los articles en cors de redaccion',
 	'info_tous_articles_presents' => 'Totes los articles publicats dins aquela rubrica',
 	'info_tous_les' => 'totes los:',
-	'info_tous_redacteurs' => 'Anoncis a totes los redactors ',
 	'info_tout_site' => 'Tot lo sit ',
 	'info_tout_site2' => 'An pas revirat l’article dins aquela lenga.',
 	'info_tout_site3' => 'An revirat l’article dins aquela lenga, mas an portat puèi de modificacions a l’article de referéncia. Cal actualizar la revirada.',
@@ -461,7 +388,6 @@ una color indica lor estat:',
 	'info_une_rubrique' => 'una rubrica, ',
 	'info_une_rubrique_02' => '1 rubrica',
 	'info_url' => 'URL :',
-	'info_url_site' => 'URL DEL SIT :',
 	'info_urlref' => 'Ligam ipertèxt:',
 	'info_utilisation_spip' => 'Ara podètz començar d’utilizar lo sistèma de publicacion assistida...',
 	'info_visites_par_mois' => 'Afichatge per mes:',
@@ -484,8 +410,6 @@ una color indica lor estat:',
 	'item_activer_messages_avertissement' => 'Activar los messatges d’avertiment',
 	'item_administrateur_2' => 'administrator',
 	'item_afficher_calendrier' => 'Afichar dins lo calendièr',
-	'item_autoriser_documents_joints' => 'Autorizar que se jonga de documents als articles',
-	'item_autoriser_documents_joints_rubriques' => 'Autorizar los documents dins las rubricas',
 	'item_autoriser_syndication_integrale' => 'Difusar l’integralitat dels articles dins los fichièrs de sindicacion',
 	'item_choix_administrateurs' => 'los administrators',
 	'item_choix_generation_miniature' => 'Congrear automaticament las miniaturas dels imatges.',
@@ -493,7 +417,6 @@ una color indica lor estat:',
 	'item_choix_redacteurs' => 'los redactors',
 	'item_choix_visiteurs' => 'los vesitaires del sit public',
 	'item_creer_fichiers_authent' => 'Crear de fichièrs .htpasswd',
-	'item_limiter_recherche' => 'Limitar la cèrca a las informacions contengudas dins vòstre sit',
 	'item_login' => 'Login',
 	'item_mots_cles_association_articles' => 'als articles',
 	'item_mots_cles_association_rubriques' => 'a las rubricas',
@@ -502,35 +425,25 @@ una color indica lor estat:',
 	'item_non_accepter_inscriptions' => 'Acceptar pas las inscripcions',
 	'item_non_activer_messages_avertissement' => 'Pas cap de messatge d’avertiment',
 	'item_non_afficher_calendrier' => 'De pas afichar dins lo calendièr',
-	'item_non_autoriser_documents_joints' => 'Autorizar pas los documents dins los articles',
-	'item_non_autoriser_documents_joints_rubriques' => 'Autorizar pas los documents dins las rubricas',
 	'item_non_autoriser_syndication_integrale' => 'Ne difusar pas qu’un resumit',
 	'item_non_creer_fichiers_authent' => 'Crear pas aqueles fichièrs',
-	'item_non_gerer_statistiques' => 'Gerir pas las estadisticas',
-	'item_non_limiter_recherche' => 'Alargar la cèrca al contengut dels sits referenciats',
 	'item_non_publier_articles' => 'Publicar pas los articles abans la data de publicacion prevista.',
-	'item_non_utiliser_moteur_recherche' => 'Utilizar pas lo motor',
 	'item_nouvel_auteur' => 'Autor nòu',
 	'item_nouvelle_rubrique' => 'Rubrica nòva',
 	'item_oui' => 'Òc',
 	'item_publier_articles' => 'Publicar los articles, quina que siá sa data de publicacion',
 	'item_reponse_article' => 'Responsa a l’article',
-	'item_utiliser_moteur_recherche' => 'Utilizar lo cercador',
 	'item_visiteur' => 'vesitaire',
 
 	// J
 	'jour_non_connu_nc' => 'n.c.',
 
 	// L
-	'lien_ajout_destinataire' => 'Apondre aquel destinatari',
 	'lien_ajouter_auteur' => 'Apondre aquel autor',
-	'lien_ajouter_participant' => 'Apondre un participant',
 	'lien_email' => 'e-mail',
 	'lien_nom_site' => 'NOM DEL SIT :',
 	'lien_retirer_auteur' => 'Levar l’autor',
-	'lien_retrait_particpant' => 'Levar aquel participant',
 	'lien_site' => 'sit',
-	'lien_supprimer_rubrique' => 'suprimir aquela rubrica',
 	'lien_tout_deplier' => 'O desplegar tot',
 	'lien_tout_replier' => 'Tornar plegar',
 	'lien_tout_supprimer' => 'Suprimir tot',
@@ -564,13 +477,14 @@ una color indica lor estat:',
 	'plugin_etat_stable' => 'estable',
 	'plugin_etat_test' => 'a l’ensag',
 	'plugin_impossible_activer' => 'Impossible d’activar l’ajuston @plugin@',
-	'plugin_necessite_plugin' => 'Demanda l’ajuston @plugin@ en version @version@ al mens.',
+	'plugin_necessite_plugin' => 'Demanda l’ajuston @plugin@ en version @version@ al mens.', # MODIF
 	'plugin_necessite_spip' => 'Demanda SPIP en version @version@ al mens.',
 	'plugins_liste' => 'Tièra dels ajustons',
 	'protocole_ldap' => 'Version del protocòl :',
 
 	// R
 	'repertoire_plugins' => 'Repertòri :',
+	'required' => '[Obligatòri]', # MODIF
 
 	// S
 	'statut_admin_restreint' => '(admin. restrench)', # MODIF
@@ -594,15 +508,11 @@ una color indica lor estat:',
 	'texte_article_virtuel_reference' => '<b>Article virtual:</b> article referenciat dins vòstre sit SPIP, mas redirigit cap a una autra URL. Per suprimir la redireccion, escafatz l’URL çai subre.',
 	'texte_aucun_resultat_auteur' => 'Cap de resultat per "@cherche_auteur@"',
 	'texte_auteur_messagerie' => 'Aqueste sit vos pòt indicar de contunh la tièra dels redactors connectats, çò que vos permet d’escambiar de messatges en dirècte. Podètz decidir d’aparéisser pas dins aquela lista (sètz "invisible/a" pels autres utilizaires).',
-	'texte_auteur_messagerie_1' => 'Aquel sit permet d’escambiar de messatges e de constituir de forums de discussion privats entre los participants del sit. Podètz decidir de participar pas a aqueles escambis.',
 	'texte_auteurs' => 'LOS AUTORS',
 	'texte_choix_base_1' => 'Causissètz vòstra basa:',
 	'texte_choix_base_2' => 'Lo servidor SQL conten mai d’una basa de donadas.',
 	'texte_choix_base_3' => '<b>Causissètz</b> çai sota la que vòstre albergador vos a atribuida:',
 	'texte_choix_table_prefix' => 'Prefix de las taulas :',
-	'texte_commande_vider_tables_indexation' => 'Utilizatz aquela comanda per vojar las taulas d’indexacion utilizadas pel cercador integrat a SPIP. Aquò permetrà
- de ganhar d’espaci disc.',
-	'texte_compresse_ou_non' => '(Aqueste se pòt comprimir o non)',
 	'texte_compte_element' => '@count@ element',
 	'texte_compte_elements' => '@count@ elements',
 	'texte_connexion_mysql' => 'Consultatz las informacions que vòstre albergador fornís: i devètz trobar los còdes de connexion al servidor SQL.', # MODIF
@@ -618,10 +528,8 @@ una color indica lor estat:',
 	'texte_date_publication_anterieure' => 'Data de redaccion anteriora:',
 	'texte_date_publication_anterieure_nonaffichee' => 'Afichar pas cap de data de redaccion anteriora.',
 	'texte_date_publication_article' => 'DATA DE PUBLICACION EN LINHA :',
-	'texte_descriptif_petition' => 'Descriptiu de la peticion',
 	'texte_descriptif_rapide' => 'Descriptiu rapid',
 	'texte_effacer_base' => 'Escafar la basa de donadas SPIP',
-	'texte_effacer_donnees_indexation' => 'Escafar las donadas d’indexacion',
 	'texte_en_cours_validation' => 'Se prepausa de publicar los articles e brèvas çai sota. Esitetz pas de donar lo vòstre vejaire gràcias als forums que i son estacats.', # MODIF
 	'texte_enrichir_mise_a_jour' => 'Podètz enriquir la compaginacion del vòstre tèxt en utilizar d’"acorchas tipograficas".',
 	'texte_fichier_authent' => '<b>Deu crear, SPIP, de fichièrs especials  <tt>.htpasswd</tt>
@@ -636,29 +544,18 @@ una color indica lor estat:',
 	'texte_informations_personnelles_2' => '(Nòta: se s’agís d’una reïnstallacion, e se vòstre accès fonciona encara, podètz', # MODIF
 	'texte_introductif_article' => '(Tèxt introductiu de l’article.)',
 	'texte_jeu_caractere' => 'S’aconselha d’emplegar, sus vòstre sit, l’alfabet universal  (<tt>utf-8</tt>) :permet d’afichar totas las lengas, e pausa pas pus de problèmas de compatibilitat amb los navigators modèrnes.',
-	'texte_jeu_caractere_2' => 'Atencion : Aqueste reglatge convertís pas los tèxtes ja enregistrats dins la basa de donadas. ',
 	'texte_jeu_caractere_3' => 'Vòstre sit es per ara installat amb lo jòc de caractèrs :',
 	'texte_jeu_caractere_4' => 'En cas qu’aquò corresponda pas a la realitat de vòstras donadas), o <em>que comencetz a pro pena aquel sit</em> e desiretz causir un autre jòc de caractèrs, indicatz-lo aicí : ',
-	'texte_jeu_caractere_conversion' => 'Nòta : podètz decidir de convertir un còp per totes l’ensem dels tèxtes de vòstre sit (articles, brèvas, forums, etc.) cap a l’alfabet <tt>utf-8</tt>, en anar a <a href="@url@">la pagina de conversion vèrs l’utf-8</a>.',
-	'texte_lien_hypertexte' => '(Se vòstre messatge se referís a un article publicat sul web, o a una pagina fornissent mai d’informacions, volgatz indicar çai sota lo títol de la pagina e son adreiça URL.)',
 	'texte_login_ldap_1' => '(Daissar vuèg per un accès anonim, o picar lo camin complet, per exemple «<tt>uid=fabre, ou=usanciers, dc=mon-domeni, dc=com</tt>».)',
 	'texte_login_precaution' => 'Atencion! Aquò’s lo login amb lo qual sètz ara connectat/ada. 
  Utilizatz aqueste formulari amb precaucion...',
-	'texte_message_edit' => 'Atencion: aqueste messatge, cada redactor lo pòt veire, e cada administrator del sit lo pòt modificar.  Utilizatz los anoncis pas que per expausar d’eveniments importants de la vida del sit.',
 	'texte_mise_a_niveau_base_1' => ' Venètz d’actualizar los fichièrs SPIP.
  Ara cal metre a nivèl la basa de donadas
  del sit.',
 	'texte_modifier_article' => 'Modificar l’article:',
-	'texte_moteur_recherche_active' => '<b>Lo cercador es activat.</b> Utilizatz aquesta commanda
-  se volètz tornar indexar la basa rapidament (aprèp restauracion
-  d’una salvagarda per exemple). Notatz que los documents modificats d’un 
-  biais normal (a partir de l’interfàcia SPIP) se tornan indexar
-  automaticament: donc aquesta comanda es utila pas que d’un biais excepcional.',
-	'texte_moteur_recherche_non_active' => 'Lo cercador es pas activat.',
 	'texte_multilinguisme' => 'Se desiratz de gerir d’articles en mai d’una lenga, amb una navigacion complèxa, podètz apondre un menut per causir la lenga dels articles e/o de las rubricas, en foncion de l’organizacion de vòstre sit.', # MODIF
 	'texte_multilinguisme_trad' => 'Podètz tanben activar un sistèma de gestion dels ligams entre las diferentas reviradas d’un article.', # MODIF
 	'texte_non_compresse' => '<i>non comprimit</i> (pr’amor que vòstre servidor supòrta pas aquela foncionalitat)',
-	'texte_nouveau_message' => 'Messatge nòu',
 	'texte_nouvelle_version_spip_1' => 'Avètz installada una version novèla d’SPIP.',
 	'texte_nouvelle_version_spip_2' => 'Aquesta version novèla demanda una actualizacion mai completa que de costuma. Se sètz webmèstre/webmèstra del sit, volgatz escafar lo fichièr @connect@ e tornar prene l’installacion per tal d’actualizar vòstres paramètres de connexion a la basa de donadas.<p> (NB: s’avètz desmembrat vòstres paramètres de connexion, espepissatz lo fichièr  @connect@ abans de lo suprimir...)</p>', # MODIF
 	'texte_operation_echec' => 'Tornatz a la pagina precedenta, causissètz una autra basa o creatz-ne una novèla. Verificatz las informacions que vòstre albergador a fornidas.',
@@ -676,7 +573,6 @@ una color indica lor estat:',
 	'texte_rappel_selection_champs' => '[Oblidetz pas de seleccionar aquel camp corrèctament.]',
 	'texte_recalcul_page' => 'Se volètz
 tornar calcular sonque una pagina, passatz puslèu per l’espaci public e utilizatz lo  boton "tornar calcular".',
-	'texte_recapitiule_liste_documents' => 'Aquesta pagina recapitula la tièra dels documents qu’avètz plaçats dins las rubricas. Per modificar las informacions de cada document, seguissètz lo ligam cap a la pagina de sa rubrica.',
 	'texte_recuperer_base' => 'Reparar la basa de donadas',
 	'texte_reference_mais_redirige' => 'article referenciat dins vòstre sit SPIP, mas redirigit cap a una autra URL.',
 	'texte_requetes_echouent' => '<b>Quora d’unas requistas SQL abocan
@@ -704,7 +600,6 @@ dins l’escondedor SPIP. Aquò permet per exemple de forçar un calcul nòu de
 s’avètz bravament modificat lo grafisme o l’estructura del sit.',
 	'texte_sur_titre' => 'Subretítol',
 	'texte_table_ok' => ': aquesta taula es condrecha.',
-	'texte_tables_indexation_vides' => 'Las taulas d’indexacion del motor son vuèjas.',
 	'texte_tentative_recuperation' => 'Ensag de reparacion',
 	'texte_tenter_reparation' => 'Ensajar de reparar la basa de donadas',
 	'texte_test_proxy' => 'Per ensajar aquel proxy, indicatz aicí l’adreiça d’un sit web
@@ -719,26 +614,8 @@ s’avètz bravament modificat lo grafisme o l’estructura del sit.',
   Aquela opcion es desactivada de manièra predefinida
   per tal d’evitar d’afichar de messatges d’avertiment
   intempestius.',
-	'texte_trop_resultats_auteurs' => 'Tròp de resultats per "@cherche_auteur@" ; volgatz afinar la cèrca.',
-	'texte_unpack' => 'telecargament de la darrièra version',
-	'texte_utilisation_moteur_syndiques' => 'Quora utilizatz lo cercador integrat 
-    a SPIP, podètz far las cèrcas suls sits e
-    articles sindicats de dos biaisses
-    diferents. <br />- Lo mai
-    simple consistís a recercar sonque dins los
-    títols e descriptius dels articles. <br />-
-    Lo segond biais, plan mai potent, permet
-    a SPIP de cercar tanben dins lo tèxt dels
-    sits referenciats. 
-   Se referenciatz un sit, alavetz SPIP farà la
-    cèrca dins lo tèxt del quite sit.', # MODIF
-	'texte_utilisation_moteur_syndiques_2' => 'Aquel metòde obliga SPIP de vesitar
-    regularament los sits referenciats,
-    aquò pòt alentir un pauc lo vòstre quite
-    sit.',
 	'texte_vide' => 'vuèg',
 	'texte_vider_cache' => 'Vojar l’escondedor',
-	'titre_admin_effacer' => 'Mantenença tecnica',
 	'titre_admin_tech' => 'Mantenença tecnica',
 	'titre_admin_vider' => 'Mantenença tecnica',
 	'titre_cadre_afficher_article' => 'Afichar los articles',
@@ -758,47 +635,26 @@ s’avètz bravament modificat lo grafisme o l’estructura del sit.',
 	'titre_naviguer_dans_le_site' => 'Navigar pel sit...',
 	'titre_nouvelle_rubrique' => 'Rubrica novèla',
 	'titre_numero_rubrique' => 'RUBRICA NUMÈRO:',
-	'titre_page_admin_effacer' => 'Mantenença tecnica: escafar la basa',
 	'titre_page_articles_edit' => 'Modificar: @titre@',
 	'titre_page_articles_page' => 'Los articles',
 	'titre_page_articles_tous' => 'Tot lo sit',
-	'titre_page_auteurs' => 'Vesitaires',
 	'titre_page_calendrier' => 'Calendièr @nom_mois@ de @annee@',
 	'titre_page_config_contenu' => 'Configuracion del sit',
-	'titre_page_config_fonctions' => 'Configuracion del sit',
-	'titre_page_configuration' => 'Configuracion del sit',
-	'titre_page_controle_petition' => 'Seguit de las peticions',
 	'titre_page_delete_all' => 'supression totala e irreversibla',
-	'titre_page_documents_liste' => 'Los documents de las rubricas',
-	'titre_page_index' => 'Vòstre espaci privat',
-	'titre_page_message_edit' => 'Redigir un messatge',
-	'titre_page_messagerie' => 'Vòstra messatjariá',
 	'titre_page_recherche' => 'Resultats de la cèrca @recherche@',
 	'titre_page_statistiques_referers' => 'Estadisticas (ligams intrants)',
 	'titre_page_upgrade' => 'Mesa a nivèl d’SPIP',
 	'titre_publication_articles_post_dates' => 'Publicacion dels articles pòstdatats',
-	'titre_referencer_site' => 'Referenciar lo sit:',
-	'titre_rendez_vous' => 'RENDÈTZ-VOS:',
 	'titre_reparation' => 'Reparacion',
 	'titre_suivi_petition' => 'Seguit de las peticions',
 	'tls_ldap' => 'Transport Layer Security :',
-	'trad_article_inexistant' => 'I a pas cap d’article que pòrte aquel numèro.',
 	'trad_article_traduction' => 'Totas las versions d’aquel article:',
-	'trad_deja_traduit' => 'Error : impossible de religar aquel article al numèro demandat.',
 	'trad_delier' => 'Ligar pas mai aqueste article a sas reviradas ', # MODIF
 	'trad_lier' => 'Aqueste article es una revirada de l’article numèro:',
 	'trad_new' => 'Escriure una revirada novèla d’aqueste article', # MODIF
 
 	// U
-	'utf8_convert_attendez' => 'Esperatz un momenton e tornatz cargar aquesta pagina.',
-	'utf8_convert_avertissement' => 'Sètz a mand de convertir lo  contengut de vòstra basa de donadas (articles, brèvas, etc) del jòc de caractèrs <b>@orig@</b> cap al jòc de caractèrs <b>@charset@</b>.',
-	'utf8_convert_backup' => 'Doblidètz pas de far d’en primièr un salvament complet de vòstre sit. Vos cal tanben verificar que vòstras esqueletas e fichièrs de lenga son compatibles @charset@. ',
-	'utf8_convert_erreur_deja' => 'Vòtre sit es ja en @charset@, inutil de lo convertir...',
 	'utf8_convert_erreur_orig' => 'Error : lo jòc de caractèrs @charset@ es pas suportat.',
-	'utf8_convert_termine' => 'Es acabat !',
-	'utf8_convert_timeout' => '<b>Important :</b> en cas de <i>timeout</i> del servidor, volgatz recargar la pagina fins a çò qu’indique « acabat ».',
-	'utf8_convert_verifier' => 'Vos cal ara vojar l’escondedor, e verificar que tot va plansus las paginas publicas del sit. En cas de gròs problèma, un salvament de vòstras donadas s’es realizat (de format SQL) dins lo repertòri @rep@.',
-	'utf8_convertir_votre_site' => 'Convertir vòstre sit en utf-8',
 
 	// V
 	'version' => 'Version :'
