@@ -3,7 +3,9 @@
 // extrait automatiquement de http://trad.spip.net/tradlang_module/ecrire_?lang_cible=oc_ni
 // ** ne pas modifier le fichier **
 
-if (!defined('_ECRIRE_INC_VERSION')) return;
+if (!defined('_ECRIRE_INC_VERSION')) {
+	return;
+}
 
 $GLOBALS[$GLOBALS['idx_lang']] = array(
 
@@ -186,8 +188,6 @@ Aqueli informacions vos devon poder èstre provesidi per l’administrator dau s
 	'info_1_rubrique' => '1 rubrica',
 	'info_1_visiteur' => '1 visitator',
 	'info_activer_cookie' => 'Podètz activar un <b>cookie de correspondença</b>; aquò vos permetrà de passar facilament dau sit public au sit privat.',
-	'info_admin_gere_rubriques' => 'Aquel administrator gerisse li rubricas seguentas:',
-	'info_admin_gere_toutes_rubriques' => 'Aquel administrator gera<b>toti li rubricas</b>.',
 	'info_administrateur' => 'Administrator',
 	'info_administrateur_1' => 'Administrator',
 	'info_administrateur_2' => 'dau sit (<i>d’utilisar emb precaucion</i>)',
@@ -341,7 +341,7 @@ Aqueli informacions vos devon poder èstre provesidi per l’administrator dau s
 	'info_post_scriptum' => 'Post-Scriptum',
 	'info_post_scriptum_2' => 'Post-Scriptum :',
 	'info_pour' => 'per',
-	'info_preview_texte' => 'Es possible de previsualisar lo site coma se toi lu articles e brèvas (que tenon au mànco l’estatut « prepauat ») èron publicats. Aquela possibilitat deu èstre duberta ai administrators solament, à toi lu redactors, ò à degun ?',
+	'info_preview_texte' => 'Es possible de previsualisar lo site coma se toi lu articles e brèvas (que tenon au mànco l’estatut « prepauat ») èron publicats. Aquela possibilitat deu èstre duberta ai administrators solament, à toi lu redactors, ò à degun ?', # MODIF
 	'info_procedez_par_etape' => 'procedètz estapa per estapa',
 	'info_procedure_maj_version' => 'la procedura de mesa à jorn deu èstre lançada per adaptar la basa de donadas à la novèla version de SPIP.',
 	'info_proxy_ok' => 'Pròva dau proxy capitat.',
@@ -562,7 +562,7 @@ una color indica lo sieu estat :',
 	'plugin_info_telecharger' => 'à descargar despì @url@ et à instalar dins @rep@',
 	'plugin_librairies_installees' => 'Librerìas instaladi',
 	'plugin_necessite_lib' => 'Aquesto plugin demanda la librerìa @lib@',
-	'plugin_necessite_plugin' => 'Demanda lo plugin @plugin@ en version @version@ minimum.',
+	'plugin_necessite_plugin' => 'Demanda lo plugin @plugin@ en version @version@ minimum.', # MODIF
 	'plugin_necessite_spip' => 'Demanda SPIP en version @version@ minimum.',
 	'plugin_source' => 'sorgent: ',
 	'plugin_titre_automatique' => 'Instalacion automatica',
