@@ -3,7 +3,9 @@
 // extrait automatiquement de http://trad.spip.net/tradlang_module/ecrire_?lang_cible=oc_ni_la
 // ** ne pas modifier le fichier **
 
-if (!defined('_ECRIRE_INC_VERSION')) return;
+if (!defined('_ECRIRE_INC_VERSION')) {
+	return;
+}
 
 $GLOBALS[$GLOBALS['idx_lang']] = array(
 
@@ -14,69 +16,43 @@ $GLOBALS[$GLOBALS['idx_lang']] = array(
 	'avis_aucun_resultat' => 'Minga de resultat.',
 	'avis_chemin_invalide_1' => 'Lo camin qu’avètz chausit',
 	'avis_chemin_invalide_2' => 'non sembla valid. Vorgatz tornar a la pàgina anteriora per verificar li informacions fornidi.',
-	'avis_connexion_echec_1' => 'La connexion au servidor SQL s’es encalada.', # MODIF
+	'avis_connexion_echec_1' => 'La conexion au servidor SQL s’es encalada.',
 	'avis_connexion_echec_2' => 'Tornatz a la pàgina anteriora, e verificatz li informacions qu’avètz fornidi.',
 	'avis_connexion_echec_3' => '<b>N.B.</b> Sus tot plen de servidors, devètz <b>demandar</b> qu’activen lo vòstre accès a la basa SQL avans de la poder utilizar. Se non vos podètz connectar, verificatz qu’augatz ben realizat aqueu procediment.', # MODIF
 	'avis_connexion_ldap_echec_1' => 'La connexion au servidor LDAP s’es encalada.',
 	'avis_connexion_ldap_echec_2' => 'Tornatz a la pàgina anteriora, e verificatz li informacions qu’avètz fornidi. ',
 	'avis_connexion_ldap_echec_3' => 'Alternativament, non utilizetz lo supòrt LDAP per importar d’utilizaires.',
 	'avis_deplacement_rubrique' => 'Atention! Aquela rubrica conten @contient_breves@ brèvas@scb@: se la desplaçatz, vorretz ben oscar aquela casa de confirmacion.',
-	'avis_destinataire_obligatoire' => 'Devètz indicar un destinatari avans de mandar aqueu messatge.',
 	'avis_erreur_connexion_mysql' => 'Error de connexion SQL',
-	'avis_erreur_version_archive' => '<b>Atencion! Lo fichier @archive@ correspònde a una autra version d’SPIP qu’aquela qu’avètz installada.</b> Anatz devèrs de dificultats grandassi: risca de destruccion de la vòstra basa de donadas, disfoncionaments divèrs dau sit, etc. Non validetz aquela demanda d’importacion.<p> Per mai d’informacions, veètz
-<a href="@spipnet@">
-la documentacion d’SPIP</a>.', # MODIF
 	'avis_espace_interdit' => '<b>Espaci proïbit</b><p>SPIP es ja installat.',
 	'avis_lecture_noms_bases_1' => 'Lo programa d’installacion non a pas legir lu noms dei basas de donadas installadi.',
 	'avis_lecture_noms_bases_2' => 'Sia minga de basa es disponibla, sia la foncion que permete d’entierar li basas es estada desactivada per de rasons de seguretat (aquò es lo cas a cò de plusors aubergadors).',
 	'avis_lecture_noms_bases_3' => 'Dins la segonda alternativa, es probable qu’una basa que pòrta lo vòstre nom de login sia utilizabla:',
-	'avis_non_acces_message' => 'Non podètz accedir a aqueu messatge.',
 	'avis_non_acces_page' => 'Non podètz accedir a aquela pàgina.',
 	'avis_operation_echec' => 'L’operacion s’es encalada.',
-	'avis_probleme_archive' => 'Problèma de lectura dau fichier @archive@',
 	'avis_suppression_base' => 'ATENCION, suprimir li donadas es irreversible',
-	'avis_version_mysql' => 'La vòstra version de SQL (@version_mysql@) non permete l’autoreparacion dei taulas de la basa.',
 
 	// B
 	'bouton_acces_ldap' => 'Apondre l’accès a LDAP >>',
 	'bouton_ajouter' => 'Apondre',
-	'bouton_ajouter_participant' => 'APONDRE UN PARTICIPANT:',
-	'bouton_annonce' => 'ANONCI',
-	'bouton_checkbox_envoi_message' => 'possibilitat de mandar un messatge',
-	'bouton_checkbox_indiquer_site' => 'indicar obligatoriament un sit web',
-	'bouton_checkbox_signature_unique_email' => 'basta una signatura per adreiça e-mail',
-	'bouton_checkbox_signature_unique_site' => 'basta una signatura per sit web',
 	'bouton_demande_publication' => 'Demandar la publicacion d’aquest article',
-	'bouton_effacer_index' => 'Esfaçar lu indèx',
 	'bouton_effacer_tout' => 'O esfaçar tot',
-	'bouton_envoi_message_02' => 'MANDAR UN MESSATGE',
 	'bouton_envoyer_message' => 'Messatge definitiu: mandar',
 	'bouton_modifier' => 'Modificar',
-	'bouton_pense_bete' => 'MEMENTO (D’USATGE PERSONAU)',
-	'bouton_radio_activer_messagerie' => 'Activar la messatjaria intèrna',
-	'bouton_radio_activer_messagerie_interne' => 'Activar la messatjaria intèrna',
-	'bouton_radio_activer_petition' => 'Activar la peticion',
 	'bouton_radio_afficher' => 'Afichar',
 	'bouton_radio_apparaitre_liste_redacteurs_connectes' => 'Afichar dins la tiera dei redactors connectats',
-	'bouton_radio_desactiver_messagerie' => 'Desactivar la messatjaria',
 	'bouton_radio_envoi_annonces_adresse' => 'Mandar lu anoncis a l’adreiça:',
 	'bouton_radio_envoi_liste_nouveautes' => 'Mandar la tiera dei novetats',
 	'bouton_radio_non_apparaitre_liste_redacteurs_connectes' => 'Non aparéisser dins la tiera dei redactors',
 	'bouton_radio_non_envoi_annonces_editoriales' => 'Non mandar d’anoncis editoriaus',
-	'bouton_radio_pas_petition' => 'Minga de peticion',
-	'bouton_radio_petition_activee' => 'Peticion activada',
-	'bouton_radio_supprimer_petition' => 'Suprimir la peticion',
 	'bouton_redirection' => 'TORNAR DIRIGIR',
 	'bouton_relancer_installation' => 'Tornar lançar l’installacion',
 	'bouton_suivant' => 'Seguent',
 	'bouton_tenter_recuperation' => 'Assaiar de reparar',
 	'bouton_test_proxy' => 'Assaiar lo proxy',
 	'bouton_vider_cache' => 'Vuar l’escondedor',
-	'bouton_voir_message' => 'Veire aqueu messatge avans de lo validar',
 
 	// C
-	'cache_mode_compresse' => 'Lu fichiers de l’escondedor son registrats en mòde comprimit.',
-	'cache_mode_non_compresse' => 'Lu fichiers de l’escondedor son registrats en mòde non comprimit.',
 	'cache_modifiable_webmestre' => 'Lo webmèstre dau sit pòu modificar aquestu paramètres.',
 	'calendrier_synchro' => 'S’utilizatz un logiciau d’agenda compatible <b>iCal</b>, lo podètz sincronizar embai informacions d’aquest sit.',
 
@@ -104,7 +80,6 @@ L’administrator dau sistèma ò de la ret vos deu poder fornir
 	'entree_login' => 'Lo vòstre login',
 	'entree_login_connexion_1' => 'Lo login de connexion',
 	'entree_login_connexion_2' => '(Correspònde de còups au vòstre login d’accès a l’FTP; de còups si laissa vuei)',
-	'entree_login_ldap' => 'Login LDAP iniciau',
 	'entree_mot_passe' => 'Lo vòstre mot de santa Clara',
 	'entree_mot_passe_1' => 'Mot de santa Clara per la connexion',
 	'entree_mot_passe_2' => '(Correspònde de còups au vòstre mot de santa Clara per l’FTP; de còups si laissa vuei)',
@@ -124,7 +99,7 @@ L’administrator dau sistèma ò de la ret vos deu poder fornir
 	'ical_info2' => 'Per tenir mai d’informacions sobre aqueli tecnicas, non esitetz de consultar <a href="@spipnet@">la documentacion d’SPIP</a>.', # MODIF
 	'ical_info_calendrier' => 'I a doi calendiers a la vòstra disposicion. Lo primier es un plan dau sit qu’anóncia toi lu articles publicats. Lo segond conten lu anoncis editoriaus en mai dei vòstres darriers messatges privats: v’es reservat gaug a una clau personala, que la podètz modificar en tot moment en renovant lo vòstre mot de santa Clara. ',
 	'ical_methode_http' => 'Telecargament',
-	'ical_methode_webcal' => 'Sincronizacion (webcal://)',
+	'ical_methode_webcal' => 'Sincronizacion (webcal://)', # MODIF
 	'ical_texte_js' => 'Lu articles publicats en aqueu sit si pòdon afichar aisat, dins toi lu sits vòstres, en fent servir una linha javascript. ',
 	'ical_texte_prive' => 'Aqueu calendier, d’us estrictament personau, v’informa de l’activitat editoriala privada d’aqueu sit (òbras e rendètz-vos personaus, articles e brèvas prepauats...).',
 	'ical_texte_public' => 'Aqueu calendier vos permete de sègre l’activitat publica d’aqueu sit (articles e brèvas publicats).',
@@ -140,9 +115,7 @@ L’administrator dau sistèma ò de la ret vos deu poder fornir
 	'icone_creer_auteur' => 'Crear un autor nòu e l’associar a aquel article',
 	'icone_creer_mot_cle' => 'Crear un mot clau nòu e lo ligar a aquel article',
 	'icone_creer_rubrique_2' => 'Crear una rubrica nòva',
-	'icone_envoyer_message' => 'Mandar aqueu messatge',
 	'icone_modifier_article' => 'Modificar aquel article',
-	'icone_modifier_message' => 'Modificar aqueu messatge',
 	'icone_modifier_rubrique' => 'Modificar aquela rubrica',
 	'icone_retour' => 'Tornar',
 	'icone_retour_article' => 'Tornar a l’article',
@@ -152,10 +125,7 @@ L’administrator dau sistèma ò de la ret vos deu poder fornir
 	'icone_valider_signature' => 'Validar aquela signatura',
 	'image_administrer_rubrique' => 'Podètz administrar aquela rubrica',
 	'info_1_article' => '1 article',
-	'info_1_site' => '1 sit',
 	'info_activer_cookie' => 'Podètz activar un <b>cookie de correspondéncia</b>; aquò vos permetrà de passar aisat dau sit public au sit privat.',
-	'info_admin_gere_rubriques' => 'Aquel administrator gerisse li rubricas seguenti:',
-	'info_admin_gere_toutes_rubriques' => 'Aquel administrator gerisse <b>toti li rubricas</b>.', # MODIF
 	'info_administrateur' => 'Administrator',
 	'info_administrateur_1' => 'Administrator',
 	'info_administrateur_2' => 'dau sit(<i>d’utilizar emb precaucion</i>)',
@@ -165,13 +135,10 @@ L’administrator dau sistèma ò de la ret vos deu poder fornir
 	'info_administrer_rubrique' => 'Podètz administrar aquela rubrica',
 	'info_adresse' => 'a l’adreiça:',
 	'info_adresse_url' => 'Adreiça (URL) dau sit public',
-	'info_afficher_visites' => 'Afichar li vesitas per:',
 	'info_aide_en_ligne' => 'Ajuda en linha SPIP',
 	'info_ajout_image' => 'Quand apondètz d’imatges coma estacaments jonchs a un article, SPIP pòu crear automaticament per vos de vinhetas (miniaturas) dei imatges inserits. Aquò permete per exemple de crear automaticament una galaria ò un pòrtfòlio.',
-	'info_ajout_participant' => 'Lo participant seguent es apondut:',
 	'info_ajouter_rubrique' => 'Apondre una autra rubrica d’administrar:',
 	'info_annonce_nouveautes' => 'Anonci dei novetats',
-	'info_anterieur' => 'anteriora',
 	'info_article' => 'article',
 	'info_article_2' => 'articles',
 	'info_article_a_paraitre' => 'Lu articles pòstdatats per paréisser',
@@ -179,10 +146,8 @@ L’administrator dau sistèma ò de la ret vos deu poder fornir
 	'info_articles_2' => 'Articles',
 	'info_articles_auteur' => 'Lu articles d’aquel autor',
 	'info_articles_trouves' => 'Articles trobats',
-	'info_articles_trouves_dans_texte' => 'Articles trobats (dins lo tèxt)',
 	'info_attente_validation' => 'Lu vòstres articles en espèra de validacion',
 	'info_aujourdhui' => 'ancuei:',
-	'info_auteur_message' => 'AUTOR DAU MESSATGE:',
 	'info_auteurs' => 'Lu autors',
 	'info_auteurs_par_tri' => 'autors@partri@',
 	'info_auteurs_trouves' => 'Autors trobats',
@@ -215,15 +180,12 @@ L’administrator dau sistèma ò de la ret vos deu poder fornir
 	'info_date_publication_anterieure' => 'Data anteriora de publicacion:',
 	'info_date_referencement' => 'DATA DE REFERENCIAMENT D’AQUEU SIT:',
 	'info_derniere_etape' => 'Darriera estapa: <b>Es acabat!',
-	'info_derniers_articles_publies' => 'Lu vòstres darriers articles publicats en linha',
-	'info_desactiver_messagerie_personnelle' => 'Podètz activar ò desactivar la vòstra messatjaria personala sus aqueu sit.',
 	'info_descriptif' => 'Descriptiu:',
 	'info_discussion_cours' => 'Discussions en cors',
 	'info_ecrire_article' => 'Avans de poder escriure d’articles, vos cau crear aumens una rubrica.',
 	'info_email_envoi' => 'Adreiça e-mail de mandadís (opcionau)',
 	'info_email_envoi_txt' => 'Indicatz aicí l’adreiça d’utilizar per enviar lu e-mails (a fauta d’aquò, s’utilizarà l’adreiça destinatari coma adreiça de mandadís):',
 	'info_email_webmestre' => 'Adreiça e-mail dau responsable dau sit (opcionau)', # MODIF
-	'info_entrer_code_alphabet' => 'Picatz lo còde de l’alfabet d’utilizar:',
 	'info_envoi_email_automatique' => 'Mandadís d’e-mails automatics',
 	'info_envoyer_maintenant' => 'Mandar aüra',
 	'info_etape_suivante' => 'Passar a l’estapa seguenta',
@@ -233,27 +195,19 @@ L’administrator dau sistèma ò de la ret vos deu poder fornir
 	'info_facilite_suivi_activite' => 'Per facilitar lo segut de l’activitat editoriala dau sit, SPIP vos pòu fornir per e-mail, per exemple a una lista de corrier dei redactors, l’anonci dei demandas de publicacion e dei validacions d’articles.',
 	'info_fichiers_authent' => 'Fichiers d’autentificacion « .htpasswd »',
 	'info_forums_abo_invites' => 'Lo vòstre sit web pòrge de forums per lu abonats; dins lo sit public lu vesitaires son convidats a si registrar.',
-	'info_gauche_admin_effacer' => '<b>A aquela pàgina, basta lu responsables dau sit i pòdon accedir.</b><p> Permete de trobar li diferenti foncions de mantenença tecnica. D’uni que i a implican un procès d’autentificacion especific, que necessita un accès FTP au sit web.</p>', # MODIF
 	'info_gauche_admin_tech' => '<b>A aquela pàgina, basta lu responsables dau sit i pòdon accedir.</b><p> Permete de trobar li diferenti foncions de mantenença tecnica. D’uni que i a implican un procès d’autentificacion especific, que necessita un accès FTP au sit web.</p>', # MODIF
 	'info_gauche_admin_vider' => '<b>A aquela pàgina, basta lu responsables dau sit i pòdon accedir.</b><p> Permete de trobar li diferenti foncions de mantenença tecnica. D’uni que i a implican un procès d’autentificacion especific, que necessita un accès FTP au sit web.</p>', # MODIF
 	'info_gauche_auteurs' => 'Trobaretz aicí toi lu autors dau sit. La color dei icònas n’indica l’estatut (administrator = verd; redactor = jaune).',
 	'info_gauche_auteurs_exterieurs' => 'Lu autors exteriors, sensa accès au sit, son indicats per una icòna blava; lu autors esfaçats per un bordilhier.', # MODIF
 	'info_gauche_messagerie' => 'La messatjaria vos permete d’escambiar de messatges entre redactors, de servar de mementos (per lo vòstre usatge personau) o d’afichar d’anoncis sus la pàgina d’acuelh de l’espaci privat (se siatz administrator/tritz).',
-	'info_gauche_numero_auteur' => 'AUTOR NÚMERO',
 	'info_gauche_statistiques_referers' => 'Aquela pàgina presenta la lista dei <i>referidors</i>, valent a dire dei sits que contenon de ligams menant vèrs lo vòstre sit pròpri, mas unicament per ièr e ancuei: aquela lista s’actualiza cada 24 oras.',
 	'info_gauche_visiteurs_enregistres' => 'Trobaretz aquí lu vesitaires registrats
  dins l’espaci public dau sit (forums emb abonament).',
 	'info_generation_miniatures_images' => 'Congreacion de miniaturas dei imatges',
-	'info_gerer_trad' => 'Gerir lu ligams de revirada?',
 	'info_hebergeur_desactiver_envoi_email' => 'D’unu aubergadors desactivan lo mandadís automatic
  d’e-mails despí lu sieus servidors. En aqueu cas, li foncionalitats seguenti
  d’SPIP non foncionaràn.',
 	'info_hier' => 'ièr:',
-	'info_historique_activer' => 'Activar lo seguiment dei revisions',
-	'info_historique_affiche' => 'Afichar aquela version',
-	'info_historique_comparaison' => 'comparason',
-	'info_historique_desactiver' => 'Desactivar lo seguiment dei revisions',
-	'info_historique_texte' => 'Lo seguiment dei revisions permete de servar un istoric de toti li modificacions que s’es portat au contengut d’un article, e d’afichar li diferéncias entre li versions successivi.',
 	'info_identification_publique' => 'La vòstra identitat publica...',
 	'info_image_process' => 'Vorgatz seleccionar lo melhor metòde de fabricacion dei vinhetas en clicant sus l’imatge correspondent.',
 	'info_image_process2' => '<b>N.B.</b> <i>Se minga d’imatge apareisse, alora lo servidor qu’aubèrga lo vòstre sit non l’an configurat per utilizar d’aisinas tali. Se desiratz d’utilizar aqueli foncions, contactatz lo responsable tecnic e demandatz li extensions «GD» ò «Imagick».</i>', # MODIF
@@ -271,8 +225,6 @@ L’administrator dau sistèma ò de la ret vos deu poder fornir
 	'info_login_trop_court' => 'Login tròup cort.',
 	'info_maximum' => 'maximum:',
 	'info_meme_rubrique' => 'Dins la meteissa rubrica',
-	'info_message' => 'Messatge dau',
-	'info_message_efface' => 'MESSATGE ESFAÇAT',
 	'info_message_en_redaction' => 'Lu vòstres messatges en cors de redaccion',
 	'info_message_technique' => 'Messatge tecnic:',
 	'info_messagerie_interne' => 'Messatjaria intèrna',
@@ -285,20 +237,15 @@ L’administrator dau sistèma ò de la ret vos deu poder fornir
 	'info_modifier_rubrique' => 'Modificar la rubrica:',
 	'info_modifier_titre' => 'Modificar: @titre@',
 	'info_mon_site_spip' => 'Lo mieu sit SPIP',
-	'info_mot_sans_groupe' => '(Mots fòra grop...)',
-	'info_moteur_recherche' => 'Cercador integrat',
 	'info_moyenne' => 'mejana:',
-	'info_multi_articles' => 'Activar lo menut de lenga per lu articles?',
 	'info_multi_cet_article' => 'Lenga d’aquest article:',
 	'info_multi_langues_choisies' => 'Vorgatz seleccionar çai sota li lengas que son a posita dei redactors dau vòstre sit.
   Li lengas ja emplegadi dins lo vòstre sit (afichadi d’en primier) non si pòdon desactivar.',
-	'info_multi_rubriques' => 'Activar lo menut de lenga per li rubricas?',
 	'info_multi_secteurs' => '... basta per li rubricas a la raiç dau sit?',
 	'info_nom' => 'Nom',
 	'info_nom_destinataire' => 'Nom dau destinatari',
 	'info_nom_site' => 'Nom dau vòstre sit',
 	'info_nombre_articles' => '@nb_articles@ articles,',
-	'info_nombre_partcipants' => 'PARTICIPANTS A LA DISCUSSION:',
 	'info_nombre_rubriques' => '@nb_rubriques@ rubricas,',
 	'info_nombre_sites' => '@nb_sites@ sits,',
 	'info_non_deplacer' => 'De non desplaçar...',
@@ -308,36 +255,26 @@ L’administrator dau sistèma ò de la ret vos deu poder fornir
 	'info_non_modifiable' => 'non si pòu modificar',
 	'info_non_suppression_mot_cle' => 'non vòli suprimir aqueu mot clau.',
 	'info_notes' => 'Nòtas',
-	'info_nouveaux_message' => 'Messatges nòus',
 	'info_nouvel_article' => 'Article nòu',
 	'info_nouvelle_traduction' => 'Revirada nòva:',
 	'info_numero_article' => 'ARTICLE NÚMERO:',
 	'info_obligatoire_02' => '[Obligatòri]', # MODIF
 	'info_option_accepter_visiteurs' => 'Acceptar l’inscripcion dei vesitaires dau sit public',
-	'info_option_faire_suivre' => 'Faire sègre lu messatges dei forums ai autors dei articles',
 	'info_option_ne_pas_accepter_visiteurs' => 'Refusar l’inscripcion de vesitaires',
 	'info_options_avancees' => 'OPCIONS AVANÇADI',
-	'info_ortho_activer' => 'Activar lo verificador d’ortografia',
-	'info_ortho_desactiver' => 'Desactivar lo verificador d’ortografia',
 	'info_ou' => 'ò... ',
 	'info_page_interdite' => 'Pàgina proïbida',
 	'info_par_nombre_article' => '(per nombre d’articles)',
 	'info_passe_trop_court' => 'Mot de santa Clara tròp cort.',
 	'info_passes_identiques' => 'Lu doi mots de santa Clara non son identics.',
-	'info_pense_bete_ancien' => 'Lu vòstres mementos ancians', # MODIF
 	'info_plus_cinq_car' => 'mai de 5 caractèrs',
 	'info_plus_cinq_car_2' => '(mai de 5 caractèrs)',
 	'info_plus_trois_car' => '(mai de 3 caractèrs)',
 	'info_popularite' => 'popularitat: @popularite@; vesitas: @visites@',
-	'info_popularite_4' => 'popularitat: @popularite@; vesitas: @visites@',
 	'info_post_scriptum' => 'Post-scriptum',
 	'info_post_scriptum_2' => 'Post-scriptum:',
 	'info_pour' => 'per',
-	'info_preview_admin' => 'Solament lu administrators pòdon previsualizar lo sit',
-	'info_preview_comite' => 'Toi lu redactors pòdon previsualizar lo sit',
-	'info_preview_desactive' => 'La previsualizacion es dau tot desactivada',
-	'info_preview_texte' => 'Es possible de previsualizar lo sit coma s’avian publicat toi lu articles e brèvas (que tenon aumens l’estatut "prepauat"). La cau durbir, aquela possibilitat, basta ai administrators, a toi lu redactors, ò en degun?',
-	'info_principaux_correspondants' => 'Lu vòstres correspondents principaus',
+	'info_preview_texte' => 'Es possible de previsualizar lo sit coma s’avian publicat toi lu articles e brèvas (que tenon aumens l’estatut "prepauat"). La cau durbir, aquela possibilitat, basta ai administrators, a toi lu redactors, ò en degun?', # MODIF
 	'info_procedez_par_etape' => 'procedissètz estapa per estapa',
 	'info_procedure_maj_version' => 'Cau lançar la procedura d’actualizacion per adaptar
  la basa de donadas a la version novèla d’SPIP.',
@@ -352,12 +289,9 @@ L’administrator dau sistèma ò de la ret vos deu poder fornir
  que li dona un còde d’accès au sit privat.
 D’unu aubergadors non autorizan lo mandadís d’e-mails despí lu sieus servidors: en aqueu cas, l’inscripcion automatica es
  impossibla.', # MODIF
-	'info_question_utilisation_moteur_recherche' => 'Desiratz d’utilizar lo cercador integrat a SPIP? (lo desactivar abriva lo foncionament dau sistèma.)',
 	'info_qui_edite' => '@nom_auteur_modif@ a travaillé sur ce contenu il y a @date_diff@ minutes', # MODIF
 	'info_racine_site' => 'Raiç dau sit',
 	'info_recharger_page' => 'Vorgatz tornar cargar aquela pàgina dins un momenton.',
-	'info_recherche_auteur_a_affiner' => 'Tròup de resultats per "@cherche_auteur@"; vorgatz afinar la cèrca.',
-	'info_recherche_auteur_ok' => 'Plusors redactors trobats per "@cherche_auteur@":',
 	'info_recherche_auteur_zero' => '<b>Minga de resultat trobat per "@cherche_auteur@".',
 	'info_recommencer' => 'Vorgatz tornar començar.',
 	'info_redacteur_1' => 'Redactor',
@@ -374,7 +308,6 @@ D’unu aubergadors non autorizan lo mandadís d’e-mails despí lu sieus servi
 	'info_rubriques' => 'Rubricas',
 	'info_rubriques_02' => 'rubricas',
 	'info_rubriques_trouvees' => 'Rubricas trobadi',
-	'info_rubriques_trouvees_dans_texte' => 'Rubricas trobadi (dins lo tèxt)',
 	'info_sans_titre' => 'Sensa títol',
 	'info_selection_chemin_acces' => '<b>Seleccionatz</b> çai sota lo camin d’accès dins l’annuari:',
 	'info_signatures' => 'signaturas',
@@ -387,11 +320,9 @@ D’unu aubergadors non autorizan lo mandadís d’e-mails despí lu sieus servi
 	'info_sites_lies_mot' => 'Lu sits referenciats ligats a aqueu mot clau',
 	'info_sites_proxy' => 'Utilizar un proxy',
 	'info_sites_trouves' => 'Sits trobats',
-	'info_sites_trouves_dans_texte' => 'Sits trobats (dins lo tèxt)',
 	'info_sous_titre' => 'Sostítol:',
 	'info_statut_administrateur' => 'Administrator',
 	'info_statut_auteur' => 'Estatut d’aquel autor:', # MODIF
-	'info_statut_efface' => 'Esfaçat',
 	'info_statut_redacteur' => 'Redactor',
 	'info_statut_utilisateurs_1' => 'Estatut predefinit dei utilizaires importats',
 	'info_statut_utilisateurs_2' => 'Chausissètz l’estatut d’atribuir ai personas presenti dins l’annuari LDAP quora si connèctan per lo primier còup. Porretz pi modificar aquel estatut per cada autor un cas per un.',
@@ -409,7 +340,6 @@ D’unu aubergadors non autorizan lo mandadís d’e-mails despí lu sieus servi
 	'info_tous_articles_en_redaction' => 'Toi lu articles en cors de redaccion',
 	'info_tous_articles_presents' => 'Toi lu articles publicats dins aquela rubrica',
 	'info_tous_les' => 'toi lu:',
-	'info_tous_redacteurs' => 'Anoncis a toi lu redactors ',
 	'info_tout_site' => 'Tot lo sit',
 	'info_tout_site2' => 'Non an revirat l’article dins aquela lenga.',
 	'info_tout_site3' => 'An revirat l’article dins aquela lenga, mas an portat pi de modificacions a l’article de referéncia. Cau actualizar la revirada.',
@@ -424,7 +354,6 @@ un color indica lo sieu estat:',
 	'info_une_rubrique' => 'una rubrica, ',
 	'info_une_rubrique_02' => '1 rubrica',
 	'info_url' => 'URL:',
-	'info_url_site' => 'URL DAU SIT:', # MODIF
 	'info_urlref' => 'Ligam ipertèxt:',
 	'info_utilisation_spip' => 'Aüra podètz començar d’utilizar lo sistèma de publicacion assistida...',
 	'info_visites_par_mois' => 'Afichatge per mes:',
@@ -441,15 +370,12 @@ un color indica lo sieu estat:',
 	'item_activer_messages_avertissement' => 'Activar lu messatges d’avertiment',
 	'item_administrateur_2' => 'administrator',
 	'item_afficher_calendrier' => 'Afichar dins lo calendier',
-	'item_autoriser_documents_joints' => 'Autorizar que si jonga de documents ai articles',
-	'item_autoriser_documents_joints_rubriques' => 'Autorizar lu documents dins li rubricas',
 	'item_choix_administrateurs' => 'lu administrators',
 	'item_choix_generation_miniature' => 'Congrear automaticament li miniaturas dei imatges.',
 	'item_choix_non_generation_miniature' => 'Congrear minga de miniaturas dei imatges.',
 	'item_choix_redacteurs' => 'lu redactors',
 	'item_choix_visiteurs' => 'lu vesitaires dau sit public',
 	'item_creer_fichiers_authent' => 'Crear de fichiers .htpasswd',
-	'item_limiter_recherche' => 'Limitar la cèrca ai informacions contengudi dins lo vòstre sit',
 	'item_login' => 'Login',
 	'item_mots_cles_association_articles' => 'ai articles',
 	'item_mots_cles_association_rubriques' => 'ai rubricas',
@@ -458,34 +384,24 @@ un color indica lo sieu estat:',
 	'item_non_accepter_inscriptions' => 'Non acceptar li inscripcions',
 	'item_non_activer_messages_avertissement' => 'Minga de messatge d’avertiment',
 	'item_non_afficher_calendrier' => 'De non afichar dins lo calendier',
-	'item_non_autoriser_documents_joints' => 'Non autorizar lu documents dins lu articles',
-	'item_non_autoriser_documents_joints_rubriques' => 'Non autorizar lu documents dins li rubricas',
 	'item_non_creer_fichiers_authent' => 'Non crear aquelu fichiers',
-	'item_non_gerer_statistiques' => 'Non gerir li estadisticas',
-	'item_non_limiter_recherche' => 'Alargar la cèrca au contengut dei sits referenciats',
 	'item_non_publier_articles' => 'Non publicar lu articles avans la data de publicacion prevista.',
-	'item_non_utiliser_moteur_recherche' => 'Non utilizar lo motor',
 	'item_nouvel_auteur' => 'Autor nòu',
 	'item_nouvelle_rubrique' => 'Rubrica nòva',
 	'item_oui' => 'Aí',
 	'item_publier_articles' => 'Publicar lu articles, quina que sia la sieu data de publicacion',
 	'item_reponse_article' => 'Respòsta a l’article',
-	'item_utiliser_moteur_recherche' => 'Utilizar lo cercador',
 	'item_visiteur' => 'vesitaire',
 
 	// J
 	'jour_non_connu_nc' => 'n.c.',
 
 	// L
-	'lien_ajout_destinataire' => 'Apondre aqueu destinatari',
 	'lien_ajouter_auteur' => 'Apondre aquel autor',
-	'lien_ajouter_participant' => 'Apondre un participant',
 	'lien_email' => 'e-mail',
 	'lien_nom_site' => 'NOM DAU SIT:',
 	'lien_retirer_auteur' => 'Levar l’autor',
-	'lien_retrait_particpant' => 'Levar aqueu participant',
 	'lien_site' => 'sit',
-	'lien_supprimer_rubrique' => 'suprimir aquela rubrica',
 	'lien_tout_deplier' => 'Desplegar tot',
 	'lien_tout_replier' => 'Tornar plegar',
 	'lien_trier_nom' => 'Triar per nom',
@@ -511,6 +427,9 @@ un color indica lo sieu estat:',
 	// O
 	'onglet_repartition_actuelle' => 'd’aquesta passa',
 
+	// R
+	'required' => '[Obligatòri]', # MODIF
+
 	// S
 	'statut_admin_restreint' => '(admin. restrench)', # MODIF
 
@@ -533,14 +452,10 @@ un color indica lo sieu estat:',
 	'texte_article_virtuel_reference' => '<b>Article virtuau:</b> article referenciat dins lo vòstre sit SPIP, mas redirigit vèrs una autra URL. Per suprimir la redireccion, esfaçatz l’URL çai sobre.',
 	'texte_aucun_resultat_auteur' => 'Minga de resultat per "@cherche_auteur@"',
 	'texte_auteur_messagerie' => 'Aquest sit vos pòu indicar de contunha la tiera dei redactors connectats, cen que vos permete d’escambiar de messatges en dirècte. Podètz decidir de non aparéisser dins aquela lista (siatz "invisible/a" per lu autres utilizaires).',
-	'texte_auteur_messagerie_1' => 'Aqueu sit permete d’escambiar de messatges e de constituir de forums de discussion privats entre lu participants dau sit. Podètz decidir de non participar a aquelu escambis.',
 	'texte_auteurs' => 'LU AUTORS',
 	'texte_choix_base_1' => 'Chausissètz la vòstra basa:',
 	'texte_choix_base_2' => 'Lo servidor SQL conten mai d’una basa de donadas.',
 	'texte_choix_base_3' => '<b>Chausissètz</b> çai sota aquela que lo vòstre aubergador v’a atribuida:',
-	'texte_commande_vider_tables_indexation' => 'Utilizatz aquela comanda per vuar li taulas d’indexacion utilizadi per lo cercador integrat a SPIP. Aquò permetrà
- de ganhar d’espaci disc.',
-	'texte_compresse_ou_non' => '(Aquest si pòu comprimir ò non)',
 	'texte_compte_element' => '@count@ element',
 	'texte_compte_elements' => '@count@ elements',
 	'texte_connexion_mysql' => 'Consultatz li informacions que lo vòstre aubergador fornisse: i devètz trobar, se lo vòstre aubergador supòrta SQL, lu còdes de connexion au servidor SQL.', # MODIF
@@ -556,10 +471,8 @@ un color indica lo sieu estat:',
 	'texte_date_publication_anterieure' => 'DATA DE PUBLICACION ANTERIORA:',
 	'texte_date_publication_anterieure_nonaffichee' => 'Afichar minga de data de publicacion anteriora.',
 	'texte_date_publication_article' => 'DATA DE PUBLICACION EN LINHA:',
-	'texte_descriptif_petition' => 'Descriptiu de la peticion',
 	'texte_descriptif_rapide' => 'Descriptiu rapid',
 	'texte_effacer_base' => 'Esfaçar la basa de donadas SPIP',
-	'texte_effacer_donnees_indexation' => 'Esfaçar li donadas d’indexacion',
 	'texte_en_cours_validation' => 'Si prepaua de publicar lu articles e brèvas çai sota. Non esitetz de donar lo vòstre vejaire gaug ai forums que i son estacats.', # MODIF
 	'texte_enrichir_mise_a_jour' => 'Podètz enriquir la compaginacion dau vòstre tèxt en utilizant d’"acorchas tipografiqui".',
 	'texte_fichier_authent' => '<b>Deu crear, SPIP, de fichiers especiaus  <tt>.htpasswd</tt>
@@ -578,29 +491,16 @@ un color indica lo sieu estat:',
  En aqueu cas, cau cambiar lo reglatge predefinit per fin d’utilizar
  un juec de caractèrs apropriat. Non oblidetz nimai d’adaptar
  lo sit public en consequéncia (balisa <tt>#CHARSET</tt>).', # MODIF
-	'texte_jeu_caractere_2' => 'Aquest reglatge a minga d’efiech retroactiu. Doncas
- lu tèxts ja sasits si pòdon afichar
- d’un biais incorrècte après que s’auga modificat lo reglatge. De tot biais
- porretz tornar sensa damatge au reglatge precedent.', # MODIF
-	'texte_lien_hypertexte' => '(Se lo vòstre messatge si referisse a un article publicat sus lo web, ò a una pàgina fornissent mai d’informacions, vorgatz indicar çai sota lo títol de la pàgina e la sieu adreiça URL.)',
 	'texte_login_ldap_1' => '(Laissar vuei per un accès anonim, ò picar lo camin complet, per exemple «<tt>uid=fabre, ou=usanciers, dc=mon-domeni, dc=com</tt>».)',
 	'texte_login_precaution' => 'Atencion! Aquò es lo login emb lo quau siatz aüra connectat/ada. 
  Utilizatz aquest formulari emb precaucion...',
-	'texte_message_edit' => 'Atencion: aquest messatge, cada redactor lo pòu veire, e cada administrator dau sit lo pòu modificar. Utilizatz lu anoncis basta per expausar d’eveniments importants de la vida dau sit.',
 	'texte_mise_a_niveau_base_1' => 'Venètz d’actualizar lu fichiers SPIP.
  Aüra cau metre a nivèu la basa de donadas
  dau sit.',
 	'texte_modifier_article' => 'Modificar l’article:',
-	'texte_moteur_recherche_active' => '<b>Lo cercador es activat.</b> Utilizatz aquesta commanda
-  se volètz tornar indexar la basa rapidament (après restauracion
-  d’una sauvagarda per exemple). Notatz que lu documents modificats d’un 
-  biais normau (a partir de l’interfàcia SPIP) si tornan indexar
-  automaticament: doncas aquesta comanda es utila basta d’un biais excepcionau.',
-	'texte_moteur_recherche_non_active' => 'Lo cercador non es activat.',
 	'texte_multilinguisme' => 'Se desiratz de gerir d’articles en plusors lengas, emb una navigacion complèxa, podètz apondre un menut per chausir la lenga dei articles e/ò dei rubricas, en foncion de l’organizacion dau vòstre sit.', # MODIF
 	'texte_multilinguisme_trad' => 'Podètz finda activar un sistèma de gestion dei ligams entre li diferenti reviradas d’un article.', # MODIF
 	'texte_non_compresse' => '<i>non comprimit</i> (perque lo vòstre servidor non supòrta aquela foncionalitat)',
-	'texte_nouveau_message' => 'Messatge nòu',
 	'texte_nouvelle_version_spip_1' => 'Avètz installada una version novèla d’SPIP.',
 	'texte_nouvelle_version_spip_2' => 'Aquesta version novèla demanda una actualizacion mai completa que de costuma. Se siatz webmèstre/webmèstra dau sit, vorgatz esfaçar lo fichier <tt>inc_connect.php3</tt> dau repertòri <tt>ecrire</tt> e tornar pilhar l’installacion per fin d’actualizar lu vòstres paramètres de connexion a la basa de donadas.<p> (NB: s’avètz demembrat lu vòstres paramètres de connexion, espepissatz lo fichier  <tt>inc_connect.php3</tt> avans de lo suprimir...)</p>', # MODIF
 	'texte_operation_echec' => 'Tornatz a la pàgina precedenta, chausissètz una autra basa ò creatz-ne’n una novèla. Verificatz li informacions que lo vòstre aubergador a fornidi.',
@@ -619,7 +519,6 @@ un color indica lo sieu estat:',
 	'texte_rappel_selection_champs' => '[Non oblidetz de seleccionar aqueu camp correctament.]',
 	'texte_recalcul_page' => 'Se volètz
 tornar calcular basta una pàgina, passatz pusprèst per l’espaci public e utilizatz lo  boton "tornar calcular".',
-	'texte_recapitiule_liste_documents' => 'Aquesta pàgina recapitula la tiera dei documents qu’avètz plaçats dins li rubricas. Per modificar li informacions de cada document, seguètz lo ligam vèrs la pàgina de la sieu rubrica.',
 	'texte_recuperer_base' => 'Reparar la basa de donadas',
 	'texte_reference_mais_redirige' => 'article referenciat dins lo vòstre sit SPIP, mas redirigit vèrs una autra URL.',
 	'texte_requetes_echouent' => '<b>Quora d’uni requistas SQL s’encalan
@@ -647,7 +546,6 @@ dins l’escondedor SPIP. Aquò permete per exemple de forçar un calcul nòu de
 s’avètz bravament modificat lo grafisme ò l’estructura dau sit.',
 	'texte_sur_titre' => 'Sobretítol',
 	'texte_table_ok' => ': aquesta taula es condrecha.',
-	'texte_tables_indexation_vides' => 'Li taulas d’indexacion dau motor son vueii.',
 	'texte_tentative_recuperation' => 'Assai de reparacion',
 	'texte_tenter_reparation' => 'Assaiar de reparar la basa de donadas',
 	'texte_test_proxy' => 'Per assaiar aqueu proxy, indicatz aicí l’adreiça d’un sit web
@@ -662,26 +560,8 @@ s’avètz bravament modificat lo grafisme ò l’estructura dau sit.',
   Aquela opcion es desactivada de maniera predefinida
   per fin d’evitar d’afichar de messatges d’avertiment
   intempestius.',
-	'texte_trop_resultats_auteurs' => 'Tròup de resultats per "@cherche_auteur@" ; vorgatz afinar la cèrca.',
-	'texte_unpack' => 'telecargament de la darriera version',
-	'texte_utilisation_moteur_syndiques' => 'Quora utilizatz lo cercador integrat 
-    a SPIP, podètz far li cèrcas sobre lu sits e
-    articles sindicats de doi biais
-    diferents. <br /><img src=\'puce.gif\' /> Lo mai
-    simple consistisse a cercar basta dins lu
-    títols e descriptius dei articles. <br /><img src=\'puce.gif\' />
-    Lo segond biais, ben mai potent, permete
-    a SPIP de cercar finda dins lo tèxt dei
-    sits referenciats. 
-   Se referenciatz un sit, alora SPIP farà la
-    cèrca dins lo tèxt dau sit meteis.', # MODIF
-	'texte_utilisation_moteur_syndiques_2' => 'Aqueu metòde obliga SPIP de vesitar
-    regularament lu sits referenciats,
-    aquò pòu alentir un chico lo vòstre
-    sit.',
 	'texte_vide' => 'vuei',
 	'texte_vider_cache' => 'Vuar l’escondedor',
-	'titre_admin_effacer' => 'Mantenença tecnica',
 	'titre_admin_tech' => 'Mantenença tecnica',
 	'titre_admin_vider' => 'Mantenença tecnica',
 	'titre_cadre_afficher_article' => 'Afichar lu articles',
@@ -701,32 +581,19 @@ s’avètz bravament modificat lo grafisme ò l’estructura dau sit.',
 	'titre_naviguer_dans_le_site' => 'Navigar per lo sit...',
 	'titre_nouvelle_rubrique' => 'Rubrica novèla',
 	'titre_numero_rubrique' => 'RUBRICA NÚMERO:',
-	'titre_page_admin_effacer' => 'Mantenença tecnica: esfaçar la basa',
 	'titre_page_articles_edit' => 'Modificar: @titre@',
 	'titre_page_articles_page' => 'Lu articles',
 	'titre_page_articles_tous' => 'Tot lo sit',
-	'titre_page_auteurs' => 'Vesitaires',
 	'titre_page_calendrier' => 'Calendier @nom_mois@ de @annee@',
 	'titre_page_config_contenu' => 'Configuracion dau sit',
-	'titre_page_config_fonctions' => 'Configuracion dau sit',
-	'titre_page_configuration' => 'Configuracion dau sit',
-	'titre_page_controle_petition' => 'Segut dei peticions',
 	'titre_page_delete_all' => 'supression totala e irreversibla',
-	'titre_page_documents_liste' => 'Lu documents dei rubricas',
-	'titre_page_index' => 'Lo vòstre espaci privat',
-	'titre_page_message_edit' => 'Redigir un messatge',
-	'titre_page_messagerie' => 'La vòstra messatjaria',
 	'titre_page_recherche' => 'Resultats de la cèrca @recherche@',
 	'titre_page_statistiques_referers' => 'Estadisticas (ligams intrants)',
 	'titre_page_upgrade' => 'Mesa a nivèu d’SPIP',
 	'titre_publication_articles_post_dates' => 'Publicacion dei articles pòstdatats',
-	'titre_referencer_site' => 'Referenciar lo sit:',
-	'titre_rendez_vous' => 'RENDÈTZ-VOS:',
 	'titre_reparation' => 'Reparacion',
 	'titre_suivi_petition' => 'Segut dei peticions',
-	'trad_article_inexistant' => 'I a minga d’article que pòrte aqueu número.',
 	'trad_article_traduction' => 'Toti li versions d’aquel article:',
-	'trad_deja_traduit' => 'Aquel article ja es una revirada de l’article present.',
 	'trad_delier' => 'Cessar de ligar aquest article ai sieus reviradas ', # MODIF
 	'trad_lier' => 'Aquest article es una revirada de l’article número:',
 	'trad_new' => 'Escriure una revirada novèla d’aquest article' # MODIF
