@@ -3,7 +3,9 @@
 // extrait automatiquement de http://trad.spip.net/tradlang_module/ecrire_?lang_cible=pt
 // ** ne pas modifier le fichier **
 
-if (!defined('_ECRIRE_INC_VERSION')) return;
+if (!defined('_ECRIRE_INC_VERSION')) {
+	return;
+}
 
 $GLOBALS[$GLOBALS['idx_lang']] = array(
 
@@ -198,9 +200,6 @@ Essas informações devem poder ser fornecidas pelo administrador do sistema ou
 	'info_activer_cookie' => 'Pode activar um <b>cookie de correspondência</b>, o que lhe
  permitirá passar facilmente do sítio público ao sítio privado ',
 	'info_admin_etre_webmestre' => 'Conceder-me os direitos de webmaster',
-	'info_admin_gere_rubriques' => 'Este administrador gere as seguintes rubricas:',
-	'info_admin_gere_toutes_rubriques' => 'Este administrador gere <b>todas as rubricas</b>.',
-	'info_admin_gere_toutes_rubriques_2' => 'Eu administro <b>todas as rubricas</b>',
 	'info_admin_je_suis_webmestre' => 'Eu sou <b>webmaster</b>',
 	'info_admin_statuer_webmestre' => 'Conceder ao administrador os direitos de webmaster',
 	'info_admin_webmestre' => 'Este administrador é <b>webmaster</b>',
@@ -236,6 +235,7 @@ Essas informações devem poder ser fornecidas pelo administrador do sistema ou
 	'info_aucun_message' => 'Sem mensagens',
 	'info_aucun_rubrique' => 'Sem rubricas',
 	'info_aujourdhui' => 'hoje :',
+	'info_auteur_gere_toutes_rubriques_2' => 'Eu administro <b>todas as rubricas</b>', # MODIF
 	'info_auteurs' => 'Os autores',
 	'info_auteurs_par_tri' => 'Autores@partri@',
 	'info_auteurs_trouves' => 'Autores encontrados',
@@ -397,7 +397,7 @@ os autores apagados, por um ícone cinzento.',
 	'info_post_scriptum' => 'Post-Scriptum',
 	'info_post_scriptum_2' => 'Post-scriptum :',
 	'info_pour' => 'para',
-	'info_preview_texte' => 'É possível pré-visualizar o site como se todas os artigos e notas (tendo pelo menos o estatuto de «proposta») estivessem publicados. Esta possibilidade deve estar disponível apenas para os administradores, para todos os redactores, ou para ninguém?',
+	'info_preview_texte' => 'É possível pré-visualizar o site como se todas os artigos e notas (tendo pelo menos o estatuto de «proposta») estivessem publicados. Esta possibilidade deve estar disponível apenas para os administradores, para todos os redactores, ou para ninguém?', # MODIF
 	'info_procedez_par_etape' => 'proceder etapa por etapa',
 	'info_procedure_maj_version' => 'o procedimento de actualização deve ser lançado para adaptar
 a base de dados à nova versão de SPIP.',
@@ -567,7 +567,7 @@ numa cor que indica o seu estado:',
 	'label_choix_langue' => 'Seleccione o seu idioma',
 	'label_nom_fichier_connect' => 'Indique o nome para este servidor',
 	'label_slogan_site' => 'Slogan do sítio',
-	'label_taille_ecran' => 'Largura do ecrã',
+	'label_taille_ecran' => 'Largura do ecrã', # MODIF
 	'label_texte_et_icones_navigation' => 'Menu de navegação',
 	'label_texte_et_icones_page' => 'Exibição da página',
 	'ldap_correspondance' => 'sucessão do campo @champ@',
@@ -606,7 +606,7 @@ numa cor que indica o seu estado:',
 	'mois_non_connu' => 'não conhecido',
 
 	// N
-	'nouvelle_version_spip' => 'A versão @version@ de SPIP está disponível',
+	'nouvelle_version_spip' => 'A versão @version@ de SPIP está disponível', # MODIF
 
 	// O
 	'onglet_contenu' => 'Conteúdo',
@@ -655,7 +655,7 @@ numa cor que indica o seu estado:',
 	'plugin_info_upgrade_ok' => 'Actualizado com sucesso',
 	'plugin_librairies_installees' => 'Bibliotecas instaladas',
 	'plugin_necessite_lib' => 'Este plugin requer a biblioteca @lib@',
-	'plugin_necessite_plugin' => 'Requer o plugin @plugin@ em versão @version@ ou mais recente.',
+	'plugin_necessite_plugin' => 'Requer o plugin @plugin@ em versão @version@ ou mais recente.', # MODIF
 	'plugin_necessite_plugin_sans_version' => 'Requer o plugin @plugin@',
 	'plugin_necessite_spip' => 'Requer SPIP em version @version@ ou mais recente.',
 	'plugin_source' => 'fonte: ',
@@ -689,7 +689,7 @@ numa cor que indica o seu estado:',
 
 	// Q
 	'queue_executer_maintenant' => 'Executar agora',
-	'queue_info_purger' => 'Pode eliminar todas as tarefas em espera e pôr a zeros a lista de tarefas periódicas',
+	'queue_info_purger' => 'Pode eliminar todas as tarefas em espera e pôr a zeros a lista de tarefas periódicas', # MODIF
 	'queue_nb_jobs_in_queue' => '@nb@ tarefas em espera',
 	'queue_next_job_in_nb_sec' => 'Próxima tarefa em @nb@ s',
 	'queue_no_job_in_queue' => 'Sem tarefas em espera',
