@@ -3,7 +3,9 @@
 // extrait automatiquement de http://trad.spip.net/tradlang_module/ecrire_?lang_cible=sv
 // ** ne pas modifier le fichier **
 
-if (!defined('_ECRIRE_INC_VERSION')) return;
+if (!defined('_ECRIRE_INC_VERSION')) {
+	return;
+}
 
 $GLOBALS[$GLOBALS['idx_lang']] = array(
 
@@ -24,70 +26,41 @@ $GLOBALS[$GLOBALS['idx_lang']] = array(
 	'avis_connexion_ldap_echec_2' => 'Återgå till den föregående sidan och kontrollera informationen du angivit.',
 	'avis_connexion_ldap_echec_3' => 'Alternativt kan du välja att inte använda LDAP stöd för att importera användare.',
 	'avis_deplacement_rubrique' => 'Varning! Den här avdelningen innehåller @contient_breves@ notiser@scb@: om du flyttar den, markera i kryssrutan för att bekräfta.',
-	'avis_destinataire_obligatoire' => 'Du måste ange en mottagare innan du skickar meddelandet.',
 	'avis_erreur_connexion_mysql' => 'Fel på SQL-förbindelsen',
-	'avis_erreur_version_archive' => '<b>Varning! Filen @archive@ motsvarar en
- annan SPIP-version än den du instellerad</b>
- Du står inför stora svårigheter: risken att
-förstöra din databas, tekniska fel för din
- webbplats, etc. Skicka inte den här begäran
-om import.<p>För mer information se <a href="@spipnet@">SPIP-dokumentationen</a> (På engelska).', # MODIF
 	'avis_espace_interdit' => '<b>Förbjudet område</b><p>SPIP är redan installerat.',
 	'avis_lecture_noms_bases_1' => 'Installerings-scriptet kunde inte läsa namnen på de installerade databaserna.',
 	'avis_lecture_noms_bases_2' => 'Antingen finns det ingen tillgänglig databas eller så är funktionen som listar
  databaser inaktiverad av säkerhetsskäl (det är fallet hos många webbvärdar).',
 	'avis_lecture_noms_bases_3' => 'I fråga om det andra alternativet är det möjligt att en databas med ditt användarnamn kan användas:',
-	'avis_non_acces_message' => 'Du har inte tillgång till det här meddelandet.',
 	'avis_non_acces_page' => 'Du har inte tillgång till den här sidan.',
 	'avis_operation_echec' => 'Operationen misslyckades.',
 	'avis_operation_impossible' => 'Operationen omöjlig att genomföra',
-	'avis_probleme_archive' => 'Läsfel i filen @archive@',
 	'avis_suppression_base' => 'OBS! Radering av data är permanent och kan inte göras ogjord.',
-	'avis_version_mysql' => 'Din version av MySql (@version_mysql@) stöder inte automatisk reparation av databas-tabeller.',
 
 	// B
 	'bouton_acces_ldap' => 'Lägg till en LDAP-katalog >>',
 	'bouton_ajouter' => 'Lägg till',
-	'bouton_ajouter_participant' => 'LÄGG TILL EN DELTAGARE',
-	'bouton_annonce' => 'MEDDELANDE',
 	'bouton_annuler' => 'Avbryt',
-	'bouton_checkbox_envoi_message' => 'möjlighet att skicka ett meddelande',
-	'bouton_checkbox_indiquer_site' => 'Du måste ange ett namn på en webbplats',
-	'bouton_checkbox_signature_unique_email' => 'endast en signatur per e-postadress',
-	'bouton_checkbox_signature_unique_site' => 'endast en signatur per webbplats',
 	'bouton_demande_publication' => 'Begär att den här artikeln ska publiceras',
 	'bouton_desactive_tout' => 'Avaktivera alla',
 	'bouton_desinstaller' => 'Avinstallera',
-	'bouton_effacer_index' => 'Radera index',
 	'bouton_effacer_tout' => 'Radera ALLA',
-	'bouton_envoi_message_02' => 'SKICKA ETT MEDDELANDE',
 	'bouton_envoyer_message' => 'Färdigt meddelande: skicka',
 	'bouton_modifier' => 'Ändra',
-	'bouton_pense_bete' => 'PERSONLIG MINNESANTECKNING',
-	'bouton_radio_activer_messagerie' => 'Möjliggör interna meddlanden',
-	'bouton_radio_activer_messagerie_interne' => 'möjliggör interna meddelanden',
-	'bouton_radio_activer_petition' => 'Aktivera namninsamlingen',
 	'bouton_radio_afficher' => 'Visa',
 	'bouton_radio_apparaitre_liste_redacteurs_connectes' => 'Synas i listan över anslutna redaktörere',
-	'bouton_radio_desactiver_messagerie' => 'Stäng av meddelandefunktionen',
 	'bouton_radio_envoi_annonces_adresse' => 'Skicka meddelanden till adressen:',
 	'bouton_radio_envoi_liste_nouveautes' => 'Skicka lista över senaste notiser',
 	'bouton_radio_non_apparaitre_liste_redacteurs_connectes' => 'Inte synas i listan över anslutna redaktörere',
 	'bouton_radio_non_envoi_annonces_editoriales' => 'Skicka inga redaktionella meddelanden',
-	'bouton_radio_pas_petition' => 'Inga namninsamlingar',
-	'bouton_radio_petition_activee' => 'Namninsamling aktiverad',
-	'bouton_radio_supprimer_petition' => 'Radera namninsamlingen',
 	'bouton_redirection' => 'OMPEKA',
 	'bouton_relancer_installation' => 'Kör installationen igen',
 	'bouton_suivant' => 'Nästa',
 	'bouton_tenter_recuperation' => 'Försök till reparation',
 	'bouton_test_proxy' => 'Testa proxyn',
 	'bouton_vider_cache' => 'Töm cachen',
-	'bouton_voir_message' => 'Förhandsgranska meddelandet innan det godkänns',
 
 	// C
-	'cache_mode_compresse' => 'Cachefilerna sparas komprimerade.',
-	'cache_mode_non_compresse' => 'Cachefilerna sparas utan komprimering.',
 	'cache_modifiable_webmestre' => 'Den här parametern kan ändras av den webbansvariga.',
 	'calendrier_synchro' => 'Om du använder ett kalenderprogram som är kompatibelt med <b>iCal</b> kan du synkronisera det med informationen på den här webbplatsen.',
 	'config_activer_champs' => 'Aktivera följande fält',
@@ -104,7 +77,6 @@ om import.<p>För mer information se <a href="@spipnet@">SPIP-dokumentationen</a
 	'config_titre_base_sup' => 'Konfigurera ytterligare en databas',
 	'config_titre_base_sup_choix' => 'Välj ytterligare en databas',
 	'connexion_ldap' => 'ldapuppkoppling:',
-	'copier_en_local' => 'Kopiera till den lokala sajten',
 
 	// D
 	'date_mot_heures' => 'h',
@@ -154,7 +126,7 @@ om import.<p>För mer information se <a href="@spipnet@">SPIP-dokumentationen</a
 	'ical_info2' => 'För mer information, tveka inte om att besöka <a href="@spipnet@">SPIP’s dokumentation</a>.', # MODIF
 	'ical_info_calendrier' => 'Du kan använda två kalendrar. En är en sajtkarta med alla publicerade artiklar. Den andra innehåller redaktionella meddelanden och dina senaste privata meddelanden: Den är personlig, tack vare en genererad nyckel som du kan förändra när som helst genom att byta lösenord.',
 	'ical_methode_http' => 'Nerladdning',
-	'ical_methode_webcal' => 'Synkronisering (webcal://)',
+	'ical_methode_webcal' => 'Synkronisering (webcal://)', # MODIF
 	'ical_texte_js' => 'En rad javascript tillåter dig att, väldigt enkelt och på vilken sajt du vill, visa en lista på de senaste artiklarna publicerade på den här sajten.',
 	'ical_texte_prive' => 'Den här kalendern som är personlig, innnehåller dina egna redaktionella händelser på den här sajten (uppgifter, egna möten, inlämnade artiklar och nyheter...).',
 	'ical_texte_public' => 'Den här kalendern låter dig följa den publika aktiviteten på sajten (publicerade artiklar och nyheter).',
@@ -170,12 +142,8 @@ om import.<p>För mer information se <a href="@spipnet@">SPIP-dokumentationen</a
 	'icone_calendrier' => 'Kalender',
 	'icone_creer_auteur' => 'Skapa en ny redaktör och koppla honom (henne) till den här artikeln',
 	'icone_creer_mot_cle' => 'Skapa ett nytt nyckelord och länka det till artikeln',
-	'icone_creer_mot_cle_rubrique' => 'Skapa ett nytt nyckelord och koppla det till den här avdelningen',
-	'icone_creer_mot_cle_site' => 'Skapa ett nytt nyckelord och koppla det till den här sajten',
 	'icone_creer_rubrique_2' => 'Skapa en ny avdelning',
-	'icone_envoyer_message' => 'Sänd detta meddelande',
 	'icone_modifier_article' => 'Editera artikeln',
-	'icone_modifier_message' => 'Editera meddelandet',
 	'icone_modifier_rubrique' => 'Editera avdelningen',
 	'icone_relancer_signataire' => 'Kontakta personen igen',
 	'icone_retour' => 'Tillbaka',
@@ -186,11 +154,8 @@ om import.<p>För mer information se <a href="@spipnet@">SPIP-dokumentationen</a
 	'icone_valider_signature' => 'Validera signaturen',
 	'image_administrer_rubrique' => 'Du kan hantera den här avdelningen',
 	'info_1_article' => '1 artikel',
-	'info_1_site' => '1 sajt',
 	'info_activer_cookie' => 'Du kan aktivera en <b>administrationscookie</b>, som tillåter dig
  att enkelt växla mellan den publika och den privata delen.',
-	'info_admin_gere_rubriques' => 'Den här administratören hanterar följande avdelningar:',
-	'info_admin_gere_toutes_rubriques' => 'Den här administratören hanterar <b>alla avdelningar</b>.', # MODIF
 	'info_administrateur' => 'Administratör',
 	'info_administrateur_1' => 'Administratör',
 	'info_administrateur_2' => 'på sajten (<i>använd med försiktighet</i>)',
@@ -200,16 +165,13 @@ om import.<p>För mer information se <a href="@spipnet@">SPIP-dokumentationen</a
 	'info_administrer_rubrique' => 'Du kan hantera den här avdelningen',
 	'info_adresse' => 'till adressen:',
 	'info_adresse_url' => 'Din sajts publika URL',
-	'info_afficher_visites' => 'Visa besök till:',
 	'info_aide_en_ligne' => 'SPIP Online Hjälp',
 	'info_ajout_image' => 'När du lägget till filer som bifogade dokument till en artikel,
   kan SPIP automatiskt skapa miniatyrer av de
   inlagda bilderna. Det tillåter till exempel
   att man automatiskt skapar ett galleri eller en portfolio.',
-	'info_ajout_participant' => 'Följande deltagare har lagts till:',
 	'info_ajouter_rubrique' => 'lägg till en annan avdelning:',
 	'info_annonce_nouveautes' => 'Senaste nyheterna',
-	'info_anterieur' => 'föregående',
 	'info_article' => 'artikel',
 	'info_article_2' => 'artiklar',
 	'info_article_a_paraitre' => 'Fördaterade artiklar som kommer att publiceras',
@@ -217,10 +179,8 @@ om import.<p>För mer information se <a href="@spipnet@">SPIP-dokumentationen</a
 	'info_articles_2' => 'Artiklar',
 	'info_articles_auteur' => 'Den här redaktörens artiklar',
 	'info_articles_trouves' => 'Artiklar hittade',
-	'info_articles_trouves_dans_texte' => 'Artiklar hittade (i texten)',
 	'info_attente_validation' => 'Dina artiklar som väntar på validering',
 	'info_aujourdhui' => 'idag:',
-	'info_auteur_message' => 'AVSÄNDARE:',
 	'info_auteurs' => 'Redaktörer',
 	'info_auteurs_par_tri' => 'Redaktörer@partri@',
 	'info_auteurs_trouves' => 'Redaktörer funna',
@@ -235,7 +195,6 @@ om import.<p>För mer information se <a href="@spipnet@">SPIP-dokumentationen</a
 	'info_chemin_acces_annuaire' => 'Inställningar: <b>Sökväg i katalogen</b>',
 	'info_choix_base' => 'Tredje steget:',
 	'info_code_acces' => 'Glöm inte ditt eget lösenord!',
-	'info_compresseur_gzip' => '<b>N. B. :</b> Il est recommandé de vérifier au préalable si l’hébergeur compresse déjà systématiquement les scripts php ; pour cela, vous pouvez par exemple utiliser le service suivant : @testgzip@', # MODIF
 	'info_config_suivi' => 'Om den här adressen är en mailing lista, kan du under adressen visa var man kan registrera sig. Det kan vara en URL (till exempel en webbsida där man kan registrera sig), eller en e-postadress med en speciell ärenderad (till exempel: <tt>@adresse_suivi@?subject=subscribe</tt>):',
 	'info_config_suivi_explication' => 'Du kan anmäla dig till sajtens nyhetsbrev. Du kommer då att automatiskt få meddelanden om artiklar och nyheter som laddats upp för publicering.',
 	'info_confirmer_passe' => 'Bekräfta ditt nya lösenord:',
@@ -253,8 +212,6 @@ om import.<p>För mer information se <a href="@spipnet@">SPIP-dokumentationen</a
 	'info_date_publication_anterieure' => 'Datum för tidigare publicering:',
 	'info_date_referencement' => 'DATUM DÅ SAJTEN LÄNKADES:',
 	'info_derniere_etape' => 'Klart!',
-	'info_derniers_articles_publies' => 'Dina senaste publicerade artiklar',
-	'info_desactiver_messagerie_personnelle' => 'Du kan aktivera eller avaktivera dina personliga meddelanden på den här sajten.',
 	'info_descriptif' => 'Beskrivning:',
 	'info_desinstaller_plugin' => 'raderar data och avaktiverar tillägget',
 	'info_discussion_cours' => 'Pågående diskussion',
@@ -262,7 +219,6 @@ om import.<p>För mer information se <a href="@spipnet@">SPIP-dokumentationen</a
 	'info_email_envoi' => 'Avsändaren mailadress (frivilligt)',
 	'info_email_envoi_txt' => 'Skriv in avsändarens e-postadress som används när man sänder mejlen (som default används mottagarens adress som avsändaradress) :',
 	'info_email_webmestre' => 'Webmasterns mejladress (frivillig)', # MODIF
-	'info_entrer_code_alphabet' => 'Skriv in koden för teckenuppsättningen som skall användas:',
 	'info_envoi_email_automatique' => 'Automatisk e-post',
 	'info_envoyer_maintenant' => 'Skicka nu',
 	'info_etape_suivante' => 'Gå till nästa steg',
@@ -273,28 +229,14 @@ om import.<p>För mer information se <a href="@spipnet@">SPIP-dokumentationen</a
   aktiviteterna, kan SPIP skicka medddelanden via e-post, exempelvis till en maillista för redaktörer,
   angående publiceringar och godkännanden.',
 	'info_fichiers_authent' => 'Lösenordsfil ".htpasswd"',
-	'info_gauche_admin_effacer' => '<b>Endast administratörer har tillgång till denna sida.</b><p> Den ger tillgång till tekniska underhållsrutiner av olika slag. En del av dem kommer, om de används, att kräva FTP-tillgång till Webservern för autentifiering.</p>', # MODIF
-	'info_gauche_admin_tech' => '<b>Cette page est uniquement accessible aux responsables du site.</b><p> Elle donne accès aux différentes
-fonctions de maintenance technique. Certaines d’entre elles donnent lieu à un processus d’authentification spécifique, qui
-exige d’avoir un accès FTP au site Web.</p>', # MODIF
-	'info_gauche_admin_vider' => '<b>Cette page est uniquement accessible aux responsables du site.</b><p> Elle donne accès aux différentes
-fonctions de maintenance technique. Certaines d’entre elles donnent lieu à un processus d’authentification spécifique, qui
-exige d’avoir un accès FTP au site Web.</p>', # MODIF
 	'info_gauche_auteurs' => 'Här hittar du alla redaktörer på sajten.
  Status på var och en av dem visas av färgen på ikonen (administratör = grön; redaktör = gul).',
 	'info_gauche_auteurs_exterieurs' => 'Externa redaktörer utan behörighet på sajten, visas med en blå ikon; raderade redaktörer med en soptunna.', # MODIF
-	'info_gauche_numero_auteur' => 'REDAKTÖR NUMMER:',
 	'info_generation_miniatures_images' => 'Skapande av tumnagelbilder.',
-	'info_gerer_trad' => 'Aktivera översättningslänkar?',
 	'info_hebergeur_desactiver_envoi_email' => 'Vissa webhotell avaktiverar automatisk mejl
 på deras servrar. Om så är fallet kan följande
 funktioner hos SPIP inte användas.',
 	'info_hier' => 'I går:',
-	'info_historique_activer' => 'Aktivera versionshantering',
-	'info_historique_affiche' => 'Visa denna version',
-	'info_historique_comparaison' => 'jämför',
-	'info_historique_desactiver' => 'Avaktivera versionshantering',
-	'info_historique_texte' => 'Versionshantering tillåter dig att se förändringar i och tillägg till en artikel och visar skillnader mellan versioner.',
 	'info_identification_publique' => 'Din publika identitet...',
 	'info_image_process' => 'Välj den bästa metoden för att skapa miniatyrer genom att klicka på motsvarande bild.',
 	'info_image_process2' => '<b>OBS!.</b> <i>Om du inte kan se någon bild, så är din server inte konfigurerad för att använda sådana verktyg. Om du vill använda dessa finesser så kontakta din leverantörs tekniska support och be dem installera utökningarna för «GD» eller «Imagick».</i>', # MODIF
@@ -311,8 +253,6 @@ funktioner hos SPIP inte användas.',
 	'info_logos' => 'Logotyperna',
 	'info_maximum' => 'maximum:',
 	'info_meme_rubrique' => 'I samma avdelning',
-	'info_message' => 'Meddelande från',
-	'info_message_efface' => 'MEDDELANDET RADERAT',
 	'info_message_en_redaction' => 'utkorg',
 	'info_message_technique' => 'Tekniskt meddelande:',
 	'info_messagerie_interne' => 'Internmeddelande',
@@ -326,20 +266,15 @@ funktioner hos SPIP inte användas.',
 	'info_modifier_rubrique' => 'Editera avdelningen:',
 	'info_modifier_titre' => 'Editera: @titre@',
 	'info_mon_site_spip' => 'Min SPIP-sajt',
-	'info_mot_sans_groupe' => '(Nyckelord utan en grupp...)',
-	'info_moteur_recherche' => 'Integrerad sökmotor',
 	'info_moyenne' => 'genomsnitt:',
-	'info_multi_articles' => 'Aktivera språkmenyen för artiklar?',
 	'info_multi_cet_article' => 'Den här artikelns språk:',
 	'info_multi_langues_choisies' => 'Var vänlig, välj tillgängliga språk för redaktörerna bland språken nedan.
   Språk som redan används på din sajt (högst upp på listan) kan inte avaktiveras.',
-	'info_multi_rubriques' => 'Aktivera språkmenyn för avdelningar?',
 	'info_multi_secteurs' => '... bara för avdelningarna i roten?',
 	'info_nom' => 'Namn',
 	'info_nom_destinataire' => 'Mottagarens namn',
 	'info_nom_site' => 'Din sajts namn',
 	'info_nombre_articles' => '@nb_articles@ artiklar,',
-	'info_nombre_partcipants' => 'DELTAGARE I DISKUSSIONEN:',
 	'info_nombre_rubriques' => '@nb_rubriques@ avdelningar,',
 	'info_nombre_sites' => '@nb_sites@ sajter,',
 	'info_non_deplacer' => 'Flytta inte...',
@@ -347,17 +282,13 @@ funktioner hos SPIP inte användas.',
 	'info_non_modifiable' => 'kan inte förändras',
 	'info_non_suppression_mot_cle' => 'Jag vill inte radera nyckelordet.',
 	'info_notes' => 'Fotnoter',
-	'info_nouveaux_message' => 'Nya meddelanden',
 	'info_nouvel_article' => 'Ny artikel',
 	'info_nouvelle_traduction' => 'Ny översättning:',
 	'info_numero_article' => 'ARTIKEL NUMMER:',
 	'info_obligatoire_02' => '[Krävs]', # MODIF
 	'info_option_accepter_visiteurs' => 'Tillåt besökare registrera sig på den publika delen',
-	'info_option_faire_suivre' => 'Vidarebefordra forummeddelanden till artikelredaktören',
 	'info_option_ne_pas_accepter_visiteurs' => 'Avvisa besökarregistrering',
 	'info_options_avancees' => 'AVANCERADE INSTÄLLNINGAR',
-	'info_ortho_activer' => 'Aktivera stavningskontrollen.',
-	'info_ortho_desactiver' => 'Avaktivera stavningskontrollen.',
 	'info_ou' => 'eller...',
 	'info_page_interdite' => 'Förbjuden sida',
 	'info_par_nom' => 'efter namn',
@@ -366,18 +297,13 @@ funktioner hos SPIP inte användas.',
 	'info_par_tri' => '’(efter @tri@)’',
 	'info_passe_trop_court' => 'lösenordet är för kort.',
 	'info_passes_identiques' => 'De två lösenorden är inte identiska.',
-	'info_pense_bete_ancien' => 'Dina gamla meddelanden', # MODIF
 	'info_plus_cinq_car' => 'mer än 5 tecken',
 	'info_plus_cinq_car_2' => '(Mer än 5 tecken)',
 	'info_plus_trois_car' => '(Mer än 3 tecken)',
 	'info_popularite' => 'popularitet: @popularite@; besök: @visites@',
-	'info_popularite_4' => 'popularitet: @popularite@; besök: @visites@',
 	'info_post_scriptum' => 'Postscript',
 	'info_post_scriptum_2' => 'PS:',
 	'info_pour' => 'för',
-	'info_preview_admin' => 'Endast administratörer har tillgång till förhandsvisning',
-	'info_preview_comite' => 'Alla redaktörer har tillgång till förhandsvisning',
-	'info_preview_desactive' => 'Förhandsvisning är avaktiverad',
 	'info_procedez_par_etape' => 'Var vänlig, fortsätt steg för steg',
 	'info_procedure_maj_version' => 'Uppdateringsproceduren skall köras för att
  anpassa databasen till den nya versionen av SPIP.',
@@ -386,22 +312,8 @@ funktioner hos SPIP inte användas.',
 	'info_publier' => 'publicera',
 	'info_publies' => 'Dina onlinepublicerade artiklar',
 	'info_question_accepter_visiteurs' => 'Om sajtens template tillåter besökare att registrera sig utan att gå in i den privata delen, var vänlig och aktivera följande option:',
-	'info_question_inscription_nouveaux_redacteurs' => 'Acceptez-vous les inscriptions de nouveaux rédacteurs à
-  partir du site public ? Si vous acceptez, les visiteurs pourront s’inscrire
-  depuis un formulaire automatisé et accéderont alors à l’espace privé pour
-  proposer leurs propres articles. <blockquote><i>Lors de la phase d’inscription,
-  les utilisateurs reçoivent un courrier électronique automatique
-  leur fournissant leurs codes d’accès au site privé. Certains
-  hébergeurs désactivent l’envoi de mails depuis leurs
-  serveurs : dans ce cas, l’inscription automatique est
-  impossible.', # MODIF
-	'info_question_utilisation_moteur_recherche' => 'Vill du använda SPIPŽs integrerade sökfunktion?
- (Att stänga av den ökar systemets prestanda.)',
-	'info_qui_edite' => '@nom_auteur_modif@ a travaillé sur ce contenu il y a @date_diff@ minutes', # MODIF
 	'info_racine_site' => 'Sajtens bas',
 	'info_recharger_page' => 'Var vänlig och uppdatera sidan om en liten stund.',
-	'info_recherche_auteur_a_affiner' => 'För många resultat för "@cherche_auteur@"; Var vänlig och avgränsa sökningen mer.',
-	'info_recherche_auteur_ok' => 'Flera redaktörer hittades för "@cherche_auteur@":',
 	'info_recherche_auteur_zero' => 'Inga resultat hittades för "@cherche_auteur@".',
 	'info_recommencer' => 'Var vänlig och försök igen.',
 	'info_redacteur_1' => 'Redaktör',
@@ -418,7 +330,6 @@ funktioner hos SPIP inte användas.',
 	'info_rubriques' => 'Avdelningar',
 	'info_rubriques_02' => 'avdelningar',
 	'info_rubriques_trouvees' => 'Hittade avdelningar',
-	'info_rubriques_trouvees_dans_texte' => 'Avdelningar funna (i texten)',
 	'info_sans_titre' => 'Utan titel',
 	'info_selection_chemin_acces' => '<b>Välj</b> åtkomstväg i katalogen:',
 	'info_signatures' => 'underskrifter',
@@ -431,13 +342,11 @@ funktioner hos SPIP inte användas.',
 	'info_sites_lies_mot' => 'Länkade sajter knutna till detta nyckelord',
 	'info_sites_proxy' => 'Använder en proxy',
 	'info_sites_trouves' => 'Hittade sajter',
-	'info_sites_trouves_dans_texte' => 'Hittade sajter (i texten)',
 	'info_sous_titre' => 'Undertitel:',
 	'info_statut_administrateur' => 'Administratör',
 	'info_statut_auteur' => 'Redaktörens status:', # MODIF
 	'info_statut_auteur_a_confirmer' => 'Registreringar som skall godkännas',
 	'info_statut_auteur_autre' => 'Annan status:',
-	'info_statut_efface' => 'Raderad',
 	'info_statut_redacteur' => 'Redaktör',
 	'info_statut_utilisateurs_1' => 'Startinställningar för importerade användare',
 	'info_suivi_activite' => 'Följ upp aktiviteten på sajten',
@@ -457,7 +366,6 @@ funktioner hos SPIP inte användas.',
 	'info_tous_articles_en_redaction' => 'Alla artiklar under arbete',
 	'info_tous_articles_presents' => 'Alla artiklar som publicerats i den här avdelningen',
 	'info_tous_les' => 'alla:',
-	'info_tous_redacteurs' => 'meddelande till alla redaktörer',
 	'info_tout_site' => 'Hela sajten',
 	'info_tout_site2' => 'Artikeln har inte blivit översatt till det här språket.',
 	'info_tout_site3' => 'Artikeln har blivit översatt till det hör språket men vissa förändringar har gjorts senare i orginalartikeln. Översättningen behöver uppdateras.',
@@ -472,7 +380,6 @@ med en färg som visar deras status:',
 	'info_une_rubrique' => 'en avdelning,',
 	'info_une_rubrique_02' => '1 avdelning',
 	'info_url' => 'URL:',
-	'info_url_site' => 'SAJTEN’S URL:',
 	'info_urlref' => 'Hyperlänk:',
 	'info_utilisation_spip' => 'SPIP är nu färdig att användas..',
 	'info_visites_par_mois' => 'Besökare per månad:',
@@ -501,8 +408,6 @@ med en färg som visar deras status:',
 	'item_activer_messages_avertissement' => 'Aktivera varningsmeddelanden',
 	'item_administrateur_2' => 'administratör',
 	'item_afficher_calendrier' => 'Visa i kalendern',
-	'item_autoriser_documents_joints' => 'Tillåt dokument bifogade till artiklarna',
-	'item_autoriser_documents_joints_rubriques' => 'Tillåt dokument i avdelningarna',
 	'item_autoriser_syndication_integrale' => 'Inkludera hela artiklar i syndikeringsfilerna',
 	'item_choix_administrateurs' => 'administratörer',
 	'item_choix_generation_miniature' => 'Generera miniatyrer automatiskt.',
@@ -510,7 +415,6 @@ med en färg som visar deras status:',
 	'item_choix_redacteurs' => 'redaktörer',
 	'item_choix_visiteurs' => 'besökare till den publika delen',
 	'item_creer_fichiers_authent' => 'Skapa .htpasswd filer',
-	'item_limiter_recherche' => 'Begränsa sökningen till information i din sajt',
 	'item_login' => 'Login',
 	'item_messagerie_agenda' => 'Aktivera meddelandesystemet och kalendern',
 	'item_mots_cles_association_articles' => 'artiklar',
@@ -520,37 +424,26 @@ med en färg som visar deras status:',
 	'item_non_accepter_inscriptions' => 'Tillåt inte registreringar',
 	'item_non_activer_messages_avertissement' => 'Inga varningsmeddelanden',
 	'item_non_afficher_calendrier' => 'Visa inte i kalendern',
-	'item_non_autoriser_documents_joints' => 'Tillåt inte dokument i artiklarna',
-	'item_non_autoriser_documents_joints_rubriques' => 'Tillåt inte dokument i avdelningarna',
 	'item_non_autoriser_syndication_integrale' => 'Skicka bara en sammanfattning',
-	'item_non_compresseur' => 'Avaktivera komprimering',
 	'item_non_creer_fichiers_authent' => 'Skapa inte dessa filer',
-	'item_non_gerer_statistiques' => 'Hantera inte statistik',
-	'item_non_limiter_recherche' => 'Utöka indexeringen till att omfatta innehåll på länkade sajter',
 	'item_non_messagerie_agenda' => 'Avaktivera meddelandesystemet och kalendern',
 	'item_non_publier_articles' => 'Publicera inte artiklar innan deras publiceringsdatum.',
-	'item_non_utiliser_moteur_recherche' => 'Använd inte sökmotorn',
 	'item_nouvel_auteur' => 'Ny redaktör',
 	'item_nouvelle_rubrique' => 'Ny avdelning',
 	'item_oui' => 'Ja',
 	'item_publier_articles' => 'Publicera artiklarna utan att ta hänsyn till publiceringsdatum.',
 	'item_reponse_article' => 'Svara på artikeln',
-	'item_utiliser_moteur_recherche' => 'Använd sökmotorn',
 	'item_visiteur' => 'besökare',
 
 	// J
 	'jour_non_connu_nc' => 'okänd',
 
 	// L
-	'lien_ajout_destinataire' => 'Lägg till som mottagare',
 	'lien_ajouter_auteur' => 'Lätt till redaktören',
-	'lien_ajouter_participant' => 'Lägg till en deltagare',
 	'lien_email' => 'e-post',
 	'lien_nom_site' => 'SAJTENS NAMN:',
 	'lien_retirer_auteur' => 'Ta bort redaktören',
-	'lien_retrait_particpant' => 'ta bort deltagaren',
 	'lien_site' => 'sajt',
-	'lien_supprimer_rubrique' => 'ta bort den här avdelningen',
 	'lien_tout_deplier' => 'Expandera alla',
 	'lien_tout_replier' => 'Kollapsa alla',
 	'lien_tout_supprimer' => 'Radera alla',
@@ -576,7 +469,6 @@ med en färg som visar deras status:',
 	'onglet_contenu' => 'Innehåll',
 	'onglet_declarer_une_autre_base' => 'Ange en annan databas',
 	'onglet_discuter' => 'Diskutera',
-	'onglet_documents' => 'Dokument',
 	'onglet_interactivite' => 'Interaktivitet',
 	'onglet_proprietes' => 'Egenskaper',
 	'onglet_repartition_actuelle' => 'nu',
@@ -587,7 +479,7 @@ med en färg som visar deras status:',
 	'plugin_etat_stable' => 'Stabil',
 	'plugin_etat_test' => 'under test',
 	'plugin_impossible_activer' => 'Omöjligt att aktivera pluginen @plugin@',
-	'plugin_necessite_plugin' => 'Version @version@ eller nyare av pluginen @plugin@ krävs.',
+	'plugin_necessite_plugin' => 'Version @version@ eller nyare av pluginen @plugin@ krävs.', # MODIF
 	'plugin_zip_active' => 'Fortsätt för att aktivera',
 	'plugin_zip_installe_finie' => 'Filen @zip@ har packats upp och installerats.',
 	'plugin_zip_installe_rep_finie' => 'Filen @zip@ har packats upp och installerats i katalogen @rep@',
@@ -598,6 +490,9 @@ med en färg som visar deras status:',
 	'plugins_erreur' => 'Fel i följande plugin: @plugins@',
 	'plugins_liste' => 'Lista över plugins',
 
+	// R
+	'required' => '[Krävs]', # MODIF
+
 	// T
 	'taille_cache_vide' => 'Cachen är tom.',
 	'text_article_propose_publication' => 'Artikel inlämnad för publicering. tveka inte att säga din mening i forumet längst ned på sidan.', # MODIF
@@ -616,51 +511,21 @@ installera om SPIP för att skapa en ny databas och den första administratören
 	'texte_choix_base_2' => 'Databasservern innehåller flera databaser.',
 	'texte_choix_base_3' => '<b>Välj</b> den som din leverantör har gett dig:',
 	'texte_choix_table_prefix' => 'Prefix för tabeller:',
-	'texte_compresse_ou_non' => '(Den kan vara komprimerad eller inte.)',
 	'texte_compte_element' => '@count@ objekt',
 	'texte_compte_elements' => '@count@ element',
-	'texte_connexion_mysql' => 'Consult the information provided by your service provider. It should contain the connection codes for the SQL server.', # MODIF
-	'texte_en_cours_validation' => 'The following articles and news are submitted for publication. Do not hesitate to give your opinion through the forums attached to them.', # MODIF
-	'texte_fichier_authent' => '<b>Should SPIP create the <tt>.htpasswd</tt>
-  and <tt>.htpasswd-admin</tt> files in the directory @dossier@?</b><p>
-  These files can be used to restrict access to authors
-  and administrators in other parts of your site
-  (for instance, external statistical programme).</p><p>
-  If you have no need of such files, you can leave this option
-  with its default value (no files 
-  creation).</p>', # MODIF
 	'texte_jeu_caractere_3' => 'Din sajt använder följande teckenuppsättning:',
 	'texte_mise_a_niveau_base_1' => 'Du har just uppdaterat filerna i SPIP.
  Nu måste du uppgradera sajtens databas.',
 	'texte_modifier_article' => 'Redigera artikeln:',
-	'texte_moteur_recherche_active' => '<b>Sökmotorn är aktiverad.</b> använd det här kommandot
-  om du vill utföra en snabb omindexering (t.ex efter
-  att ha tagit tillbaka data från en backup). Kom ihåg att dokument som skapats på
-  det normala sättet (från gränssnittet i SPIP ) automatiskt
-  indexeras igen: därför är kommandot bara användbart i speciella omständigheter.',
-	'texte_moteur_recherche_non_active' => 'Sökfunktionen är inte aktiverad.',
 	'texte_multilinguisme' => 'Om du vill hantera artiklar på flera språk, med en avancerad navigering, kan du lägga till en option för språkval i artiklar och avdelningar, i enlighet med sajtens struktur.', # MODIF
 	'texte_multilinguisme_trad' => 'Dessutom kan du aktivera ett system för länkhantering av de olika översättningarna av en artikel.', # MODIF
 	'texte_non_compresse' => '<i>okomprimerad</i> (din server stöder inte denna funktion)',
-	'texte_nouveau_message' => 'Nytt meddelande',
 	'texte_nouvelle_version_spip_1' => 'Du har installerat en ny version av SPIP.',
-	'texte_nouvelle_version_spip_2' => 'Cette nouvelle version nécessite une mise à jour plus complète qu’à l’accoutumée. Si vous êtes webmestre du site, veuillez effacer le fichier @connect@ et reprendre l’installation afin de mettre à jour vos paramètres de connexion à la base de données.<p> (NB. : si vous avez oublié vos paramètres de connexion, jetez un œil au fichier @connect@ avant de le supprimer...)</p>', # MODIF
 	'texte_plus_trois_car' => 'mer än tre tecken',
 	'texte_plusieurs_articles' => 'Flera redaktörer hittades för  "@cherche_auteur@":',
 	'texte_recalcul_page' => 'Om du vill uppdatera
 enbart en sida, är det bäst att göra det från den publika delen genom att klicka på « Ladda om sidan ».',
 	'texte_recuperer_base' => 'Reparera databasen',
-	'texte_requetes_echouent' => '<b>Lorsque certaines requêtes SQL échouent
-  systématiquement et sans raison apparente, il est possible
-  que ce soit à cause de la base de données
-  elle-même.</b><p>
-  Votre serveur SQL dispose d’une faculté de réparation de ses
-  tables lorsqu’elles ont été endommagées par
-  accident. Vous pouvez ici tenter cette réparation ; en
-  cas d’échec, conservez une copie de l’affichage, qui contient
-  peut-être des indices de ce qui ne va pas...</p><p>
-  Si le problème persiste, prenez contact avec votre
-  hébergeur.</p>', # MODIF
 	'texte_sous_titre' => 'Undertitel',
 	'texte_statistiques_visites' => '(mörka staplar:  Söndag / mörk linje: genomsnittlig nivå)',
 	'texte_statut_attente_validation' => 'väntar på godkännande',
@@ -671,26 +536,13 @@ i SPIP’s cache. Det gör det möjligt att tvinga fram en uppdatering av alla s
 gjort viktiga förändringar i sajtens utseende eller struktur.',
 	'texte_sur_titre' => 'Övertitel',
 	'texte_table_ok' => ': den här tabellen är OK.',
-	'texte_tables_indexation_vides' => 'Indextabellerna är tomma.',
 	'texte_tentative_recuperation' => 'Reparationsförsök',
 	'texte_tenter_reparation' => 'Försök att reparera databasen',
 	'texte_titre_02' => 'Ärenderad:',
 	'texte_titre_obligatoire' => '<b>Titel</b> [Krävs]',
 	'texte_travail_article' => '@nom_auteur_modif@ arbetade med den här artikeln för @date_diff@ minuter sedan',
-	'texte_trop_resultats_auteurs' => 'För många resultat för "@cherche_auteur@"; Var vänlig att smalna av frågan.',
-	'texte_utilisation_moteur_syndiques' => 'When you use SPIP’s integrated search engine, 
-you can perform searches on sites and
- articles syndicated in two different ways. <br />- The simplest
- way is to search only in the
- titles and descriptions of the articles. <br />-
- A second, much more powerful, method allows
- SPIP to search also in the text
- of the referenced sites. If you
- reference a site, SPIP will perform
- the search in the site’s text itself.', # MODIF
 	'texte_vide' => 'tom',
 	'texte_vider_cache' => 'töm cachen',
-	'titre_admin_effacer' => 'Tekniskt underhåll',
 	'titre_admin_tech' => 'Tekniskt underhåll',
 	'titre_admin_vider' => 'Tekniskt underhåll',
 	'titre_cadre_afficher_article' => 'Visa artiklarna:',
@@ -710,43 +562,25 @@ you can perform searches on sites and
 	'titre_naviguer_dans_le_site' => 'Navigera i sajten...',
 	'titre_nouvelle_rubrique' => 'Ny avdelning',
 	'titre_numero_rubrique' => 'AVDELNING NUMMER:',
-	'titre_page_admin_effacer' => 'Tekniskt underhåll: raderar databasen',
 	'titre_page_articles_edit' => 'Editera: @titre@',
 	'titre_page_articles_page' => 'Artiklar',
 	'titre_page_articles_tous' => 'Hela sajten',
-	'titre_page_auteurs' => 'Besökare',
 	'titre_page_calendrier' => 'Kalender @nom_mois@ @annee@',
 	'titre_page_config_contenu' => 'Sajtens inställningar',
-	'titre_page_config_fonctions' => 'Sajtens inställningare',
-	'titre_page_configuration' => 'Sajtens inställningar',
 	'titre_page_delete_all' => 'total och oåterkallelig radering',
-	'titre_page_documents_liste' => 'Bifogade dokument',
-	'titre_page_index' => 'Din privata del',
 	'titre_page_recherche' => 'Sökresultat @recherche@',
 	'titre_page_statistiques_referers' => 'Statistik (inkommande länkar)',
 	'titre_page_upgrade' => 'Uppgradera SPIP',
 	'titre_publication_articles_post_dates' => 'Tidsstyrd publicering av artiklar',
-	'titre_referencer_site' => 'Referera webbplatsen:',
-	'titre_rendez_vous' => 'MÖTEN:',
 	'titre_reparation' => 'Reparera',
 	'titre_suivi_petition' => 'Uppföljning av namninasamlingar',
-	'trad_article_inexistant' => 'Det finns ingen artikel med det här numret',
 	'trad_article_traduction' => 'Alla versioner av den här artikeln:',
-	'trad_deja_traduit' => 'Den här artikeln är i sig en översättning av den nuvarande artikeln.', # MODIF
 	'trad_delier' => 'Sluta länka den här artikeln till dess översättningar', # MODIF
 	'trad_lier' => 'Den här artikeln är en översättning av artikel nummer:',
 	'trad_new' => 'Skriv en ny översättning av den här artikeln', # MODIF
 
 	// U
-	'utf8_convert_attendez' => 'Vänta några sekunder och ladda sedan om den här sidan.',
-	'utf8_convert_avertissement' => 'Du håller på att konvertera innehållet i din databas (artiklar, notiser, etc) från teckenkodningen <b>@orig@</b> till teckenkodningen <b>@charset@</b>',
-	'utf8_convert_backup' => 'Glöm inte bort att göra en fullständig säkerhetskopia av din webbplats. Du behöver också kontrollera att dina dokumentmallar och språkfiler är kompatibla med @charset@. Om spårning av revideringar är påslaget kommer den hur som helst att bli skadad.', # MODIF
-	'utf8_convert_erreur_deja' => 'Din webbplats är redan i @charset@, det är ingen mening med att konvertera.',
 	'utf8_convert_erreur_orig' => 'Fel: teckenkodningen @charset@ stöds inte.',
-	'utf8_convert_termine' => 'Klart!',
-	'utf8_convert_timeout' => '<b>Viktigt:</b> Om servern svarar med <i>timeout</i>, ladda om sidan tills du får meddelandet "Klart!".',
-	'utf8_convert_verifier' => 'Nu behöver du tömma webbplatsens cache och sedan kontrollera att allt är bra med de offentliga delarna av webbplatsen. Om du upplever allvarliga problem har en säkerhetskopia av ditt ursprungliga data (i SQL-format) placerats i @rep@-katalogen.',
-	'utf8_convertir_votre_site' => 'Konvertera din webbplats till utf-8',
 
 	// V
 	'version' => 'Version:'
