@@ -3,7 +3,9 @@
 // extrait automatiquement de http://trad.spip.net/tradlang_module/ecrire_?lang_cible=vi
 // ** ne pas modifier le fichier **
 
-if (!defined('_ECRIRE_INC_VERSION')) return;
+if (!defined('_ECRIRE_INC_VERSION')) {
+	return;
+}
 
 $GLOBALS[$GLOBALS['idx_lang']] = array(
 
@@ -21,63 +23,36 @@ $GLOBALS[$GLOBALS['idx_lang']] = array(
 	'avis_connexion_ldap_echec_2' => 'Trở lại trang trước và xem lại các dữ kiện đã cung cấp.',
 	'avis_connexion_ldap_echec_3' => 'Một cách khác, đừng dùng LDAP support để đem tên người dùng vào.',
 	'avis_deplacement_rubrique' => 'LƯU Ý! Đề mục này chứa @contient_breves@ các tin ngắn @scb@: nếu bạn dời nó đi, xin đánh dấu vào ô này để xác nhận.',
-	'avis_destinataire_obligatoire' => 'Phải chọn một người nhận trước khi gửi thư tín này đi.',
 	'avis_erreur_connexion_mysql' => 'Có Lỗi-không nối với SQL',
-	'avis_erreur_version_archive' => '<b>Báo động! Hồ sơ @archive@ thuộc dạng SPIP khác với dạng mà bạn có.</b>
- Bạn sẽ gặp rất nhiều rắc rối: có thể database bị tiêu hủy, website bị trắc trở, v.v...
- Xin đừng nộp bài này vào.<p> Để biết thêm chi tiết, xem bài <a href="@spipnet@">
-Hồ sơ SPIP</a>.', # MODIF
 	'avis_espace_interdit' => '<b>Vùng cấm địa</b><p>SPIP đã được thiết trí rồi.',
 	'avis_lecture_noms_bases_1' => 'Nhu liệu thiết trí không đọc được tên của database thiết trí.',
 	'avis_lecture_noms_bases_2' => 'Không có database nào hết, hoặc đặc điểm cho phép liệt kê tên database bị tắt đi vì lý do an ninh (thường là như vậy cho nhiều máy chủ)',
 	'avis_lecture_noms_bases_3' => 'Trong trường hợp lựa chọn thứ nhì xảy ra, sau khi bạn login vào, có thể một database có tên lúc đó có thể dùng được: ',
-	'avis_non_acces_message' => 'Bạn không có quyền xem thư tín này.',
 	'avis_non_acces_page' => 'Bạn không có quyền vào trang này.',
 	'avis_operation_echec' => 'Thao tác thất bại.',
-	'avis_probleme_archive' => 'Có lỗi khi đọc hồ sơ @archive@',
 	'avis_suppression_base' => 'BÁO ĐỘNG, xóa dữ kiện rồi sẽ không lấy lại được',
-	'avis_version_mysql' => 'Ấn bản SQL này (@version_mysql@) không cho phép sửa chữa tự động các bản trong database.',
 
 	// B
 	'bouton_acces_ldap' => 'Thêm hồ sơ vào LDAP >>',
 	'bouton_ajouter' => 'Thêm',
-	'bouton_ajouter_participant' => 'THÊM MỘT THAM DỰ VIÊN:',
-	'bouton_annonce' => 'THÔNG BÁO',
-	'bouton_checkbox_envoi_message' => 'Có thể viết vài chữ ',
-	'bouton_checkbox_indiquer_site' => 'Qúy vị phải ghi tên một trang Web',
-	'bouton_checkbox_signature_unique_email' => 'Chỉ một chữ ký cho một địa chỉ email ',
-	'bouton_checkbox_signature_unique_site' => 'Chỉ một chữ ký cho một địa chỉ Web',
 	'bouton_demande_publication' => 'Đề nghị bài này cho ban biên tập',
-	'bouton_effacer_index' => 'Xoá bản index',
 	'bouton_effacer_tout' => 'Xoá TẤT CẢ',
-	'bouton_envoi_message_02' => 'GỬI THƯ TÍN',
 	'bouton_envoyer_message' => 'Tin thư đầy đủ: Gửi đi ',
 	'bouton_modifier' => 'Thay đổi',
-	'bouton_pense_bete' => 'GHI NHỚ CÁ NHÂN',
-	'bouton_radio_activer_messagerie' => 'Sử dụng thư tín nội bộ  ',
-	'bouton_radio_activer_messagerie_interne' => 'Sử dụng thư tín nội bộ',
-	'bouton_radio_activer_petition' => 'Dùng thỉnh nguyện thư ',
 	'bouton_radio_afficher' => 'Hiển thị',
 	'bouton_radio_apparaitre_liste_redacteurs_connectes' => 'Hiện tên ra',
-	'bouton_radio_desactiver_messagerie' => 'Không sử dụng thư tín nội bộ',
 	'bouton_radio_envoi_annonces_adresse' => 'Gửi thông báo đến địa chỉ:',
 	'bouton_radio_envoi_liste_nouveautes' => 'Gửi các tin tức mới nhất',
 	'bouton_radio_non_apparaitre_liste_redacteurs_connectes' => 'Không hiện tên ra  ',
 	'bouton_radio_non_envoi_annonces_editoriales' => 'Đừng gửi bất cứ thông báo xã luận nào',
-	'bouton_radio_pas_petition' => 'Không dùng',
-	'bouton_radio_petition_activee' => 'Thỉnh nguyện thư được mở lên',
-	'bouton_radio_supprimer_petition' => 'Xóa thỉnh nguyện thư',
 	'bouton_redirection' => 'CHUYỂN TỚI',
 	'bouton_relancer_installation' => 'Thiết trí lại',
 	'bouton_suivant' => 'Kế tiếp',
 	'bouton_tenter_recuperation' => 'Tìm cách sửa chữa',
 	'bouton_test_proxy' => 'Thử nghiệm proxy',
 	'bouton_vider_cache' => 'Làm sạch cache',
-	'bouton_voir_message' => 'Xem lại trước khi gửi',
 
 	// C
-	'cache_mode_compresse' => 'Hồ sơ cache được lưu trữ trong dạng nén/ép.',
-	'cache_mode_non_compresse' => 'Hồ sơ cache được giữ nguyên dạng, không nén.',
 	'cache_modifiable_webmestre' => 'Webmaster có thể điều chỉnh các thông số này.',
 	'calendrier_synchro' => 'Nếu bạn có thiết trí nhu liệu nhật ký tương ứng với <b>iCal</b>, bạn có thể đồng bộ hóa nó với trang web.',
 
@@ -103,7 +78,6 @@ Hồ sơ SPIP</a>.', # MODIF
 	'entree_login' => 'Login của bạn',
 	'entree_login_connexion_1' => 'Nối vào',
 	'entree_login_connexion_2' => '(Đôi khi giống với ký danh FTP của bạn và đôi khi để trống)',
-	'entree_login_ldap' => 'Nối sơ khởi vào LDAP',
 	'entree_mot_passe' => 'Mật mã của bạn',
 	'entree_mot_passe_1' => 'Mật mã để nối vào',
 	'entree_mot_passe_2' => '(Đôi khi giống mật mã FTP của bạn và đôi khi để trống)',
@@ -123,7 +97,7 @@ Hồ sơ SPIP</a>.', # MODIF
 	'ical_info2' => 'Để biết thêm chi tiết xin vào xem trang web <a href="@spipnet@">SPIP’s documentation</a>.', # MODIF
 	'ical_info_calendrier' => 'Bạn có 2 thời biểu để sử dụng. Thời biểu thứ nhất liệt kê tất cả các bài viết được đăng. Thời biểu thứ hai liệt kê các thông báo của Ban Biên Tập và những thông tin cá nhân của bạn. Phần này được dành cho bạn qua một mật mã riêng mà bạn có thể thay đổi bằng cách thay đổi mật mã của mình.',
 	'ical_methode_http' => 'Đang tải xuống',
-	'ical_methode_webcal' => 'Đồng bộ hoá (webcal://)',
+	'ical_methode_webcal' => 'Đồng bộ hoá (webcal://)', # MODIF
 	'ical_texte_js' => 'Một mệnh lệnh javascript có thể được sử dụng để hiển thị những bài vỡ mới nhất được đăng của trang web này trên bất kỳ trang web nào của bạn một cách rất dễ dàng.',
 	'ical_texte_prive' => 'Thời biểu này, với tính cách cá nhân, sẽ cho bạn biết các hoạt động cá nhân của Ban Biên Tập (công việc, các cuộc hẹn, các bài đã nộp và các tin tức...).',
 	'ical_texte_public' => 'Thời biểu này giúp bạn theo dõi các hoạt động chung của trang web (các bài viết và các tin tức đã được đăng).',
@@ -139,9 +113,7 @@ Hồ sơ SPIP</a>.', # MODIF
 	'icone_creer_auteur' => 'Thêm tên một tác giả mới và ghi vào bài này',
 	'icone_creer_mot_cle' => 'Thêm một từ then chốt mới và ghi vào bài này',
 	'icone_creer_rubrique_2' => 'Thêm một đề mục mới ',
-	'icone_envoyer_message' => 'Gửi thư tín này',
 	'icone_modifier_article' => 'Sửa bài này',
-	'icone_modifier_message' => 'Sửa thư tín này',
 	'icone_modifier_rubrique' => 'Sửa đề mục này',
 	'icone_retour' => 'Trở lại',
 	'icone_retour_article' => 'Trở về bài trước',
@@ -151,10 +123,7 @@ Hồ sơ SPIP</a>.', # MODIF
 	'icone_valider_signature' => 'Chấp thuận',
 	'image_administrer_rubrique' => 'Bạn có thể quản trị đề mục này',
 	'info_1_article' => '1 bài',
-	'info_1_site' => '1 trang web',
 	'info_activer_cookie' => 'Bạn có thể cho chạy <b>administration cookie</b> để bạn có thể qua lại giữa trang web công cộng và khu vực riêng.',
-	'info_admin_gere_rubriques' => 'Nhân vật này có quyền quản trị các đề mục sau đây:',
-	'info_admin_gere_toutes_rubriques' => 'Nhân vật này có quyền quản trị <b>tất cả các đề mục</b>.', # MODIF
 	'info_administrateur' => 'Quản lý',
 	'info_administrateur_1' => 'Quản lý',
 	'info_administrateur_2' => 'của trang web (<i>sử dụng cẩn thận</i>)',
@@ -164,13 +133,10 @@ Hồ sơ SPIP</a>.', # MODIF
 	'info_administrer_rubrique' => 'Bạn có thể quản trị đề mục này',
 	'info_adresse' => 'đến địa chỉ:',
 	'info_adresse_url' => 'Địa chỉ trang web của bạn',
-	'info_afficher_visites' => 'Liệt kê những lần viếng thăm cho:',
 	'info_aide_en_ligne' => 'Giúp đỡ SPIP online',
 	'info_ajout_image' => 'Khi bạn đính kèm hình (trong dạng hồ sơ) vào một bài, SPIP có thể tự động chế ra các hình mẫu để xem trước (tức thumbnails) từ tấm hình nguyên thủy. Với đặc điểm này có thể tự động thiết lập ra một tập/bộ hình ảnh, album.',
-	'info_ajout_participant' => 'Những tham dự viên sau đây đã được thêm vào:',
 	'info_ajouter_rubrique' => 'Thêm một đề mục khác để quản trị:',
 	'info_annonce_nouveautes' => 'Thông tin mới nhất',
-	'info_anterieur' => 'trước đó',
 	'info_article' => 'bài',
 	'info_article_2' => 'bài',
 	'info_article_a_paraitre' => 'Những bài đã đề ngày để phát hành',
@@ -178,10 +144,8 @@ Hồ sơ SPIP</a>.', # MODIF
 	'info_articles_2' => 'Bài',
 	'info_articles_auteur' => 'Bài của tác giả này',
 	'info_articles_trouves' => 'Những bài tìm thấy',
-	'info_articles_trouves_dans_texte' => 'Những bài tìm thấy (trong văn bản)',
 	'info_attente_validation' => 'Bài vở của bạn đang chờ thông qua',
 	'info_aujourdhui' => 'hôm nay:',
-	'info_auteur_message' => 'NGƯỜI GỬI:',
 	'info_auteurs' => 'Tác giả',
 	'info_auteurs_par_tri' => 'Tác giả@partri@',
 	'info_auteurs_trouves' => 'Những tác giả tìm thấy',
@@ -214,15 +178,12 @@ Hồ sơ SPIP</a>.', # MODIF
 	'info_date_publication_anterieure' => 'Ngày tháng của bài đã đăng:',
 	'info_date_referencement' => 'NGÀY NỐI KẾT WEBSITE NÀY:',
 	'info_derniere_etape' => 'Bước chót: <b>Hoàn tất!</b>',
-	'info_derniers_articles_publies' => 'Những bài phát hành mới nhất của bạn',
-	'info_desactiver_messagerie_personnelle' => 'Bạn có thể tắt/mở hộp thư tín cá nhân của bạn.',
 	'info_descriptif' => 'Tóm lược:',
 	'info_discussion_cours' => 'Đang trao đổi',
 	'info_ecrire_article' => 'Để có thể soạn một bài vở, bạn phải lập ra một đề mục trước đã. <Trước khi có thể viết bài, bạn phải lập ra ít nhất một đề mục.',
 	'info_email_envoi' => 'Địa chỉ email của người gửi (không bắt buộc)',
 	'info_email_envoi_txt' => 'Đánh vào địa chỉ người gửi để gửi email (theo định sẵn, thì địa chỉ người nhận sẽ được dùng làm địa chỉ gửi) :',
 	'info_email_webmestre' => 'Địa chỉ email của webmaster (không bắt buộc) ', # MODIF
-	'info_entrer_code_alphabet' => 'Cho biết bảng mã sử dụng: ',
 	'info_envoi_email_automatique' => 'Gửi email tự động',
 	'info_envoyer_maintenant' => 'Gửi bây giờ',
 	'info_etape_suivante' => 'Qua bước kế',
@@ -232,24 +193,16 @@ Hồ sơ SPIP</a>.', # MODIF
 	'info_facilite_suivi_activite' => 'Để làm nhẹ công việc của Ban Biên Tập, SPIP gửi bằng email các thông báo xin phép đăng và chấp thuận bài vở (đến mailing list của chủ bút chẳng hạn) ',
 	'info_fichiers_authent' => 'Hồ sơ xác nhận ".htpasswd"',
 	'info_forums_abo_invites' => 'Trang web có các diễn đàn cần ghi danh; khách có thể vào ghi danh ở trang công cộng.',
-	'info_gauche_admin_effacer' => '<b>Chỉ có quản trị viên được phép vào trang này.</b><p> Nơi đây cho phép bạn thực hiện một số việc quản trị kỹ thuật. Một số việc đòi hỏi phải có chứng nhận đặc biệt, và cần phải dùng FTP để vào trang web.</p>', # MODIF
 	'info_gauche_admin_tech' => '<b>Chỉ có quản trị viên được phép vào trang này.</b><p> Nơi đây cho phép bạn thực hiện một số công việc bảo trì. Một số việc cần phải có chứng nhận đặc biệt, cần phải dùng FTP để vào trang web.</p>', # MODIF
 	'info_gauche_admin_vider' => '<b>Chỉ có quản trị viên được phép vào trang này.</b><p> Nơi đây cho phép bạn thực hiện một số công việc bảo trì. Một số việc cần phải có chứng nhận đặc biệt, và cần phải dùng FTP để vào trang web.</p>', # MODIF
 	'info_gauche_auteurs' => 'Danh sách tất cả tác giả được liệt kê nơi đây. Trách nhiệm của mỗi người được biểu hiện qua màu của icon (chủ bút=màu xanh lá cây; quản lý=màu vàng).',
 	'info_gauche_auteurs_exterieurs' => 'Các tác giả bên ngoài (không được phép vào trang web) được biểu hiện bằng icon màu xanh dương; Tác giả nào bị xóa tên được biểu hiện bằng icon thùng rác.', # MODIF
 	'info_gauche_messagerie' => 'Phương tiện thư tín cho phép bạn trao đổi thư tín giữa các chủ bút với nhau, lưu trữ bản ghi nhớ (để sử dụng riêng) hoặc hiển thị thông báo trên trang nhà của vùng riêng (nếu bạn là người quản trị).',
-	'info_gauche_numero_auteur' => 'SỐ THỨ TỰ TÁC GIẢ:',
 	'info_gauche_statistiques_referers' => 'Trang này liệt kê danh sách <i>referrers</i>, tức là các trang có chứa điểm nối đến trang của bạn, chỉ cho hôm nay mà thôi: thật ra danh sách này được soạn mỗi 24 giờ.',
 	'info_gauche_visiteurs_enregistres' => 'Danh sách những người khách ghi danh trong vùng công cộng của trang web (theo diễn đàn)',
 	'info_generation_miniatures_images' => 'Hình mẫu xem trước (thumbnail)',
-	'info_gerer_trad' => 'Quản trị phần nối dịch thuật?',
 	'info_hebergeur_desactiver_envoi_email' => 'Một số máy chủ không cho phép gửi email tự động từ server. Trong trường hợp này, những đặc điểm sau đây của SPIP không thể thiết lập được.',
 	'info_hier' => 'hôm qua: ',
-	'info_historique_activer' => 'Cho phép tiếp tục sửa đổi',
-	'info_historique_affiche' => 'Hiển thị ấn bản này',
-	'info_historique_comparaison' => 'so sánh',
-	'info_historique_desactiver' => 'Đóng việc nối tiếp sửa đổi',
-	'info_historique_texte' => 'Nối tiếp sửa đổi cho phép bạn theo dõi những sửa đổi của một bài và cho thấy sự khác biệt giữa các ấn bản được sửa.',
 	'info_identification_publique' => 'Danh tánh công cộng của bạn...',
 	'info_image_process' => 'Xin chọn cách tạo ra hình trang trí bằng bấm trên hình đẹp nhất.',
 	'info_image_process2' => '<b>N.B.</b> <i>Nếu bạn không thấy hình nào cả có nghĩa là máy chủ chưa được thiết trí để sử dụng hình. Nếu bạn muốn dùng hình, liên lạc với nhóm phụ trách kỹ thuật của công ty cung cấp dịch vụ để yêu cầu có extension «GD» hay «Imagick».</i>', # MODIF
@@ -267,8 +220,6 @@ Hồ sơ SPIP</a>.', # MODIF
 	'info_login_trop_court' => 'Login ngắn quá.',
 	'info_maximum' => 'tối đa:',
 	'info_meme_rubrique' => 'Cũng đề mục',
-	'info_message' => 'Thư tín từ ',
-	'info_message_efface' => 'THƯ TÍN ĐƯỢC XÓA',
 	'info_message_en_redaction' => 'Thư tín đang soạn',
 	'info_message_technique' => 'Thư tín kỹ thuật:',
 	'info_messagerie_interne' => 'Tin tức nội bộ',
@@ -277,20 +228,15 @@ Hồ sơ SPIP</a>.', # MODIF
 	'info_modifier_rubrique' => 'Sửa đổi đề mục:',
 	'info_modifier_titre' => 'Sửa đổi: @titre@',
 	'info_mon_site_spip' => 'Website SPIP của tôi',
-	'info_mot_sans_groupe' => '(Từ then chốt không thuộc một nhóm...)',
-	'info_moteur_recherche' => 'Cơ phận tìm kiếm',
 	'info_moyenne' => 'trung bình: ',
-	'info_multi_articles' => 'Cho phép dụng nhiều thứ tiếng trong những bài ?',
 	'info_multi_cet_article' => 'Bài tiếng:',
 	'info_multi_langues_choisies' => 'Xin chọn ngôn ngữ có sẵn cho các chủ bút.
   Ngôn ngữ đã dùng cho trang web thì không tắt được.',
-	'info_multi_rubriques' => 'Cho phép dụng nhiều thứ tiếng trong những đề mục ?',
 	'info_multi_secteurs' => '... chỉ dành cho các đề mục ở gốc trang web ?',
 	'info_nom' => 'Tên',
 	'info_nom_destinataire' => 'Tên người nhận',
 	'info_nom_site' => 'Tên website của bạn',
 	'info_nombre_articles' => '@nb_articles@ bài,',
-	'info_nombre_partcipants' => 'THAM DỰ VIÊN VÀO CUỘC THẢO LUẬN:',
 	'info_nombre_rubriques' => '@nb_rubriques@ đề mục, ',
 	'info_nombre_sites' => '@nb_sites@ website, ',
 	'info_non_deplacer' => 'Đừng dời...',
@@ -299,36 +245,26 @@ Hồ sơ SPIP</a>.', # MODIF
 	'info_non_modifiable' => 'không thể sửa đổi được',
 	'info_non_suppression_mot_cle' => 'Tôi không muốn xóa từ then chốt này.',
 	'info_notes' => 'Chú thích',
-	'info_nouveaux_message' => 'Thư tín mới',
 	'info_nouvel_article' => 'Bài mới',
 	'info_nouvelle_traduction' => 'Bản dịch mới:',
 	'info_numero_article' => 'SỐ THỨ TỰ BÀI:',
 	'info_obligatoire_02' => '[Bắt buộc] ', # MODIF
 	'info_option_accepter_visiteurs' => 'Cho phép khách ghi danh từ trang công cộng',
-	'info_option_faire_suivre' => 'Chuyển thư tín trong diễn đàn đến tác giả bài',
 	'info_option_ne_pas_accepter_visiteurs' => 'Từ chối khách ghi danh',
 	'info_options_avancees' => 'ĐẶC TÍNH PHỤ TRỘI',
-	'info_ortho_activer' => 'Mở lên cơ phận xét lỗi chính tả',
-	'info_ortho_desactiver' => 'Tắt cơ phận xét lỗi chính tả',
 	'info_ou' => 'hoặc... ',
 	'info_page_interdite' => 'Trang cấm vào',
 	'info_par_nombre_article' => '(theo số lượng bài) ',
 	'info_passe_trop_court' => 'Mật mã ngắn quá.',
 	'info_passes_identiques' => 'Hai mật mã không giống hệt nhau.',
-	'info_pense_bete_ancien' => 'Bản ghi nhớ cũ của bạn', # MODIF
 	'info_plus_cinq_car' => 'hơn 5 mẫu tự',
 	'info_plus_cinq_car_2' => '(Hơn 5 mẫu tự) ',
 	'info_plus_trois_car' => '(Hơn 3 mẫu tự) ',
 	'info_popularite' => 'Mức phổ thông: @popularite@; lần viếng: @visites@',
-	'info_popularite_4' => 'Mức phổ thông: @popularite@; lần viếng: @visites@',
 	'info_post_scriptum' => 'Tái bút',
 	'info_post_scriptum_2' => 'Tái bút:',
 	'info_pour' => 'cho',
-	'info_preview_admin' => 'Chỉ có quản trị viên được phép dùng dạng xem trước',
-	'info_preview_comite' => 'Tất cả tác giả có thể dùng dạng xem trước.',
-	'info_preview_desactive' => 'Dạng xem trước chưa mở lên',
-	'info_preview_texte' => 'Bạn có thể xem trước trang web mà các bài vở, tin ngắn (với tình trạng "được đăng") trong đó như đã được cho đăng lên chính thức. Dạng xem trước này chỉ nên giới hạn cho quản trị viên, cho tất cả các tác giả, hay hoàn toàn tắt nó đi ?',
-	'info_principaux_correspondants' => 'Những người liên lạc chính',
+	'info_preview_texte' => 'Bạn có thể xem trước trang web mà các bài vở, tin ngắn (với tình trạng "được đăng") trong đó như đã được cho đăng lên chính thức. Dạng xem trước này chỉ nên giới hạn cho quản trị viên, cho tất cả các tác giả, hay hoàn toàn tắt nó đi ?', # MODIF
 	'info_procedez_par_etape' => 'Xin tiếp diễn từng bước một',
 	'info_procedure_maj_version' => 'Quy trình nâng cấp cần được chạy để database thích ứng với ấn bản SPIP mới.',
 	'info_ps' => 'Tái bút.', # MODIF
@@ -336,12 +272,8 @@ Hồ sơ SPIP</a>.', # MODIF
 	'info_publies' => 'Bài của bạn được đăng online',
 	'info_question_accepter_visiteurs' => 'Nếu trang web cho phép khách ghi danh mà không cần phải vào vùng riêng, thì xin hãy mở lên những chọn lựa sau:',
 	'info_question_inscription_nouveaux_redacteurs' => 'Bạn có cho phép ghi danh các chủ bút mới từ website công cộng không? Nếu đồng ý, khách có thể ghi danh qua một mẫu tự động, và sẽ được phép vào vùng riêng của họ để soạn bài. <blockquote><i>Trong quá trình ghi danh, người dùng sẽ nhận được email cho biết login/mật mã vào chỗ riêng của họ. Một số máy chủ tắt đặc điểm này: trong trường hợp đó, ghi danh tự động không dùng được.</i>', # MODIF
-	'info_question_utilisation_moteur_recherche' => 'Bạn có muốn dùng cơ phận tìm kiếm có sẵn của SPIP? (<i>Nếu tắt nó đi sẽ làm hệ thống chạy lẹ hơn</i>) ',
-	'info_qui_edite' => '@nom_auteur_modif@ a travaillé sur ce contenu il y a @date_diff@ minutes', # MODIF
 	'info_racine_site' => 'Gốc của website',
 	'info_recharger_page' => 'Xin nạp lại trang này trong giây lát.',
-	'info_recherche_auteur_a_affiner' => 'Quá nhiều kết quả cho "@cherche_auteur@"; Xin lọc lựa lại việc tìm kiếm.',
-	'info_recherche_auteur_ok' => 'Tìm thấy một số chủ bút cho "@cherche_auteur@":',
 	'info_recherche_auteur_zero' => 'Không có kết quả cho "@cherche_auteur@".',
 	'info_recommencer' => 'Xin thử lại.',
 	'info_redacteur_1' => 'Tác giả',
@@ -358,7 +290,6 @@ Hồ sơ SPIP</a>.', # MODIF
 	'info_rubriques' => 'Đề mục',
 	'info_rubriques_02' => 'đề mục',
 	'info_rubriques_trouvees' => 'Tìm thấy đề mục',
-	'info_rubriques_trouvees_dans_texte' => 'Tìm thấy đề mục (trong văn tư)',
 	'info_sans_titre' => 'Không tựa đề',
 	'info_selection_chemin_acces' => '<b>Chọn</b> dưới đây đường vào trong thư mục:',
 	'info_signatures' => 'chữ ký',
@@ -371,11 +302,9 @@ Hồ sơ SPIP</a>.', # MODIF
 	'info_sites_lies_mot' => 'Những website nối kết liên đới với từ then chốt này',
 	'info_sites_proxy' => 'Dùng một proxy',
 	'info_sites_trouves' => 'Tìm thấy website',
-	'info_sites_trouves_dans_texte' => 'Tìm thấy website (trong văn tự)',
 	'info_sous_titre' => 'Tựa đề phụ:',
 	'info_statut_administrateur' => 'Quản trị viên',
 	'info_statut_auteur' => 'Quyền hạn của tác giả:', # MODIF
-	'info_statut_efface' => 'Xóa',
 	'info_statut_redacteur' => 'Chủ bút',
 	'info_statut_utilisateurs_1' => 'Trạng thái định sẵn của người dùng được đưa vào',
 	'info_statut_utilisateurs_2' => 'Chọn trạng thái cho những người liệt kê trong thư mục LDAP khi họ nối vào lần đầu. Về sau, bạn có thể sửa đổi trị giá này cho từng tác giả theo từng trường hợp một.',
@@ -393,7 +322,6 @@ Hồ sơ SPIP</a>.', # MODIF
 	'info_tous_articles_en_redaction' => 'Tất cả bài vở đang được soạn',
 	'info_tous_articles_presents' => 'Tất cả bài vở đã phát hành trong đề mục này',
 	'info_tous_les' => 'mỗi:',
-	'info_tous_redacteurs' => 'Thông báo đến tất cả chủ bút',
 	'info_tout_site' => 'Toàn bộ website',
 	'info_tout_site2' => 'Bài nầy chưa được dịch qua ngôn ngữ nầy.',
 	'info_tout_site3' => 'Bài nầy đã được dịch qua ngôn ngữ nầy rồi, nhưng bài gốc đã được sửa. Các bản dịch cần được cập nhật.  ',
@@ -408,7 +336,6 @@ và hiển ra với những màu khác nhau tùy theo tình trạng bài vở :
 	'info_une_rubrique' => 'một đề mục, ',
 	'info_une_rubrique_02' => '1 đề mục',
 	'info_url' => 'URL:', # MODIF
-	'info_url_site' => 'URL CỦA WEBSITE:', # MODIF
 	'info_urlref' => 'Nối kết:',
 	'info_utilisation_spip' => 'SPIP sẵn sàng để sử dụng...',
 	'info_visites_par_mois' => 'Hiển thị hàng tháng:',
@@ -425,15 +352,12 @@ và hiển ra với những màu khác nhau tùy theo tình trạng bài vở :
 	'item_activer_messages_avertissement' => 'Cho phép cảnh báo',
 	'item_administrateur_2' => 'quản lý',
 	'item_afficher_calendrier' => 'Hiện ra trong lịch',
-	'item_autoriser_documents_joints' => 'Cho phép đính kèm tài liệu vào bài vở',
-	'item_autoriser_documents_joints_rubriques' => 'Cho phép đính kèm tài liệu trong đề mục',
 	'item_choix_administrateurs' => 'quản trị viên',
 	'item_choix_generation_miniature' => 'Tự động tạo ra các hình mẫu.',
 	'item_choix_non_generation_miniature' => 'Đừng tạo ra hình mẫu.',
 	'item_choix_redacteurs' => 'chủ bút',
 	'item_choix_visiteurs' => 'Khách của website công',
 	'item_creer_fichiers_authent' => 'Lập ra hồ sơ .htpasswd',
-	'item_limiter_recherche' => 'Giới hạn việc tìm kiếm trong khối lượng tin của website bạn',
 	'item_login' => 'Login',
 	'item_mots_cles_association_articles' => 'bài vở',
 	'item_mots_cles_association_rubriques' => 'các đề mục',
@@ -442,34 +366,24 @@ và hiển ra với những màu khác nhau tùy theo tình trạng bài vở :
 	'item_non_accepter_inscriptions' => 'Không cho phép ghi danh',
 	'item_non_activer_messages_avertissement' => 'Không cần cảnh báo',
 	'item_non_afficher_calendrier' => 'Không hiện ra trong lịch',
-	'item_non_autoriser_documents_joints' => 'Không cho phép đính kèm tài liệu vào bài vở',
-	'item_non_autoriser_documents_joints_rubriques' => 'Không cho phép đính kèm tài liệu trong đề mục',
 	'item_non_creer_fichiers_authent' => 'Đừng lập ra các hồ sơ này',
-	'item_non_gerer_statistiques' => 'Không quản trị các thống kê',
-	'item_non_limiter_recherche' => 'Nới rộng việc tìm kiếm qua đến nội dung của các website nối kết',
 	'item_non_publier_articles' => 'Không đăng tải bài trước ngày được phép đăng.',
-	'item_non_utiliser_moteur_recherche' => 'Đừng dùng',
 	'item_nouvel_auteur' => 'Tác giả mới',
 	'item_nouvelle_rubrique' => 'Đề mục mới',
 	'item_oui' => 'Dùng',
 	'item_publier_articles' => 'Cứ đăng tải bài bất kể ngày ghi.',
 	'item_reponse_article' => 'Hồi đáp bài ',
-	'item_utiliser_moteur_recherche' => 'Dùng cơ phận tìm kiếm',
 	'item_visiteur' => 'khách',
 
 	// J
 	'jour_non_connu_nc' => 'k.b.',
 
 	// L
-	'lien_ajout_destinataire' => 'Thêm người nhận này',
 	'lien_ajouter_auteur' => 'Thêm tác giả này',
-	'lien_ajouter_participant' => 'Thêm một tham dự viên',
 	'lien_email' => 'email',
 	'lien_nom_site' => 'TÊN WEBSITE:',
 	'lien_retirer_auteur' => 'Loại bỏ tác giả',
-	'lien_retrait_particpant' => 'Loại bỏ tham dự viên này',
 	'lien_site' => 'website',
-	'lien_supprimer_rubrique' => 'xóa đề mục này',
 	'lien_tout_deplier' => 'Mở ra tất cả',
 	'lien_tout_replier' => 'Gộp tất cả lại',
 	'lien_trier_nom' => 'Xếp theo tên',
@@ -495,6 +409,9 @@ và hiển ra với những màu khác nhau tùy theo tình trạng bài vở :
 	// O
 	'onglet_repartition_actuelle' => 'hiện nay',
 
+	// R
+	'required' => '[Bắt buộc] ', # MODIF
+
 	// S
 	'statut_admin_restreint' => '(Quản trị viên có giới hạn)', # MODIF
 
@@ -516,13 +433,10 @@ và hiển ra với những màu khác nhau tùy theo tình trạng bài vở :
 	'texte_article_virtuel_reference' => '<b>Bài ảo:</b> chỉ vào một bài khác trong SPIP của bạn, nhưng chuyển qua một địa chỉ khác. Để loại bỏ việc chuyển qua, xóa địa chỉ URL trên.',
 	'texte_aucun_resultat_auteur' => 'Không có kết quả cho "@cherche_auteur@".',
 	'texte_auteur_messagerie' => 'Website này có thể giám sát liên tục danh sách những chủ bút đang vào, và cho phép bạn trao đổi thư tín ngay lập tức (nếu hệ thư tín bị tắt thì danh sách các chủ bút đang vào cũng bị tắt theo). Bạn có thể chọn không xuất hiện trong danh sách này (đối với những người khác, bạn sẽ «vô hình»).',
-	'texte_auteur_messagerie_1' => 'Website này cho phép trao đổi thư tín và cho lập ra những diễn đàn trao đổi riêng tư của các tham dự viên. Bạn có thể chọn không tham gia vào sự trao đổi này. ',
 	'texte_auteurs' => 'TÁC GIẢ',
 	'texte_choix_base_1' => 'Chọn database của bạn:',
 	'texte_choix_base_2' => 'Server SQL chứa nhiều database.',
 	'texte_choix_base_3' => '<b>Chọn</b> một trong số dưới đây thuộc về bạn:',
-	'texte_commande_vider_tables_indexation' => 'Dùng mệnh lệnh này để dọn sạch bản index dùng bởi cơ phận tìm kiếm của SPIP. Làm thế để tiết kiệm được một số chỗ trống trong dĩa.',
-	'texte_compresse_ou_non' => '(có thể trong dạng nén hoặc dạng thường) ',
 	'texte_compte_element' => '@count@ món',
 	'texte_compte_elements' => '@count@ món',
 	'texte_connexion_mysql' => 'Xem lại tài liệu cung cấp bởi máy chủ: nếu dùng SQL, máy chủ cho bạn mã số ra vào server SQL. ', # MODIF
@@ -534,10 +448,8 @@ và hiển ra với những màu khác nhau tùy theo tình trạng bài vở :
 	'texte_date_publication_anterieure' => 'Ngày phát hành truớc đó :',
 	'texte_date_publication_anterieure_nonaffichee' => 'Dấu ngày phát hành trước đó.',
 	'texte_date_publication_article' => 'NGÀY ĐĂNG TẢI ONLINE :',
-	'texte_descriptif_petition' => 'Mô tả Thỉnh nguyện thư',
 	'texte_descriptif_rapide' => 'Tóm lược',
 	'texte_effacer_base' => 'Xóa database SPIP',
-	'texte_effacer_donnees_indexation' => 'Xóa dữ kiện indexing',
 	'texte_en_cours_validation' => 'Bài vở và tin ngắn sau đây được nộp để chờ phát hành. Xin góp ý qua diễn đàn đính kèm. ', # MODIF
 	'texte_enrichir_mise_a_jour' => 'Bạn có thể trình bày văn bản gọn đẹp hơn bằng cách dùng những <b>«lối xếp bài tắt»</b>.',
 	'texte_fichier_authent' => 'SPIP có nên lập ra hồ sơ đặc biệt <tt>.htpasswd</tt> và <tt>.htpasswd-admin</tt> trong thư mục @dossier@?</b><p> Hai hồ sơ này dùng để giới hạn các tác giả và quản lý viên ra/vào các nơi khác trong website.<p>Nếu bạn chưa từng sử dụng đặc tính này, hãy để nguyên lựa chọn này với các giá trị định sẵn (không lập ra hồ sơ). ', # MODIF
@@ -546,19 +458,13 @@ và hiển ra với những màu khác nhau tùy theo tình trạng bài vở :
 	'texte_introductif_article' => '(Lời mở đầu cho bài viết.) ',
 	'texte_jeu_caractere' => 'Chọn lựa này thích hợp nếu website bạn dùng ngôn ngữ khác với mẫu tự latinh (tức "western") và các ngôn ngữ cùng hệ.
  Trong trường hợp này, phải chọn một bộ mã khác. Và cũng nên nhớ sửa đổi website để thích ứng (<tt>#CHARSET</tt> tag).', # MODIF
-	'texte_jeu_caractere_2' => 'Sửa đổi này không có hiệu lực trở về trước. Do đó, bài vở đã cho vào có thể hiện ra không đúng sau khi sửa bảng mã lại. Tuy nhiên, bạn vẫn có thể chọn trở lại bảng mã trước đó. ', # MODIF
-	'texte_lien_hypertexte' => '(Nếu thư tín có đề cập đến bài đã đăng tải trên web, hay đề cập đến một trang web có thêm dữ kiện, xin điền vào đây tựa đề và địa chỉ.)',
 	'texte_login_ldap_1' => '(Để trống nếu muốn ra/vào ẩn danh hoặc cho biết trọn vẹn lộ tuyến, lấy thí dụ «<tt>uid=smith, ou=users, dc=my-domain, dc=com</tt>».)',
 	'texte_login_precaution' => 'Cảnh báo! Đây là login bạn dùng để vào. Dùng mẫu này cẩn thận...',
-	'texte_message_edit' => 'Cảnh báo: thư tín này có thể được sửa bởi bất cứ người quản lý nào, và mọi chủ bút đều xem được. Chỉ nên thông báo để nhấn mạnh những việc quan trọng đối với website.',
 	'texte_mise_a_niveau_base_1' => 'Bạn vừa cập nhật hồ sơ SPIP. Bây giờ bạn phải nâng cấp database của website.',
 	'texte_modifier_article' => 'Sửa bài:',
-	'texte_moteur_recherche_active' => '<b>Cơ phận tìm kiếm được chạy.</b> Dùng mệnh lệnh này nếu bạn muốn re-indexing cho lẹ (sau khi phục hồi các hồ sơ dự trữ chẳng hạn). Lưu ý là trong trường hợp bài được sửa đổi một cách bình thường (dùng giao diện SPIP) thì bài đó được tự động đánh chỉ số (index) lần nữa: do đó mệnh lệnh này chỉ hữu dụng trong trường hợp rất ư đặc biệt. ',
-	'texte_moteur_recherche_non_active' => 'Cơ phận tìm kiếm đã bị tắt, không được phép chạy.',
 	'texte_multilinguisme' => 'Nếu bạn muốn quản trị các bài vỡ này trong nhiều ngôn ngữ, bạn có thể thêm vào bài/đề mục một mục lục chọn ngôn ngữ.', # MODIF
 	'texte_multilinguisme_trad' => 'Đồng thời, bạn có thể mở lên một hệ thống quản trị cho các bản dịch của một bài.', # MODIF
 	'texte_non_compresse' => '<i>Giản ra</i> (server của bạn không dùng đặc tính này)',
-	'texte_nouveau_message' => 'Thư tín mới',
 	'texte_nouvelle_version_spip_1' => 'Bạn vừa thiết trí ấn bản mới của SPIP.',
 	'texte_nouvelle_version_spip_2' => 'Ấn bản mới này cần cập nhật
  kỹ lưởng hơn bình thường.
@@ -579,7 +485,6 @@ và hiển ra với những màu khác nhau tùy theo tình trạng bài vở :
 	'texte_publication_articles_post_dates' => 'SPIP sẽ làm gì khi một bài viết có đề ngày đăng tải sắp tới (trong tương lai)?',
 	'texte_rappel_selection_champs' => '[Nhớ chọn phần này cho đúng]',
 	'texte_recalcul_page' => 'Nếu bạn chỉ muốn làm mới lại một trang thôi, thì nên làm lại từ vùng công cộng và bấm vào nút «refresh» hay «reload».',
-	'texte_recapitiule_liste_documents' => 'Trang này tóm tắt danh sách các tài liệu bạn để trong các đề mục. Để tu sửa dữ kiện của mỗi tài liệu, theo điểm nối để đến trang của đề mục đó.',
 	'texte_recuperer_base' => 'Sữa chữa database',
 	'texte_reference_mais_redirige' => 'Bài nối kết trong website SPIP, nhưng chuyển hướng qua địa chỉ URL khác.',
 	'texte_requetes_echouent' => '<b>Khi một số hỏi-đáp SQL trượt hàng loạt và có vẻ như không có lý do gì cả, điều đó cho thấy có thể chính database là thủ phạm. </b><p>SQL có một đặc điểm sửa chữa các bản của nó khi chúng bị hư hại. Bạn có thể thử dùng đặc điểm sửa chữa này, trong trường hợp thất bại, bạn nên giữ lại một bản sao của màn ảnh để giúp soi sáng vấn đề ... <p> Nếu vấn đề vẫn tiếp tục xảy ra, liên lạc với chủ nhân của máy.', # MODIF
@@ -598,7 +503,6 @@ và hiển ra với những màu khác nhau tùy theo tình trạng bài vở :
 	'texte_suppression_fichiers' => 'Dùng mệnh lệnh này để xóa tất cả hồ sơ trong SPIP cache. Làm vậy để buộc làm mới lại mọi trang web, trong trường hợp bạn vừa có một số thay đổi về đồ họa hay cấu trúc của website.',
 	'texte_sur_titre' => 'Đầu đề',
 	'texte_table_ok' => ': bản này OK.',
-	'texte_tables_indexation_vides' => 'Bản indexing của máy trống rỗng. ',
 	'texte_tentative_recuperation' => 'Tìm cách sửa chữa',
 	'texte_tenter_reparation' => 'Tìm cách sửa chữa database',
 	'texte_test_proxy' => 'Để thử proxy này, đánh vào địa chỉ một website bạn muốn thử.',
@@ -607,13 +511,8 @@ và hiển ra với những màu khác nhau tùy theo tình trạng bài vở :
 	'texte_travail_article' => '@nom_auteur_modif@ đã soạn/bổ túc bài này cách đây @date_diff@ phút',
 	'texte_travail_collaboratif' => 'Nếu có nhiều người cùng soạn/sửa đổi một bài, hệ thống có thể cho thấy những bài đang được «làm việc» để tránh trường hợp sửa đổi cùng một lúc. 
 Bạn có thể cho phép cảnh báo hay không:',
-	'texte_trop_resultats_auteurs' => 'Quá nhiều kết quả khi tìm "@cherche_auteur@"; hãy duyệt lại việc tìm kiếm.',
-	'texte_unpack' => 'Đang tải xuống ấn bản mới nhất',
-	'texte_utilisation_moteur_syndiques' => 'Nếu bạn dùng cơ phận tìm kiếm của SPIP, bạn có thể tìm trong webiste và bài vở syndicated bằng nhiều cách khác nhau. <br /><img src=\'puce.gif\' />Cách đơn giản nhất là tìm trong tựa đề và phần mô tả bài. <br /><img src=\'puce.gif\' /> Cách thứ nhất, mạnh hơn, cho phép SPIP tìm kiếm trong văn bản của website nối kết. Nếu bạn nối kết một website, SPIP sẽ tìm trong văn bản của website đó. ', # MODIF
-	'texte_utilisation_moteur_syndiques_2' => 'Phương pháp này buộc SPIP đến viếng thường xuyên những website kết nối; việc này có thể làm giảm hiệu suất của website bạn.',
 	'texte_vide' => 'Trống rỗng',
 	'texte_vider_cache' => 'Dọn sạch cache',
-	'titre_admin_effacer' => 'Bảo trì kỹ thuật',
 	'titre_admin_tech' => 'Bảo trì kỹ thuật',
 	'titre_admin_vider' => 'Bảo trì kỹ thuật',
 	'titre_cadre_afficher_article' => 'Liệt kê những bài',
@@ -633,32 +532,19 @@ Bạn có thể cho phép cảnh báo hay không:',
 	'titre_naviguer_dans_le_site' => 'Xem trang web...',
 	'titre_nouvelle_rubrique' => 'Đề mục mới',
 	'titre_numero_rubrique' => 'SỐ THỨ TỰ ĐỀ MỤC:',
-	'titre_page_admin_effacer' => 'Bảo trì kỹ thuật: xóa database',
 	'titre_page_articles_edit' => 'Bổ túc: @titre@',
 	'titre_page_articles_page' => 'Bài vỡ',
 	'titre_page_articles_tous' => 'Toàn bộ trang web',
-	'titre_page_auteurs' => 'Khách',
 	'titre_page_calendrier' => 'Lịch @nom_mois@ @annee@',
 	'titre_page_config_contenu' => 'Cấu hình website',
-	'titre_page_config_fonctions' => 'Cấu hình website',
-	'titre_page_configuration' => 'Cấu hình website',
-	'titre_page_controle_petition' => 'Tiếp theo Thỉnh nguyện thư',
 	'titre_page_delete_all' => 'xóa luôn và không lấy lại được',
-	'titre_page_documents_liste' => 'Tài liệu của đề mục',
-	'titre_page_index' => 'Vùng riêng của bạn',
-	'titre_page_message_edit' => 'Viết thư tín',
-	'titre_page_messagerie' => 'Thư tín của bạn',
 	'titre_page_recherche' => 'Kết quả tìm kiếm @recherche@',
 	'titre_page_statistiques_referers' => 'Thống kê (các điểm nối vào)',
 	'titre_page_upgrade' => 'nâng cấp SPIP',
 	'titre_publication_articles_post_dates' => 'Đăng tải bài vở có đề ngày',
-	'titre_referencer_site' => 'Nối qua website:',
-	'titre_rendez_vous' => 'VÔ SỔ LỊCH:',
 	'titre_reparation' => 'Sửa chữa',
 	'titre_suivi_petition' => 'Quản trị Thỉnh nguyện thư',
-	'trad_article_inexistant' => 'Không có bài nào với số này',
 	'trad_article_traduction' => 'Tất cả ấn bản của bài này:',
-	'trad_deja_traduit' => 'Bài này là bản dịch của bài hiện thời',
 	'trad_delier' => 'Đừng nối bài này qua bản dịch', # MODIF
 	'trad_lier' => 'Bài này là bản dịch của bài số',
 	'trad_new' => 'Dịch bài này' # MODIF
