@@ -3,7 +3,9 @@
 // extrait automatiquement de http://trad.spip.net/tradlang_module/public?lang_cible=fr_fem
 // ** ne pas modifier le fichier **
 
-if (!defined('_ECRIRE_INC_VERSION')) return;
+if (!defined('_ECRIRE_INC_VERSION')) {
+	return;
+}
 
 $GLOBALS[$GLOBALS['idx_lang']] = array(
 
@@ -11,15 +13,15 @@ $GLOBALS[$GLOBALS['idx_lang']] = array(
 	'accueil_site' => 'Accueil',
 	'article' => 'Article',
 	'articles' => 'Articles',
-	'articles_auteur' => 'Articles de cette auteure',
+	'articles_auteur' => 'Articles de cette autrice',
 	'articles_populaires' => 'Articles les plus populaires',
 	'articles_rubrique' => 'Articles de cette rubrique',
 	'aucun_article' => 'Il n’y a pas d’article à cette adresse',
-	'aucun_auteur' => 'Il n’y a pas d’auteure à cette adresse',
+	'aucun_auteur' => 'Il n’y a pas d’autrice à cette adresse',
 	'aucun_site' => 'Il n’y a pas de site à cette adresse',
 	'aucune_breve' => 'Il n’y a pas de brève à cette adresse',
 	'aucune_rubrique' => 'Il n’y a pas de rubrique à cette adresse',
-	'auteur' => 'Auteure',
+	'auteur' => 'Autrice',
 	'autres' => 'Autres',
 	'autres_breves' => 'Autres brèves',
 	'autres_groupes_mots_clefs' => 'Autres groupes de mots-clés',
@@ -61,9 +63,9 @@ $GLOBALS[$GLOBALS['idx_lang']] = array(
 	'lien_connecter' => 'Se connecter',
 
 	// M
-	'meme_auteur' => 'De la même auteure',
+	'meme_auteur' => 'De la même autrice',
 	'meme_rubrique' => 'Dans la même rubrique',
-	'memes_auteurs' => 'Des mêmes auteures',
+	'memes_auteurs' => 'Des mêmes autrices',
 	'message' => 'Message',
 	'messages_forum' => 'Messages',
 	'messages_recents' => 'Messages de forums les plus récents',
