@@ -3,7 +3,9 @@
 // extrait automatiquement de http://trad.spip.net/tradlang_module/spip?lang_cible=br
 // ** ne pas modifier le fichier **
 
-if (!defined('_ECRIRE_INC_VERSION')) return;
+if (!defined('_ECRIRE_INC_VERSION')) {
+	return;
+}
 
 $GLOBALS[$GLOBALS['idx_lang']] = array(
 
@@ -23,6 +25,7 @@ $GLOBALS[$GLOBALS['idx_lang']] = array(
 	'admin_modifier_mot' => 'Kemmañ ar ger-stur-mañ',
 	'admin_modifier_rubrique' => 'Kemmañ ar rubrikenn-mañ',
 	'admin_recalculer' => 'Hizivaat ar bajenn',
+	'afficher_calendrier' => 'Kinnig an deiziater',
 	'afficher_trad' => 'diskouez an troidigezhioù',
 	'alerte_maj_impossible' => '<b>Diwallit !</b> N’eus ket tu da hizivaat an diaz SQL etrezek ar stumm @version@, marteze abalamour d’ur gudenn aotre evit kemmañ an diaz titouroù. Mar plij kit e darempred gant ho herberc’hier.',
 	'alerte_modif_info_concourante' => 'DIWALLIT : Kemmet eo bet an titour-mañ en ul lec’h all. Setu an talvoud nevez :',
@@ -63,7 +66,7 @@ $GLOBALS[$GLOBALS['idx_lang']] = array(
 	'bouton_changer' => 'Kemmañ',
 	'bouton_chercher' => 'Klask',
 	'bouton_choisir' => 'Dibab',
-	'bouton_download' => 'Pellgargañ', # MODIF
+	'bouton_download' => 'Pellgargañ',
 	'bouton_enregistrer' => 'Enrollañ',
 	'bouton_radio_desactiver_messagerie_interne' => 'Diweredekaat ar postelerezh diabarzh',
 	'bouton_radio_envoi_annonces' => 'Kas ar c’hemennoù embann',
@@ -71,7 +74,7 @@ $GLOBALS[$GLOBALS['idx_lang']] = array(
 	'bouton_radio_non_envoi_liste_nouveautes' => 'Chom hep kas roll an nevezinti',
 	'bouton_recharger_page' => 'adkargañ ar bajenn-mañ',
 	'bouton_telecharger' => 'Pellgargañ',
-	'bouton_upload' => 'Pellgargañ', # MODIF
+	'bouton_upload' => 'Pellgas',
 	'bouton_valider' => 'Kadarnaat',
 
 	// C
@@ -105,11 +108,14 @@ $GLOBALS[$GLOBALS['idx_lang']] = array(
 	'date_de_mois_9' => '@j@ @nommois@',
 	'date_demain' => 'warc’hoazh',
 	'date_fmt_heures_minutes' => '@h@eur@m@munut',
+	'date_fmt_heures_minutes_court' => '@h@h@m@',
 	'date_fmt_jour_heure' => '@jour@ da @heure@',
 	'date_fmt_jour_mois' => '@jour@ a viz @nommois@',
 	'date_fmt_jour_mois_annee' => '@jour@ a viz @nommois@ @annee@',
 	'date_fmt_mois_annee' => '@nommois@ @annee@',
 	'date_fmt_nomjour_date' => '@nomjour@ @date@',
+	'date_fmt_periode_from' => 'Adalek',
+	'date_fmt_periode_to' => 'betek',
 	'date_heures' => 'eur',
 	'date_hier' => 'dec’h',
 	'date_il_y_a' => '@delai@ zo',
@@ -170,16 +176,24 @@ $GLOBALS[$GLOBALS['idx_lang']] = array(
 	'date_mois' => 'miz',
 	'date_mois_1' => 'Genver',
 	'date_mois_10' => 'Here',
+	'date_mois_10_abbr' => 'here.',
 	'date_mois_11' => 'Du',
+	'date_mois_11_abbr' => 'du.',
 	'date_mois_12' => 'Kerzu',
+	'date_mois_12_abbr' => 'kerzu.',
+	'date_mois_1_abbr' => 'genver.',
 	'date_mois_2' => 'C’hwevrer',
+	'date_mois_2_abbr' => 'c’hevrer.',
 	'date_mois_3' => 'Meurzh',
 	'date_mois_4' => 'Ebrel',
+	'date_mois_4_abbr' => 'ebrel.',
 	'date_mois_5' => 'Mae',
 	'date_mois_6' => 'Mezheven',
 	'date_mois_7' => 'Gouere',
+	'date_mois_7_abbr' => 'gouere.',
 	'date_mois_8' => 'Eost',
 	'date_mois_9' => 'Gwengolo',
+	'date_mois_9_abbr' => 'gweng.',
 	'date_saison_1' => 'Goañv',
 	'date_saison_2' => 'nevez-amzer',
 	'date_saison_3' => 'hañv',
@@ -210,15 +224,29 @@ $GLOBALS[$GLOBALS['idx_lang']] = array(
 	'envoi_via_le_site' => 'Kas dre al lec’hienn',
 	'erreur' => 'Fazi',
 	'erreur_balise_non_fermee' => 'Balizenn ziwezhañ chomet digor :',
+	'erreur_technique_enregistrement_champs' => 'Miret eo bet enrolliñ mat al heuliad-gerioù @champs@ abalamour d’ur fazi teknikel.',
+	'erreur_technique_enregistrement_impossible' => 'Miret eo bet an enrolladenn abalamour d’ur fazi teknikel.',
 	'erreur_texte' => 'fazi',
 	'etape' => 'Pazenn',
 
 	// F
 	'fichier_introuvable' => 'Restr @fichier@ dibosupl da gavout',
+	'form_auteur_confirmation' => 'Gwirekait ho postel',
+	'form_auteur_email_modifie' => 'Ho postel a zo bet kemmet.',
+	'form_auteur_envoi_mail_confirmation' => 'Ur postel a wiriekadur a zo paouez bezañ kaset da @email@.  Ret eo deoc’h mont da welet ar chomlec’h merket e-barzh al lizher-se evit gwiriekaat ho postel.',
+	'form_auteur_mail_confirmation' => 'Demat,
+
+Goulennet ho peus cheñch ho postel. 
+Evit gwiriekaat ho postel nevez, n’ho peus nemet kevreañ d’ar chomlec’h amañ dindan (e-giz-all e vo dianavezet ho koulenn) : 
+
+    @url@
+',
 	'form_deja_inscrit' => 'Enskrivet oc’h c’hoazh.',
 	'form_email_non_valide' => 'N’eo ket reizh ho postel.',
 	'form_forum_access_refuse' => 'N’oc’h ket aotreet da vont war al lec’hienn-mañ ken.',
 	'form_forum_bonjour' => 'Demat @nom@,',
+	'form_forum_confirmer_email' => 'Evit gwiriekaat ho postel, mont d’ar chomlec’h :
+@url_confirm@',
 	'form_forum_email_deja_enregistre' => 'Enrollet eo ar postel-se dija. Gallout a rit ober gant ho ker-tremen boas neuze.',
 	'form_forum_identifiant_mail' => 'Emañ ho kod moned nevez o paouez bezañ kaset deoc’h dre bostel.',
 	'form_forum_identifiants' => 'Titouroù hiniennel',
@@ -237,14 +265,14 @@ $GLOBALS[$GLOBALS['idx_lang']] = array(
 	'form_prop_confirmer_envoi' => 'Kadarnaat ar c’has',
 	'form_prop_description' => 'Deskrivadur/evezhiadenn',
 	'form_prop_enregistre' => 'Enrollet eo bet ho kinnig. Embannet e vo goude bezañ bet asantet gant tud e-karg eus al lec’hienn-mañ.',
-	'form_prop_envoyer' => 'Kas ur gemennadenn',
+	'form_prop_envoyer' => 'Kas ur gemenadenn',
 	'form_prop_indiquer_email' => 'Merkit ur postel reizh mar plij',
 	'form_prop_indiquer_nom_site' => 'Merkit anv al lec’hienn.',
 	'form_prop_indiquer_sujet' => 'Merkit ur sujed',
 	'form_prop_message_envoye' => 'Kaset eo bet ar gemennadenn',
 	'form_prop_non_enregistre' => 'N’eo ket bet enrollet ho kinnig',
 	'form_prop_sujet' => 'Sujed',
-	'form_prop_url_site' => 'Chomlec’h (URL) al lec’hienn', # MODIF
+	'form_prop_url_site' => 'Chomlec’h (URL) al lec’hienn',
 	'forum_non_inscrit' => 'N’oc’h ket enskrivet, pe direizh eo ar ger-tremen pe ar chomlec’h.',
 	'forum_par_auteur' => 'gant @auteur@',
 	'forum_titre_erreur' => 'Fazi...',
@@ -290,7 +318,8 @@ $GLOBALS[$GLOBALS['idx_lang']] = array(
 	'icone_supprimer_image' => 'Diverkañ ar skeudenn-mañ',
 	'icone_tous_articles' => 'Ho holl bennadoù',
 	'icone_tous_auteur' => 'An holl skridaozerien',
-	'icone_visiter_site' => 'Gweladenniñ', # MODIF
+	'icone_tous_visiteur' => 'An holl gweladerien',
+	'icone_visiter_site' => 'Gweladenniñ al lec’hienn foran',
 	'icone_voir_en_ligne' => 'Gwelet enlinenn',
 	'img_indisponible' => 'skeudenn dibosupl da gaout',
 	'impossible' => 'dibosupl',
@@ -315,12 +344,13 @@ $GLOBALS[$GLOBALS['idx_lang']] = array(
 	'info_auteurs_nombre' => 'skridaozer(ien) :',
 	'info_authentification_ftp' => 'Gwiriañ (dre FTP).',
 	'info_breves_2' => 'berrskridoù',
+	'info_breves_nb' => '@nb@ pennadoù-berr',
 	'info_connexion_refusee' => 'Kevreañ nac’het',
 	'info_contact_developpeur' => 'Kit e darempred gant un diorroer.',
 	'info_contenance' => 'El lec’hienn-mañ ez eus :',
-	'info_contribution' => 'kemennadenn er forom', # MODIF
+	'info_contribution' => 'kenaozadurioù',
 	'info_copyright' => 'Ur meziant dieub eo @spip@, dasparzhet @lien_gpl@.',
-	'info_copyright_doc' => 'Evit titouroù ouzhpenn, gwelet al lec’hienn <a href="@spipnet@">http://www.spip.net/fr</a>.', # MODIF
+	'info_copyright_doc' => 'Evit titouroù ouzhpenn, gwelet al lec’hienn <a href="@spipnet@">@spipnet_affiche@</a>.',
 	'info_copyright_gpl' => 'dindan aotre implijout GPL',
 	'info_cours_edition' => 'Ar pennadoù emaoc’h o skrivañ',
 	'info_creer_repertoire' => 'Krouit ur restr pe ur c’havlec’h anvet :',
@@ -331,6 +361,7 @@ $GLOBALS[$GLOBALS['idx_lang']] = array(
 	'info_description' => 'Deskrivadur :',
 	'info_description_2' => 'Deskrivadur :',
 	'info_dimension' => 'Ment :',
+	'info_documents_un' => '1 diell',
 	'info_ecire_message_prive' => 'Skrivañ ur gerig prevez;',
 	'info_email_invalide' => 'Postel direizh.',
 	'info_en_cours_validation' => 'Ar pennadoù emaoc’h o skrivañ',
@@ -369,12 +400,13 @@ $GLOBALS[$GLOBALS['idx_lang']] = array(
 	'info_mail_fournisseur' => 'hoc’hanv@herberc’hier.com',
 	'info_message_2' => 'KEMENNADENN',
 	'info_message_supprime' => 'KEMENNADENN BET DIVERKET',
+	'info_messages_nb' => '@nb@ kemennadennoù',
 	'info_mise_en_ligne' => 'Lakaet war ar rouedad d’an :',
 	'info_modification_parametres_securite' => 'kemm an arventennoù surentez',
 	'info_mois_courant' => 'E-kerzh ar miz :',
 	'info_mot_cle_ajoute' => 'Ar ger-stur-mañ zo bet ouzhpennet',
 	'info_multi_herit' => 'Yezh dre ziouer',
-	'info_multi_langues_soulignees' => 'Ar <u>yezhoù islinennet</u> zo bet troet holl destennoù an etrefas enne. Ma tibabit ar yezhoù-se e vo troet o-unan ul lodenn vat eus elfennoù al lec’hienn (deiziadoù, furmskridoù, hag all). Evit ar yezhoù n’int ket islinennet e vo an elfennoù-se e yezh pennañ al lec’hienn.', # MODIF
+	'info_multi_langues_soulignees' => 'Ar <u>yezhoù islinennet</u> zo bet troet holl destennoù an etrefas enne. Ma tibabit ar yezhoù-se e vo troet ul lodenn vat eus elfennoù al lec’hienn (deiziadoù, furmskridoù, hag all) en un doare otomatek. Evit ar yezhoù n’int ket islinennet e vo an elfennoù-se e yezh pennañ al lec’hienn.',
 	'info_multilinguisme' => 'Liesyezhegezh',
 	'info_nom_non_utilisateurs_connectes' => 'N’emañ ket hoc’h  anv war roll an implijerien kevreet.',
 	'info_nom_utilisateurs_connectes' => 'Gwelet e vez hoc’h anv war roll an implijerien kevreet.',
@@ -427,14 +459,15 @@ $GLOBALS[$GLOBALS['idx_lang']] = array(
 	'info_vignette_personnalisee' => 'skeudennig personelaet',
 	'info_visite' => 'gweladenn :',
 	'info_vos_rendez_vous' => 'Hoc’h emgavioù da zont',
-	'infos_vos_pense_bete' => 'Ho notennigoù-eñvor', # MODIF
+	'infos_vos_pense_bete' => 'Ho notennigoù-eñvor',
 
 	// L
+	'label_ajout_id_rapide' => 'Ouzhpennet buan',
 	'lien_afficher_icones_seuls' => 'Diskouez ar skeudennigoù hepken',
 	'lien_afficher_texte_icones' => 'Diskouez ar skeudennigoù hag an destenn',
 	'lien_afficher_texte_seul' => 'Diskouez an destenn hepken',
 	'lien_liberer' => 'dieubiñ',
-	'lien_liberer_tous' => 'dieubiñ ar pennadoù-mañ', # MODIF
+	'lien_liberer_tous' => 'Dinaskañ an holl',
 	'lien_nouvea_pense_bete' => 'NOTENNIG-EÑVOR NEVEZ',
 	'lien_nouveau_message' => 'KEMENNADENN NEVEZ',
 	'lien_nouvelle_annonce' => 'KEMENN NEVEZ',
@@ -459,7 +492,7 @@ $GLOBALS[$GLOBALS['idx_lang']] = array(
 	'login_espace_prive' => 'lodenn brevez',
 	'login_identifiant_inconnu' => 'N’eo ket anavezet ar c’hoad anaout « @login@ ».',
 	'login_login' => 'Kod kevreañ :',
-	'login_login2' => 'Kod kevreañ (kod anaout evit kevreañ ouzh al lec’hienn) :', # MODIF
+	'login_login2' => 'Login pe postel :',
 	'login_login_pass_incorrect' => '(direizh eo ar c’hod kevreañ pe ar ger-tremen)',
 	'login_motpasseoublie' => 'ankouaet ho ker-tremen ganeoc’h ?',
 	'login_non_securise' => 'Diwallit, n’eo ket suraet ar furmskrid-mañ.
@@ -474,7 +507,7 @@ $GLOBALS[$GLOBALS['idx_lang']] = array(
 	'login_retour_public' => 'Distreiñ d’al lodenn foran',
 	'login_retour_site' => 'Distreiñ d’al lodenn foran',
 	'login_retoursitepublic' => 'distreiñ d’al lodenn foran',
-	'login_sans_cookiie' => 'Kevreañ hep toupinoù',
+	'login_securise' => 'Login diogelet',
 	'login_sinscrire' => 'en em enskrivañ',
 	'login_test_navigateur' => 'taol-arnod merdeer/adkevreañ',
 	'login_verifiez_navigateur' => '(Gwiriit memes tra n’eo ket bet memoret ho ker-tremen gant ar merdeer...)',
@@ -532,6 +565,7 @@ kevreañ en-dro ouzh al lec’hienn.
 	'pass_nouveau_pass' => 'Ger-tremen nevez',
 	'pass_ok' => 'MAT EO',
 	'pass_oubli_mot' => 'Ankouaet ar ger-tremen',
+	'pass_procedure_changer' => 'Evit kemmañ ho ker-tremen, ez eo ret deomp gwiriekaat piv oc’h. Evit en ober diskouezit deomp ar postel liammet gant ho kont.', # MODIF
 	'pass_quitter_fenetre' => 'Kuitaat ar prenestr-mañ',
 	'pass_rappel_login' => 'Dalc’hit soñj : « @login@ » eo ho anv-tremen (login).',
 	'pass_recevoir_mail' => 'Ur postel a vo kaset deoc’h, ennañ an titouroù ret da c’hallout tizhout al lec’hienn en-dro.',
@@ -604,7 +638,7 @@ Aliet oc’h da chom hep kemmañ tra ebet e-keit ha n’oc’h ket boas ouzh SPI
 	'titre_statistiques' => 'Stadegoù al lec’hienn', # Stadegoù, termen skoueriekaet gant TermBret evit Statistiques.
 	'titre_titre_document' => 'Titl an teul :',
 	'todo' => 'da zont',
-	'trad_reference' => '(pennad orin)', # MODIF
+	'trad_reference' => '(Pennad diazez evit an troidigezhioù)',
 
 	// Z
 	'zbug_balise_b_aval' => ' : balizenn B en ardraoñ',
