@@ -3,7 +3,9 @@
 // extrait automatiquement de http://trad.spip.net/tradlang_module/spip?lang_cible=en
 // ** ne pas modifier le fichier **
 
-if (!defined('_ECRIRE_INC_VERSION')) return;
+if (!defined('_ECRIRE_INC_VERSION')) {
+	return;
+}
 
 $GLOBALS[$GLOBALS['idx_lang']] = array(
 
@@ -534,7 +536,7 @@ the site "@nom_site_spip@" (@adresse_login@):',
 	'login_retour_public' => 'Back to the public site',
 	'login_retour_site' => 'Back to the public site',
 	'login_retoursitepublic' => 'back to the public site',
-	'login_sans_cookiie' => 'Identification without cookie',
+	'login_sans_cookie' => 'Identification without cookie',
 	'login_securise' => 'Secure login',
 	'login_sinscrire' => 'register',
 	'login_test_navigateur' => 'testing browser/reconnection',
