@@ -3,7 +3,9 @@
 // extrait automatiquement de http://trad.spip.net/tradlang_module/spip?lang_cible=he
 // ** ne pas modifier le fichier **
 
-if (!defined('_ECRIRE_INC_VERSION')) return;
+if (!defined('_ECRIRE_INC_VERSION')) {
+	return;
+}
 
 $GLOBALS[$GLOBALS['idx_lang']] = array(
 
@@ -481,7 +483,6 @@ $GLOBALS[$GLOBALS['idx_lang']] = array(
 	'login_retour_public' => 'חזור לאתר הציבורי',
 	'login_retour_site' => 'חזור לאתר הציבורי',
 	'login_retoursitepublic' => 'חזור לאתר הציבורי',
-	'login_sans_cookiie' => 'חיובר ללא עוגיה',
 	'login_sinscrire' => 'הרשמה',
 	'login_test_navigateur' => 'מבחן הדפדפן /חיבור מחדש',
 	'login_verifiez_navigateur' => '(בכל זאת נא לבדוק שהדפדפן שלך לא זכר את הסיסמה...)',
