@@ -3,7 +3,9 @@
 // extrait automatiquement de http://trad.spip.net/tradlang_module/spip?lang_cible=it
 // ** ne pas modifier le fichier **
 
-if (!defined('_ECRIRE_INC_VERSION')) return;
+if (!defined('_ECRIRE_INC_VERSION')) {
+	return;
+}
 
 $GLOBALS[$GLOBALS['idx_lang']] = array(
 
@@ -31,6 +33,7 @@ $GLOBALS[$GLOBALS['idx_lang']] = array(
 	'annuler' => 'Annulla',
 	'antispam_champ_vide' => 'Si prega di lasciare vuoto questo campo:',
 	'articles_recents' => 'Articoli più recenti',
+	'avis_1_erreur_saisie' => 'C’è un errore nell’input, verificare le informazioni.', # MODIF
 	'avis_archive_incorrect' => 'il file archivio non è un file SPIP',
 	'avis_archive_invalide' => 'il file archivio non è valido',
 	'avis_attention' => 'ATTENZIONE!',
@@ -43,6 +46,7 @@ $GLOBALS[$GLOBALS['idx_lang']] = array(
 	'avis_erreur_mysql' => 'Errore SQL ',
 	'avis_erreur_sauvegarde' => 'Errore nel salvataggio (@type@ @id_objet@)! ',
 	'avis_erreur_visiteur' => 'Problema di accesso all’area riservata',
+	'avis_nb_erreurs_saisie' => 'Ci sono @nb@ errori nell’input, verificare le informazioni.',
 
 	// B
 	'barre_a_accent_grave' => 'Inserire una A maiscola con accento grave',
@@ -111,7 +115,7 @@ $GLOBALS[$GLOBALS['idx_lang']] = array(
 	'date_fmt_jour' => '@nomjour@ @jour@',
 	'date_fmt_jour_heure' => '@jour@ ore @heure@',
 	'date_fmt_jour_heure_debut_fin' => 'Il @jour@ dalle @heure_debut@ alle @heure_fin@',
-	'date_fmt_jour_heure_debut_fin_abbr' => 'Il @dtstart@@jour@ dalle @heure_debut@@dtabbr@ al @dtstart@@heure_fin@@dtend@',
+	'date_fmt_jour_heure_debut_fin_abbr' => 'Il @dtstart@@jour@ dalle @heure_debut@@dtabbr@ alle @dtstart@@heure_fin@@dtend@',
 	'date_fmt_jour_mois' => '@jourmois@',
 	'date_fmt_jour_mois_annee' => '@jourmois@ @annee@',
 	'date_fmt_mois_annee' => '@nommois@ @annee@',
@@ -121,6 +125,7 @@ $GLOBALS[$GLOBALS['idx_lang']] = array(
 	'date_fmt_periode_abbr' => 'Dal @dtart@@date_debut@@dtabbr@ al @dtend@@date_fin@@dtabbr@',
 	'date_fmt_periode_from' => 'Dal',
 	'date_fmt_periode_to' => 'a',
+	'date_fmt_saison_annee' => '@saison@ @annee@',
 	'date_heures' => 'ore',
 	'date_hier' => 'ieri',
 	'date_il_y_a' => '@delai@ fa',
@@ -532,7 +537,6 @@ devi attivare Javascript nel tuo browser e',
 	'login_retour_public' => 'Ritorna al sito pubblico',
 	'login_retour_site' => 'Ritorna al sito pubblico',
 	'login_retoursitepublic' => 'ritorna al sito pubblico',
-	'login_sans_cookiie' => 'Identificazione senza cookie',
 	'login_securise' => 'Accesso protetto',
 	'login_sinscrire' => 'registrati',
 	'login_test_navigateur' => 'test browser/riconnessione',
@@ -593,7 +597,7 @@ e riconnetterti all’area riservata.
 	'pass_nouveau_pass' => 'Nuova password',
 	'pass_ok' => 'OK',
 	'pass_oubli_mot' => 'Password dimenticata',
-	'pass_procedure_changer' => 'Per modificare la tua password, dobbiamo prima verificare la tua identità. Inserisci l’indirizzo email associato al tuo account.',
+	'pass_procedure_changer' => 'Per modificare la tua password, dobbiamo prima verificare la tua identità. Inserisci l’indirizzo email associato al tuo account.', # MODIF
 	'pass_quitter_fenetre' => 'Chiudi la finestra',
 	'pass_rappel_login' => 'Ricorda: il tuo ID (login) è « @login@ ».',
 	'pass_recevoir_mail' => 'Riceverai un email contenente le istruzioni per recuperare i dati di accesso al sito.',
@@ -670,6 +674,7 @@ funzionamento del sito. Non intervenire finché non conosci bene i meccanismi de
 	'titre_statistiques' => 'Statistiche del sito',
 	'titre_titre_document' => 'Titolo del documento:',
 	'todo' => 'prossimo',
+	'trad_definir_reference' => 'Scegliere "@titre@" come riferimento per le traduzioni',
 	'trad_reference' => '(articolo di riferimento)',
 
 	// Z
@@ -683,6 +688,7 @@ funzionamento del sito. Non intervenire finché non conosci bene i meccanismi de
 	'zbug_champ_hors_motif' => 'Campo @champ@ fuori da un contesto @motif@',
 	'zbug_code' => 'codice',
 	'zbug_critere_inconnu' => 'criterio sconosciuto @critere@',
+	'zbug_critere_sur_table_sans_cle_primaire' => '{@critere@} su una tabella senza una chiave primaria atomica',
 	'zbug_distant_interdit' => 'esterno non accessibile',
 	'zbug_doublon_table_sans_cle_primaire' => 'doppioni su una tabella senza chiave primaria atomica',
 	'zbug_doublon_table_sans_index' => 'doppioni su una tabella senza indice',
