@@ -3,7 +3,9 @@
 // extrait automatiquement de http://trad.spip.net/tradlang_module/spip?lang_cible=lb
 // ** ne pas modifier le fichier **
 
-if (!defined('_ECRIRE_INC_VERSION')) return;
+if (!defined('_ECRIRE_INC_VERSION')) {
+	return;
+}
 
 $GLOBALS[$GLOBALS['idx_lang']] = array(
 
@@ -529,7 +531,6 @@ Wann dir net wëllt dat äert Passwuert ka um Internet ofgefaange ginn, aktivéi
 	'login_retour_public' => 'Zeréck op den ëffentleche Site',
 	'login_retour_site' => 'Zeréck op de Site',
 	'login_retoursitepublic' => 'zeréck op den ëffentleche Site',
-	'login_sans_cookiie' => 'Umeldung ouni Cookie',
 	'login_securise' => 'Séchere Login',
 	'login_sinscrire' => 'sech aschreiwen',
 	'login_test_navigateur' => 'Browser/Login-Test',
@@ -584,7 +585,7 @@ Dir kënnt do e neit Passwuert aginn an Iech um Site umellen.
 	'pass_nouveau_pass' => 'Neit Passwuert',
 	'pass_ok' => 'OK',
 	'pass_oubli_mot' => 'Vergiessen vum Passwuert',
-	'pass_procedure_changer' => 'Mir mussen är Identitéit kontrolléieren fir äert Passwuert ze änneren. Dofir gitt ons d’Email-Adress un déi zu ärem Login gehéiert.',
+	'pass_procedure_changer' => 'Mir mussen är Identitéit kontrolléieren fir äert Passwuert ze änneren. Dofir gitt ons d’Email-Adress un déi zu ärem Login gehéiert.', # MODIF
 	'pass_quitter_fenetre' => 'Dës Fënster zoumaachen',
 	'pass_rappel_login' => 'Rappel: äre Login ass "@login@".',
 	'pass_recevoir_mail' => 'Dir kritt e Message mat Instruktiounen fir den Zougang zum Site erëm ze kréien.',
