@@ -3,7 +3,9 @@
 // extrait automatiquement de http://trad.spip.net/tradlang_module/spip?lang_cible=my
 // ** ne pas modifier le fichier **
 
-if (!defined('_ECRIRE_INC_VERSION')) return;
+if (!defined('_ECRIRE_INC_VERSION')) {
+	return;
+}
 
 $GLOBALS[$GLOBALS['idx_lang']] = array(
 
@@ -60,7 +62,6 @@ $GLOBALS[$GLOBALS['idx_lang']] = array(
 	'bouton_changer' => 'ပြုပြင်ရန်',
 	'bouton_chercher' => 'ရှာဖွေရန်',
 	'bouton_choisir' => 'ရွေးချယ်ရန်',
-	'bouton_download' => 'Télécharger', # MODIF
 	'bouton_enregistrer' => 'သိမ်းဆည်းရန်',
 	'bouton_radio_desactiver_messagerie_interne' => 'အတွင်းသတင်းစကား ပေးပို့ခြင်းတားမြစ်ရန်',
 	'bouton_radio_envoi_annonces' => 'အယ်ဒီတာ့ ပြန်ကြားချက်များ ပေးပို့ရန်',
@@ -88,18 +89,18 @@ $GLOBALS[$GLOBALS['idx_lang']] = array(
 	'date_aujourdhui' => 'ဒီနေ့',
 	'date_avant_jc' => 'B.C.',
 	'date_dans' => '@delai@ထဲမှာ',
-	'date_de_mois_1' => '@nommois@ @j@',
-	'date_de_mois_10' => '@nommois@ @j@',
-	'date_de_mois_11' => '@nommois@ @j@',
-	'date_de_mois_12' => '@nommois@ @j@',
-	'date_de_mois_2' => '@nommois@ @j@',
-	'date_de_mois_3' => '@nommois@ @j@',
-	'date_de_mois_4' => '@nommois@ @j@',
-	'date_de_mois_5' => '@nommois@ @j@',
-	'date_de_mois_6' => '@nommois@ @j@',
-	'date_de_mois_7' => '@nommois@ @j@',
-	'date_de_mois_8' => '@nommois@ @j@',
-	'date_de_mois_9' => '@nommois@ @j@',
+	'date_de_mois_1' => '@j@ @nommois@',
+	'date_de_mois_10' => '@j@ @nommois@',
+	'date_de_mois_11' => '@j@ @nommois@',
+	'date_de_mois_12' => '@j@ @nommois@',
+	'date_de_mois_2' => '@j@ @nommois@',
+	'date_de_mois_3' => '@j@ @nommois@',
+	'date_de_mois_4' => '@j@ @nommois@',
+	'date_de_mois_5' => '@j@ @nommois@',
+	'date_de_mois_6' => '@j@ @nommois@',
+	'date_de_mois_7' => '@j@ @nommois@',
+	'date_de_mois_8' => '@j@ @nommois@',
+	'date_de_mois_9' => '@j@ @nommois@',
 	'date_demain' => 'မနက်ဖြန်',
 	'date_fmt_heures_minutes' => '@h@:@m@',
 	'date_fmt_jour_heure' => '@jour@ မှ @heure@',
@@ -141,54 +142,41 @@ $GLOBALS[$GLOBALS['idx_lang']] = array(
 	'date_jnum7' => '၇',
 	'date_jnum8' => '၈',
 	'date_jnum9' => '၉',
-	'date_jour_1' => 'တနဂၤေႏြွေ',
-	'date_jour_1_abbr' => 'ေႏြေ',
+	'date_jour_1' => 'တနင်္ဂနွေ',
+	'date_jour_1_abbr' => 'နွေ',
 	'date_jour_1_initiale' => 'န',
-	'date_jour_2' => 'တနလၤာ',
+	'date_jour_2' => '​တနင်္လာ',
 	'date_jour_2_abbr' => 'လာ',
 	'date_jour_2_initiale' => 'လ',
-	'date_jour_3' => 'အဂၤါ',
+	'date_jour_3' => 'အင်္ဂါ',
 	'date_jour_3_abbr' => 'ဂါ',
 	'date_jour_3_initiale' => 'ဂ',
-	'date_jour_4' => 'ဗုဒၶဟူး',
+	'date_jour_4' => '​ဗုဒ္ဓဟူး',
 	'date_jour_4_abbr' => 'ဟူး',
 	'date_jour_4_initiale' => 'ဟ',
-	'date_jour_5' => 'ကၾကာသပေတး',
-	'date_jour_5_abbr' => 'ၾကာ',
+	'date_jour_5' => 'ကြာတပတေး',
+	'date_jour_5_abbr' => 'ကြာ',
 	'date_jour_5_initiale' => 'က',
-	'date_jour_6' => 'ေသာၾကာ',
-	'date_jour_6_abbr' => 'ေသာ',
+	'date_jour_6' => 'သောကြာ',
+	'date_jour_6_abbr' => 'သော',
 	'date_jour_6_initiale' => 'သ',
-	'date_jour_7' => 'စေန',
-	'date_jour_7_abbr' => 'ေန',
+	'date_jour_7' => 'စနေ',
+	'date_jour_7_abbr' => 'နေ',
 	'date_jour_7_initiale' => 'စ',
 	'date_jours' => 'ရက်များ',
 	'date_minutes' => 'မိနစ်များ',
 	'date_mois' => 'လများ',
-	'date_mois_1' => 'ျပာသုိ',
-	'date_mois_10' => 'သီတင္းကြ်တ္',
-	'date_mois_10_abbr' => 'ကြ်တ္', 
+	'date_mois_1' => '	ျပာသုိ',
+	'date_mois_10' => ' ျပာသုိ',
 	'date_mois_11' => 'တန္ေဆာင္မုန္း',
-	'date_mois_11_abbr' => 'မုန္း', 
-	'date_mois_12' => 'နတ္ေတာ္',
-	'date_mois_12_abbr' => 'နတ္',
-	'date_mois_1_abbr' => 'ျပာ',
-	'date_mois_2' => 'တပုိ႔တြဲ',
-	'date_mois_2_abbr' => 'တြဲ',
-	'date_mois_3' => 'တန္ေပါင္း',
-	'date_mois_3_abbr' => 'ေပါင္း',
-	'date_mois_4' => 'တန္ခူး',
-	'date_mois_4_abbr' => 'ခူး',
-	'date_mois_5' => 'ကဆုန္',
-	'date_mois_5_abbr' => 'ဆုန္',
-	'date_mois_6' => 'နယုန္',
-	'date_mois_6_abbr' => 'ယုန္',
-	'date_mois_7' => 'ဝါဆုိ',
-	'date_mois_7_abbr' => 'ဝါဆုိ',
-	'date_mois_8' => 'ဝါေခါင္',
-	'date_mois_8_abbr' => 'ဝါေခါင္',
-	'date_mois_9' => 'ေတာ္သလင္း',
-	'date_mois_9_abbr' => 'ေတာ္',
+	'date_mois_12' => 'တန္ေပါင္း',
+	'date_mois_2' => 'တပုိတ႔ ဲြ',
+	'date_mois_3' => 'နယုန္',
+	'date_mois_4' => 'ဝါဆုိ',
+	'date_mois_6' => ' ေတာ္သလင္း',
+	'date_mois_7' => 'သီတင္းကြ်တ္',
+	'date_mois_8' => 'တန္ေဆာင္မုန္း',
+	'date_mois_9' => 'နတ္ေတာ္',
 	'date_saison_1' => 'ဆောင်းရာသီ',
 	'date_saison_2' => 'နွေဦးရာသီ',
 	'date_saison_3' => 'နွေရာသီ',
@@ -464,7 +452,6 @@ $GLOBALS[$GLOBALS['idx_lang']] = array(
 	'login_retour_public' => 'အများဆိုင် စာမျက်နှာသို့ ပြန်သွားရန်',
 	'login_retour_site' => 'အများဆိုင် စာမျက်နှာသို့ ပြန်သွားရန်',
 	'login_retoursitepublic' => 'အများဆိုင် စာမျက်နှာသို့ ပြန်သွားရန်',
-	'login_sans_cookiie' => 'cookie မပါအမှတ်အသား',
 	'login_sinscrire' => 'မှတ်ပုံတင်ရန်',
 	'login_test_navigateur' => 'စမ်းသပ်ရန်',
 	'login_verifiez_navigateur' => '(သင့် browser မှ သင့်စကားဝှက်ကို မမှတ်မိပါ)',
@@ -570,24 +557,19 @@ $GLOBALS[$GLOBALS['idx_lang']] = array(
 	// Z
 	'zbug_balise_b_aval' => ': B tag too late in loop',
 	'zbug_boucle' => 'loop',
-	'zbug_boucle_recursive_undef' => 'undefined recursive loop', # MODIF
 	'zbug_champ_hors_boucle' => 'Field @champ@ outside loop',
-	'zbug_champ_hors_motif' => 'Field @champ@ outside loop tagged @motif@', # MODIF
 	'zbug_code' => 'ကုဒ်',
 	'zbug_critere_inconnu' => 'အမည်မသိ စံညွှန်း @critere@', # MODIF
 	'zbug_distant_interdit' => 'ပြင်ပ ​အချက်အလက် တားမြစ်ထားသည်', # MODIF
 	'zbug_doublon_table_sans_index' => 'စာညွှန်းတွင်မပါဘဲနှင့် ဇယားတွင် နှစ်ခါပါဝင်သည်', # MODIF
 	'zbug_erreur_boucle_double' => 'BOUCLE@id@ နှစ်ခါထပ်နေသော အဓိပ္ပါယ်ဖွင့်ဆိုချက်', # MODIF
 	'zbug_erreur_boucle_fermant' => 'BOUCLE@id@: အပိတ်တေးမှတ်ချက် မရှိဖြစ်ခြင်း', # MODIF
-	'zbug_erreur_boucle_syntaxe' => 'Incorrect loop (BOUCLE) syntax ', # MODIF
 	'zbug_erreur_compilation' => 'စုဆောင်းမှု အမှားအယွင်း',
 	'zbug_erreur_execution_page' => 'စာမျက်နှာတွက်ချက်မှု အမှားအယွင်း', # MODIF
-	'zbug_erreur_filtre' => 'အမှားအယွင်း၊ ဖော်ပြမထားသော စမ်းစစ်ချက် <b>\\"@filtre@\\"</b>', # MODIF
-	'zbug_erreur_meme_parent' => '{meme_parent} only applies to loops (FORUMS) and (RUBRIQUES)', # MODIF
+	'zbug_erreur_filtre' => 'အမှားအယွင်း၊ ဖော်ပြမထားသော စမ်းစစ်ချက် @filtre@', # MODIF
 	'zbug_erreur_squelette' => 'စာမျက်နှာ ပုံစံခွက်ထဲမှ အမှားအယွင်းများ',
 	'zbug_info_erreur_squelette' => 'ُဆိုက်ထဲအမှားအယွင်း',
 	'zbug_inversion_ordre_inexistant' => 'မရှိဘူး​​​သော စာစဉ်မှု', # MODIF
-	'zbug_pagination_sans_critere' => '#PAGINATION tag without {pagination} criterion, or used in a recursive loop', # MODIF
 	'zbug_parametres_inclus_incorrects' => 'ထပ်မံဖြည့်စွပ်ချက် အမှား', # MODIF
 	'zbug_resultat' => 'ရှာဖွေမှု ရလဒ်',
 	'zbug_serveur_indefini' => 'ဖော်ပြခြင်းမရှိသော SQL ဆာဗာ', # MODIF
