@@ -3,7 +3,9 @@
 // extrait automatiquement de http://trad.spip.net/tradlang_module/spip?lang_cible=nl
 // ** ne pas modifier le fichier **
 
-if (!defined('_ECRIRE_INC_VERSION')) return;
+if (!defined('_ECRIRE_INC_VERSION')) {
+	return;
+}
 
 $GLOBALS[$GLOBALS['idx_lang']] = array(
 
@@ -538,7 +540,7 @@ de website "@nom_site_spip@" (@adresse_login@) :',
 	'login_retour_public' => 'Terug naar de publieke site',
 	'login_retour_site' => 'Terug naar de publieke site',
 	'login_retoursitepublic' => 'terug naar de publieke site',
-	'login_sans_cookiie' => 'Aanmelden zonder koekie',
+	'login_sans_cookie' => 'Aanmelden zonder koekie',
 	'login_securise' => 'Secure Login',
 	'login_sinscrire' => 'Registreren',
 	'login_test_navigateur' => 'Testen van browser/opnieuw verbinden',
@@ -600,7 +602,7 @@ opnieuw verbinding maken met de site
 	'pass_nouveau_pass' => 'Nieuw paswoord',
 	'pass_ok' => 'OK',
 	'pass_oubli_mot' => 'Paswoord vergeten',
-	'pass_procedure_changer' => 'Om je wachtwoord te wijzigen, moeten we eerst uw identiteit controleren. Geef hiervoor het e-mailadres gekoppeld aan je account.',
+	'pass_procedure_changer' => 'Om je wachtwoord te wijzigen, moeten we eerst je identiteit controleren. Geef hiervoor het e-mailadres dat is gekoppeld aan je account.',
 	'pass_quitter_fenetre' => 'Venster sluiten',
 	'pass_rappel_login' => 'Herinnering : je aanmeldingsnaam (login) is "@login@".',
 	'pass_recevoir_mail' => 'Je zal een e-mail ontvangen waarin uitgelegd staat hoe je opnieuw toegang krijgt tot de site.',
