@@ -3,7 +3,9 @@
 // extrait automatiquement de http://trad.spip.net/tradlang_module/spip?lang_cible=pt
 // ** ne pas modifier le fichier **
 
-if (!defined('_ECRIRE_INC_VERSION')) return;
+if (!defined('_ECRIRE_INC_VERSION')) {
+	return;
+}
 
 $GLOBALS[$GLOBALS['idx_lang']] = array(
 
@@ -529,7 +531,6 @@ Pediu para alterar o seu endereço e-mail. Para confirmar o seu novo endereço,
 	'login_retour_public' => 'Regresso ao sítio público',
 	'login_retour_site' => 'Regresso ao sítio público',
 	'login_retoursitepublic' => 'Regresso ao sítio público',
-	'login_sans_cookiie' => 'identificação sem cookie',
 	'login_securise' => 'Login seguro',
 	'login_sinscrire' => 'inscrever-se',
 	'login_test_navigateur' => 'teste navegação/nova ligação',
@@ -589,7 +590,7 @@ Poderá então introduzir uma nova palavra-passe e reconectar-se ao sítio.
 	'pass_nouveau_pass' => 'Nova palavra-passe',
 	'pass_ok' => 'OK',
 	'pass_oubli_mot' => 'Palavra-passe esquecida',
-	'pass_procedure_changer' => 'Para alterar a sua palavra-passe, temos primeiro de verificar a sua identidade. Por favor escreva o endereço e-mail associado a esta conta.',
+	'pass_procedure_changer' => 'Para alterar a sua palavra-passe, temos primeiro de verificar a sua identidade. Por favor escreva o endereço e-mail associado a esta conta.', # MODIF
 	'pass_quitter_fenetre' => 'Fechar esta janela',
 	'pass_rappel_login' => 'Recorde : o seu identificador (login) é « @login@ ».',
 	'pass_recevoir_mail' => 'Vai receber um email que indica como recuperar o seu acesso ao sítio.',
