@@ -3,7 +3,9 @@
 // extrait automatiquement de http://trad.spip.net/tradlang_module/spip?lang_cible=pt_br
 // ** ne pas modifier le fichier **
 
-if (!defined('_ECRIRE_INC_VERSION')) return;
+if (!defined('_ECRIRE_INC_VERSION')) {
+	return;
+}
 
 $GLOBALS[$GLOBALS['idx_lang']] = array(
 
@@ -25,16 +27,17 @@ $GLOBALS[$GLOBALS['idx_lang']] = array(
 	'admin_recalculer' => 'Atualizar esta página',
 	'afficher_calendrier' => 'Exibir o calendário',
 	'afficher_trad' => 'exibir as traduções',
-	'alerte_maj_impossible' => 'Atenção! A atualização da base de dados SQL para a versão @version@ não é possível, provavelmente por problema de direitos de edição na base de dados. Por favor, contate o seu provedor de hospedagem.',
+	'alerte_maj_impossible' => '<b>Atenção!</b> A atualização da base de dados SQL para a versão @version@ não é possível, provavelmente por problema de direitos de edição na base de dados. Por favor, contate o seu provedor de hospedagem.',
 	'alerte_modif_info_concourante' => 'ATENÇÃO: Esta informação foi alterada por outra pessoa. O valor atual é:',
 	'analyse_xml' => 'Analisar XML',
 	'annuler' => 'Cancelar',
-	'antispam_champ_vide' => 'Deixe, por favor, este campo vazio:',
+	'antispam_champ_vide' => 'Por favor, deixe este campo vazio:',
 	'articles_recents' => 'Matérias mais recentes',
+	'avis_1_erreur_saisie' => 'Há um erro nos dados informados. Por favor, verifique.', # MODIF
 	'avis_archive_incorrect' => 'a cópia de segurança não é um arquivo do SPIP',
 	'avis_archive_invalide' => 'a cópia de segurança não é válida',
 	'avis_attention' => 'ATENÇÃO!',
-	'avis_champ_incorrect_type_objet' => 'Nome de campo incorreto @name@ para objeto do tipo @type@',
+	'avis_champ_incorrect_type_objet' => 'Nome de campo @name@ incorreto para objeto do tipo @type@',
 	'avis_colonne_inexistante' => 'A coluna @col@ não existe',
 	'avis_erreur' => 'Erro: ver abaixo',
 	'avis_erreur_connexion' => 'Erro de conexão',
@@ -43,6 +46,7 @@ $GLOBALS[$GLOBALS['idx_lang']] = array(
 	'avis_erreur_mysql' => 'Erro SQL',
 	'avis_erreur_sauvegarde' => 'Erro na cópia de segurança (@type@ @id_objet@) !',
 	'avis_erreur_visiteur' => 'Problema de acesso ao espaço privado',
+	'avis_nb_erreurs_saisie' => 'Há @nb@ erros nos dados informados. Por favor, verifique.',
 
 	// B
 	'barre_a_accent_grave' => 'Inserir um A maiúsculo com acento grave',
@@ -65,7 +69,7 @@ $GLOBALS[$GLOBALS['idx_lang']] = array(
 	'bouton_chercher' => 'Procurar',
 	'bouton_choisir' => 'Escolher',
 	'bouton_deplacer' => 'Deslocar',
-	'bouton_download' => 'Download',
+	'bouton_download' => 'Baixar',
 	'bouton_enregistrer' => 'Gravar',
 	'bouton_radio_desactiver_messagerie_interne' => 'Desativar o sistema interno de mensagens',
 	'bouton_radio_envoi_annonces' => 'Enviar os avisos editoriais',
@@ -121,6 +125,7 @@ $GLOBALS[$GLOBALS['idx_lang']] = array(
 	'date_fmt_periode_abbr' => 'De @dtart@@date_debut@@dtabbr@ a @dtend@@date_fin@@dtabbr@',
 	'date_fmt_periode_from' => 'De',
 	'date_fmt_periode_to' => 'para',
+	'date_fmt_saison_annee' => '@saison@ @annee@',
 	'date_heures' => 'horas',
 	'date_hier' => 'ontem',
 	'date_il_y_a' => 'à @delai@',
@@ -231,6 +236,7 @@ Verifique se as maiúsculas e minúsuculas destes diretórios coincidem exatamen
 	'envoi_via_le_site' => 'Envio pelo site',
 	'erreur' => 'Erro',
 	'erreur_balise_non_fermee' => 'Última tag em aberto:',
+	'erreur_technique_ajaxform' => 'Ooops. Um erro inesperado impediu o envio do formulário. Você pode tentar novamente.',
 	'erreur_technique_enregistrement_champs' => 'Um erro técnico impediu a gravação correta do campo @champs@.',
 	'erreur_technique_enregistrement_impossible' => 'Um erro técnico impediu a gravação.',
 	'erreur_texte' => 'erro(s)',
@@ -507,7 +513,7 @@ Para confirmar o seu novo endereço, basta acessar o endereço abaixo (cas contr
 	'login_deconnexion_ok' => 'Desconexão efetuada.',
 	'login_erreur_pass' => 'Erro de senha.',
 	'login_espace_prive' => 'espaço privado',
-	'login_identifiant_inconnu' => 'O identificador « @login@ » não está cadastrado.',
+	'login_identifiant_inconnu' => 'O identificador «@login@» não está cadastrado.',
 	'login_login' => 'Login:',
 	'login_login2' => 'Login',
 	'login_login_pass_incorrect' => '(Login ou senha incorreta.)',
@@ -523,7 +529,6 @@ Se você não quiser que a sua senha possa ser interceptada na rede, por favor a
 	'login_retour_public' => 'Voltar ao site público',
 	'login_retour_site' => 'Voltar ao site público',
 	'login_retoursitepublic' => 'voltar ao site público',
-	'login_sans_cookiie' => 'Identificação sem cookie',
 	'login_securise' => 'Login seguro',
 	'login_sinscrire' => 'cadastrar-se',
 	'login_test_navigateur' => 'testar navegador/reconexão',
@@ -580,7 +585,7 @@ e reconectar-se com o site.
 	'pass_nouveau_pass' => 'Nova senha',
 	'pass_ok' => 'OK',
 	'pass_oubli_mot' => 'Esquecimento de senha',
-	'pass_procedure_changer' => 'Para alterar a sua senha, é necessário verificar a sua identidade. Para isso, informe o endereço de e-mail associado a esta sua conta.',
+	'pass_procedure_changer' => 'Para alterar a sua senha, é necessário verificar a sua identidade. Para isso, informe o endereço de e-mail associado a esta sua conta.', # MODIF
 	'pass_quitter_fenetre' => 'Fechar esta janela',
 	'pass_rappel_login' => 'Lembrete: seu login é «@login@».',
 	'pass_recevoir_mail' => 'Você receberá um e-mail explicando como você pode recuperar o acesso ao site.',
@@ -639,16 +644,18 @@ Tente se',
 	'titre_image_auteur_supprime' => 'Autor excluído',
 	'titre_image_redacteur' => 'Redator sem acesso',
 	'titre_image_redacteur_02' => 'Redator',
+	'titre_image_selecteur' => 'Ver a lista',
 	'titre_image_visiteur' => 'Visitante',
 	'titre_joindre_document' => 'INCLUIR UM DOCUMENTO',
 	'titre_mots_cles' => 'PALAVRAS-CHAVE',
-	'titre_probleme_technique' => 'Atenção: um problema técnico (servidor SQL) impede o acesso a esta parte do site. Obrigado por sua compreenção.',
+	'titre_probleme_technique' => 'Atenção: um problema técnico (servidor SQL) impede o acesso a esta parte do site. Agradecemos sua compreensão.',
 	'titre_publier_document' => 'PUBLICAR UM DOCUMENTO NESTA SEÇÃO',
 	'titre_signatures_attente' => 'Assinaturas aguardando validação',
 	'titre_signatures_confirmees' => 'Assinaturas confirmadas',
 	'titre_statistiques' => 'Estatísticas do site',
 	'titre_titre_document' => 'Título do documento:',
 	'todo' => 'breve',
+	'trad_definir_reference' => 'Escolher "@titre@" como referência das traduções',
 	'trad_reference' => '(matéria das traduções)',
 
 	// Z
@@ -662,6 +669,7 @@ Tente se',
 	'zbug_champ_hors_motif' => 'Campo @champ@ fora de um contexto @motif@',
 	'zbug_code' => 'código',
 	'zbug_critere_inconnu' => 'Critério @critere@ desconhecido',
+	'zbug_critere_sur_table_sans_cle_primaire' => '{@critere@} em uma tabela sem chave primária atômica',
 	'zbug_distant_interdit' => 'Externa interdita',
 	'zbug_doublon_table_sans_cle_primaire' => 'Duplicação em tabela sem chave primária atômica',
 	'zbug_doublon_table_sans_index' => 'Doublons em uma tabela sem index',
