@@ -3,7 +3,9 @@
 // extrait automatiquement de http://trad.spip.net/tradlang_module/spip?lang_cible=sk
 // ** ne pas modifier le fichier **
 
-if (!defined('_ECRIRE_INC_VERSION')) return;
+if (!defined('_ECRIRE_INC_VERSION')) {
+	return;
+}
 
 $GLOBALS[$GLOBALS['idx_lang']] = array(
 
@@ -31,7 +33,7 @@ $GLOBALS[$GLOBALS['idx_lang']] = array(
 	'annuler' => 'Zrušiť',
 	'antispam_champ_vide' => 'Toto pole, prosím, nevypĺňajte:',
 	'articles_recents' => 'Najnovšie články',
-	'avis_1_erreur_saisie' => 'Vo vašom zadaní je 1 chyba, skontrolujte si údaje.',
+	'avis_1_erreur_saisie' => 'Vo vašom zadaní je 1 chyba, skontrolujte si údaje.', # MODIF
 	'avis_archive_incorrect' => 'archívny súbor nie je platný súbor SPIPu',
 	'avis_archive_invalide' => 'archívny súbor nie je platný',
 	'avis_attention' => 'POZOR!',
@@ -534,7 +536,7 @@ stránku "@nom_site_spip@" (@adresse_login@):',
 	'login_retour_public' => 'Späť na verejne prístupnú stránku',
 	'login_retour_site' => 'Späť na verejne prístupnú stránku',
 	'login_retoursitepublic' => 'Späť na verejne prístupnú stránku',
-	'login_sans_cookiie' => 'Identifikácia bez cookie',
+	'login_sans_cookie' => 'Identifikácia bez cookie',
 	'login_securise' => 'Zabezpečené prihlásenie',
 	'login_sinscrire' => 'Zaregistrovať sa',
 	'login_test_navigateur' => 'Testuje sa prehliadač/nové pripojenie',
@@ -597,7 +599,7 @@ a znova sa prihlásiť na stránku.
 	'pass_nouveau_pass' => 'Nové heslo',
 	'pass_ok' => 'OK',
 	'pass_oubli_mot' => 'Zabudnuté heslo',
-	'pass_procedure_changer' => 'Ak si chcete zmeniť heslo, musíme overiť vašu identitu. Použijeme na to e-mailovú adresu priradenú k vášmu účtu.',
+	'pass_procedure_changer' => 'Ak si chcete zmeniť heslo, musíme overiť vašu identitu. Použijeme na to e-mailovú adresu priradenú k vášmu účtu.', # MODIF
 	'pass_quitter_fenetre' => 'Zatvoriť toto okno',
 	'pass_rappel_login' => 'Na pripomenutie: váš identifikátor (prihlasovacie meno) je "@login@".',
 	'pass_recevoir_mail' => 'Dostanete e-mail, ktorý vám vysvetlí, ako znova získať prístup na stránku.',
