@@ -10,10 +10,20 @@
  *  Pour plus de details voir le fichier COPYING.txt ou l'aide en ligne.   *
 \***************************************************************************/
 
-if (!defined('_ECRIRE_INC_VERSION')) return;
-
-function maj_v015_dist($version_installee, $version_cible)
-{
+/**
+ * Gestion des mises à jour de SPIP, versions 1.5*
+ *
+ * @package SPIP\Core\SQL\Upgrade
+ **/
+if (!defined('_ECRIRE_INC_VERSION')) {
+	return;
 }
 
-?>
+/**
+ * Mises à jour de SPIP n°015
+ *
+ * @param float $version_installee Version actuelle
+ * @param float $version_cible Version de destination
+ **/
+function maj_v015_dist($version_installee, $version_cible) {
+}
