@@ -10,7 +10,9 @@
  *  Pour plus de details voir le fichier COPYING.txt ou l'aide en ligne.   *
 \***************************************************************************/
 
-if (!defined('_ECRIRE_INC_VERSION')) return;
+if (!defined('_ECRIRE_INC_VERSION')) {
+	return;
+}
 
 
 /**
@@ -18,20 +20,23 @@ if (!defined('_ECRIRE_INC_VERSION')) return;
  *
  * @param array $arbre
  */
-function plugins_extraire_pipelines_dist(&$arbre){
+function plugins_extraire_pipelines_dist(&$arbre) {
 	$pipeline = array();
-	if (spip_xml_match_nodes(',^pipeline,',$arbre,$pipes)){
-		foreach($pipes as $tag=>$p){
-			if (!is_array($p[0])){
-				list($tag,$att) = spip_xml_decompose_tag($tag);
-				$pipeline[] = $att;
-			}
-			else foreach($p as $pipe){
-				$att = array();
-				if (is_array($pipe))
-					foreach($pipe as $k=>$t)
-						$att[$k] = trim(end($t));
+	if (spip_xml_match_nodes(',^pipeline,', $arbre, $pipes)) {
+		foreach ($pipes as $tag => $p) {
+			if (!is_array($p[0])) {
+				list($tag, $att) = spip_xml_decompose_tag($tag);
 				$pipeline[] = $att;
+			} else {
+				foreach ($p as $pipe) {
+					$att = array();
+					if (is_array($pipe)) {
+						foreach ($pipe as $k => $t) {
+							$att[$k] = trim(end($t));
+						}
+					}
+					$pipeline[] = $att;
+				}
 			}
 		}
 		unset($arbre[$tag]);
@@ -39,6 +44,3 @@ function plugins_extraire_pipelines_dist(&$arbre){
 
 	return $pipeline;
 }
-
-
-?>
