@@ -1754,9 +1754,9 @@ function balise_HTTP_HEADER_dist($p) {
 		$err_b_s_a = array('zbug_balise_sans_argument', array('balise' => 'HTTP_HEADER'));
 		erreur_squelette($err_b_s_a, $p);
 	} else {
-		$p->code = "'<'.'?php header(\"' . "
+		$p->code = "'<'.'?php header(' . _q("
 			. $header
-			. " . '\"); ?'.'>'";
+			. ") . '); ?'.'>'";
 	}
 	$p->interdire_scripts = false;
 
