@@ -10,8 +10,9 @@
  *  Pour plus de details voir le fichier COPYING.txt ou l'aide en ligne.   *
 \***************************************************************************/
 
-if (!defined('_ECRIRE_INC_VERSION')) return;
-
+if (!defined('_ECRIRE_INC_VERSION')) {
+	return;
+}
 
 
 include_spip('req/sqlite_generique');
@@ -19,24 +20,21 @@ include_spip('req/sqlite_generique');
 $GLOBALS['spip_sqlite3_functions_1'] = _sqlite_ref_fonctions();
 
 
-// http://doc.spip.org/@req_sqlite3_dist
-function req_sqlite3_dist($addr, $port, $login, $pass, $db='', $prefixe='') {
-	return req_sqlite_dist($addr, $port, $login, $pass, $db, $prefixe, $sqlite_version=3);
+// http://code.spip.net/@req_sqlite3_dist
+function req_sqlite3_dist($addr, $port, $login, $pass, $db = '', $prefixe = '') {
+	return req_sqlite_dist($addr, $port, $login, $pass, $db, $prefixe, $sqlite_version = 3);
 }
 
 
-// http://doc.spip.org/@spip_sqlite3_constantes
-function spip_sqlite3_constantes(){
+// http://code.spip.net/@spip_sqlite3_constantes
+function spip_sqlite3_constantes() {
 	if (!defined('SPIP_SQLITE3_ASSOC')) {
 		define('SPIP_SQLITE3_ASSOC', PDO::FETCH_ASSOC);
-		define('SPIP_SQLITE3_NUM',   PDO::FETCH_NUM);
-		define('SPIP_SQLITE3_BOTH',  PDO::FETCH_BOTH);
+		define('SPIP_SQLITE3_NUM', PDO::FETCH_NUM);
+		define('SPIP_SQLITE3_BOTH', PDO::FETCH_BOTH);
 	}
 }
 
-function spip_versions_sqlite3()
-{
+function spip_versions_sqlite3() {
 	return _sqlite_charger_version(3) ? 3 : false;
 }
-
-?>
