@@ -10,7 +10,9 @@
  *  Pour plus de details voir le fichier COPYING.txt ou l'aide en ligne.   *
 \***************************************************************************/
 
-if (!defined('_ECRIRE_INC_VERSION')) return;
+if (!defined('_ECRIRE_INC_VERSION')) {
+	return;
+}
 
 // rien sauf les "~" et "-,"
 
@@ -43,4 +45,3 @@ function typographie_en_dist($letexte) {
 
 	return $letexte;
 }
-?>
