@@ -10,7 +10,9 @@
  *  Pour plus de details voir le fichier COPYING.txt ou l'aide en ligne.   *
 \***************************************************************************/
 
-if (!defined('_ECRIRE_INC_VERSION')) return;
+if (!defined('_ECRIRE_INC_VERSION')) {
+	return;
+}
 
 // Correction typographique francaise
 
@@ -33,33 +35,42 @@ function typographie_fr_dist($letexte) {
 		$chars = array(160 => '~', 187 => '&#187;', 171 => '&#171;', 148 => '&#8221;', 147 => '&#8220;', 176 => '&#176;');
 		$chars_trans = array_keys($chars);
 		$chars = array_values($chars);
-		$chars_trans = implode(' ',array_map('chr',$chars_trans));
+		$chars_trans = implode(' ', array_map('chr', $chars_trans));
 		$chars_trans = unicode2charset(charset2unicode($chars_trans, 'iso-8859-1', 'forcer'));
-		$chars_trans = explode(" ",$chars_trans);
-		foreach($chars as $k=>$r)
+		$chars_trans = explode(" ", $chars_trans);
+		foreach ($chars as $k => $r) {
 			$trans[$chars_trans[$k]] = $r;
+		}
 	}
 
 	$letexte = strtr($letexte, $trans);
 
 	$cherche1 = array(
-		/* 1 */ 	'/((?:^|[^\#0-9a-zA-Z\&])[\#0-9a-zA-Z]*)\;/S',
-		/* 2 */		'/&#187;| --?,|(?::(?!:)| %)(?:\W|$)/S',
-		/* 3 */		'/([^[<(!?.])([!?][!?\.]*)/iS',
-		/* 4 */		'/&#171;|(?:M(?:M?\.|mes?|r\.?)|[MnN]&#176;) /S'
+		/* 1 */
+		'/((?:^|[^\#0-9a-zA-Z\&])[\#0-9a-zA-Z]*)\;/S',
+		/* 2 */
+		'/&#187;| --?,|(?::(?!:)| %)(?:\W|$)/S',
+		/* 3 */
+		'/([^[<(!?.])([!?][!?\.]*)/iS',
+		/* 4 */
+		'/&#171;|(?:M(?:M?\.|mes?|r\.?)|[MnN]&#176;) /S'
 	);
 	$remplace1 = array(
-		/* 1 */		'\1~;',
-		/* 2 */		'~\0',
-		/* 3 */		'\1~\2',
-		/* 4 */		'\0~'
+		/* 1 */
+		'\1~;',
+		/* 2 */
+		'~\0',
+		/* 3 */
+		'\1~\2',
+		/* 4 */
+		'\0~'
 	);
 	$letexte = preg_replace($cherche1, $remplace1, $letexte);
 	$letexte = preg_replace("/ *~+ */S", "~", $letexte);
 
 	$cherche2 = array(
 		'/([^-\n]|^)--([^-]|$)/S',
-		',(' ._PROTOCOLES_STD . ')~((://[^"\'\s\[\]\}\)<>]+)~([?]))?,S',
+		',(' . _PROTOCOLES_STD . ')~((://[^"\'\s\[\]\}\)<>]+)~([?]))?,S',
 		'/~/'
 	);
 	$remplace2 = array(
