@@ -10,27 +10,48 @@
  *  Pour plus de details voir le fichier COPYING.txt ou l'aide en ligne.   *
 \***************************************************************************/
 
-if (!defined("_ECRIRE_INC_VERSION")) return;
+/**
+ * Gestion du formulaire de configuration des brèves
+ *
+ * @package SPIP\Breves\Formulaires
+ **/
+if (!defined("_ECRIRE_INC_VERSION")) {
+	return;
+}
 
-function formulaires_configurer_breves_charger_dist(){
-	foreach(array(
-		"activer_breves",
-		) as $m)
+/**
+ * Chargement du formulaire de configuration des brèves
+ *
+ * @return array
+ *     Environnement du formulaire
+ **/
+function formulaires_configurer_breves_charger_dist() {
+	foreach (array(
+		         "activer_breves",
+	         ) as $m) {
 		$valeurs[$m] = $GLOBALS['meta'][$m];
+	}
 
 	return $valeurs;
 }
 
-
-function formulaires_configurer_breves_traiter_dist(){
-	$res = array('editable'=>true);
-	foreach(array(
-		"activer_breves",
-		) as $m)
-		if (!is_null($v=_request($m)))
-			ecrire_meta($m, $v=='oui'?'oui':'non');
+/**
+ * Traitement du formulaire de configuration des brèves
+ *
+ * @return array
+ *     Retours du traitement
+ **/
+function formulaires_configurer_breves_traiter_dist() {
+	$res = array('editable' => true);
+	foreach (array(
+		         "activer_breves",
+	         ) as $m) {
+		if (!is_null($v = _request($m))) {
+			ecrire_meta($m, $v == 'oui' ? 'oui' : 'non');
+		}
+	}
 
 	$res['message_ok'] = _T('config_info_enregistree');
+
 	return $res;
 }
-
