@@ -3,12 +3,14 @@
 // extrait automatiquement de http://trad.spip.net/tradlang_module/paquet-breves?lang_cible=oc_ni_mis
 // ** ne pas modifier le fichier **
 
-if (!defined('_ECRIRE_INC_VERSION')) return;
+if (!defined('_ECRIRE_INC_VERSION')) {
+	return;
+}
 
 $GLOBALS[$GLOBALS['idx_lang']] = array(
 
 	// B
-	'breves_description' => 'Li brèva soun dei infourmacioun courti, sensa autour.',
+	'breves_description' => 'Li brèva soun de infourmacioun courti, sensa autour.',
 	'breves_slogan' => 'Gestioun dei brèva en SPIP'
 );
 
