@@ -3,7 +3,9 @@
 // extrait automatiquement de http://trad.spip.net/tradlang_module/compresseur?lang_cible=br
 // ** ne pas modifier le fichier **
 
-if (!defined('_ECRIRE_INC_VERSION')) return;
+if (!defined('_ECRIRE_INC_VERSION')) {
+	return;
+}
 
 $GLOBALS[$GLOBALS['idx_lang']] = array(
 
@@ -11,14 +13,11 @@ $GLOBALS[$GLOBALS['idx_lang']] = array(
 	'info_compresseur_titre' => 'Gwellekaat ha gwaskañ',
 	'info_question_activer_compactage_css' => 'Ha c’hoant hoc’h eus ma vefe gwasket ar follennoù stil (CSS) ?', # MODIF
 	'info_question_activer_compactage_js' => 'Ha c’hoant hoc’h e vefe gwasket ar skriptoù javascript ?', # MODIF
-	'info_question_activer_compresseur' => 'Ha c’hoant hoc’h eus e vefe gwasket al lanvad HTTP ?', # MODIF
 
 	// T
 	'texte_compacter_avertissement' => 'Diwallit da chom hep gweredekaat an dibarzhioù-mañ e-keit hag emeur o sevel ho lec’hienn : n’hall ket an elfennoù gwasket bezañ lennet ken war-lerc’h.',
 	'texte_compacter_script_css' => 'Gallout a ra SPIP gwaskañ ar skriptoù javascript hag ar follennoù-stil CSS, evit o enrollañ er restroù difiñv;  buanoc’h e teu al lec’hienn war wel.',
-	'texte_compresseur_page' => 'Gallout a ra SPIP gwaskañ ent emgefre pep pajenn kaset da weladennerien al lec’hienn. Skañvoc’h eo evit ar bann drafet (buanoc’h ez aio evit ar c’hevreadennoù gorrek, da skouer), met goulenn a ra muioc’h a nerzh digant ar servijer.',
-	'titre_compacter_script_css' => 'Gwaskañ ar furmskridoù hag ar follennoù-stil',
-	'titre_compresser_flux_http' => 'Gwaskañ al lanvad HTTP' # MODIF
+	'titre_compacter_script_css' => 'Gwaskañ ar furmskridoù hag ar follennoù-stil'
 );
 
 ?>
