@@ -3,7 +3,9 @@
 // extrait automatiquement de http://trad.spip.net/tradlang_module/compresseur?lang_cible=co
 // ** ne pas modifier le fichier **
 
-if (!defined('_ECRIRE_INC_VERSION')) return;
+if (!defined('_ECRIRE_INC_VERSION')) {
+	return;
+}
 
 $GLOBALS[$GLOBALS['idx_lang']] = array(
 
@@ -11,16 +13,12 @@ $GLOBALS[$GLOBALS['idx_lang']] = array(
 	'info_compresseur_titre' => 'Uttimizazione è cumpressione',
 	'info_question_activer_compactage_css' => 'Vulete attivà a cumpressione di e foglie di stile (CSS)?', # MODIF
 	'info_question_activer_compactage_js' => 'Vulete attivà a cumpressione di i scripts (javascript)?', # MODIF
-	'info_question_activer_compresseur' => 'Vulete attivà a cumpressione di u flussu HTTP?', # MODIF
 
 	// T
 	'texte_compacter_avertissement' => 'Attenti à ùn attivà st’opzioni durante u sviluppu di u situ : L’elementi cumpressi ùn diventenu propriu più leghjitoghji.',
 	'texte_compacter_script_css' => 'SPIP pò cumpressà i scripts javascript è e foglie di stile CSS, da arregitrà li in i schedari stàtichi; 
 	cusì u situ diventa più veloce.',
-	'texte_compresseur_page' => 'SPIP pò cumpressà in autumàticu ogni pàgina ch’ellu manda à i visitori di u situ. Cusì vene uttimizata a banda passante 
-	(u situ diventa più veloce cù una cunnessione à dèbbitu bassu), ma richere putenza più maiò à u servore.',
-	'titre_compacter_script_css' => 'Cumpressione di i scripts è CSS',
-	'titre_compresser_flux_http' => 'Cumpressione di i flussi HTTP' # MODIF
+	'titre_compacter_script_css' => 'Cumpressione di i scripts è CSS'
 );
 
 ?>
