@@ -3,29 +3,30 @@
 // extrait automatiquement de http://trad.spip.net/tradlang_module/compresseur?lang_cible=de
 // ** ne pas modifier le fichier **
 
-if (!defined('_ECRIRE_INC_VERSION')) return;
+if (!defined('_ECRIRE_INC_VERSION')) {
+	return;
+}
 
 $GLOBALS[$GLOBALS['idx_lang']] = array(
 
+	// E
+	'explication_url_statique_ressources' => 'Ein URL für statische Dateien (images, JS…), die ohne Cookie übertragen werden. Meistens handelt es dabie sich um eine Subdomain, die ebenfalls auf die Website geschlatet ist.',
+
 	// I
 	'info_compresseur_titre' => 'Optimierung und Kompression',
 	'info_question_activer_compactage_css' => 'CSS',
 	'info_question_activer_compactage_js' => 'Skripte',
-	'info_question_activer_compresseur' => 'HTML',
 	'item_compresseur_closure' => 'Google Closure Compiler verwenden [experimentell]',
 	'item_compresseur_css' => 'Kompression der Stylesheets aktivieren (CSS)',
-	'item_compresseur_html' => 'Kompression von HTML aktivieren',
 	'item_compresseur_js' => 'Kompression der Skripte aktivieren (Javascript)',
 
+	// L
+	'label_url_statique_ressources' => 'Ressourcen URL',
+
 	// T
 	'texte_compacter_avertissement' => 'Achtung: Bitte aktivieren Sie diese Option nicht während der Entwicklung Ihrer Site. Die komprimierten Elemente verlieren dadurch ihre Lesbarkeit.',
 	'texte_compacter_script_css' => 'SPIP kann Javascripte und CSS Stilvorlagen komprimieren. Dadurch wird die Anzeigegeschwindigkeit der Website erhöht.',
-	'texte_compresseur_page' => 'SPIP kann alle Seiten, die zum Besucher übertragen werden
-komprimieren.Diese Einstellung ermöglicht es, Bandbreite zu sparen (Die
-Site wird über langsame Verbindungen schneller angezeigt), benötigt
-jedoch zusätzliche Serverleistung.',
-	'titre_compacter_script_css' => 'Skripte und CSS komprimieren',
-	'titre_compresser_flux_http' => 'HTML komprimieren'
+	'titre_compacter_script_css' => 'Skripte und CSS komprimieren'
 );
 
 ?>
