@@ -3,7 +3,9 @@
 // extrait automatiquement de http://trad.spip.net/tradlang_module/compresseur?lang_cible=es
 // ** ne pas modifier le fichier **
 
-if (!defined('_ECRIRE_INC_VERSION')) return;
+if (!defined('_ECRIRE_INC_VERSION')) {
+	return;
+}
 
 $GLOBALS[$GLOBALS['idx_lang']] = array(
 
@@ -11,21 +13,14 @@ $GLOBALS[$GLOBALS['idx_lang']] = array(
 	'info_compresseur_titre' => 'Optimizaciones y compresión',
 	'info_question_activer_compactage_css' => 'CSS',
 	'info_question_activer_compactage_js' => 'Scripts',
-	'info_question_activer_compresseur' => 'HTML',
 	'item_compresseur_closure' => 'Utilizar Google Closure Compiler [experimental]',
 	'item_compresseur_css' => 'Activar la compresión de hojas de estilo (CSS)',
-	'item_compresseur_html' => 'Activar la compresión del HTML',
 	'item_compresseur_js' => 'Activar la compresión de los scripts (javascript)',
 
 	// T
 	'texte_compacter_avertissement' => 'Atención a no activar estas opciones durante el desarrollo de tu sitio: los elementos compactados pierden toda legibilidad.',
 	'texte_compacter_script_css' => 'SPIP puede compactar los scripts javascript y las hojas de estilo CSS, para almacenarlos en ficheros estáticos; esto acelera la presentación del sitio.',
-	'texte_compresseur_page' => 'SPIP puede comprimir automáticamente cada página que envía a los
-visitantes del sitio. Este ajuste permite optimizar la banda pasante (el
-sitio es más rápido en caso de una conexión de baja banda pasante), pero
-requiere más potencia del servidor.',
-	'titre_compacter_script_css' => 'Compresión de los scripts y CSS',
-	'titre_compresser_flux_http' => 'Compresión del HTML'
+	'titre_compacter_script_css' => 'Compresión de los scripts y CSS'
 );
 
 ?>
