@@ -3,7 +3,9 @@
 // extrait automatiquement de http://trad.spip.net/tradlang_module/compresseur?lang_cible=gl
 // ** ne pas modifier le fichier **
 
-if (!defined('_ECRIRE_INC_VERSION')) return;
+if (!defined('_ECRIRE_INC_VERSION')) {
+	return;
+}
 
 $GLOBALS[$GLOBALS['idx_lang']] = array(
 
@@ -11,17 +13,11 @@ $GLOBALS[$GLOBALS['idx_lang']] = array(
 	'info_compresseur_titre' => 'Optimización e compresión',
 	'info_question_activer_compactage_css' => 'Quere activar a compactación das follas de estilo(CSS) ?', # MODIF
 	'info_question_activer_compactage_js' => 'Quere activar a compactación de scripts (javascript) ?', # MODIF
-	'info_question_activer_compresseur' => 'Quere activar a compactación do fluxo  HTTP ?', # MODIF
 
 	// T
 	'texte_compacter_avertissement' => 'Atención para non activar estas opcións durante o desenvolvemento do seu web: os elementos compactados perden toda a súa lexibilidade.',
 	'texte_compacter_script_css' => 'SPIP pode compactar os scripts javascript e as follas de estilo CSS, para rexistralos nas fichas estáticas ; iso acelera a presentación do web.',
-	'texte_compresseur_page' => 'SPIP pode comprimir automaticamente cada páxina que envía ao
-visitante do web. Esta regraxe permite optimizar o ancho de banda (o 
-web é máis rápido ao seguirse unha ligazón de baixa velocidade), mais
-demanda máis potencia do servidor.',
-	'titre_compacter_script_css' => 'Compactación de scripts e CSS',
-	'titre_compresser_flux_http' => 'Compactación do fluxo HTTP' # MODIF
+	'titre_compacter_script_css' => 'Compactación de scripts e CSS'
 );
 
 ?>
