@@ -3,7 +3,9 @@
 // extrait automatiquement de http://trad.spip.net/tradlang_module/compresseur?lang_cible=lb
 // ** ne pas modifier le fichier **
 
-if (!defined('_ECRIRE_INC_VERSION')) return;
+if (!defined('_ECRIRE_INC_VERSION')) {
+	return;
+}
 
 $GLOBALS[$GLOBALS['idx_lang']] = array(
 
@@ -11,18 +13,14 @@ $GLOBALS[$GLOBALS['idx_lang']] = array(
 	'info_compresseur_titre' => 'Optimisatioun a Kompressioun',
 	'info_question_activer_compactage_css' => 'CSS',
 	'info_question_activer_compactage_js' => 'Skripten',
-	'info_question_activer_compresseur' => 'HTML',
 	'item_compresseur_closure' => 'Google Closure Compiler benotzen [experimentell]',
 	'item_compresseur_css' => 'Kompressioun vun de Style-Sheets (CSS) aschalten',
-	'item_compresseur_html' => 'Kompressioun vum HTML aschalten',
 	'item_compresseur_js' => 'Kompressioun vun de Skripten (Javascript) aschalten',
 
 	// T
 	'texte_compacter_avertissement' => 'Schalt dës Optiounen net während der Entwécklung vum Site an: déi kompriméiert Elementer si net einfach liesbar.',
 	'texte_compacter_script_css' => 'SPIP ka Javascript oder CSS Style-Sheets kompriméieren an als statesch Dokumenter späicheren; da ginn d’Säite vum Site méi séier gewisen.',
-	'texte_compresseur_page' => 'SPIP kann automatesch all Säit kompriméieren déi gewise gëtt. Dës Astellung erlaabt Bandbreet ze spueren (d.h. de Site ass mat enger lueser Leitung méi séier), mais dat verlaangt méi Leeschtung vum Server.',
-	'titre_compacter_script_css' => 'Skripten an CSS kompriméieren',
-	'titre_compresser_flux_http' => 'HTML kompriméieren'
+	'titre_compacter_script_css' => 'Skripten an CSS kompriméieren'
 );
 
 ?>
