@@ -3,7 +3,9 @@
 // extrait automatiquement de http://trad.spip.net/tradlang_module/compresseur?lang_cible=pt_br
 // ** ne pas modifier le fichier **
 
-if (!defined('_ECRIRE_INC_VERSION')) return;
+if (!defined('_ECRIRE_INC_VERSION')) {
+	return;
+}
 
 $GLOBALS[$GLOBALS['idx_lang']] = array(
 
@@ -11,18 +13,14 @@ $GLOBALS[$GLOBALS['idx_lang']] = array(
 	'info_compresseur_titre' => 'Otimizações e compressão',
 	'info_question_activer_compactage_css' => 'CSS',
 	'info_question_activer_compactage_js' => 'Scripts',
-	'info_question_activer_compresseur' => 'HTML',
 	'item_compresseur_closure' => 'Usar o Google Closure Compiler [experimental]',
 	'item_compresseur_css' => 'Ativar a compressão das folhas de estilo (CSS)',
-	'item_compresseur_html' => 'Ativar a compressão do HTML',
 	'item_compresseur_js' => 'Ativar a compressão dos scripts (javascript)',
 
 	// T
 	'texte_compacter_avertissement' => 'Atenção para não ativar estas opções durante o desenvolvimento do seu site: os elementos compactados perdem toda a legibilidade.',
 	'texte_compacter_script_css' => 'O SPIP pode compactar os scripts javascript e as folhas de estilo CSS, para gravá-los nos arquivos de estatísticas; isto acelera a exibição do site.',
-	'texte_compresseur_page' => 'O SPIP pode comprimir automaticamente cada página que ele envia aos visitantes do site. Esta regulagem permite otimizar a banda de transmissão (le site torna-se mais rápido quando estiver sob uma conexão de banda baixa), mas demanda mais potência do servidor.',
-	'titre_compacter_script_css' => 'Compactação de scripts e CSS',
-	'titre_compresser_flux_http' => 'Compressão do HTML'
+	'titre_compacter_script_css' => 'Compactação de scripts e CSS'
 );
 
 ?>
