@@ -3,7 +3,9 @@
 // extrait automatiquement de http://trad.spip.net/tradlang_module/compresseur?lang_cible=ro
 // ** ne pas modifier le fichier **
 
-if (!defined('_ECRIRE_INC_VERSION')) return;
+if (!defined('_ECRIRE_INC_VERSION')) {
+	return;
+}
 
 $GLOBALS[$GLOBALS['idx_lang']] = array(
 
@@ -11,14 +13,11 @@ $GLOBALS[$GLOBALS['idx_lang']] = array(
 	'info_compresseur_titre' => 'Optimizări şi compresie',
 	'info_question_activer_compactage_css' => 'Doriţi să activaţi compactarea foilor de stil (CSS) ?', # MODIF
 	'info_question_activer_compactage_js' => 'Doriţi să activaţi compactarea scripturilor (javascript) ?', # MODIF
-	'info_question_activer_compresseur' => 'Doriţi să activaţi compresia fluxului HTTP ?', # MODIF
 
 	// T
 	'texte_compacter_avertissement' => 'Atenţie: nu activaţi aceste opţiuni în timpul dezvoltării site-ului dumneavoastră, pentru că elementele compactate îşi pierd lizibilitatea.',
 	'texte_compacter_script_css' => 'SPIP poate compacta script-urile javascript şi foile de stil CSS pentru a le înregistra în fişiere statice; aceasta operaţiune accelerează afişarea site-ului.',
-	'texte_compresseur_page' => 'SPIP poate comprima în mod automatic fiecare pagină pe care o trimite vizitatorilor site-ului. Aceast reglaj permite să optimizaţi banda pasantă (site-ul este mai rapid chiar şi cu o conexiune internet cu debit scăzut) dar cere mai multe resurse server.',
-	'titre_compacter_script_css' => 'Compactarea script-urilor şi a CSS-urlor',
-	'titre_compresser_flux_http' => 'Comprimarea fluxului HTTP' # MODIF
+	'titre_compacter_script_css' => 'Compactarea script-urilor şi a CSS-urlor'
 );
 
 ?>
