@@ -3,7 +3,9 @@
 // extrait automatiquement de http://trad.spip.net/tradlang_module/compresseur?lang_cible=ru
 // ** ne pas modifier le fichier **
 
-if (!defined('_ECRIRE_INC_VERSION')) return;
+if (!defined('_ECRIRE_INC_VERSION')) {
+	return;
+}
 
 $GLOBALS[$GLOBALS['idx_lang']] = array(
 
@@ -11,18 +13,14 @@ $GLOBALS[$GLOBALS['idx_lang']] = array(
 	'info_compresseur_titre' => 'Оптимизация и сжатие исходного кода',
 	'info_question_activer_compactage_css' => 'Сжатие CSS:',
 	'info_question_activer_compactage_js' => 'Сжатие Javascript:',
-	'info_question_activer_compresseur' => 'Сжатие HTML:',
 	'item_compresseur_closure' => 'Использовать Google Closure Compiler ',
 	'item_compresseur_css' => 'Сжимать файлы CSS',
-	'item_compresseur_html' => 'Сжимать HTML',
 	'item_compresseur_js' => 'Сжимать javascript',
 
 	// T
 	'texte_compacter_avertissement' => 'Внимание! При включенном сжатии css и javascript файлов крайне затруднена отладка исходного кода. Используйте эти настройки после окончания работ по созданию сайта.',
 	'texte_compacter_script_css' => 'Для ускорения времени загрузки сайта SPIP может объединять и сжимать (минимизировать) Javascript  и CSS файлы.',
-	'texte_compresseur_page' => 'Для ускорения времени загрузки сайта SPIP может сжимать код страницы (gzip), это делает работу сайта более быстрой, но увеличивает нагрузку на сервер.',
-	'titre_compacter_script_css' => 'Сжатие javascript и CSS',
-	'titre_compresser_flux_http' => 'Сжатие HTML (gzip)'
+	'titre_compacter_script_css' => 'Сжатие javascript и CSS'
 );
 
 ?>
