@@ -3,27 +3,31 @@
 // extrait automatiquement de http://trad.spip.net/tradlang_module/compresseur?lang_cible=sk
 // ** ne pas modifier le fichier **
 
-if (!defined('_ECRIRE_INC_VERSION')) return;
+if (!defined('_ECRIRE_INC_VERSION')) {
+	return;
+}
 
 $GLOBALS[$GLOBALS['idx_lang']] = array(
 
+	// E
+	'explication_url_statique_ressources' => 'URL, ktorá môže obslúžiť statické súbory (obrázky, JS...) bez cookie. Obyčajne je to alternatívna subdoména, ktorá aj odkazuje na stránku.',
+
 	// I
 	'info_compresseur_titre' => 'Optimalizácia a kompresia',
 	'info_question_activer_compactage_css' => 'CSS',
 	'info_question_activer_compactage_js' => 'Skripty',
-	'info_question_activer_compresseur' => 'HTML',
 	'item_compresseur_closure' => 'Používať kompilátor Google Closure [experimentálny]',
 	'item_compresseur_css' => 'Aktivovať kompresiu súborov so štýlmi (CSS)',
-	'item_compresseur_html' => 'Aktivovať kompresiu HTML',
 	'item_compresseur_js' => 'Aktivovať kompresiu skriptov
 (javascript)',
 
+	// L
+	'label_url_statique_ressources' => 'Zdroje URL',
+
 	// T
 	'texte_compacter_avertissement' => 'Dajte si pozor na to, aby ste tieto možnosti nenastavili počas vývoja svojej stránky, lebo kompaktné prvky sa stanú nečitateľné.',
 	'texte_compacter_script_css' => 'SPIP dokáže zmenšiť Javascriptove súbory a súbory so štýlmi a uložiť ich ako statické súbory. Tak zrýchľuje zobrazenie stránky.',
-	'texte_compresseur_page' => 'SPIP dokáže automaticky skomprimovať každú stránku, ktorú posiela návštevníkovi stránky. Tieto nastavenia optimalizujú šírku pásma (pri pomalšom pripojení je stránka rýchlejšia), ale vyžadujú si väčší výkon na strane servera. ',
-	'titre_compacter_script_css' => 'Kompresia skriptov a CSS',
-	'titre_compresser_flux_http' => 'Kompresia HTML'
+	'titre_compacter_script_css' => 'Kompresia skriptov a CSS'
 );
 
 ?>
