@@ -3,15 +3,16 @@
 // extrait automatiquement de http://trad.spip.net/tradlang_module/compresseur?lang_cible=sv
 // ** ne pas modifier le fichier **
 
-if (!defined('_ECRIRE_INC_VERSION')) return;
+if (!defined('_ECRIRE_INC_VERSION')) {
+	return;
+}
 
 $GLOBALS[$GLOBALS['idx_lang']] = array(
 
 	// I
 	'info_compresseur_titre' => 'Optimering och komprimering',
 	'info_question_activer_compactage_css' => 'CSS',
-	'info_question_activer_compactage_js' => 'Vill du aktivera komprimering av  Javascript filer?', # MODIF
-	'info_question_activer_compresseur' => 'Vill du aktivera komprimering av HTTP trafiken?' # MODIF
+	'info_question_activer_compactage_js' => 'Vill du aktivera komprimering av  Javascript filer?' # MODIF
 );
 
 ?>
