@@ -3,7 +3,9 @@
 // extrait automatiquement de http://trad.spip.net/tradlang_module/compresseur?lang_cible=tr
 // ** ne pas modifier le fichier **
 
-if (!defined('_ECRIRE_INC_VERSION')) return;
+if (!defined('_ECRIRE_INC_VERSION')) {
+	return;
+}
 
 $GLOBALS[$GLOBALS['idx_lang']] = array(
 
@@ -11,14 +13,11 @@ $GLOBALS[$GLOBALS['idx_lang']] = array(
 	'info_compresseur_titre' => 'Optimizasyon ve sıkıştırma',
 	'info_question_activer_compactage_css' => 'CSS’lerin sıkıştırılmasını aktive etmek ister misiniz ?', # MODIF
 	'info_question_activer_compactage_js' => 'Skriptlerin (javascript) sıkıştırılmasını aktive etmek ister misiniz ?', # MODIF
-	'info_question_activer_compresseur' => 'HTTP akışının sıkıştırılmasını aktive etmek ister misiniz ?', # MODIF
 
 	// T
 	'texte_compacter_avertissement' => 'Sitenizin geliştirilmesi esnasında bu seçenekleri aktive etmeyin : sıkıştırılmış elemanlar tüm okunabilirliklerini kaybederler.',
 	'texte_compacter_script_css' => 'SPIP javascript sktripleri ve CSSleri sıkıştırabilir ve bunları statik dosyalara kaydedebilir ; böylece sitenin gösterilmesi hızlanır.',
-	'texte_compresseur_page' => 'SPIP site ziyaretçilerine gönderdiği her sayfayı sıkıştırabilir. Bu ayar bandı optimize eder. (site düşük debili bir bağlantıda hızlanmış olur) ama hizmet biriminden çok fazla güç ister.',
-	'titre_compacter_script_css' => 'Skriptlerin ve CSSlerin sıkıştırılması',
-	'titre_compresser_flux_http' => 'HTTP akısının sıkıştırılması' # MODIF
+	'titre_compacter_script_css' => 'Skriptlerin ve CSSlerin sıkıştırılması'
 );
 
 ?>
