@@ -89,7 +89,7 @@ class JavaScriptPacker {
 	);
 
 // http://code.spip.net/@JavaScriptPacker
-	function JavaScriptPacker($_script, $_encoding = 62, $_fastDecode = true, $_specialChars = false)
+	function __construct($_script, $_encoding = 62, $_fastDecode = true, $_specialChars = false)
 	{
 		$this->_script = $_script . "\n";
 		if (array_key_exists($_encoding, $this->LITERAL_ENCODING))
