@@ -10,13 +10,18 @@
  *  Pour plus de details voir le fichier COPYING.txt ou l'aide en ligne.   *
 \***************************************************************************/
 
-if (!defined('_ECRIRE_INC_VERSION')) return;
+if (!defined('_ECRIRE_INC_VERSION')) {
+	return;
+}
+
+/**
+ * Se reconnecter a la base sqlite dont le nom est stocke dans le fichier de statut
+ */
 
 include_spip('inc/dump');
 if ($args = dump_serveur()) {
 	$GLOBALS['spip_connect_version'] = 0.7;
-	if (call_user_func_array('spip_connect_db',$args))
-		define('_DUMP_SERVEUR_OK',true);
+	if (call_user_func_array('spip_connect_db', $args)) {
+		define('_DUMP_SERVEUR_OK', true);
+	}
 }
-
-?>
\ No newline at end of file
