@@ -10,18 +10,22 @@
  *  Pour plus de details voir le fichier COPYING.txt ou l'aide en ligne.   *
 \***************************************************************************/
 
-if (!defined('_ECRIRE_INC_VERSION')) return;
+/**
+ * Gestion d'affichage de la page en cas de restauration interrompue
+ */
+
+if (!defined('_ECRIRE_INC_VERSION')) {
+	return;
+}
 
 /**
  * Finir une restauration interrompue par logout
  */
-function exec_base_restaurer_dist(){
+function exec_base_restaurer_dist() {
 
 	include_spip('base/dump');
-	$status_file = base_dump_meta_name(0)."_restauration";
-	$restaurer = charger_fonction("restaurer","action");
+	$status_file = base_dump_meta_name(0) . "_restauration";
+	$restaurer = charger_fonction("restaurer", "action");
 	$restaurer($status_file);
 
 }
-
-?>
\ No newline at end of file
