@@ -312,7 +312,7 @@ function image_recadre($im, $width, $height, $position = 'center', $background_c
 	$y_i = $image["hauteur"];
 
 	if (_IMG_GD_MAX_PIXELS && $x_i * $y_i > _IMG_GD_MAX_PIXELS) {
-		spip_log("image_recadre impossible sur $im : " . $srcWidth * $srcHeight . "pixels");
+		spip_log("image_recadre impossible sur $im : " . $x_i * $y_i . "pixels");
 
 		// on se rabat sur une reduction CSS
 		return _image_tag_changer_taille($im, $width, $height);
