@@ -13,10 +13,12 @@
 /**
  * Ce fichier ne sert plus
  * Il est maintenu pour assurer la compatibilite des anciens scripts
- *  
+ *
  */
 
-if (!defined('_ECRIRE_INC_VERSION')) return;
+if (!defined('_ECRIRE_INC_VERSION')) {
+	return;
+}
 
 // prise en charge des renomage de fonction
 include_spip('inc/filtres_images_compat');
@@ -29,5 +31,3 @@ include_spip('filtres/images_typo');
 
 // prise en charge des fonctions de transformation de couleur
 include_spip('filtres/couleurs');
-
-?>
\ No newline at end of file
