@@ -10,12 +10,14 @@
  *  Pour plus de details voir le fichier COPYING.txt ou l'aide en ligne.   *
 \***************************************************************************/
 
-if (!defined("_ECRIRE_INC_VERSION")) return;
+if (!defined("_ECRIRE_INC_VERSION")) {
+	return;
+}
 
 // http://code.spip.net/@action_instituer_forum_dist
-function action_instituer_forum_dist($arg=null) {
+function action_instituer_forum_dist($arg = null) {
 
-	if (is_null($arg)){
+	if (is_null($arg)) {
 		$securiser_action = charger_fonction('securiser_action', 'inc');
 		$arg = $securiser_action();
 	}
@@ -23,29 +25,32 @@ function action_instituer_forum_dist($arg=null) {
 	list($id_forum, $statut) = preg_split('/\W/', $arg);
 	$id_forum = intval($id_forum);
 	$row = sql_fetsel("*", "spip_forum", "id_forum=$id_forum");
-	if (!$row) return;
+	if (!$row) {
+		return;
+	}
 
-	instituer_un_forum($statut,$row);
+	instituer_un_forum($statut, $row);
 }
 
-function instituer_un_forum($statut,$row){
+function instituer_un_forum($statut, $row) {
 
 	$id_forum = $row['id_forum'];
 	$old = $row['statut'];
- // rien a faire si pas de changement de statut
- 	if ($old==$statut)
+	// rien a faire si pas de changement de statut
+	if ($old == $statut) {
 		return;
+	}
 
 	// changer le statut de toute l'arborescence dependant de ce message
 	$id_messages = array($id_forum);
 	while ($id_messages) {
-		sql_updateq("spip_forum", array("statut" => $statut), sql_in("id_forum", $id_messages) ." AND statut = '$old'");
+		sql_updateq("spip_forum", array("statut" => $statut), sql_in("id_forum", $id_messages) . " AND statut = '$old'");
 
-		$id_messages = array_map('reset',sql_allfetsel("id_forum", "spip_forum", sql_in("id_parent", $id_messages)));
+		$id_messages = array_map('reset', sql_allfetsel("id_forum", "spip_forum", sql_in("id_parent", $id_messages)));
 	}
 
 	// Notifier de la publication du message, s'il etait 'prop'
-	if ($old=='prop' AND $statut=='publie') {
+	if ($old == 'prop' and $statut == 'publie') {
 		if ($notifications = charger_fonction('notifications', 'inc')) {
 			$notifications('forumvalide', $id_forum);
 		}
@@ -58,18 +63,20 @@ function instituer_un_forum($statut,$row){
 	// c'est imparfait dans le cas ou les crayons ont ete utilises pour modifier ce message entre temps
 	// car la date_thread aurait cette derniere date alors que pas le message
 	// mais c'est au mieux de ce que l'on peut faire quand on depublie un SPAM ou supprime un message
-	if ($statut=='publie' OR $old=='publie') {
-		if ($statut=='publie'
-			OR !($date_thread = sql_getfetsel("date_heure", "spip_forum", "statut='publie' AND id_thread=".$row['id_thread'], "", "date_heure DESC","0,1"))){
+	if ($statut == 'publie' or $old == 'publie') {
+		if ($statut == 'publie'
+			or !($date_thread = sql_getfetsel("date_heure", "spip_forum",
+				"statut='publie' AND id_thread=" . $row['id_thread'], "", "date_heure DESC", "0,1"))
+		) {
 			$date_thread = date('Y-m-d H:i:s');
 		}
-		sql_updateq("spip_forum", array("date_thread" => $date_thread), "id_thread=".$row['id_thread']);
+		sql_updateq("spip_forum", array("date_thread" => $date_thread), "id_thread=" . $row['id_thread']);
 	}
 
 	// invalider les pages comportant ce forum
 	include_spip('inc/invalideur');
 	suivre_invalideur("id='forum/$id_forum'");
-	suivre_invalideur("id='".$row['objet']."/".$row['id_objet']."'");
+	suivre_invalideur("id='" . $row['objet'] . "/" . $row['id_objet'] . "'");
 
 	// Reindexation du thread (par exemple)
 	pipeline('post_edition',
@@ -81,11 +88,9 @@ function instituer_un_forum($statut,$row){
 				'type' => 'forum',
 				'id_objet' => $id_forum,
 				'action' => 'instituer',
-				'statut_ancien'=> $old,
+				'statut_ancien' => $old,
 			),
-			'data' => array('statut'=>$statut)
+			'data' => array('statut' => $statut)
 		)
 	);
 }
-
-?>
