@@ -10,25 +10,28 @@
  *  Pour plus de details voir le fichier COPYING.txt ou l'aide en ligne.   *
 \***************************************************************************/
 
-if (!defined("_ECRIRE_INC_VERSION")) return;
+if (!defined("_ECRIRE_INC_VERSION")) {
+	return;
+}
 
-function formulaires_configurer_forums_participants_charger_dist(){
+function formulaires_configurer_forums_participants_charger_dist() {
 
 	return array(
 		'forums_publics' => $GLOBALS['meta']["forums_publics"],
 	);
-	
+
 }
 
-function formulaires_configurer_forums_participants_traiter_dist(){
+function formulaires_configurer_forums_participants_traiter_dist() {
 	include_spip('inc/config');
 	include_spip('inc/meta');
 
 	$purger_skel = false;
 	if ($accepter_forum = _request('forums_publics')
-	AND ($accepter_forum != $GLOBALS['meta']["forums_publics"])) {
+		and ($accepter_forum != $GLOBALS['meta']["forums_publics"])
+	) {
 		$purger_skel = true;
-		$accepter_forum = substr($accepter_forum,0,3);
+		$accepter_forum = substr($accepter_forum, 0, 3);
 	}
 
 	// Appliquer les changements de moderation forum
@@ -40,11 +43,12 @@ function formulaires_configurer_forums_participants_traiter_dist(){
 			? "accepter_forum != 'non'"
 			: '';
 
-		sql_updateq('spip_articles', array('accepter_forum'=>$accepter_forum), $sauf);
+		sql_updateq('spip_articles', array('accepter_forum' => $accepter_forum), $sauf);
 	}
 
-	if ($accepter_forum == 'abo')
+	if ($accepter_forum == 'abo') {
 		ecrire_meta('accepter_visiteurs', 'oui');
+	}
 
 	appliquer_modifs_config();
 	if ($purger_skel) {
@@ -52,7 +56,5 @@ function formulaires_configurer_forums_participants_traiter_dist(){
 		suivre_invalideur("forum/*");
 	}
 
-	return array('message_ok'=>_T('config_info_enregistree'));
+	return array('message_ok' => _T('config_info_enregistree'));
 }
-
-?>
\ No newline at end of file
