@@ -10,7 +10,15 @@
  *  Pour plus de details voir le fichier COPYING.txt ou l'aide en ligne.   *
 \***************************************************************************/
 
-if (!defined("_ECRIRE_INC_VERSION")) return;
+/**
+ * Fichier gérant l'installation et désinstallation du plugin
+ *
+ * @package SPIP\Forum\Installation
+ **/
+
+if (!defined("_ECRIRE_INC_VERSION")) {
+	return;
+}
 
 /**
  * Installation/maj des tables forum
@@ -18,68 +26,77 @@ if (!defined("_ECRIRE_INC_VERSION")) return;
  * @param string $nom_meta_base_version
  * @param string $version_cible
  */
-function forum_upgrade($nom_meta_base_version,$version_cible){
+function forum_upgrade($nom_meta_base_version, $version_cible) {
 
 	// cas particulier :
 	// si plugin pas installe mais que la table existe
 	// considerer que c'est un upgrade depuis v 1.0.0
 	// pour gerer l'historique des installations SPIP <=2.1
-	if (!isset($GLOBALS['meta'][$nom_meta_base_version])){
-		$trouver_table = charger_fonction('trouver_table','base');
+	if (!isset($GLOBALS['meta'][$nom_meta_base_version])) {
+		$trouver_table = charger_fonction('trouver_table', 'base');
 		$trouver_table(''); // vider le cache des descriptions !
 		if ($desc = $trouver_table('spip_forum')
-		  AND isset($desc['field']['id_article'])){
-			ecrire_meta($nom_meta_base_version,'1.0.0');
+			and isset($desc['field']['id_article'])
+		) {
+			ecrire_meta($nom_meta_base_version, '1.0.0');
 		}
 		// si pas de table en base, on fera une simple creation de base
 	}
 
 	$maj = array();
 	$maj['create'] = array(
-		array('maj_tables',array('spip_forum')),
+		array('maj_tables', array('spip_forum')),
 	);
 	$maj['1.1.0'] = array(
-		array('sql_alter',"TABLE spip_forum ADD id_objet bigint(21) DEFAULT 0 NOT NULL AFTER id_forum"),
-		array('sql_alter',"TABLE spip_forum ADD objet VARCHAR (25) DEFAULT '' NOT NULL AFTER id_objet"),
+		array('sql_alter', "TABLE spip_forum ADD id_objet bigint(21) DEFAULT 0 NOT NULL AFTER id_forum"),
+		array('sql_alter', "TABLE spip_forum ADD objet VARCHAR (25) DEFAULT '' NOT NULL AFTER id_objet"),
 		#array('sql_alter',"TABLE spip_forum DROP INDEX optimal"),
 		#array('sql_alter',"TABLE spip_forum ADD INDEX optimal (statut,id_parent,id_objet,objet,date_heure)"),
 	);
 	$maj['1.1.1'] = array(
-		array('sql_update',"spip_forum", array('objet' => "'breve'",'id_objet' => 'id_breve'), 'id_breve> 0'),
+		array('sql_update', "spip_forum", array('objet' => "'breve'", 'id_objet' => 'id_breve'), 'id_breve> 0'),
 		#array('sql_alter',"TABLE spip_forum DROP id_breve"),
-		array('sql_update',"spip_forum", array('objet' => "'article'",'id_objet' => 'id_article'), 'id_article>0'),
+		array('sql_update', "spip_forum", array('objet' => "'article'", 'id_objet' => 'id_article'), 'id_article>0'),
 		#array('sql_alter',"TABLE spip_forum DROP id_article"),
-		array('sql_update',"spip_forum", array('objet' => "'site'",'id_objet' => 'id_syndic'), 'id_syndic>0'),
+		array('sql_update', "spip_forum", array('objet' => "'site'", 'id_objet' => 'id_syndic'), 'id_syndic>0'),
 		#array('sql_alter',"TABLE spip_forum DROP id_syndic"),
-		array('sql_update',"spip_forum", array('objet' => "'message'",'id_objet' => 'id_message'), 'id_message>0'),
+		array('sql_update', "spip_forum", array('objet' => "'message'", 'id_objet' => 'id_message'), 'id_message>0'),
 		#array('sql_alter',"TABLE spip_forum DROP id_message"),
-		array('sql_update',"spip_forum", array('objet' => "'rubrique'",'id_objet' => 'id_rubrique'), 'id_rubrique>0'),
+		array('sql_update', "spip_forum", array('objet' => "'rubrique'", 'id_objet' => 'id_rubrique'), 'id_rubrique>0'),
 		#array('sql_alter',"TABLE spip_forum DROP id_rubrique"),
 	);
 
 	# champ ip sur 40 car (compat IPv6)
 	$maj['1.2.0'] = array(
-		array('sql_alter',"TABLE spip_forum CHANGE ip ip VARCHAR(40) DEFAULT '' NOT NULL"),
+		array('sql_alter', "TABLE spip_forum CHANGE ip ip VARCHAR(40) DEFAULT '' NOT NULL"),
 	);
 	# rejouer la suppression/creation de l'index optimal
 	# et la suppression des vieux champs, car la premiere sequence avait echoue
 	# en raison d'un DROP KEY au lieu de DROP INDEX
 	$maj['1.2.1'] = array(
-		array('sql_alter',"TABLE spip_forum DROP INDEX optimal"),
-		array('sql_alter',"TABLE spip_forum ADD INDEX optimal (statut,id_parent,id_objet,objet,date_heure)"),
-		array('sql_alter',"TABLE spip_forum DROP id_breve"),
-		array('sql_alter',"TABLE spip_forum DROP id_article"),
-		array('sql_alter',"TABLE spip_forum DROP id_syndic"),
-		array('sql_alter',"TABLE spip_forum DROP id_message"),
-		array('sql_alter',"TABLE spip_forum DROP id_rubrique"),
+		array('sql_alter', "TABLE spip_forum DROP INDEX optimal"),
+		array('sql_alter', "TABLE spip_forum ADD INDEX optimal (statut,id_parent,id_objet,objet,date_heure)"),
+		array('sql_alter', "TABLE spip_forum DROP id_breve"),
+		array('sql_alter', "TABLE spip_forum DROP id_article"),
+		array('sql_alter', "TABLE spip_forum DROP id_syndic"),
+		array('sql_alter', "TABLE spip_forum DROP id_message"),
+		array('sql_alter', "TABLE spip_forum DROP id_rubrique"),
 	);
+	$maj['1.2.2'] = array(
+		array(
+			'ecrire_meta',
+			'forum_prive_objets',
+			($GLOBALS['meta']['forum_prive_objets'] == 'non') ? '' : 'spip_articles,spip_breves,spip_syndic'
+		),
+	);
+
 
 	include_spip('base/upgrade');
 	maj_plugin($nom_meta_base_version, $version_cible, $maj);
 }
 
 /**
- * Desinstallation/suppression des tables forum
+ * Désinstallation/suppression des tables forum
  *
  * @param string $nom_meta_base_version
  */
@@ -91,6 +108,7 @@ function forum_vider_tables($nom_meta_base_version) {
 	effacer_meta("forums_texte");
 	effacer_meta("forums_urlref");
 	effacer_meta("forums_afficher_barre");
+	effacer_meta("forums_forcer_previsu");
 	effacer_meta("formats_documents_forum");
 	effacer_meta("forums_publics");
 	effacer_meta("forum_prive");
@@ -99,5 +117,3 @@ function forum_vider_tables($nom_meta_base_version) {
 
 	effacer_meta($nom_meta_base_version);
 }
-
-?>
