@@ -3,7 +3,9 @@
 // extrait automatiquement de http://trad.spip.net/tradlang_module/forum?lang_cible=en
 // ** ne pas modifier le fichier **
 
-if (!defined('_ECRIRE_INC_VERSION')) return;
+if (!defined('_ECRIRE_INC_VERSION')) {
+	return;
+}
 
 $GLOBALS[$GLOBALS['idx_lang']] = array(
 
@@ -28,6 +30,8 @@ $GLOBALS[$GLOBALS['idx_lang']] = array(
 
 	// E
 	'erreur_enregistrement_message' => 'Your post could not be saved due to technical problem',
+	'extensions_autorisees' => 'Authorized extensions:',
+	'extensions_autorisees_toutes' => 'all',
 
 	// F
 	'form_pet_message_commentaire' => 'Any message or comments?',
@@ -40,6 +44,7 @@ $GLOBALS[$GLOBALS['idx_lang']] = array(
 	'forum_attention_trop_caracteres' => '<b>Warning !</b> Your message is too long (@compte@ characters) to be saved, it cannot contain more than @max@ characters.',
 	'forum_avez_selectionne' => 'You have selected:',
 	'forum_cliquer_retour' => 'Click <a href=\'@retour_forum@\'>here</a> to continue.',
+	'forum_envoyer' => 'Send',
 	'forum_forum' => 'forum',
 	'forum_info_modere' => 'This forum is moderated before publication: your contribution will only appear after being validated by an administrator.',
 	'forum_lien_hyper' => 'Hypertext link',
@@ -91,6 +96,8 @@ $GLOBALS[$GLOBALS['idx_lang']] = array(
  basis for articles; they will be permanently disabled for sections, news, etc.',
 	'info_envoi_forum' => 'Send article forums to the respective authors',
 	'info_fonctionnement_forum' => 'Forum operation:',
+	'info_forcer_previsualisation_court' => 'Force a preview',
+	'info_forcer_previsualisation_long' => 'Force a preview before sending a message',
 	'info_forums_liees_mot' => 'Forum posts related to this keyword',
 	'info_gauche_suivi_forum_2' => 'The <i>forums management</i> page is a site management tool, not a discussion or editing area. It displays all contributions to the forums, both on the public site and in the private area and allows you to manage these contributions.',
 	'info_liens_syndiques_3' => 'forums',
