@@ -3,7 +3,9 @@
 // extrait automatiquement de http://trad.spip.net/tradlang_module/forum?lang_cible=es
 // ** ne pas modifier le fichier **
 
-if (!defined('_ECRIRE_INC_VERSION')) return;
+if (!defined('_ECRIRE_INC_VERSION')) {
+	return;
+}
 
 $GLOBALS[$GLOBALS['idx_lang']] = array(
 
@@ -21,50 +23,53 @@ $GLOBALS[$GLOBALS['idx_lang']] = array(
 	'bouton_radio_modere_abonnement' => 'sólo para inscritos',
 	'bouton_radio_modere_posteriori' => 'moderación a posteriori',
 	'bouton_radio_modere_priori' => 'moderación a priori',
-	'bouton_radio_publication_immediate' => 'Publicación inmediata de los mensajes (las contribuciones aparecen en cuanto enviadas, pueden suprimirse posteriormente desde la administración).',
+	'bouton_radio_publication_immediate' => 'Publicación inmediata de los mensajes (las contribuciones aparecen en cuanto son enviadas, siendo posible eliminarlas después).',
 
 	// D
 	'documents_interdits_forum' => 'Documentos prohibidos en el foro',
 
 	// E
-	'erreur_enregistrement_message' => 'No se pudo guardar tu mensaje debidos un problema técnico ',
+	'erreur_enregistrement_message' => 'No se ha podido guardar su mensaje debido a un problema técnico ',
+	'extensions_autorisees' => 'Extensiones autorizadas:',
+	'extensions_autorisees_toutes' => 'todas',
 
 	// F
 	'form_pet_message_commentaire' => '¿Un mensaje, un comentario?',
 	'forum' => 'Foro',
-	'forum_acces_refuse' => 'Ya no tienes acceso a estos foros.',
-	'forum_attention_dix_caracteres' => '<b>¡Atención!</b> tu mensaje debe tener al menos diez caracteres.',
-	'forum_attention_message_non_poste' => '¡Atención! Aún no has publicado tu mensaje',
-	'forum_attention_nb_caracteres_mini' => '<b>¡OjO!</b> tu mensaje debe tener al menos @min@ caracteres.',
+	'forum_acces_refuse' => 'Ya no tiene acceso a estos foros.',
+	'forum_attention_dix_caracteres' => '<b>¡Atención!</b> su mensaje debe tener al menos diez caracteres.',
+	'forum_attention_message_non_poste' => '¡Atención! Aún no ha publicado su mensaje',
+	'forum_attention_nb_caracteres_mini' => '<b>¡Atención!</b> su mensaje debe tener al menos @min@ caracteres.',
 	'forum_attention_trois_caracteres' => '<b>¡Atención!</b> el título debe tener al menos tres caracteres.',
-	'forum_attention_trop_caracteres' => '<b>¡Atención!</b> el mensaje es demasiado largo (@compte@ caracteres) para poder guardarlo, no debe sobrepasar los @max@ caracteres.',
-	'forum_avez_selectionne' => 'Has seleccionado:',
-	'forum_cliquer_retour' => 'Pinchar <a href=\'@retour_forum@\'>aquí</a> para continuar.',
+	'forum_attention_trop_caracteres' => '<b>¡Atención!</b> el mensaje es demasiado largo (@compte@ caracteres) para poder guardarse, no debe sobrepasar los @max@ caracteres.',
+	'forum_avez_selectionne' => 'Ha seleccionado:',
+	'forum_cliquer_retour' => 'Haga clic <a href=\'@retour_forum@\'>aquí</a> para continuar.',
+	'forum_envoyer' => 'Enviar',
 	'forum_forum' => 'foro',
-	'forum_info_modere' => 'Este foro es moderado a priori: tu contribución sólo aparecerá una vez validada por un/a administrador/a del sitio.',
+	'forum_info_modere' => 'Este foro es moderado a priori: su contribución sólo aparecerá una vez validada por un/a administrador/a del sitio.',
 	'forum_lien_hyper' => 'Enlace hipertexto',
-	'forum_message' => 'Tu mensaje',
+	'forum_message' => 'Su mensaje',
 	'forum_message_definitif' => 'Mensaje definitivo: enviar al sitio',
-	'forum_message_trop_long' => 'Tu mensaje es demasiado largo. Sólo se admite un máximo de 20.000 caracteres.',
-	'forum_ne_repondez_pas' => 'No conteste a este correo, sino el foro en la dirección siguiente:',
-	'forum_page_url' => '(Si tu mensaje se refiere a un artículo publicado en Internet, o a una página que contiene más informaciones, indica a continuación el título de la página y su dirección URL.)',
+	'forum_message_trop_long' => 'Su mensaje es demasiado largo. Sólo se admite un máximo de 20.000 caracteres.',
+	'forum_ne_repondez_pas' => 'No conteste a este correo, sino al foro en la siguiente dirección:',
+	'forum_page_url' => '(Si su mensaje se refiere a un artículo publicado en Internet, o a una página que contiene más informaciones, indique a continuación el título de la página y su dirección URL)',
 	'forum_permalink' => 'Enlace permanente al comentario',
 	'forum_poste_par' => 'Mensaje enviado@parauteur@ como respuesta al artículo «@titre@».',
 	'forum_poste_par_court' => 'Mensaje enviado@parauteur@.',
 	'forum_poste_par_generique' => 'Mensaje enviado@parauteur@ (@objet@ «@titre@»).',
-	'forum_qui_etes_vous' => '¿Quién eres?',
-	'forum_saisie_texte_info' => 'En este formulario se pueden ingresar atajos SPIP <code>[-&gt;url] {{negrita}} {cursiva} &lt;quote&gt; &lt;code&gt;</code> código HTML <code>&lt;q&gt; &lt;del&gt; &lt;ins&gt;</code>. Para separar párrafos, simplemente deja líneas vacías.',
-	'forum_texte' => 'Texto de tu mensaje',
+	'forum_qui_etes_vous' => '¿Quién es usted?',
+	'forum_saisie_texte_info' => 'Este formulario acepta atajos SPIP <code>[-&gt;url] {{negrita}} {cursiva} &lt;quote&gt; &lt;code&gt;</code> código HTML <code>&lt;q&gt; &lt;del&gt; &lt;ins&gt;</code>. Para separar párrafos, simplemente deje líneas vacías.',
+	'forum_texte' => 'Texto de su mensaje',
 	'forum_titre' => 'Título',
-	'forum_url' => 'Tu sitio web',
+	'forum_url' => 'Su sitio web',
 	'forum_valider' => 'Validar la elección',
 	'forum_voir_avant' => 'Previsualización',
-	'forum_votre_email' => 'Tu dirección de correo electrónico',
-	'forum_votre_nom' => 'Tu nombre',
-	'forum_vous_enregistrer' => 'Para participar en este foro, previamente debes registrarte.
-Gracias por indicar a continuación el identificador personal que se te ha
-suministrado. Si no estás inscrito/a, debes',
-	'forum_vous_inscrire' => 'inscribirte.',
+	'forum_votre_email' => 'Su dirección de correo electrónico',
+	'forum_votre_nom' => 'Su nombre',
+	'forum_vous_enregistrer' => 'Para participar en este foro, debe registrarte previamente.
+Gracias por indicar a continuación el identificador personal que se le ha
+suministrado. Si no está inscrito/a, debe',
+	'forum_vous_inscrire' => 'inscribirse.',
 
 	// I
 	'icone_bruler_message' => 'Señalar como Spam ',
@@ -73,23 +78,25 @@ suministrado. Si no estás inscrito/a, debes',
 	'icone_poster_message' => 'Enviar un mensaje',
 	'icone_suivi_forum' => 'Actualidad del foro público: @nb_forums@ contribución(es)',
 	'icone_suivi_forums' => 'Seguir y administrar los foros',
-	'icone_supprimer_message' => 'Suprimir este mensaje',
-	'icone_supprimer_messages' => 'Suprimir estos mensajes',
+	'icone_supprimer_message' => 'Eliminar este mensaje',
+	'icone_supprimer_messages' => 'Eliminar estos mensajes',
 	'icone_valider_message' => 'Validar este mensaje',
 	'icone_valider_messages' => 'Validar estos mensajes ',
-	'icone_valider_repondre_message' => 'Confirmar & Reponder a este mensaje',
+	'icone_valider_repondre_message' => 'Confirmar y reponder a este mensaje',
 	'info_1_message_forum' => '1 mensaje de foro',
-	'info_activer_forum_public' => 'Para activar los foros públicos, seleccionar el modo de moderación por omisión:',
+	'info_activer_forum_public' => 'Para activar los foros públicos, seleccione el modo de moderación por defecto:',
 	'info_appliquer_choix_moderation' => 'Aplicar este tipo de moderación',
-	'info_config_forums_prive' => 'En el espacio privado del sitio, se pueden activar varios tipos de foros:',
-	'info_config_forums_prive_admin' => 'Un foro reservado a los administradores del sitio :',
-	'info_config_forums_prive_global' => 'Un foro global, abierto a todos los redactores :',
-	'info_config_forums_prive_objets' => 'Un foro para cada artículo, breve, sitio referenciado, etc. :',
-	'info_desactiver_forum_public' => 'Desactivar los foros públicos. Podrán ser activados puntualmente para los artículos, pero no para las breves o las secciones.',
+	'info_config_forums_prive' => 'En el espacio privado del sitio, puede activar varios tipos de foro:',
+	'info_config_forums_prive_admin' => 'Un foro reservado a los administradores del sitio:',
+	'info_config_forums_prive_global' => 'Un foro global, abierto a todos los redactores:',
+	'info_config_forums_prive_objets' => 'Un foro para cada artículo, breve, sitio referenciado, etc.:',
+	'info_desactiver_forum_public' => 'Desactivar los foros públicos. Podrán ser activados puntualmente para los artículos, pero no para los breves, las secciones, etc.',
 	'info_envoi_forum' => 'Seguimiento de los foros',
 	'info_fonctionnement_forum' => 'Funcionamiento del foro:',
+	'info_forcer_previsualisation_court' => 'Forzar la vista previa',
+	'info_forcer_previsualisation_long' => 'Forzar la vista previa antes de mandar el mensaje',
 	'info_forums_liees_mot' => 'Los mensajes de foro ligados a esta palabra',
-	'info_gauche_suivi_forum_2' => 'La página de <i>seguimiento de los foros</i> es una herramienta de gestión de tu sitio (y no un espacio de diálogo o de redacción). Muestra todas las contribuciones de foros del sitio, tanto en público como en el espacio privado, y permite gestionarlas.',
+	'info_gauche_suivi_forum_2' => 'La página de <i>seguimiento de los foros</i> es una herramienta de gestión de su sitio (y no un espacio de diálogo o de redacción). Muestra todas las contribuciones a los foros del sitio, tanto en público como en el espacio privado, y permite gestionarlas.',
 	'info_liens_syndiques_3' => 'foros',
 	'info_liens_syndiques_4' => 'están',
 	'info_liens_syndiques_5' => 'foro',
@@ -99,9 +106,9 @@ suministrado. Si no estás inscrito/a, debes',
 	'info_liens_titre' => 'Enlace(s) que contiene el título del mensaje',
 	'info_mode_fonctionnement_defaut_forum_public' => 'Modo de funcionamiento de los foros públicos',
 	'info_nb_messages_forum' => '@nb@ mensajes de foro',
-	'info_option_email' => 'Cuando se deposita una nueva contribución en un foro asociado a un artículo, se puede notificarlo por correo electrónico a los autores y autoras del artículo. ¿Deseas utilizar esta opción?',
+	'info_option_email' => 'Cuando se envía una nueva contribución a un foro asociado a un artículo, los autores del artículo pueden recibir una notificación por correo electrónico. Indique para cada tipo de foro si hay que utilizar esta opción.',
 	'info_pas_de_forum' => 'sin foro',
-	'info_question_visiteur_ajout_document_forum' => 'Para que los visitantes puedan depositar documentos (imágenes, sonidos...) al participar en los foros, indica aquí  la lista de extensiones de documentos autorizados en los foros (por ejemplo: gif, jpg, png, mp3).',
+	'info_question_visiteur_ajout_document_forum' => 'Si desea autorizar la publicación de documentos (imágenes, sonidos...) en los mensajes de foro, indique la lista de extensiones de documentos autorizados en los foros (por ejemplo: gif, jpg, png, mp3).',
 	'info_question_visiteur_ajout_document_forum_format' => 'Para autorizar todos los tipos de documentos considerados como fiables por SPIP, marca un asterisco. Para no autorizar ninguno, no indiques nada.',
 	'info_selectionner_message' => 'Seleccionar los mensajes:',
 	'interface_formulaire' => 'Interfaz formulario',
@@ -116,7 +123,7 @@ suministrado. Si no estás inscrito/a, debes',
 	// L
 	'label_selectionner' => 'Seleccionar:',
 	'lien_reponse_article' => 'Respuesta al artículo',
-	'lien_reponse_breve_2' => 'Respuesta a la breve',
+	'lien_reponse_breve_2' => 'Respuesta al breve',
 	'lien_reponse_message' => 'Respuesta al mensaje',
 	'lien_reponse_rubrique' => 'Respuesta a la sección',
 	'lien_reponse_site_reference' => 'Respuesta al sitio referenciado',
@@ -127,11 +134,11 @@ suministrado. Si no estás inscrito/a, debes',
 	'messages_meme_auteur' => 'Todos los mensajes de este autor/a',
 	'messages_meme_email' => 'Todos los mensajes de este email',
 	'messages_meme_ip' => 'Todos los mensajes de esta IP',
-	'messages_off' => 'Suprimidos',
+	'messages_off' => 'Eliminados',
 	'messages_perso' => 'Personales',
 	'messages_privadm' => 'Administradores',
 	'messages_prive' => 'Privados',
-	'messages_privoff' => 'Suprimidos',
+	'messages_privoff' => 'Eliminados',
 	'messages_privrac' => 'Generales',
 	'messages_prop' => 'Propuestos',
 	'messages_publie' => 'Publicados',
@@ -144,25 +151,25 @@ suministrado. Si no estás inscrito/a, debes',
 	'onglet_messages_vide' => 'Mensajes sin texto',
 
 	// R
-	'repondre_message' => 'Responder este mensaje',
+	'repondre_message' => 'Responder a este mensaje',
 
 	// S
-	'statut_off' => 'Suprimido',
+	'statut_off' => 'Eliminado',
 	'statut_original' => 'original',
 	'statut_prop' => 'Propuesto',
 	'statut_publie' => 'Publicado',
 	'statut_spam' => 'Spam',
 
 	// T
-	'text_article_propose_publication_forum' => 'Expresa tu opinión mediante el foro adjunto al artículo (en la parte inferior de la página).',
-	'texte_en_cours_validation' => 'Los artículos, breves y foros a continuación están propuestos a la publicación.',
-	'texte_en_cours_validation_forum' => 'No dudes en dar tu opinión mediante los foros adjuntos.',
+	'text_article_propose_publication_forum' => 'No dude en dar su opinión mediante el foro adjunto a este artículo (en la parte inferior de la página).',
+	'texte_en_cours_validation' => 'Los siguientes artículos, breves y foros están propuestos para publicación.',
+	'texte_en_cours_validation_forum' => 'No dude en dar su opinión mediante los foros adjuntos.',
 	'texte_messages_publics' => 'Mensajes públicos sobre:',
 	'titre_cadre_forum_administrateur' => 'Foro administradores',
 	'titre_cadre_forum_interne' => 'Foro interno',
 	'titre_config_forums_prive' => 'Foros del espacio privado',
 	'titre_forum' => 'Foros',
-	'titre_forum_suivi' => 'Gestión de los foros',
+	'titre_forum_suivi' => 'Seguimiento de los foros',
 	'titre_page_forum_suivi' => 'Seguimiento de los foros',
 	'titre_selection_action' => 'Selección',
 	'tout_voir' => 'Ver todos los mensajes',
