@@ -1,7 +1,9 @@
 <?php
 // This is a SPIP language file  --  Ceci est un fichier langue de SPIP
 // Fichier source, a modifier dans svn://zone.spip.org/spip-zone/_core_/plugins/forum/lang/
-if (!defined('_ECRIRE_INC_VERSION')) return;
+if (!defined('_ECRIRE_INC_VERSION')) {
+	return;
+}
 
 $GLOBALS[$GLOBALS['idx_lang']] = array(
 
@@ -28,6 +30,8 @@ $GLOBALS[$GLOBALS['idx_lang']] = array(
 
 	// E
 	'erreur_enregistrement_message' => 'Votre message n’a pas pu être enregistré en raison d’un problème technique',
+	'extensions_autorisees' => 'Extensions autorisées :',
+	'extensions_autorisees_toutes' => 'toutes',
 
 	// F
 	'form_pet_message_commentaire' => 'Un message, un commentaire ?',
@@ -40,6 +44,7 @@ $GLOBALS[$GLOBALS['idx_lang']] = array(
 	'forum_attention_trop_caracteres' => '<b>Attention !</b> votre message est trop long (@compte@ caractères) pour pouvoir être enregistré, il ne doit pas dépasser @max@ caractères.',
 	'forum_avez_selectionne' => 'Vous avez sélectionné :',
 	'forum_cliquer_retour' => 'Cliquez <a href=\'@retour_forum@\'>ici</a> pour continuer.',
+	'forum_envoyer' => 'Envoyer',
 	'forum_forum' => 'forum',
 	'forum_info_modere' => 'Ce forum est modéré a priori : votre contribution n’apparaîtra qu’après avoir été validée par un administrateur du site.',
 	'forum_lien_hyper' => 'Lien hypertexte',
@@ -92,6 +97,8 @@ $GLOBALS[$GLOBALS['idx_lang']] = array(
 	sur les articles ; ils seront interdits sur les rubriques, brèves, etc.',
 	'info_envoi_forum' => 'Envoi des forums aux auteurs des articles',
 	'info_fonctionnement_forum' => 'Fonctionnement du forum :',
+	'info_forcer_previsualisation_court' => 'Forcer la prévisualisation',
+	'info_forcer_previsualisation_long' => 'Forcer la prévisualisation avant envoi du message',
 	'info_forums_liees_mot' => 'Les messages de forum liés à ce mot',
 	'info_gauche_suivi_forum_2' => 'La page de <i>suivi des forums</i> est un outil de gestion de votre site (et non un espace de discussion ou de rédaction). Elle affiche toutes les contributions des forums du site, aussi bien celles du site public que celles de l’espace privé et vous permet de gérer ces contributions.',
 	'info_liens_syndiques_3' => 'forums',
