@@ -3,7 +3,9 @@
 // extrait automatiquement de http://trad.spip.net/tradlang_module/forum?lang_cible=oc_ni
 // ** ne pas modifier le fichier **
 
-if (!defined('_ECRIRE_INC_VERSION')) return;
+if (!defined('_ECRIRE_INC_VERSION')) {
+	return;
+}
 
 $GLOBALS[$GLOBALS['idx_lang']] = array(
 
@@ -32,20 +34,20 @@ $GLOBALS[$GLOBALS['idx_lang']] = array(
 	'forum_cliquer_retour' => 'Clicatz <a href=\'@retour_forum@\'>aquí</a> per continuar.',
 	'forum_forum' => 'fòro',
 	'forum_info_modere' => 'Aqueu fòro es moderat à priòri : la voastra contribucion apareisserà après èstre estada validada d’un administrator dau sit.', # MODIF
-	'forum_lien_hyper' => '<b>Ligam ipertèxt</b> (opcionau)', # MODIF
+	'forum_lien_hyper' => 'Ligam ipertèxt',
 	'forum_message_definitif' => 'Messatge definitieu: mandar au sit',
-	'forum_message_trop_long' => 'Lo voastre messatge es tròup lòng. La talha maximala es de 20000 caractèrs.', # MODIF
-	'forum_ne_repondez_pas' => 'Respondatz pas à-n-aquel e-mail ma sus lo fòro à l’adreça seguenta : ', # MODIF
+	'forum_message_trop_long' => 'Lo voastre messatge es tròup lòng. La talha maximala es de 20 000 caractèrs.', # RELIRE
+	'forum_ne_repondez_pas' => 'Respondatz pas à-n-aquel e-mail ma sus lo fòro à l’adreça seguenta : ',
 	'forum_page_url' => '(se lo voastre messatge si referisse à un article publicat sus lo web, ò à una pàgina que fornisse mai d’informacions, podetz marcar çai sota lo titre de la pàgina e la sieu adreça.)',
 	'forum_poste_par' => 'Messatge postat @parauteur@ à la seguida de l’article « @titre@ ».', # MODIF
-	'forum_qui_etes_vous' => '<b>Cu siètz ?</b> (opcionau)', # MODIF
-	'forum_texte' => 'Tèxt dau voastre messatge :', # MODIF
-	'forum_titre' => 'Titre :', # MODIF
+	'forum_qui_etes_vous' => 'Cu siètz ?',
+	'forum_texte' => 'Tèxt dau voastre messatge',
+	'forum_titre' => 'Titre',
 	'forum_url' => 'URL :', # MODIF
 	'forum_valider' => 'Validar aquesta chausida',
 	'forum_voir_avant' => 'Veire aqueu messatge denant de lo postar', # MODIF
-	'forum_votre_email' => 'La voastra adreça e-mail :', # MODIF
-	'forum_votre_nom' => 'Lo voastre nom (ò pseudonim) :', # MODIF
+	'forum_votre_email' => 'La voastra adreça e-mail',
+	'forum_votre_nom' => 'Lo voastre nom',
 	'forum_vous_enregistrer' => 'Per participar à
   aquest fòro, vos devètz registrar d’en premier. Mercé
   d’indicar çai sota l’identificant personau que vos es
@@ -80,7 +82,7 @@ $GLOBALS[$GLOBALS['idx_lang']] = array(
 	'lien_reponse_article' => 'Respoasta à l’article',
 	'lien_reponse_breve_2' => 'Respoasta à la brèva',
 	'lien_reponse_rubrique' => 'Respoasta à la rubrica',
-	'lien_reponse_site_reference' => 'Respoasta au sit referençat :', # MODIF
+	'lien_reponse_site_reference' => 'Respoasta au sit referençat',
 
 	// O
 	'onglet_messages_internes' => 'Messatges internes',
