@@ -3,7 +3,9 @@
 // extrait automatiquement de http://trad.spip.net/tradlang_module/paquet-jqueryui?lang_cible=it
 // ** ne pas modifier le fichier **
 
-if (!defined('_ECRIRE_INC_VERSION')) return;
+if (!defined('_ECRIRE_INC_VERSION')) {
+	return;
+}
 
 $GLOBALS[$GLOBALS['idx_lang']] = array(
 
@@ -12,7 +14,7 @@ $GLOBALS[$GLOBALS['idx_lang']] = array(
 Le funzionalità di questa libreria sono divise in tre categorie:
 -* {{Le interazioni}}. Queste aggiungono interessanti proprietà agli elementi HTML, come la possibilità di essere prese e trascinate con il mouse (drag & drop), di essere ridimensionate come una finestra, oppure di essere selezionate come le icone del desktop del vostro sistema operativo.
 -* {{I Widgets}}. Questi sono oggetti che offrono caratteristiche di alto livello come il DatePicker per esempio, che mostra un calendario per selezionare le date.
--* {{Gli Effetti}}. Questi arrichiscono gli effetti già offerti da jQuery (fadeIn, slideUp). Grazie a jQuery UI, è possibile per esempio animare la propriety CSS background-color con .animate() oppure aggiungere una transizione per l’azione addClass/removeClass...',
+-* {{Gli Effetti}}. Questi arrichiscono gli effetti già offerti da jQuery (fadeIn, slideUp). Grazie a jQuery UI, è possibile per esempio animare la propriety CSS background-color con .animate() oppure aggiungere una transizione per l’azione addClass/removeClass...', # MODIF
 	'jqueryui_slogan' => 'Animazioni, effetti e widget jQuery'
 );
 
