@@ -3,15 +3,17 @@
 // extrait automatiquement de http://trad.spip.net/tradlang_module/paquet-jqueryui?lang_cible=nl
 // ** ne pas modifier le fichier **
 
-if (!defined('_ECRIRE_INC_VERSION')) return;
+if (!defined('_ECRIRE_INC_VERSION')) {
+	return;
+}
 
 $GLOBALS[$GLOBALS['idx_lang']] = array(
 
 	// J
 	'jqueryui_description' => 'Deze plugin implementeert het extra bibliotheek jQuery UI in SPIP waardoor de creatie van dynamische grafische tabs, drag & drop, vooruitgang bars mogelijk wordt...
-Kenmerken van dit bibliotheek bestaan uit drie categorieën:
+Kenmerken van deze bibliotheek bestaan uit drie categorieën:
 -* {{Interacties}}. Zij kunnen zeer interessante eigenschappen aan HTML-elementen geven, zoals de mogelijkheid om ze te kunnen grijpen en verplaatsen met de muis (drag & drop), aanpassen als een venster, of nog geselecteerd te worden als pictogrammen op het bureau van uw OS.
--* {{Widgets}}. Het zijn objecten "klaar om te gebruiken" die hoog niveau functionaliteit aanbieden, zoals bijvoorbeeld  datepicker die een kalender aanmaakt om het selecteren van een datum te toelaten.
+-* {{Widgets}}. Het zijn objecten "klaar voor gebruik" die een hoog niveau van functionaliteit aanbieden, zoals bijvoorbeeld  datepicker die een kalender aanmaakt om het selecteren van een datum te toelaten.
 -* {{De effecten}}. Ze verrijken  de effecten aangeboden door jQuery (FadeIn, slideUp ...). Dankzij jQuery UI is het bijvoorbeeld mogelijk om de CSS background-color met .animate() te animeren of nog overgangen tijdens addClass / removeClass toe te voegen ...',
 	'jqueryui_slogan' => 'jQuery Animatie, effecten en widgets '
 );
