@@ -1,13 +1,14 @@
 <?php
 
-if (!defined('_ECRIRE_INC_VERSION')) return;
+if (!defined('_ECRIRE_INC_VERSION')) {
+	return;
+}
 
-function mediabox_config_theme(){
+function mediabox_config_theme() {
 	$config = array(
 		'minHeight' => false,
 		'minWidth' => false
 	);
+
 	return $config;
 }
-
-?>
\ No newline at end of file
