@@ -10,7 +10,9 @@
  *  Pour plus de details voir le fichier COPYING.txt ou l'aide en ligne.   *
 \***************************************************************************/
 
-if (!defined("_ECRIRE_INC_VERSION")) return;
+if (!defined("_ECRIRE_INC_VERSION")) {
+	return;
+}
 
 /**
  * Verifier tous les fichiers brises
@@ -22,14 +24,13 @@ function action_verifier_documents_brises_dist() {
 	$arg = $securiser_action();
 
 	include_spip('inc/autoriser');
-	if (autoriser('administrer','mediatheque')) {
+	if (autoriser('administrer', 'mediatheque')) {
 		include_spip('inc/documents');
-		$res = sql_select('fichier,brise,id_document','spip_documents',"distant='non'");
-		while ($row = sql_fetch($res)){
-			if (($brise = !@file_exists(get_spip_doc($row['fichier'])))!=$row['brise'])
-				sql_updateq('spip_documents',array('brise'=>$brise),'id_document='.intval($row['id_document']));
+		$res = sql_select('fichier,brise,id_document', 'spip_documents', "distant='non'");
+		while ($row = sql_fetch($res)) {
+			if (($brise = !@file_exists(get_spip_doc($row['fichier']))) != $row['brise']) {
+				sql_updateq('spip_documents', array('brise' => $brise), 'id_document=' . intval($row['id_document']));
+			}
 		}
 	}
 }
-
-?>
\ No newline at end of file
