@@ -10,23 +10,32 @@
  *  Pour plus de details voir le fichier COPYING.txt ou l'aide en ligne.   *
 \***************************************************************************/
 
-if (!defined("_ECRIRE_INC_VERSION")) return;
+/**
+ * Gestion de l'action verifier_documents_liens
+ *
+ * @package SPIP\Medias\Action
+ **/
+
+if (!defined("_ECRIRE_INC_VERSION")) {
+	return;
+}
 
 /**
- * Verifier tous les fichiers brises
+ * Vérifier tous les fichiers brisés
  *
+ * @param int|null $id_document
+ *     Indique le document cible de l'action, sinon il sera
+ *     obtenu par la clé d'action sécurisée.
  */
-function action_verifier_documents_liens_dist($id_document=null) {
+function action_verifier_documents_liens_dist($id_document = null) {
 
-	if (is_null($id_document)){
+	if (is_null($id_document)) {
 		$securiser_action = charger_fonction('securiser_action', 'inc');
 		$id_document = $securiser_action();
 	}
 
-	$id_document = ($id_document=='*')?'*':intval($id_document);
+	$id_document = ($id_document == '*') ? '*' : intval($id_document);
 	include_spip('action/editer_liens');
-	objet_optimiser_liens(array('document'=>$id_document),'*');
+	objet_optimiser_liens(array('document' => $id_document), '*');
 
 }
-
-?>
\ No newline at end of file
