@@ -9,18 +9,22 @@
  *  Pour plus de details voir le fichier COPYING.txt ou l'aide en ligne.   *
 \***************************************************************************/
 
-if (!defined("_ECRIRE_INC_VERSION")) return;
+if (!defined("_ECRIRE_INC_VERSION")) {
+	return;
+}
 
-function inc_verifier_document_mode_image_dist($infos){
+function inc_verifier_document_mode_image_dist($infos) {
 
 	// Si on veut uploader une image, il faut qu'elle ait ete bien lue
-	if ($infos['inclus'] != 'image')
-		return _T('medias:erreur_format_fichier_image',array('nom'=> $infos['fichier'])); #SVG
+	if ($infos['inclus'] != 'image') {
+		return _T('medias:erreur_format_fichier_image', array('nom' => $infos['fichier']));
+	} #SVG
 
-	if (isset($infos['largeur']) AND isset($infos['hauteur'])){
-		if (!($infos['largeur'] OR $infos['hauteur']))
-			return _T('medias:erreur_upload_vignette',array('nom'=>$infos['fichier']));
+	if (isset($infos['largeur']) and isset($infos['hauteur'])) {
+		if (!($infos['largeur'] or $infos['hauteur'])) {
+			return _T('medias:erreur_upload_vignette', array('nom' => $infos['fichier']));
+		}
 	}
 
 	return true;
-}
\ No newline at end of file
+}
