@@ -11,6 +11,8 @@
 \***************************************************************************/
 
 
-if (!defined('_ECRIRE_INC_VERSION')) return;
+if (!defined('_ECRIRE_INC_VERSION')) {
+	return;
+}
 
-include_spip('formulaires/joindre_document');
\ No newline at end of file
+include_spip('formulaires/joindre_document');
