@@ -10,8 +10,19 @@
  *  Pour plus de details voir le fichier COPYING.txt ou l'aide en ligne.   *
 \***************************************************************************/
 
-if (!defined("_ECRIRE_INC_VERSION")) return;
+/**
+ * Gestion de l'action supprimer_mot
+ *
+ * @package SPIP\Mots\Actions
+ */
+if (!defined("_ECRIRE_INC_VERSION")) {
+	return;
+}
 
+/**
+ * Action supprimant un mot clé dans la base de données dont l'identifiant
+ * est en argument de l'action sécurisée
+ */
 function action_supprimer_mot_dist() {
 
 	$securiser_action = charger_fonction('securiser_action', 'inc');
@@ -20,5 +31,3 @@ function action_supprimer_mot_dist() {
 	include_spip('action/editer_mot');
 	mot_supprimer($id_mot);
 }
-
-?>
