@@ -3,13 +3,15 @@
 // extrait automatiquement de http://trad.spip.net/tradlang_module/paquet-mots?lang_cible=nl
 // ** ne pas modifier le fichier **
 
-if (!defined('_ECRIRE_INC_VERSION')) return;
+if (!defined('_ECRIRE_INC_VERSION')) {
+	return;
+}
 
 $GLOBALS[$GLOBALS['idx_lang']] = array(
 
 	// M
 	'mots_description' => 'Terfwoorden en groepen van trefwoorden',
-	'mots_slogan' => 'Beheer van terfwoorden en groepen van trefwoorden in SPIP'
+	'mots_slogan' => 'Beheer van trefwoorden en groepen van trefwoorden in SPIP'
 );
 
 ?>
