@@ -10,8 +10,14 @@
  *  Pour plus de details voir le fichier COPYING.txt ou l'aide en ligne.   *
 \***************************************************************************/
 
-if (!defined("_ECRIRE_INC_VERSION")) return;
+/**
+ * Charger les fonctions mots
+ *
+ * @package SPIP\Mots\Fonctions
+ **/
+if (!defined("_ECRIRE_INC_VERSION")) {
+	return;
+}
+
 
 include_spip('inc/mots');
-
-?>
