@@ -10,27 +10,30 @@
  *  Pour plus de details voir le fichier COPYING.txt ou l'aide en ligne.   *
 \***************************************************************************/
 
-if (!defined('_ECRIRE_INC_VERSION')) return;
+if (!defined('_ECRIRE_INC_VERSION')) {
+	return;
+}
 
 
 /**
  * @param int $id_message
  * @return void
  */
-function action_envoyer_message_dist($id_message=null){
+function action_envoyer_message_dist($id_message = null) {
 
-	if (is_null($id_message)){
-		$securiser_action = charger_fonction('securiser_action','inc');
+	if (is_null($id_message)) {
+		$securiser_action = charger_fonction('securiser_action', 'inc');
 		$id_message = $securiser_action();
 	}
 
 	include_spip('inc/autoriser');
 	if (intval($id_message)
-		AND $type=sql_getfetsel('type','spip_messages','id_message='.intval($id_message))
-	  AND autoriser('envoyermessage',$type, $id_message)){
+		and $type = sql_getfetsel('type', 'spip_messages', 'id_message=' . intval($id_message))
+		and autoriser('envoyermessage', $type, $id_message)
+	) {
 
 		include_spip('action/editer_objet');
-		objet_modifier('message',$id_message,array('statut'=>'publie'));
+		objet_modifier('message', $id_message, array('statut' => 'publie'));
 	}
 
-}
\ No newline at end of file
+}
