@@ -3,7 +3,9 @@
 // extrait automatiquement de http://trad.spip.net/tradlang_module/organiseur?lang_cible=nl
 // ** ne pas modifier le fichier **
 
-if (!defined('_ECRIRE_INC_VERSION')) return;
+if (!defined('_ECRIRE_INC_VERSION')) {
+	return;
+}
 
 $GLOBALS[$GLOBALS['idx_lang']] = array(
 
@@ -23,8 +25,8 @@ $GLOBALS[$GLOBALS['idx_lang']] = array(
 	'erreur_date_avant_apres' => 'Geef een einddatum na de begindatum aan !',
 	'erreur_date_corrigee' => 'De datum werd verbeterd',
 	'erreur_destinataire_invalide' => 'De ontvanger @dest@ is niet geldig',
-	'erreur_heure' => 'Uur is ongeldig',
-	'erreur_heure_corrigee' => 'Het uur werd verbeterd',
+	'erreur_heure' => 'Tijdstip is ongeldig',
+	'erreur_heure_corrigee' => 'Het tijdstip werd verbeterd',
 
 	// I
 	'icone_ecrire_nouveau_message' => 'Een nieuwe boodschap opsturen',
@@ -32,6 +34,7 @@ $GLOBALS[$GLOBALS['idx_lang']] = array(
 	'icone_ecrire_nouvelle_annonce' => 'Een nieuwe aankondiging aanmaken',
 	'icone_effacer_message' => 'Deze boodschap uitwissen',
 	'icone_modifier_annonce' => 'Deze aankondiging veranderen',
+	'icone_modifier_message' => 'Dit bericht aanpassen',
 	'icone_modifier_pensebete' => 'De herinneringsnota veranderen',
 	'icone_supprimer_message' => 'Deze boodschap uitwissen',
 	'info_1_message_envoye' => '1 boodschap opgestuurd',
@@ -40,7 +43,7 @@ $GLOBALS[$GLOBALS['idx_lang']] = array(
 	'info_message_a' => 'Naar',
 	'info_message_date' => 'Datum',
 	'info_message_date_debut' => 'Begindatum',
-	'info_message_date_fin' => 'Eindtum',
+	'info_message_date_fin' => 'Einddatum',
 	'info_message_de' => 'Van',
 	'info_message_non_lu' => 'Nieuwe boodschap',
 	'info_message_objet' => 'Onderwerp',
@@ -65,11 +68,11 @@ $GLOBALS[$GLOBALS['idx_lang']] = array(
 	'messages' => 'Boodschappen',
 
 	// N
-	'notification_annonce_lire_a_ladresse' => 'Je kan ze lezen op volgende address: @url@.',
+	'notification_annonce_lire_a_ladresse' => 'Je kan ze lezen op het volgende addres: @url@.',
 	'notification_annonce_publie_1' => '[@nom_site_spip@] Algemene aankondiging',
-	'notification_message_lire_a_ladresse' => 'Je kan het boodschap lezen en beantwoorden op het address: @url@.',
+	'notification_message_lire_a_ladresse' => 'Je kan de boodschap lezen en beantwoorden op het adres: @url@.',
 	'notification_message_publie_1' => '[@nom_site_spip@] Nieuwe boodschap',
-	'notification_message_recu_de' => 'Je hebt een nieuwe boodschap gekregen vanuit @nom@.',
+	'notification_message_recu_de' => 'Je hebt een nieuwe boodschap gekregen van @nom@.',
 
 	// T
 	'texte_message_brouillon' => 'Deze boodschapsontwerp werd opgeslagen.',
