@@ -10,21 +10,23 @@
  *  Pour plus de details voir le fichier COPYING.txt ou l'aide en ligne.   *
 \***************************************************************************/
 
-if (!defined("_ECRIRE_INC_VERSION")) return;
+if (!defined("_ECRIRE_INC_VERSION")) {
+	return;
+}
 
-function action_supprimer_signature_dist($id_signature=null){
-	if (!$id_signature){
-		$securiser_action = charger_fonction('securiser_action','inc');
+function action_supprimer_signature_dist($id_signature = null) {
+	if (!$id_signature) {
+		$securiser_action = charger_fonction('securiser_action', 'inc');
 		$id_signature = $securiser_action();
 	}
 
-	if (autoriser('supprimer','signature',$id_signature)){
-		$id_article = sql_getfetsel('P.id_article','spip_signatures AS S JOIN spip_petitions AS P ON S.id_petition=P.id_petition','S.id_signature='.intval($id_signature));
-		if ($id_article AND autoriser('modererpetition','article',$id_article)) {
+	if (autoriser('supprimer', 'signature', $id_signature)) {
+		$id_article = sql_getfetsel('P.id_article',
+			'spip_signatures AS S JOIN spip_petitions AS P ON S.id_petition=P.id_petition',
+			'S.id_signature=' . intval($id_signature));
+		if ($id_article and autoriser('modererpetition', 'article', $id_article)) {
 			include_spip('action/editer_signature');
-			signature_modifier($id_signature, array('statut'=>'poubelle'));
+			signature_modifier($id_signature, array('statut' => 'poubelle'));
 		}
 	}
 }
-
-?>
\ No newline at end of file
