@@ -3,10 +3,15 @@
 // extrait automatiquement de http://trad.spip.net/tradlang_module/petitions?lang_cible=fi
 // ** ne pas modifier le fichier **
 
-if (!defined('_ECRIRE_INC_VERSION')) return;
+if (!defined('_ECRIRE_INC_VERSION')) {
+	return;
+}
 
 $GLOBALS[$GLOBALS['idx_lang']] = array(
 
+	// B
+	'bouton_radio_supprimer_petition' => 'Poista vetoomus',
+
 	// F
 	'form_pet_adresse_site' => 'Sivustosi URL-osoite', # MODIF
 	'form_pet_aucune_signature' => 'Mikään allekirjoitus ei sovi tähän koodiin...', # MODIF
