@@ -10,7 +10,9 @@
  *  Pour plus de details voir le fichier COPYING.txt ou l'aide en ligne.   *
 \***************************************************************************/
 
-if (!defined("_ECRIRE_INC_VERSION")) return;
+if (!defined("_ECRIRE_INC_VERSION")) {
+	return;
+}
 
 include_spip('inc/diff');
 
@@ -25,16 +27,19 @@ include_spip('inc/diff');
  * @param string $format
  * @return string
  */
-function afficher_diff_id_rubrique_dist($champ,$old,$new,$format='diff'){
+function afficher_diff_id_rubrique_dist($champ, $old, $new, $format = 'diff') {
 	// ne pas se compliquer la vie !
-	if ($old==$new)
+	if ($old == $new) {
 		$out = _T('info_dans_rubrique')
-		       . " <b>&#171;&nbsp;".generer_info_entite($new,'rubrique','titre')."&nbsp;&#187;</b>";
-	else
+			. " <b>&#171;&nbsp;" . generer_info_entite($new, 'rubrique', 'titre') . "&nbsp;&#187;</b>";
+	} else {
 		$out = _T('revisions:version_deplace_rubrique',
-							 array('from'=> generer_info_entite($old,'rubrique','titre')
-									 ,'to'=>generer_info_entite($new,'rubrique','titre')
-							 )
-		         );
+			array(
+				'from' => generer_info_entite($old, 'rubrique', 'titre'),
+				'to' => generer_info_entite($new, 'rubrique', 'titre')
+			)
+		);
+	}
+
 	return $out;
-}
\ No newline at end of file
+}
