@@ -10,41 +10,45 @@
  *  Pour plus de details voir le fichier COPYING.txt ou l'aide en ligne.   *
 \***************************************************************************/
 
-if (!defined("_ECRIRE_INC_VERSION")) return;
+if (!defined("_ECRIRE_INC_VERSION")) {
+	return;
+}
 
-function formulaires_configurer_revisions_objets_charger_dist(){
-	if (!$objets = unserialize($GLOBALS['meta']['objets_versions']))
+function formulaires_configurer_revisions_objets_charger_dist() {
+	if (!$objets = unserialize($GLOBALS['meta']['objets_versions'])) {
 		$objets = array();
+	}
 	$valeurs = array(
-		'objets_versions'=>$objets,
+		'objets_versions' => $objets,
 	);
 
 	return $valeurs;
 }
 
-function formulaires_configurer_revisions_objets_traiter_dist(){
+function formulaires_configurer_revisions_objets_traiter_dist() {
 
 	include_spip('inc/meta');
 	$tables = serialize(_request('objets_versions'));
-	ecrire_meta('objets_versions',$tables);
+	ecrire_meta('objets_versions', $tables);
 
-	return array('message_ok'=>_T('config_info_enregistree'));
+	return array('message_ok' => _T('config_info_enregistree'));
 }
 
-function test_objet_versionable($desc){
+function test_objet_versionable($desc) {
 	if (!$desc['editable']
-		OR !isset($desc['champs_versionnes'])
-		OR !count($desc['champs_versionnes'])
-	)
+		or !isset($desc['champs_versionnes'])
+		or !count($desc['champs_versionnes'])
+	) {
 		return '';
+	}
 
 	// regarder si il y a un vrai champ versionne, pas seulement une jointure
-	foreach ($desc['champs_versionnes'] as $c){
-		if (strncmp($c,'jointure_',9)!=0)
+	foreach ($desc['champs_versionnes'] as $c) {
+		if (strncmp($c, 'jointure_', 9) != 0) {
 			return ' ';
+		}
 	}
 
 
 	return '';
 }
-?>
\ No newline at end of file
