@@ -14,27 +14,33 @@
 /**
  * Autorisations du plugin révisions
  *
- * @package Revisions\Autorisations
-**/
+ * @package SPIP\Revisions\Autorisations
+ **/
 
-if (!defined('_ECRIRE_INC_VERSION')) return;
+if (!defined('_ECRIRE_INC_VERSION')) {
+	return;
+}
 
-/** Chargement pour le pipeline d'autorisation */
-function revisions_autoriser(){}
+/**
+ * Fonction du pipeline autoriser. N'a rien à faire.
+ *
+ * @pipeline autoriser
+ */
+function revisions_autoriser() { }
 
 /**
  * Autorisation de voir les revisions ?
- * 
+ *
  * Il faut :
  * - des revisions définies pour cet objet
  * - que l'objet existe
  * - que l'on soit autorisé à voir l'objet
  *
  * @param  string $faire Action demandée
- * @param  string $type  Type d'objet sur lequel appliquer l'action
- * @param  int    $id    Identifiant de l'objet
- * @param  array  $qui   Description de l'auteur demandant l'autorisation
- * @param  array  $opt   Options de cette autorisation
+ * @param  string $type Type d'objet sur lequel appliquer l'action
+ * @param  int $id Identifiant de l'objet
+ * @param  array $qui Description de l'auteur demandant l'autorisation
+ * @param  array $opt Options de cette autorisation
  * @return bool          true s'il a le droit, false sinon
  */
 function autoriser_voirrevisions_dist($faire, $type, $id, $qui, $opt) {
@@ -42,11 +48,13 @@ function autoriser_voirrevisions_dist($faire, $type, $id, $qui, $opt) {
 	$id_table_objet = id_table_objet($type);
 
 	include_spip('inc/revisions');
-	if (!liste_champs_versionnes($table))
+	if (!liste_champs_versionnes($table)) {
 		return false;
+	}
 
-	if (!$row = sql_fetsel("*", $table, "$id_table_objet=".intval($id)))
+	if (!$row = sql_fetsel("*", $table, "$id_table_objet=" . intval($id))) {
 		return false;
+	}
 
 	return
 		autoriser('voir', $type, $id, $qui, $opt);
@@ -55,24 +63,23 @@ function autoriser_voirrevisions_dist($faire, $type, $id, $qui, $opt) {
 
 /**
  * Autorisation de voir le menu révisions
- * 
+ *
  * Il faut des révisions activées et présentes.
  *
  * @param  string $faire Action demandée
- * @param  string $type  Type d'objet sur lequel appliquer l'action
- * @param  int    $id    Identifiant de l'objet
- * @param  array  $qui   Description de l'auteur demandant l'autorisation
- * @param  array  $opt   Options de cette autorisation
+ * @param  string $type Type d'objet sur lequel appliquer l'action
+ * @param  int $id Identifiant de l'objet
+ * @param  array $qui Description de l'auteur demandant l'autorisation
+ * @param  array $opt Options de cette autorisation
  * @return bool          true s'il a le droit, false sinon
  */
-function autoriser_revisions_menu_dist($faire, $type='', $id=0, $qui = NULL, $opt = NULL){
+function autoriser_revisions_menu_dist($faire, $type = '', $id = 0, $qui = null, $opt = null) {
 	// SI pas de revisions sur un objet quelconque.
 	// ET pas de version... pas de bouton, c'est inutile...
 	include_spip('inc/config');
-	if (!lire_config('objets_versions/') AND !sql_countsel('spip_versions')) {
+	if (!lire_config('objets_versions/') and !sql_countsel('spip_versions')) {
 		return false;
 	}
+
 	return true;
 }
-
-?>
