@@ -10,7 +10,9 @@
  *  Pour plus de details voir le fichier COPYING.txt ou l'aide en ligne.   *
 \***************************************************************************/
 
-if (!defined("_ECRIRE_INC_VERSION")) return;
+if (!defined("_ECRIRE_INC_VERSION")) {
+	return;
+}
 
 // http://code.spip.net/@action_instituer_syndic_article_dist
 function action_instituer_syndic_article_dist() {
@@ -21,11 +23,11 @@ function action_instituer_syndic_article_dist() {
 	list($id_syndic_article, $statut) = preg_split('/\W/', $arg);
 
 	if ($id_syndic_article = intval($id_syndic_article)
-	  AND $id_syndic = sql_getfetsel('id_syndic','spip_syndic_articles',"id_syndic_article=".intval($id_syndic_article))
-		AND autoriser('moderer','site',$id_syndic)) {
-		sql_updateq("spip_syndic_articles", array("statut" => $statut), "id_syndic_article=".intval($id_syndic_article));
+		and $id_syndic = sql_getfetsel('id_syndic', 'spip_syndic_articles',
+			"id_syndic_article=" . intval($id_syndic_article))
+		and autoriser('moderer', 'site', $id_syndic)
+	) {
+		sql_updateq("spip_syndic_articles", array("statut" => $statut), "id_syndic_article=" . intval($id_syndic_article));
 	}
 
 }
-
-?>
