@@ -10,27 +10,26 @@
  *  Pour plus de details voir le fichier COPYING.txt ou l'aide en ligne.   *
 \***************************************************************************/
 
-if (!defined("_ECRIRE_INC_VERSION")) return;
+if (!defined("_ECRIRE_INC_VERSION")) {
+	return;
+}
 
 // http://code.spip.net/@action_editer_site_dist
-function action_syndiquer_site_dist($id_syndic=null) {
+function action_syndiquer_site_dist($id_syndic = null) {
 
-	if (is_null($id_syndic)){
+	if (is_null($id_syndic)) {
 		$securiser_action = charger_fonction('securiser_action', 'inc');
 		$id_syndic = $securiser_action();
 	}
 
 
-	$id_job = job_queue_add('syndic_a_jour','syndic_a_jour',array($id_syndic),'genie/syndic',true);
+	$id_job = job_queue_add('syndic_a_jour', 'syndic_a_jour', array($id_syndic), 'genie/syndic', true);
 	// l'executer immediatement si possible
 	if ($id_job) {
 		include_spip('inc/queue');
 		queue_schedule(array($id_job));
-	}
-	else {
-		spip_log("Erreur insertion syndic_a_jour($id_syndic) dans la file des travaux",_LOG_ERREUR);
+	} else {
+		spip_log("Erreur insertion syndic_a_jour($id_syndic) dans la file des travaux", _LOG_ERREUR);
 	}
 
 }
-
-?>
\ No newline at end of file
