@@ -10,14 +10,16 @@
  *  Pour plus de details voir le fichier COPYING.txt ou l'aide en ligne.   *
 \***************************************************************************/
 
-if (!defined("_ECRIRE_INC_VERSION")) return;	#securite
+if (!defined("_ECRIRE_INC_VERSION")) {
+	return;
+}  #securite
 
 // Le contexte indique dans quelle rubrique le visiteur peut proposer le site
 
 
 // http://code.spip.net/@balise_FORMULAIRE_SITE
-function balise_FORMULAIRE_SITE ($p) {
-  return calculer_balise_dynamique($p,'FORMULAIRE_SITE', array('id_rubrique'));
+function balise_FORMULAIRE_SITE($p) {
+	return calculer_balise_dynamique($p, 'FORMULAIRE_SITE', array('id_rubrique'));
 }
 
 // http://code.spip.net/@balise_FORMULAIRE_SITE_stat
@@ -25,15 +27,19 @@ function balise_FORMULAIRE_SITE_stat($args, $context_compil) {
 
 	// Pas d'id_rubrique ? Erreur de contexte
 	if (!$args[0]) {
-		$msg = array('zbug_champ_hors_motif',
-				array ('champ' => 'FORMULAIRE_SITE',
-					'motif' => 'RUBRIQUES'));
+		$msg = array(
+			'zbug_champ_hors_motif',
+			array(
+				'champ' => 'FORMULAIRE_SITE',
+				'motif' => 'RUBRIQUES'
+			)
+		);
 		erreur_squelette($msg, $context_compil);
+
 		return '';
 	}
+
 	// Verifier que les visisteurs sont autorises a proposer un site
 
 	return (($GLOBALS['meta']["proposer_sites"] != 2) ? '' : $args);
 }
-
-?>
