@@ -10,13 +10,15 @@
  *  Pour plus de details voir le fichier COPYING.txt ou l'aide en ligne.   *
 \***************************************************************************/
 
-if (!defined("_ECRIRE_INC_VERSION")) return;
-
-function liens_implicite_site_dist($texte,$id,$type,$args,$ancre,$connect=''){
-	if (!$id = intval($id))
-		return false;
-	$url = sql_getfetsel('url_site', 'spip_syndic', "id_syndic=".intval($id),'','','','',$connect);
-	return $url;
+if (!defined("_ECRIRE_INC_VERSION")) {
+	return;
 }
 
-?>
\ No newline at end of file
+function liens_implicite_site_dist($texte, $id, $type, $args, $ancre, $connect = '') {
+	if (!$id = intval($id)) {
+		return false;
+	}
+	$url = sql_getfetsel('url_site', 'spip_syndic', "id_syndic=" . intval($id), '', '', '', '', $connect);
+
+	return $url;
+}
