@@ -10,19 +10,22 @@
  *  Pour plus de details voir le fichier COPYING.txt ou l'aide en ligne.   *
 \***************************************************************************/
 
-if (!defined('_ECRIRE_INC_VERSION')) return;
+if (!defined('_ECRIRE_INC_VERSION')) {
+	return;
+}
 
 /**
  * Un test sur les articles syndiques
  * pour "depublier les items qui ne figurent plsu dans le flux"
+ *
  * @global <type> $my_sites
  * @param <type> $id
  * @return <type>
  */
-function filtre_test_syndic_article_miroir_dist($id){
-	if (isset($GLOBALS['my_sites'][$id]['miroir']) AND $GLOBALS['my_sites'][$id]['miroir'] == 'oui')
+function filtre_test_syndic_article_miroir_dist($id) {
+	if (isset($GLOBALS['my_sites'][$id]['miroir']) and $GLOBALS['my_sites'][$id]['miroir'] == 'oui') {
 		return ' ';
+	}
+
 	return '';
 }
-
-?>
\ No newline at end of file
