@@ -3,12 +3,14 @@
 // extrait automatiquement de http://trad.spip.net/tradlang_module/paquet-squelettes_par_rubrique?lang_cible=ru
 // ** ne pas modifier le fichier **
 
-if (!defined('_ECRIRE_INC_VERSION')) return;
+if (!defined('_ECRIRE_INC_VERSION')) {
+	return;
+}
 
 $GLOBALS[$GLOBALS['idx_lang']] = array(
 
 	// S
-	'squelettes_par_rubrique_description' => 'Позволяет задавать отдельные шаблоны по номеру раздела, статьи, а так же языковой версии : (-23.html, =23.html, и .en.html)',
+	'squelettes_par_rubrique_description' => 'Позволяет задавать отдельные шаблоны по номеру раздела, статьи, а также языковой версии: (-23.html, =23.html, и .en.html)',
 	'squelettes_par_rubrique_slogan' => 'Номерные шаблоны для SPIP'
 );
 
