@@ -10,7 +10,9 @@
  *  Pour plus de details voir le fichier COPYING.txt ou l'aide en ligne.   *
 \***************************************************************************/
 
-if (!defined("_ECRIRE_INC_VERSION")) return; // securiser
+if (!defined("_ECRIRE_INC_VERSION")) {
+	return;
+} // securiser
 
 // faudrait plutot recuperer dans inc_serialbase et inc_auxbase
 // mais il faudra prevenir ceux qui affectent les globales qui s'y trouvent
@@ -19,21 +21,22 @@ if (!defined("_ECRIRE_INC_VERSION")) return; // securiser
 
 /**
  * Supprimer les stats
+ *
  * @param strinf $titre
  * @param bool $reprise
  * @return string
  */
-function base_delete_stats_dist($titre='', $reprise='')
-{
-	if (!$titre) return; // anti-testeur automatique
+function base_delete_stats_dist($titre = '', $reprise = '') {
+	if (!$titre) {
+		return;
+	} // anti-testeur automatique
 	sql_delete("spip_visites");
 	sql_delete("spip_visites_articles");
 	sql_delete("spip_referers");
 	sql_delete("spip_referers_articles");
-	sql_update("spip_articles", array('visites'=>0, 'referers'=>0, 'popularite'=>0));
+	sql_update("spip_articles", array('visites' => 0, 'referers' => 0, 'popularite' => 0));
 
 	// un pipeline pour detruire les tables de stats installees par les plugins
 	pipeline('delete_statistiques', '');
 	spip_log("raz des stats operee redirige vers " . _request('redirect'));
 }
-?>
