@@ -10,21 +10,25 @@
  *  Pour plus de details voir le fichier COPYING.txt ou l'aide en ligne.   *
 \***************************************************************************/
 
-if (!defined("_ECRIRE_INC_VERSION")) return;
+if (!defined("_ECRIRE_INC_VERSION")) {
+	return;
+}
 
 
-function exec_base_delete_stats_dist()
-{
+function exec_base_delete_stats_dist() {
 	include_spip('inc/autoriser');
-	if (!autoriser('detruire','_statistiques')) {
+	if (!autoriser('detruire', '_statistiques')) {
 		include_spip('inc/minipres');
 		echo minipres();
 	} else {
 		include_spip('inc/headers');
 		$admin = charger_fonction('admin', 'inc');
 		$res = $admin('delete_stats', _T('statistiques:bouton_effacer_statistiques'), '');
-		if ($res) echo $res; else redirige_url_ecrire('stats_visites','');
-		
+		if ($res) {
+			echo $res;
+		} else {
+			redirige_url_ecrire('stats_visites', '');
+		}
+
 	}
 }
-?>
