@@ -10,29 +10,34 @@
  *  Pour plus de details voir le fichier COPYING.txt ou l'aide en ligne.   *
 \***************************************************************************/
 
-if (!defined("_ECRIRE_INC_VERSION")) return;
+if (!defined("_ECRIRE_INC_VERSION")) {
+	return;
+}
 
 /**
  * Calculer la moyenne glissante sur un nombre d'echantillons donnes
+ *
  * @param int|bool $valeur
  * @param int $glisse
  * @return float
  */
-function moyenne_glissante($valeur = false, $glisse=0) {
+function moyenne_glissante($valeur = false, $glisse = 0) {
 	static $v = array();
 	// pas d'argument, raz de la moyenne
 	if ($valeur === false) {
 		$v = array();
+
 		return 0;
 	}
 
 	// argument, on l'ajoute au tableau...
 	// surplus, on enleve...
 	$v[] = $valeur;
-	if (count($v) > $glisse)
+	if (count($v) > $glisse) {
 		array_shift($v);
+	}
 
-	return round(statistiques_moyenne($v),2);
+	return round(statistiques_moyenne($v), 2);
 }
 
 /**
@@ -43,28 +48,34 @@ function moyenne_glissante($valeur = false, $glisse=0) {
  * @param array $tab
  * @return float
  */
-function statistiques_moyenne($tab){
-	if (!$tab) return 0;
+function statistiques_moyenne($tab) {
+	if (!$tab) {
+		return 0;
+	}
 	$moyenne = 0;
-	foreach($tab as $v) $moyenne += $v;
-	return  $moyenne / count($tab);
+	foreach ($tab as $v) {
+		$moyenne += $v;
+	}
+
+	return $moyenne / count($tab);
 }
 
 /**
  * Construire un tableau par popularite
  *   classemnt => id_truc
+ *
  * @param string $type
  * @param string $serveur
  * @return array
  */
-function classement_populaires($type, $serveur=''){
+function classement_populaires($type, $serveur = '') {
 	static $classement = array();
-	if (isset($classement[$type]))
+	if (isset($classement[$type])) {
 		return $classement[$type];
-	$classement[$type] = sql_allfetsel(id_table_objet($type, $serveur), table_objet_sql($type, $serveur), "statut='publie' AND popularite > 0", "", "popularite DESC",'','',$serveur);
-	$classement[$type] = array_map('reset',$classement[$type]);
+	}
+	$classement[$type] = sql_allfetsel(id_table_objet($type, $serveur), table_objet_sql($type, $serveur),
+		"statut='publie' AND popularite > 0", "", "popularite DESC", '', '', $serveur);
+	$classement[$type] = array_map('reset', $classement[$type]);
+
 	return $classement[$type];
 }
-
-
-?>
