@@ -3,10 +3,29 @@
 // extrait automatiquement de http://trad.spip.net/tradlang_module/statistiques?lang_cible=ar
 // ** ne pas modifier le fichier **
 
-if (!defined('_ECRIRE_INC_VERSION')) return;
+if (!defined('_ECRIRE_INC_VERSION')) {
+	return;
+}
 
 $GLOBALS[$GLOBALS['idx_lang']] = array(
 
+	// A
+	'archiver' => 'أرشفة',
+	'archiver_concatener_explications' => 'ستقوم هذه العملية بتجميع إحصاءات زيارات المقالات:',
+	'archiver_concatener_ignorer' => 'الزيارات الاحدث من @nb@ سنة لن تتأثر.',
+	'archiver_concatener_par_an' => 'سيتم تجميع الزيارات الأقدم من @nb@ سنة، لكل مقال، في اول يوم من كل سنة.',
+	'archiver_concatener_par_mois' => 'سيتم تجميع الزيارات الأقدم من @nb@ سنة، لكل مقال، في اليوم الأول من كل شهر.',
+	'archiver_conseil_sauvegarde' => 'ينصح في البداية بإنشاء نسخة احتياطية من قاعدة البيانات.',
+	'archiver_description' => 'توفر هذه الصفحة أدوات لتنظيف او أرشفة إحصاءات الموقع.',
+	'archiver_et_nettoyer' => 'أرشفة وتنظيف',
+	'archiver_nettoyer' => 'تنظيف',
+	'archiver_nettoyer_explications' => 'يحذف اسطر «المصادر» او «الزيارات» العائدة الى مقالات غير موجودة (او محذوفة) في قاعدة البيانات.',
+	'archiver_nettoyer_referers_articles' => 'تنظيف مصادر المقالات referers_articles',
+	'archiver_nettoyer_visites_articles' => 'تنظيف زيارات المقالات visites_articles',
+	'archiver_nombre_lignes' => 'عدد الاسطر',
+	'archiver_operation_longue' => 'يمكن ان تستغرق هذه العملية وقتاً طويلاً، خاصة لدي تنفيذها للمرة الاولي.',
+	'archiver_operations_irreversibles' => 'لا يمكن التراجع عن هذه العمليات!',
+
 	// B
 	'bouton_effacer_referers' => 'حذف الوصلات الداخلة الآتية',
 	'bouton_effacer_statistiques' => 'حذف كل الاحصاءات',
@@ -22,12 +41,14 @@ $GLOBALS[$GLOBALS['idx_lang']] = array(
 	'info_affichier_visites_articles_plus_visites' => 'إظهار الزيارات المتعلقة <b> بأكثر المقالات زيارة منذ البداية:</ b>',
 	'info_comment_lire_tableau' => 'كيفية قراءة هذا الرسم البياني',
 	'info_forum_statistiques' => 'إحصاءات الزيارات',
+	'info_graphiques' => 'الرسوم البيانية',
 	'info_popularite_2' => 'شعبية الموقع:',
 	'info_popularite_3' => 'الشعبية: @popularite@؛ الزيارات: @visites@',
 	'info_popularite_5' => 'الشعبية:',
 	'info_previsions' => 'توقعات:',
 	'info_question_vignettes_referer' => 'عندما تعاين الاحضاءات، يمكنك ايضاً مشاهدة مصغرات عن المواقع الصادرة منها.',
 	'info_question_vignettes_referer_oui' => 'عرض مصغرات عن مواقع مصدر الزيارات',
+	'info_tableaux' => 'الجداول',
 	'info_visites' => 'زيارة:',
 	'info_visites_plus_populaires' => 'إظهار الزيارات <b>لأكثر المقالات شعبية</b> و<b>لأحدث المقالات المنشورة:</ b>',
 	'info_zoom' => 'تكبير-تصغير العرض',
