@@ -3,7 +3,9 @@
 // extrait automatiquement de http://trad.spip.net/tradlang_module/svp?lang_cible=es
 // ** ne pas modifier le fichier **
 
-if (!defined('_ECRIRE_INC_VERSION')) return;
+if (!defined('_ECRIRE_INC_VERSION')) {
+	return;
+}
 
 $GLOBALS[$GLOBALS['idx_lang']] = array(
 
@@ -34,6 +36,7 @@ $GLOBALS[$GLOBALS['idx_lang']] = array(
 	'bulle_actualiser_tout_depot' => 'Actualizar los paquetes de todos los repositorios',
 	'bulle_afficher_xml_plugin' => 'Contenido del archivo XML del plugin',
 	'bulle_ajouter_spipzone' => 'Añadir el repositorio SPIP-Zone',
+	'bulle_aller_demonstration' => 'Ir a la página de demostración',
 	'bulle_aller_depot' => 'Ir a la página de este repositorio ',
 	'bulle_aller_documentation' => 'Se dirige a la página de documentación',
 	'bulle_aller_plugin' => 'Se dirige a la página del plugin',
@@ -62,31 +65,32 @@ $GLOBALS[$GLOBALS['idx_lang']] = array(
 	'config_activer_log_verbeux_explication' => 'Esta opción genera logs de SVP mucho más locuaces...',
 	'config_activer_pas_a_pas' => '¿Activar el modo paso a paso?',
 	'config_activer_pas_a_pas_explication' => 'Activar este modo permite mostrar información sobre los resultados de la acción después de que se completa cada paso, en lugar de mostrar conjuntamente el resultado global de todas las acciones al finalizar el proceso solicitado.',
-	'config_activer_runtime' => '¿Activer el modo runtime ?',
-	'config_activer_runtime_explication' => 'El modo runtime (si) carga únicamente los plugins compatibles con la versión de SPIP que estás utilizando, lo que es altamente recomendado para la mayoría de los usuarios. En el modo no-runtime (non) son cargados todos los plugins de un repositorio, cualquiera sea la versión de SPIP que estés utilizando. Esto es útil únicamente para utilizar SVP con el propósito de presentar todos los plugins existentes, como lo hace el sitio Plugins SPIP (plugins.spip.net)',
+	'config_activer_runtime' => '¿Activar el modo runtime?',
+	'config_activer_runtime_explication' => 'El modo runtime (si) carga únicamente los plugins compatibles con la versión de SPIP que estás utilizando, lo que es altamente recomendado para la mayoría de los usuarios. En el modo no-runtime (non) son cargados todos los plugins de un repositorio, cualquiera sea la versión de SPIP que esté utilizando. Esto es útil únicamente para utilizar SVP con el propósito de presentar todos los plugins existentes, como lo hace el sitio Plugins SPIP (plugins.spip.net)',
 	'config_autoriser_activer_paquets_obsoletes' => '¿Autorizar la activación de los paquetes obsoletos?',
 	'config_autoriser_activer_paquets_obsoletes_explication' => 'Los paquetes obsoletos son paquetes locales que son más antiguos que otros paquetes existentes a nivel local. La obsolescencia es determinada sobre la base del estado (estable, en prueba, en desarrollo) del paquete, así como en función de su versión. Activa esta opción si deseas conservar la capacidad de activar estos plugins obsoletos. ',
 	'config_depot_editable' => '¿Permitir la edición de los repositorios?',
-	'config_depot_editable_explication' => 'Esto permite que la información de un repositorio puedan ser modificada y que se le pueda asignar palabras clave o documentos. ¡Esta opción no debería interesarle a nadie! ¡Es preferible dejarla establecida en "no"!',
-	'confirmer_telecharger_dans' => 'El plugin será cargado en una carpeta (@dir@) que ya existe. Esta acción  eliminará el contenido actual de dicha carpeta. Una copia de los contenidos actuales será guardado en "@dir_backup@". Debes confirmar esta acción.',
+	'config_depot_editable_explication' => 'Esto permite que la información de un repositorio pueda ser modificada y que se le pueda asignar palabras clave o documentos. ¡Esta opción no debería interesarle a nadie! Es preferible dejarla establecida en "no"',
+	'confirmer_desinstaller' => 'Atención, la desinstalación de un plugin <b>borra</b> sus datos de la base y es irreversible.<br />Si no está seguro, desactive simplemente el plugin.',
+	'confirmer_telecharger_dans' => 'El plugin será cargado en una carpeta (@dir@) que ya existe. Esta acción  eliminará el contenido actual de dicha carpeta. Una copia de los contenidos actuales será guardado en "@dir_backup@". Debe confirmar esta acción.',
 
 	// E
 	'erreur_actions_non_traitees' => 'Ciertas acciones no fueron realizadas. Esto puede provenir de un error durante las acciones por realizar, o de la activación de esta página mientras las acciones aún están en curso. Las acciones fueron lanzadas por @auteur@ el @date@.',
 	'erreur_auth_plugins_ajouter_lib' => 'No dispone de los derechos necesarios para añadir una biblioteca.',
-	'erreur_dir_dib_ecriture' => 'El reprertorio de las bibliotecas @dir@ no está accesible en escritura. ¡Imposible cargar en él una biblioteca!',
-	'erreur_dir_dib_indefini' => 'El repertorio _DIR_LIB no está définido. ¡Imposible cargar una biblioteca!',
-	'erreur_dir_plugins_auto' => 'El repertorio «plugins/auto» que permite desargar paquetes no está creado o no tenemos acceso en escritura 		<strong>Tienes que crearlo para poder instalar nuevos plugins desde esta interfaz.</strong>',
-	'erreur_dir_plugins_auto_ecriture' => 'El repertorio de paquetes @dir@ no está accesible en escritura. ¡Imposible cargar en él un paquete!',
-	'erreur_dir_plugins_auto_indefini' => 'La carpeta _DIR_PLUGIN_AUTO no está definida. No es posible cargar el paquete! ',
-	'erreur_dir_plugins_auto_titre' => 'No se puede acceder a "plugins/auto"!',
+	'erreur_dir_dib_ecriture' => 'El repertorio de las bibliotecas @dir@ no es accesible en escritura. ¡Imposible cargar en él una biblioteca!',
+	'erreur_dir_dib_indefini' => 'El directorio _DIR_LIB no está définido. ¡Imposible cargar una biblioteca!',
+	'erreur_dir_plugins_auto' => 'El directorio «plugins/auto» que permite descargar paquetes no está creado o no tenemos acceso en escritura 		<strong>Debe crearlo para poder instalar nuevos plugins desde esta interfaz.</strong>',
+	'erreur_dir_plugins_auto_ecriture' => 'El directorio de paquetes @dir@ no está accesible en escritura. ¡Imposible cargar en él un paquete!',
+	'erreur_dir_plugins_auto_indefini' => 'La carpeta _DIR_PLUGIN_AUTO no está definida. ¡No es posible cargar el paquete! ',
+	'erreur_dir_plugins_auto_titre' => '¡No se puede acceder a "plugins/auto"!',
 	'erreur_teleporter_chargement_source_impossible' => 'Descarga imposible desde la fuente @source@',
 	'erreur_teleporter_destination_erreur' => 'Carpeta @dir@ no accesible para subir archivos',
 	'erreur_teleporter_echec_deballage_archive' => 'No se puede descomprimir  @fichier@',
-	'erreur_teleporter_format_archive_non_supporte' => 'El formato @extension@ no está soportado por el teleportador',
+	'erreur_teleporter_format_archive_non_supporte' => 'El teleportador no soporta el formato @extension@  ',
 	'erreur_teleporter_methode_inconue' => 'Método @methode@ desconocido para teleportar',
 	'erreur_teleporter_type_fichier_inconnu' => 'Tipo de archivo desconocido para  @source@',
 	'erreurs_xml' => 'Imposible leer ciertas descripciones XML',
-	'explication_destination' => 'El camino será calculado a partir del nombre de archivos, si no se lo ingresa.',
+	'explication_destination' => 'El camino será calculado a partir del nombre del archivo, si no lo indica.',
 
 	// F
 	'fieldset_debug' => 'Depurar',
@@ -105,24 +109,24 @@ $GLOBALS[$GLOBALS['idx_lang']] = array(
 	'info_admin_plugin_verrou_tous' => 'Esta página muestra todos los plugins del sitio.',
 	'info_admin_plugin_verrouille' => 'Esta página lista los plugins activos y bloqueados (situados en la carpeta <code>@dir_plugins_dist@</code>). Si quiere desactivarlos, contacte al administrador del sitio, o consulte <a href="http://programmer.spip.net/repertoire_plugins-dist">la documentación</a>.',
 	'info_adresse_spipzone' => 'SPIP-Zone - Plugins',
-	'info_ajouter_depot' => 'Agregando repositorios a tu base, tendrás la posibilidad de obtener información y realizar búsquedas sobre todos los paquetes hospedados en los repositorios agregados.<br />Un repositorio se describe por un archivo XML que contiene informaciones sobre el repositorio y todos sus paquetes.',
+	'info_ajouter_depot' => 'Agregando repositorios a su base, tendrá la posibilidad de obtener información y realizar búsquedas sobre todos los paquetes alojados en los repositorios agregados.<br />Un repositorio se describe por un archivo XML que contiene informaciones sobre el repositorio y todos sus paquetes.',
 	'info_aucun_depot' => 'ningún repositorio',
 	'info_aucun_depot_ajoute' => '¡Ningún repositorio disponible!<br /> Utiliza el formulario a continuación para agregar el repositorio «SPIP-Zone - Plugins» cuya URL ya está pre-ingresada u otro repositorio de tu elección.',
 	'info_aucun_paquet' => 'ningún paquete',
 	'info_aucun_plugin' => 'ningún plugin',
-	'info_boite_charger_plugin' => '<strong>Esta página sólo es accesible a los webmestres del sitio.</strong><p>Te permite buscar plugins a disposición en los depósitos registrados en la configuración del sitio e instalarlos físicamente en tu servidor.</p>',
-	'info_boite_depot_gerer' => '<strong>Esta página sólo es accesible a los webmestres del sitio.</strong><p>Perrmite agregar o actualizar los depósitos de plugins.</p>',
-	'info_charger_plugin' => 'Para agregar uno o varios plugins, realiza primero una búsqueda multi-criterios entre los plugins de la galaxia SPIP. La búsqueda solo incluirá los plugins compatibles con la versión SPIP instalada, y señala los plugins que ya están activados en el sitio.',
+	'info_boite_charger_plugin' => '<strong>Esta página sólo es accesible a los administradores del sitio.</strong><p>Le permite buscar plugins puestos a disposición en los repositorios registrados en la configuración del sitio e instalarlos físicamente en su servidor.</p>',
+	'info_boite_depot_gerer' => '<strong>Esta página sólo es accesible a los administradores del sitio.</strong><p>Permite agregar o actualizar los repositorios de plugins.</p>',
+	'info_charger_plugin' => 'Para agregar uno o varios plugins, realice primero una búsqueda multi-criterios entre los plugins de la galaxia SPIP. La búsqueda solamente incluirá los plugins compatibles con la versión SPIP instalada, y señala los plugins que ya están activados en el sitio.',
 	'info_compatibilite_dependance' => 'Para @compatibilite@:',
-	'info_contributions_hebergees' => '@total_autres@ otra(s) contribución(es) hospedada(s)',
-	'info_critere_phrase' => 'Ingresa las palabras clave que quieres buscar en el prefijo, el nombre, el eslogan, la descripción y los autores de los plugins',
+	'info_contributions_hebergees' => '@total_autres@ otra(s) contribución(es) alojada(s)',
+	'info_critere_phrase' => 'Ingrese las palabras clave que quiere buscar en el prefijo, el nombre, el eslogan, la descripción y los autores de los plugins',
 	'info_depots_disponibles' => '@total_depots@ repositorio(s)',
-	'info_fichier_depot' => 'Ingresa la URL del archivo de descripción del repositorio para agregar.<br />Para agregar el repositorio «SPIP-Zone - Plugins» visita el siguiente enlace: ',
+	'info_fichier_depot' => 'Ingrese la URL del archivo de descripción del repositorio a agregar.<br />Para agregar el repositorio «SPIP-Zone - Plugins» visite el siguiente enlace: ',
 	'info_nb_depots' => '@nb@ repositorios',
 	'info_nb_paquets' => '@nb@ paquetes',
 	'info_nb_plugins' => '@nb@ plugins',
 	'info_paquets_disponibles' => '@total_paquets@ paquete(s) disponible(s)',
-	'info_plugin_attente_dependance' => 'dependencias faltantes',
+	'info_plugin_attente_dependance' => 'dependencias ausentes',
 	'info_plugin_incompatible' => 'versión incompatible',
 	'info_plugin_installe' => 'ya instalado',
 	'info_plugin_obsolete' => 'versión obsoleta',
@@ -148,7 +152,7 @@ $GLOBALS[$GLOBALS['idx_lang']] = array(
 	'label_critere_doublon' => 'Compatibilidad',
 	'label_critere_etat' => 'Estados',
 	'label_critere_phrase' => 'Buscar en los plugins',
-	'label_destination' => 'Ruta del directorio « auto » donde subir el plugin',
+	'label_destination' => 'Ruta del directorio «auto» donde subir el plugin',
 	'label_modifie_le' => 'Modificado el',
 	'label_n_autres_contributions' => 'otras contribuciones',
 	'label_prefixe' => 'Prefijo',
@@ -166,18 +170,20 @@ $GLOBALS[$GLOBALS['idx_lang']] = array(
 	'label_xml_plugin' => 'XML',
 	'legende_installer_plugins' => 'Instalar plugins',
 	'legende_rechercher_plugins' => 'Buscar plugins',
+	'lien_demo' => 'Demostración',
+	'lien_documentation' => 'Documentación',
 
 	// M
 	'message_action_finale_get_fail' => 'El plugin "@plugin@" (versión: @version@) no ha podido ser recuperado correctamente',
-	'message_action_finale_get_ok' => 'El plugin "@plugin@" (versión: @version@) ha sido recuperado exitosamente',
+	'message_action_finale_get_ok' => 'El plugin "@plugin@" (versión: @version@) ha sido recuperado correctamente',
 	'message_action_finale_getlib_fail' => 'La instalación de la biblioteca "@plugin@" ha fallado',
 	'message_action_finale_getlib_ok' => 'La biblioteca "@plugin@" ha sido instalada',
-	'message_action_finale_geton_fail' => 'La descarga o la activación del  plugin "@plugin@"  (versión: @version@) no se han  efectuado correctamente',
-	'message_action_finale_geton_ok' => 'La descarga y la activación del plugin "@plugin@" (versión: @version@) se ejecutaron exitosamente.',
-	'message_action_finale_install_fail' => 'La instalación del plugin  "@plugin@" (versión : @version@) ha fallado',
-	'message_action_finale_install_ok' => 'La instalación del plugin "@plugin@" (versión : @version@) se ha ejecutado exitosamente',
+	'message_action_finale_geton_fail' => 'La descarga o la activación del  plugin "@plugin@"  (versión: @version@) no se ha efectuado correctamente',
+	'message_action_finale_geton_ok' => 'La descarga y la activación del plugin "@plugin@" (versión: @version@) se ha ejecutado correctamente',
+	'message_action_finale_install_fail' => 'La instalación del plugin  "@plugin@" (versión: @version@) ha fallado',
+	'message_action_finale_install_ok' => 'La instalación del plugin "@plugin@" (versión: @version@) se ha ejecutado correctamente',
 	'message_action_finale_kill_fail' => 'Los archivos del plugin "@plugin@" (versión: @version@) no han podido ser correctamente eliminados',
-	'message_action_finale_kill_ok' => 'Los archivos del plugin "@plugin@" (versión: @version@) han sido eliminados exitosamente',
+	'message_action_finale_kill_ok' => 'Los archivos del plugin "@plugin@" (versión: @version@) han sido eliminados correctamente',
 	'message_action_finale_off_fail' => 'La desactivación del plugin "@plugin@" (versión: @version@) no se ha completado correctamente',
 	'message_action_finale_off_ok' => 'La desactivación del plugin "@plugin@" (versión: @version@) se ha ejecutado exitosamente',
 	'message_action_finale_on_fail' => 'La activación del plugin "@plugin@" (versión: @version@) no se ha completado correctamente',
@@ -185,9 +191,9 @@ $GLOBALS[$GLOBALS['idx_lang']] = array(
 	'message_action_finale_stop_fail' => 'La desinstalación del plugin "@plugin@" (versión: @version@) no se ha completado correctamente',
 	'message_action_finale_stop_ok' => 'La desinstalación del plugin "@plugin@" (versión: @version@) se ha ejecutado exitosamente',
 	'message_action_finale_up_fail' => 'La actualización del plugin "@plugin@" (de la versión  @version@ a la @version_maj@) no se ha completado correctamente',
-	'message_action_finale_up_ok' => 'La actualización del "@plugin@" (de la versión @version@ a la  @version_maj@) se ha ejecutado exitosamente',
+	'message_action_finale_up_ok' => 'La actualización del "@plugin@" (de la versión @version@ a la  @version_maj@) se ha ejecutado correctamente',
 	'message_action_finale_upon_fail' => 'La actualización y la activación del plugin "@plugin@" (de la versión @version@ a la @version_maj@) no se ha completado correctamente',
-	'message_action_finale_upon_ok' => 'La actualización y la activación del plugin "@plugin@" (de la versión @version@ a la @version_maj@) se ha completado exitosamente',
+	'message_action_finale_upon_ok' => 'La actualización y la activación del plugin "@plugin@" (de la versión @version@ a la @version_maj@) se ha completado correctamente',
 	'message_action_get' => 'Descargar el plugin "@plugin@"  (versión: @version@)',
 	'message_action_getlib' => 'Descargar la biblioteca "<a href="@version@" class="spip_out">@plugin@</a>"',
 	'message_action_geton' => 'Descargar y activar el plugin "@plugin@" (versión: @version@)',
@@ -201,25 +207,26 @@ $GLOBALS[$GLOBALS['idx_lang']] = array(
 	'message_dependance_plugin' => 'El plugin @plugin@ depende de @dependance@.',
 	'message_dependance_plugin_version' => 'El plugin @plugin@ depende de @dependance@ @version@',
 	'message_erreur_aucun_plugin_selectionne' => 'No se ha seleccionado ningún plugin.',
-	'message_erreur_ecriture_lib' => '@plugin@ necesita la biblioteca <a href="@lib_url@">@lib@</a> situada en la carpeta <var>lib/</var> en la raíz de tu sitio. Sin embargo, esta carpeta no existe o no está accesible en escritura. Tienes que instalarla manualmente o dar derechos a esta carpeta al servidor web.',
+	'message_erreur_ecriture_lib' => '@plugin@ necesita la biblioteca <a href="@lib_url@">@lib@</a> situada en la carpeta <var>lib/</var> en la raíz de su sitio. Sin embargo, esta carpeta no existe o no está accesible en escritura. Tiene que instalarla manualmente o crear este repertorio dándole derechos de escritura.',
 	'message_erreur_maj_inconnu' => 'No se puede actualizar un plugin desconocido.',
 	'message_erreur_plugin_introuvable' => 'No fue posible encontrar el plugin @plugin@ para @action@.',
 	'message_erreur_plugin_non_actif' => 'No se puede desactivar un plugin inactivo.',
-	'message_incompatibilite_spip' => '@plugin@  no es compatible con la versión de SPIP que estás utilizando.',
-	'message_nok_aucun_depot_disponible' => '¡Ningún plugin está disponible! Puedes dirigirte a la página de gestión de los depósitos para agregar listas de plugins.',
+	'message_incompatibilite_spip' => '@plugin@  no es compatible con la versión de SPIP que está utilizando.',
+	'message_nok_aucun_depot_disponible' => '¡Ningún plugin está disponible! Puede dirigirte a la página de gestión de los depósitos para agregar listas de plugins.',
 	'message_nok_aucun_paquet_ajoute' => 'El repositorio «@url@» no proporciona ningún nuevo paquete respecto a la base que ya estaba registrada. Por ende, no fue agregado. ',
-	'message_nok_aucun_plugin_selectionne' => 'No hay plugins a instalar. Selecciona los plugins que deseas instalar',
+	'message_nok_aucun_plugin_selectionne' => 'No hay plugins a instalar. Seleccione los plugins que desee instalar',
 	'message_nok_champ_obligatoire' => 'Este campo es requerido',
 	'message_nok_depot_deja_ajoute' => 'La dirección "@url@" corresponde a un repositorio que ya ha sido añadido',
 	'message_nok_maj_introuvable' => 'No fue posible encontrar la actualización del plugin @plugin@.',
 	'message_nok_plugin_inexistant' => 'El plugin solicitado no existe  (@plugin@).',
-	'message_nok_sql_insert_depot' => 'Se obtuvo un error SQL al intentar añadir el repositorio  @objet@',
+	'message_nok_sql_insert_depot' => 'Error SQL al intentar añadir el repositorio  @objet@',
+	'message_nok_url_archive' => 'La URL del archivo es inválida',
 	'message_nok_url_depot_incorrecte' => 'La dirección "@url@" no es correcta',
 	'message_nok_xml_non_conforme' => 'El archivo XML « @fichier@ » de descripción del repositorio no es conforme',
 	'message_nok_xml_non_recupere' => 'El archivo XML «@fichier@» no ha podido recuperarse',
 	'message_ok_aucun_plugin_trouve' => 'No hay plugins coincidentes con los criterios señalados.',
 	'message_ok_depot_ajoute' => 'El repositorio "@url@" ha sido añadido.',
-	'message_ok_plugins_trouves' => '@nb_plugins@ plugin(s) coinciden con los criterios de búsqueda señalados (@tri@). Selecciona debajo los plugins que deseas descargar y activar en tu servidor.',
+	'message_ok_plugins_trouves' => '@nb_plugins@ plugin(s) coinciden con los criterios de búsqueda señalados (@tri@). Seleccione a continuación los plugins que desee descargar y activar en tu servidor.',
 	'message_telechargement_archive_effectue' => 'El archivo ha sido descomprimido exitosamente en @dir@.',
 
 	// N
@@ -248,14 +255,14 @@ $GLOBALS[$GLOBALS['idx_lang']] = array(
 	'resume_table_plugins' => 'Lista de plugins @categorie@',
 
 	// T
-	'telecharger_archive_plugin_explication' => 'Puedes subir un archivo que será cargado en la carpeta «plugins/auto» del sitio, escribiendo la URL del archivo en el campo de ingreso.',
+	'telecharger_archive_plugin_explication' => 'Puede subir un archivo que será cargado en la carpeta «plugins/auto» del sitio, escribiendo la URL del archivo en el campo de entrada.',
 	'titre_depot' => 'Repositorio',
 	'titre_depots' => 'Repositorios',
 	'titre_form_ajouter_depot' => 'Añadir un repositorio',
 	'titre_form_charger_plugin' => 'Buscar y añadir plugins',
 	'titre_form_charger_plugin_archive' => 'Descargar un plugin desde su archivo',
 	'titre_form_configurer_svp' => 'Configurar el Servidor de Plugins',
-	'titre_liste_autres_contributions' => 'Esqueletos, bibliotecas, paquetes de íconos...',
+	'titre_liste_autres_contributions' => 'Esqueletos, bibliotecas, paquetes de iconos...',
 	'titre_liste_autres_depots' => 'Otros repositorios',
 	'titre_liste_depots' => 'Lista de los repositorios  disponibles',
 	'titre_liste_paquets_plugin' => 'Lista de los paquetes del plugin',
