@@ -3,7 +3,9 @@
 // extrait automatiquement de http://trad.spip.net/tradlang_module/svp?lang_cible=it
 // ** ne pas modifier le fichier **
 
-if (!defined('_ECRIRE_INC_VERSION')) return;
+if (!defined('_ECRIRE_INC_VERSION')) {
+	return;
+}
 
 $GLOBALS[$GLOBALS['idx_lang']] = array(
 
@@ -68,7 +70,7 @@ $GLOBALS[$GLOBALS['idx_lang']] = array(
 	'config_autoriser_activer_paquets_obsoletes_explication' => 'Pacchetti obsoleti sono pacchetti locali che sono più vecchi rispetto agli altri pacchetti locali. L’obsolescenza di un pacchetto è stabilita sulla base dello stato (stable, testing, dev) del pacchetto e in base della sua versione. Attivare questa opzione se si vuole attivare questi plugin obsoleti.',
 	'config_depot_editable' => 'Consentire la modifica dei repository?',
 	'config_depot_editable_explication' => 'Questo rende modificabili le informazioni di un repository e abilitata eventualmente l’associazione di parole chiave o documenti ad esso. Questa opzione non dovrebbe interessanre nessuno! Quindi lasciate "no"!',
-	'confirmer_desinstaller' => 'Attenzione, la disinstallazione di un plug-in ne <b>cancella</b> i dati dal database ed è irreversibile.<br />Se non sei sicuro, disattiva semplicemente il plug-in.',
+	'confirmer_desinstaller' => 'Attenzione, la disinstallazione di un plug-in ne <b>cancella</b> i dati dal database ed è irreversibile.<br />Se non sei sicuro, disattiva semplicemente il plug-in.', # MODIF
 	'confirmer_telecharger_dans' => 'Il plugin sarà caricato nella directory (@dir@) che esiste già.
 Questo sovrascriverà il contenuto della directory.
 Una copia dei vecchi file saranno salvati in "@dir_backup@".
@@ -173,6 +175,8 @@ Se vuoi disabilitarla, per favore contatta il webmaster del sito oppure controll
 	'label_xml_plugin' => 'XML',
 	'legende_installer_plugins' => 'Installa plugin',
 	'legende_rechercher_plugins' => 'Cerca plugin',
+	'lien_demo' => 'Dimostrazione',
+	'lien_documentation' => 'Documentazione',
 
 	// M
 	'message_action_finale_get_fail' => 'Il plugin "@plugin@" (versione: @version@) non può essere scaricato con successo',
@@ -263,7 +267,7 @@ Se vuoi disabilitarla, per favore contatta il webmaster del sito oppure controll
 	'titre_form_charger_plugin' => 'Cerca e aggiungi i plugin',
 	'titre_form_charger_plugin_archive' => 'Scarica il plugin usando l’url dell’archivio',
 	'titre_form_configurer_svp' => 'Configurazione del server dei plugin',
-	'titre_liste_autres_contributions' => 'Template, libreria, set di icone',
+	'titre_liste_autres_contributions' => 'Template, libreria, set di icone', # MODIF
 	'titre_liste_autres_depots' => 'Altri repository',
 	'titre_liste_depots' => 'Lista dei repository disponibili',
 	'titre_liste_paquets_plugin' => 'Lista dei pacchetti del plugin',
