@@ -3,7 +3,9 @@
 // extrait automatiquement de http://trad.spip.net/tradlang_module/svp?lang_cible=nl
 // ** ne pas modifier le fichier **
 
-if (!defined('_ECRIRE_INC_VERSION')) return;
+if (!defined('_ECRIRE_INC_VERSION')) {
+	return;
+}
 
 $GLOBALS[$GLOBALS['idx_lang']] = array(
 
@@ -34,6 +36,7 @@ $GLOBALS[$GLOBALS['idx_lang']] = array(
 	'bulle_actualiser_tout_depot' => 'De pakketten van alle depots bijwerken',
 	'bulle_afficher_xml_plugin' => 'Inhoud van het XML-bestand van de plugin',
 	'bulle_ajouter_spipzone' => 'Het SPIP-Zone depot toevoegen',
+	'bulle_aller_demonstration' => 'Ga naar de voorbeeld-bladzijde',
 	'bulle_aller_depot' => 'Ga naar de bladzijde van dit depot',
 	'bulle_aller_documentation' => 'Ga naar de documentatie bladzijde',
 	'bulle_aller_plugin' => 'Ga naar de bladzijde van de plugin',
@@ -68,7 +71,7 @@ $GLOBALS[$GLOBALS['idx_lang']] = array(
 	'config_autoriser_activer_paquets_obsoletes_explication' => 'Obsolete pakketten zijn oudere versies van lokale pakketten. Hun status wordt bepaald aan de hand van de status van de plugin (stable, testing, dev) en de versie. Schakel deze optie in wanneer je toch verouderde plugins wilt activeren.',
 	'config_depot_editable' => 'Depot aanpassingen toestaan?',
 	'config_depot_editable_explication' => 'Dit laat je toe de informatie van een depot aan te passen, zoals het toevoegen van extra trefwoorden. Een niet interessante optie, die je beter niet inschakelt!',
-	'confirmer_desinstaller' => 'Het verwijderen van een plugin <b>wist</b> alle gerelateerde gegevens en is onomkeerbaar.<br />Twijfel je, maak de plugin dan gewoon inactief.',
+	'confirmer_desinstaller' => 'Het verwijderen van een plugin <b>wist</b> alle gerelateerde gegevens en is onomkeerbaar.<br />Twijfel je, maak de plugin dan gewoon inactief.', # MODIF
 	'confirmer_telecharger_dans' => 'De plugin wordt geladen in een bestaande map (@dir@).
 Hierdoor wordt de inhoud van deze map overschreven.
 Een kopie van de oude bestanden wordt opgeslagen in "@dir_backup@".
@@ -171,6 +174,8 @@ Je moet deze actie bevestigen.',
 	'label_xml_plugin' => 'XML',
 	'legende_installer_plugins' => 'Plugins installeren',
 	'legende_rechercher_plugins' => 'Plugins zoeken',
+	'lien_demo' => 'Voorbeeld',
+	'lien_documentation' => 'Documentatie',
 
 	// M
 	'message_action_finale_get_fail' => 'Plugin "@plugin@" (versie: @version@) kon niet worden gedownload',
