@@ -3,7 +3,9 @@
 // extrait automatiquement de http://trad.spip.net/tradlang_module/svp?lang_cible=oc_ni_mis
 // ** ne pas modifier le fichier **
 
-if (!defined('_ECRIRE_INC_VERSION')) return;
+if (!defined('_ECRIRE_INC_VERSION')) {
+	return;
+}
 
 $GLOBALS[$GLOBALS['idx_lang']] = array(
 
@@ -34,6 +36,7 @@ $GLOBALS[$GLOBALS['idx_lang']] = array(
 	'bulle_actualiser_tout_depot' => 'Atualisà lu paquet de toui lu depòsiti',
 	'bulle_afficher_xml_plugin' => 'Countengut dóu fichié XML dau plugin',
 	'bulle_ajouter_spipzone' => 'Ajustà lou depòsiti SPIP-Zone',
+	'bulle_aller_demonstration' => 'Anà sus la pàgina de demounstracioun',
 	'bulle_aller_depot' => 'Anà sus la pàgina d’aqueu depòsiti',
 	'bulle_aller_documentation' => 'Anà sus la pàgina de doucumentacioun',
 	'bulle_aller_plugin' => 'Anà sus la pàgina dóu plugin',
@@ -68,7 +71,7 @@ $GLOBALS[$GLOBALS['idx_lang']] = array(
 	'config_autoriser_activer_paquets_obsoletes_explication' => 'Lu paquet oussoulet soun dei paquet loucal present que soun mai viei que d’autre paquet loucal. L’oussoulecència es estabilida soubre la basa de l’estat (stable, test, dev) dóu paquet e finda soubre la basa de la siéu versioun. Ativàs aquela oupcioun s’auguràs maugrà tout d’avé la poussibilità d’ativà aquelu plugin oussoulet.',
 	'config_depot_editable' => 'Permetre l’edicioun dei depòsiti ?',
 	'config_depot_editable_explication' => 'Acò rende li infourmacioun d’un depòsiti editable e permet eventualamen de jougne dei mot clau o dei doucumen. Aquela oupcioun deurìa interessà degun ! Vourguès laissà « noun » !',
-	'confirmer_desinstaller' => 'Mèfi, la desinstalacioun d’un plugin <b>escassa</b> li siéu dounada de la basa e es irreversìbla.<br />Se noun sias certen, desativàs simplamen lou plugin.',
+	'confirmer_desinstaller' => 'Mèfi, la desinstalacioun d’un plugin <b>escassa</b> li siéu dounada de la basa e es irreversibla.<br />Se noun sias certen, desativàs simplamen lou plugin.',
 	'confirmer_telecharger_dans' => 'Lou plugin serà cargat en un repertori (@dir@) qu’esista jà.
 	Acò esquisserà lou countengut d’aqueu repertori.
 	Una còpia dóu viei countengut serà sauvagardada en « @dir_backup@ ».
@@ -118,7 +121,7 @@ $GLOBALS[$GLOBALS['idx_lang']] = array(
 	'info_aucun_depot_ajoute' => 'Mìnga depòsiti dispounible !<br /> Utilisàs lou fourmulari aquì souta da ajustà lou depòsiti « SPIP-Zone - Plugins » que l’url es jà preclafida o un autre depòsiti de la vouòstra chausida.',
 	'info_aucun_paquet' => 'mìnga paquet',
 	'info_aucun_plugin' => 'mìnga plugin',
-	'info_boite_charger_plugin' => '<strong>Aquela pàgina es basta achessible ai webmestre dóu sit.</strong><p>Vi permete de recercà dei plugin metut da dispousicioun dai depòsiti registrat en la vouòstra counfiguracioun e lu instalà fisicamen sus lou vouòstre servidou</p>',
+	'info_boite_charger_plugin' => '<strong>Aquela pàgina es basta achessible ai webmestre dóu sit.</strong><p>Vi permete de recercà dei plugin mes da dispousicioun dai depòsiti registrat en la vouòstra counfiguracioun e lu instalà fisicamen sus lou vouòstre servidou</p>',
 	'info_boite_depot_gerer' => '<strong>Aquela pàgina es basta achessible ai webmestre dóu sit.</strong><p>Permet l’ajountamen et l’atualisacioun dei depòsiti de plugin.</p>',
 	'info_charger_plugin' => 'Per ajustà un plugin o mai, efetuàs en premié una recerca multicriteri sus lu plugin de la galassìa SPIP. La recerca enclude basta lu plugin coumpatible embé la versioun SPIP instalada e signala lu plugin jà atiéu sus lou sit.',
 	'info_compatibilite_dependance' => 'Per @compatibilite@ :',
@@ -174,6 +177,8 @@ $GLOBALS[$GLOBALS['idx_lang']] = array(
 	'label_xml_plugin' => 'XML',
 	'legende_installer_plugins' => 'Instalà dei plugin',
 	'legende_rechercher_plugins' => 'Recercà dei plugin',
+	'lien_demo' => 'Demounstracioun',
+	'lien_documentation' => 'Doucumentacioun',
 
 	// M
 	'message_action_finale_get_fail' => 'Lou plugin « @plugin@ » (versioun : @version@) noun es estat recuperat courretamen',
@@ -192,10 +197,10 @@ $GLOBALS[$GLOBALS['idx_lang']] = array(
 	'message_action_finale_on_ok' => 'L’ativacioun dóu plugin « @plugin@ » (versioun : @version@) s’es efetuada courretamen',
 	'message_action_finale_stop_fail' => 'La desinstalacioun dóu plugin « @plugin@ » (versioun : @version@) noun s’es efetuada courretamen',
 	'message_action_finale_stop_ok' => 'La desinstalacioun dóu plugin « @plugin@ » (versioun : @version@) s’es efetuada courretamen',
-	'message_action_finale_up_fail' => 'La metuda a jou dóu plugin « @plugin@ » (da la versioun : @version@ a @version_maj@) noun s’es efetuada courretamen',
-	'message_action_finale_up_ok' => 'La metuda a jou dóu plugin « @plugin@ » (da la versioun : @version@ a @version_maj@) s’es efetuada courretamen',
-	'message_action_finale_upon_fail' => 'La metuda a jou e l’ativacioun dóu plugin « @plugin@ » (da la versioun : @version@ a @version_maj@) noun si soun efetuadi courretamen',
-	'message_action_finale_upon_ok' => 'La metuda a jou e l’ativacioun dóu plugin « @plugin@ » (de la versioun : @version@ a @version_maj@) si soun efetuadi courretamen',
+	'message_action_finale_up_fail' => 'La messa a jou dóu plugin « @plugin@ » (da la versioun : @version@ a @version_maj@) noun s’es efetuada courretamen',
+	'message_action_finale_up_ok' => 'La messa a jou dóu plugin « @plugin@ » (da la versioun : @version@ a @version_maj@) s’es efetuada courretamen',
+	'message_action_finale_upon_fail' => 'La messa a jou e l’ativacioun dóu plugin « @plugin@ » (da la versioun : @version@ a @version_maj@) noun si soun efetuadi courretamen',
+	'message_action_finale_upon_ok' => 'La messa a jou e l’ativacioun dóu plugin « @plugin@ » (de la versioun : @version@ a @version_maj@) si soun efetuadi courretamen',
 	'message_action_get' => 'Telecargà lou plugin « @plugin@ » (versioun : @version@)',
 	'message_action_getlib' => 'Telecargà la biblioutéca « <a href="@version@" class="spip_out">@plugin@</a> »',
 	'message_action_geton' => 'Telecargà a ativà lou plugin « @plugin@ » (versioun : @version@)',
@@ -204,13 +209,13 @@ $GLOBALS[$GLOBALS['idx_lang']] = array(
 	'message_action_off' => 'Desativà lou plugin « @plugin@ » versioun : @version@)',
 	'message_action_on' => 'Ativà lou plugin « @plugin@ » (versioun : @version@)',
 	'message_action_stop' => 'Desinstalà lou plugin « @plugin@ » (versioun : @version@)',
-	'message_action_up' => 'Metuda a jou dóu plugin « @plugin@ » (da la versioun @version@ a @version_maj@)',
-	'message_action_upon' => 'Metuda a jou e ativacioun dóu plugin « @plugin@ » (versioun : @version@)',
+	'message_action_up' => 'Messa a jou dóu plugin « @plugin@ » (da la versioun @version@ a @version_maj@)',
+	'message_action_upon' => 'Messa a jou e ativacioun dóu plugin « @plugin@ » (versioun : @version@)',
 	'message_dependance_plugin' => 'Lou plugin @plugin@ depende da @dependance@.',
 	'message_dependance_plugin_version' => 'Lou plugin @plugin@ depende da @dependance@ @version@',
 	'message_erreur_aucun_plugin_selectionne' => 'Mìnga plugin seleciounat.',
 	'message_erreur_ecriture_lib' => '@plugin@ a da besoun de la biblioutèca <a href="@lib_url@">@lib@</a> situada en lou repertori <var>lib/</var> en la raïs dóu vouòstre sit. Pùra, aqueu repertori noun esista o noun es achessible en escritura. Devès instalà manualamen aquela biblioutèca o creà aqueu repertori en lì dounant dei permissioun d’escritura.',
-	'message_erreur_maj_inconnu' => 'Metuda a jou impoussibla d’un plugin escounouissut.',
+	'message_erreur_maj_inconnu' => 'Messa a jou impoussibla d’un plugin escounouissut.',
 	'message_erreur_plugin_introuvable' => 'Es empoussible de trouvà lou plugin @plugin@ per @action@.',
 	'message_erreur_plugin_non_actif' => 'Es empoussible de desativà un plugin noun atiéu.',
 	'message_incompatibilite_spip' => '@plugin@ noun es coumpatible embé la versioun de SPIP qu’utilisàs.',
@@ -219,7 +224,7 @@ $GLOBALS[$GLOBALS['idx_lang']] = array(
 	'message_nok_aucun_plugin_selectionne' => 'Mìnga plugin da instalà. Vourguès selecioun) lu plugin da instalà',
 	'message_nok_champ_obligatoire' => 'Aqueu camp es oubligatori',
 	'message_nok_depot_deja_ajoute' => 'L’adressa « @url@ » courrespouònde a un depòsiti jà ajustat',
-	'message_nok_maj_introuvable' => 'Metuda a jou dóu plugin @plugin@ introuvable.',
+	'message_nok_maj_introuvable' => 'Messa a jou dóu plugin @plugin@ introuvable.',
 	'message_nok_plugin_inexistant' => 'Lou plugin demandat noun esista (@plugin@).',
 	'message_nok_sql_insert_depot' => 'Errour SQL dóu tems de l’ajountamen dóu depòsiti @objet@',
 	'message_nok_url_archive' => 'L’URL de l’arquivi es invalide',
@@ -245,7 +250,7 @@ $GLOBALS[$GLOBALS['idx_lang']] = array(
 	// P
 	'placeholder_phrase' => 'prefis, noum, eslougan, descritiéu o autour',
 	'plugin_info_actif' => 'Plugin atiéu',
-	'plugin_info_up' => 'Una metuda a jou dóu plugin es dispounible (versioun @version@)',
+	'plugin_info_up' => 'Una messa a jou dóu plugin es dispounible (versioun @version@)',
 	'plugin_info_verrouille' => 'Plugin ferouiat',
 	'plugins_inactifs_liste' => 'Inatiéu',
 	'plugins_non_verrouilles_liste' => 'Noun ferouiat',
