@@ -3,7 +3,9 @@
 // extrait automatiquement de http://trad.spip.net/tradlang_module/svp?lang_cible=pt_br
 // ** ne pas modifier le fichier **
 
-if (!defined('_ECRIRE_INC_VERSION')) return;
+if (!defined('_ECRIRE_INC_VERSION')) {
+	return;
+}
 
 $GLOBALS[$GLOBALS['idx_lang']] = array(
 
@@ -68,7 +70,7 @@ $GLOBALS[$GLOBALS['idx_lang']] = array(
 	'config_autoriser_activer_paquets_obsoletes_explication' => 'Os pacotes obsoletos são pacotes locais atuais que são mais antigos do que outros pacotes locais. A obsolescência é estabelecida na base do status (estável, teste, dev) do pacote bem como na base de sua versão. Ative esta opção se você deseja, apesar de tudo, ativar estes plugins obsoletos.',
 	'config_depot_editable' => 'Permitir a edição dos repositórios?',
 	'config_depot_editable_explication' => 'Isto torna editáveis as informações de um repositório, permitindo eventualmente vincular palavras-chave ou documentos. Esta opção não deverá interessar a ninguém! É melhor deixar como «não»!',
-	'confirmer_desinstaller' => 'Atenção, a desinstalação de um plugin <b>exclui<b> os seus dados da base e é irreversível.<br />Se voce não está seguro, simplesmente desative o plugin.',
+	'confirmer_desinstaller' => 'Atenção, a desinstalação de um plugin <b>exclui<b> os seus dados da base e é irreversível.<br />Se voce não está seguro, simplesmente desative o plugin.', # MODIF
 	'confirmer_telecharger_dans' => 'O plugin será carregado num diretório (@dir@) que já existe.
 Isso irá sobrepor o conteúdo desse diretório.
 Uma cópia do conteúdo anterior será gravada em «@dir_backup@».
@@ -261,7 +263,7 @@ Se você deseja desativá-los, contate o webmaster do site, ou consulte <a href=
 	'titre_form_charger_plugin' => 'Buscar e incluir plugins',
 	'titre_form_charger_plugin_archive' => 'Transferir um plugin a partir do seu arquivo',
 	'titre_form_configurer_svp' => 'Configurar o Servidor de Plugins',
-	'titre_liste_autres_contributions' => 'Templates, bibliotecas, conjuntos de ícones...',
+	'titre_liste_autres_contributions' => 'Templates, bibliotecas, conjuntos de ícones...', # MODIF
 	'titre_liste_autres_depots' => 'Outros repositórios',
 	'titre_liste_depots' => 'Lista dos repositórios disponíveis',
 	'titre_liste_paquets_plugin' => 'Lista dos pacotes do plugin',
