@@ -3,16 +3,18 @@
 // extrait automatiquement de http://trad.spip.net/tradlang_module/svp?lang_cible=ru
 // ** ne pas modifier le fichier **
 
-if (!defined('_ECRIRE_INC_VERSION')) return;
+if (!defined('_ECRIRE_INC_VERSION')) {
+	return;
+}
 
 $GLOBALS[$GLOBALS['idx_lang']] = array(
 
 	// A
 	'action_patienter' => 'Выполняются операции. Пожалуйста, подождите немного…',
 	'actions_a_faire' => 'Выполнить операцию',
-	'actions_demandees' => 'Необходимо выполнить операцию :',
+	'actions_demandees' => 'Необходимо выполнить операцию:',
 	'actions_en_erreur' => 'Произошли ошибки',
-	'actions_necessaires' => 'Будут выполнены следующие операции :',
+	'actions_necessaires' => 'Будут выполнены следующие операции:',
 	'actions_non_traitees' => 'Операция не выполнена',
 	'actions_realises' => 'Операция выполнена',
 	'afficher_les_plugins_incompatibles' => 'Показать несовместимые плагины',
@@ -34,18 +36,19 @@ $GLOBALS[$GLOBALS['idx_lang']] = array(
 	'bulle_actualiser_tout_depot' => 'Обновить пакеты во всех репозиториях',
 	'bulle_afficher_xml_plugin' => 'Содержимое XML файла плагина',
 	'bulle_ajouter_spipzone' => 'Добавить репозиторий  SPIP-Zone',
+	'bulle_aller_demonstration' => 'Перейти к странице демонстрации',
 	'bulle_aller_depot' => 'Перейти на страницу репозитория',
 	'bulle_aller_documentation' => 'Перейти на страницу с документацией',
 	'bulle_aller_plugin' => 'Перейти на страницу пакета',
 	'bulle_supprimer_depot' => 'Удалить репозиторий и его пакеты',
 	'bulle_telecharger_archive' => 'Скачать архивный файл',
-	'bulle_telecharger_fichier_depot' => 'Добавить XML файл репоизитрия',
+	'bulle_telecharger_fichier_depot' => 'Добавить XML файл репозитория',
 	'bulle_telecharger_librairie' => 'Скачать библиотеку',
 
 	// C
 	'cacher_les_plugins_incompatibles' => 'Скрыть несовместимые плагины',
 	'categorie_aucune' => 'Тематика не задана',
-	'categorie_auteur' => 'Автора, авторизация, управление  правами доступа',
+	'categorie_auteur' => 'Авторы, авторизация, управление  правами доступа',
 	'categorie_communication' => 'Интерактивность, коммуникации',
 	'categorie_date' => 'Расписания, календари, дата и время',
 	'categorie_divers' => 'Внешние сервисы, новые объекты',
@@ -61,35 +64,36 @@ $GLOBALS[$GLOBALS['idx_lang']] = array(
 	'config_activer_log_verbeux' => 'Включить подробное логирование?',
 	'config_activer_log_verbeux_explication' => 'Эта опция позволяет вести подробное логирование действий…',
 	'config_activer_pas_a_pas' => 'Включить пошаговый режим?',
-	'config_activer_pas_a_pas_explication' => 'Данная опция позволяет выполнять операции с плагинами не в пакетном режиме ( когда сразу выполняется несколько операция), а пошагово, подтверждая каждую операцию.',
-	'config_activer_runtime' => 'Включить режим совместимости ?',
-	'config_activer_runtime_explication' => 'Если режим совместимости включен, то будут показываться только плагины совсместимые с текущей версией SPIP. Если режим совместимости выключен, то будут показываться все плагины вне зависимости от текущей версии.',
-	'config_autoriser_activer_paquets_obsoletes' => 'Разрешить включать устаревшие плагины ?',
-	'config_autoriser_activer_paquets_obsoletes_explication' => 'Устаревшие плагины - это плагины, установленные на вашем сайте, которые старше других плагинов. Определяется по статусу плагина ( тестируется, стабильный и т.д.), а так же по номеру текущей версии. Включить эту настройку, если вы хотите иметь возможность использовать устаревшие плагины.',
+	'config_activer_pas_a_pas_explication' => 'Данная опция позволяет выполнять операции с плагинами не в пакетном режиме (когда сразу выполняется несколько операций), а пошагово, подтверждая каждую операцию.',
+	'config_activer_runtime' => 'Включить режим совместимости?',
+	'config_activer_runtime_explication' => 'Если режим совместимости включен, то будут показываться только плагины совместимые с текущей версией SPIP. Если режим совместимости выключен, то будут показываться все плагины вне зависимости от текущей версии.',
+	'config_autoriser_activer_paquets_obsoletes' => 'Разрешить включать устаревшие плагины?',
+	'config_autoriser_activer_paquets_obsoletes_explication' => 'Устаревшие плагины - это плагины, установленные на вашем сайте, которые старше других плагинов. Определяется по статусу плагина (тестируется, стабильный и т.д.), а так же по номеру текущей версии. Включите эту настройку, если вы хотите иметь возможность использовать устаревшие плагины.',
 	'config_depot_editable' => 'Разрешить редактирование репозитория?',
-	'config_depot_editable_explication' => 'Возможность редактировать информацию о репозитории. Такая потребность не должна у вас возникнуть, поэтому оставьте эту опцию выключенной.',
+	'config_depot_editable_explication' => 'Возможность редактировать информацию о репозитории. Такой потребности не должно у вас возникнуть, поэтому оставьте эту опцию выключенной.',
+	'confirmer_desinstaller' => 'Внимание: деинсталляция плагина <b>удаляет</b> его базу данных и является необратимой. <br /> Если вы не уверены, просто отключите плагин.',
 	'confirmer_telecharger_dans' => 'Эта операция перезапишет содержимое папки.
-Плагин будет загружен в существующую папку « @dir@».
-Старые файлы будут сохранены в папке« @dir_backup@ ».
+Плагин будет загружен в существующую папку «@dir@».
+Старые файлы будут сохранены в папке «@dir_backup@».
 Вам необходимо подтвердить выполнение этой операции.
 		',
 
 	// E
 	'erreur_actions_non_traitees' => 'Некоторые операции не были выполнены. Возможно, были ошибки в процессе выполнения. Выполнение операции инициировал @auteur@  @date@.',
-	'erreur_auth_plugins_ajouter_lib' => 'Не достаточно прав для того, что бы установить библиотеку.',
-	'erreur_dir_dib_ecriture' => 'Отсутствуют права на запись папки @dir@. Невозможно загркзить библиотеку!',
+	'erreur_auth_plugins_ajouter_lib' => 'Недостаточно прав для того, чтобы установить библиотеку.',
+	'erreur_dir_dib_ecriture' => 'Отсутствуют права на запись папки @dir@. Невозможно загрузить библиотеку!',
 	'erreur_dir_dib_indefini' => 'Не задано значение _DIR_LIB. Невозможно загрузить библиотеку!',
-	'erreur_dir_plugins_auto' => 'Папка « plugins/auto » позволяющая добавлять плагины из административной части сайта не создана или не хватает прав для записи в нее. Если вы хотите иметь такую возможность, то <strong>вам необходимо ее создать или установить права доступа 777 ( если такая папка существует)</strong>.',
+	'erreur_dir_plugins_auto' => 'Папка «plugins/auto» позволяющая добавлять плагины из административной части сайта не создана или не хватает прав для записи в нее. Если вы хотите иметь такую возможность, то <strong>вам необходимо ее создать или установить права доступа 777 ( если такая папка существует)</strong>.',
 	'erreur_dir_plugins_auto_ecriture' => 'Отсутствуют права на запись в папке @dir@. Невозможно загрузить пакет!',
 	'erreur_dir_plugins_auto_indefini' => 'Не указана папка _DIR_PLUGIN_AUTO. Невозможно загрузить плагин!',
-	'erreur_dir_plugins_auto_titre' => 'недоступна папка « plugins/auto »!',
+	'erreur_dir_plugins_auto_titre' => 'недоступна папка «plugins/auto»!',
 	'erreur_teleporter_chargement_source_impossible' => 'Невозможно загрузить источник @source@',
 	'erreur_teleporter_destination_erreur' => 'Папка @dir@ недоступна для  загрузчика файлов',
 	'erreur_teleporter_echec_deballage_archive' => 'Не получается разархивировать файл @fichier@',
 	'erreur_teleporter_format_archive_non_supporte' => 'Формат файлов @extension@ не поддерживается загрузчиком файлов',
 	'erreur_teleporter_methode_inconue' => 'Неизвестный метод @methode@ для загрузчика файлов',
 	'erreur_teleporter_type_fichier_inconnu' => 'Неизвестный тип файла для источника @source@',
-	'erreurs_xml' => 'Невозможно прочитать некоторый XML описания',
+	'erreurs_xml' => 'Невозможно прочитать некоторые XML описания',
 	'explication_destination' => 'Если вы не заполните, то путь будет задан по имени архивного файла.',
 
 	// F
@@ -108,7 +112,7 @@ $GLOBALS[$GLOBALS['idx_lang']] = array(
 	'info_admin_plugin_verrou_non' => 'Список всех плагинов, кроме системных. Включенные и отключенные.',
 	'info_admin_plugin_verrou_tous' => 'Список всех плагинов на сайте.',
 	'info_admin_plugin_verrouille' => 'На этой странице вы видите список всех включенных и системных плагинов (установленных в папке <code>@dir_plugins_dist@</code>).
-Если вы хотите отключить плагин - свяжитесь с разработчиками сайта или проконсультируйтесь в  <a href="http://programmer.spip.org/repertoire_plugins_dist">документации</a>.', # MODIF
+Если вы хотите отключить плагин - свяжитесь с разработчиками сайта или проконсультируйтесь в  <a href="http://programmer.spip.org/repertoire_plugins_dist">документации</a>.',
 	'info_adresse_spipzone' => 'Плагины SPIP-Zone',
 	'info_ajouter_depot' => 'Добавив репозиторий на сайт вы получаете возможность получить информацию о всех плагинах, которые находятся в репозитории. <br /> Название и описание плагинов содержится в  XML файле репозитория.',
 	'info_aucun_depot' => 'Нет репозитория',
@@ -134,7 +138,7 @@ $GLOBALS[$GLOBALS['idx_lang']] = array(
 	'info_plugins_disponibles' => 'доступно @total_plugins@ плагинов',
 	'info_plugins_heberges' => 'Размещено @total_plugins@ плагинов',
 	'info_tri_nom' => 'в алфавитном порядке',
-	'info_tri_score' => 'сортировать по ревалентности',
+	'info_tri_score' => 'сортировать по релевантности',
 	'info_type_depot_git' => 'Репозиторий под управлением GIT',
 	'info_type_depot_manuel' => 'Простой репозиторий ( без системы управления версиями)',
 	'info_type_depot_svn' => 'Репозиторий на системе SVN',
@@ -171,60 +175,63 @@ $GLOBALS[$GLOBALS['idx_lang']] = array(
 	'label_xml_plugin' => 'XML',
 	'legende_installer_plugins' => 'Установить плагин',
 	'legende_rechercher_plugins' => 'Поиск плагинов',
+	'lien_demo' => 'Демонстрация',
+	'lien_documentation' => 'Документация',
 
 	// M
-	'message_action_finale_get_fail' => 'Не удалось загрузить плагин « @plugin@ » (версия : @version@) ',
-	'message_action_finale_get_ok' => 'Плагин « @plugin@ » (версия : @version@) успешно загружен',
-	'message_action_finale_getlib_fail' => 'Не удалось установить библиотеку « @plugin@ »',
-	'message_action_finale_getlib_ok' => 'Библиотека « @plugin@ » успешно установлена',
-	'message_action_finale_geton_fail' => 'Не удалось загрузить и установить плагин « @plugin@ » (версия : @version@) ',
-	'message_action_finale_geton_ok' => 'Плагин « @plugin@ » (версия : @version@) успешно загружен и установлен',
-	'message_action_finale_install_fail' => 'Не удалось установить плагин « @plugin@ » (версия : @version@) ',
-	'message_action_finale_install_ok' => 'Плагин « @plugin@ » (версия : @version@) успешно установлен',
+	'message_action_finale_get_fail' => 'Не удалось загрузить плагин «@plugin@» (версия: @version@) ',
+	'message_action_finale_get_ok' => 'Плагин «@plugin@» (версия: @version@) успешно загружен',
+	'message_action_finale_getlib_fail' => 'Не удалось установить библиотеку «@plugin@»',
+	'message_action_finale_getlib_ok' => 'Библиотека «@plugin@» успешно установлена',
+	'message_action_finale_geton_fail' => 'Не удалось загрузить и установить плагин «@plugin@» (версия: @version@) ',
+	'message_action_finale_geton_ok' => 'Плагин «@plugin@» (версия: @version@) успешно загружен и установлен',
+	'message_action_finale_install_fail' => 'Не удалось установить плагин «@plugin@» (версия : @version@) ',
+	'message_action_finale_install_ok' => 'Плагин «@plugin@» (версия : @version@) успешно установлен',
 	'message_action_finale_kill_fail' => 'Не удалось удалить файлы плагина « @plugin@ » (версия : @version@)',
-	'message_action_finale_kill_ok' => 'Файлі плагин « @plugin@ » (версия : @version@) успешно удалены',
-	'message_action_finale_off_fail' => 'Не удалось отключить плагин « @plugin@ » (версия : @version@) ',
-	'message_action_finale_off_ok' => 'Плагин « @plugin@ » (version : @version@) успешно отключен',
-	'message_action_finale_on_fail' => 'Не удалось включить плагин « @plugin@ » (версия : @version@) ',
-	'message_action_finale_on_ok' => 'Плагин « @plugin@ » (версия : @version@) включен ',
-	'message_action_finale_stop_fail' => 'Не удалось удалить плагин « @plugin@ » (версия: @version@)',
-	'message_action_finale_stop_ok' => 'Плагин « @plugin@ » (версия : @version@) успешно удален',
-	'message_action_finale_up_fail' => 'Не удалось обновить плагин « @plugin@ » с версии @version@ до @version_maj@',
-	'message_action_finale_up_ok' => 'Обновление плагина « @plugin@ » (с версии : @version@ до  @version_maj@) прошло успешно',
-	'message_action_finale_upon_fail' => 'Не удалось обновить и включить плагин « @plugin@ » (с  @version@ до @version_maj@) ',
-	'message_action_finale_upon_ok' => 'Плагин « @plugin@ » успешно обновлен с версии  @version@ до @version_maj@ и включен',
-	'message_action_get' => 'Загрузить плагин « @plugin@ » (версия : @version@)',
+	'message_action_finale_kill_ok' => 'Файлы плагина «@plugin@» (версия : @version@) успешно удалены',
+	'message_action_finale_off_fail' => 'Не удалось отключить плагин «@plugin@» (версия: @version@) ',
+	'message_action_finale_off_ok' => 'Плагин «@plugin@» (version: @version@) успешно отключён',
+	'message_action_finale_on_fail' => 'Не удалось включить плагин «@plugin@» (версия: @version@) ',
+	'message_action_finale_on_ok' => 'Плагин «@plugin@» (версия: @version@) включён ',
+	'message_action_finale_stop_fail' => 'Не удалось удалить плагин «@plugin@» (версия: @version@)',
+	'message_action_finale_stop_ok' => 'Плагин «@plugin@» (версия: @version@) успешно удалён',
+	'message_action_finale_up_fail' => 'Не удалось обновить плагин «@plugin@» с версии @version@ до @version_maj@',
+	'message_action_finale_up_ok' => 'Обновление плагина «@plugin@» (с версии @version@ до  @version_maj@) прошло успешно',
+	'message_action_finale_upon_fail' => 'Не удалось обновить и включить плагин «@plugin@» (с  @version@ до @version_maj@) ',
+	'message_action_finale_upon_ok' => 'Плагин «@plugin@» успешно обновлён с версии  @version@ до @version_maj@ и включён',
+	'message_action_get' => 'Загрузить плагин «@plugin@» (версия: @version@)',
 	'message_action_getlib' => 'Скачать библиотеку « <a href="@version@" class="spip_out">@plugin@</a> »',
-	'message_action_geton' => 'Скачать и включить плагин « @plugin@ » (версия : @version@)',
-	'message_action_install' => 'Будет установлен плагин « @plugin@ » (версия : @version@) va être installé',
-	'message_action_kill' => 'Удалить файлы из плагина « @plugin@ » (version : @version@)',
-	'message_action_off' => 'Отключить плагин « @plugin@ » (версия : @version@)',
-	'message_action_on' => 'Включить плагин « @plugin@ » (версия : @version@)',
-	'message_action_stop' => 'Удалить плагин « @plugin@ » (версия : @version@)',
-	'message_action_up' => 'Обновить плагин « @plugin@ » (с @version@ до @version_maj@)',
-	'message_action_upon' => 'Обновление и активация плагина « @plugin@ » (версия: @version@)',
+	'message_action_geton' => 'Скачать и включить плагин «@plugin@» (версия: @version@)',
+	'message_action_install' => 'Будет установлен плагин «@plugin@» (версия : @version@) va être installé',
+	'message_action_kill' => 'Удалить файлы из плагина «@plugin@» (версия: @version@)',
+	'message_action_off' => 'Отключить плагин «@plugin@» (версия: @version@)',
+	'message_action_on' => 'Включить плагин «@plugin@» (версия: @version@)',
+	'message_action_stop' => 'Удалить плагин «@plugin@» (версия: @version@)',
+	'message_action_up' => 'Обновить плагин «@plugin@» (с @version@ до @version_maj@)',
+	'message_action_upon' => 'Обновление и активация плагина «@plugin@» (версия: @version@)',
 	'message_dependance_plugin' => 'Для  @plugin@ необходим @dependance@.',
 	'message_dependance_plugin_version' => 'Для установки @plugin@ необходим @dependance@ @version@',
 	'message_erreur_aucun_plugin_selectionne' => 'Ни один плагин не выбран.',
-	'message_erreur_ecriture_lib' => 'Для установки плагина @plugin@ необходима библиотека <a href="@lib_url@">@lib@</a>. Библиотеки должны находится в папке <var>lib/</var> в корне сайта. Но эта папка или не существует или не хвватает прав на запись. Необходимо или создать папку, или установить права на запись (обычно 777).',
+	'message_erreur_ecriture_lib' => 'Для установки плагина @plugin@ необходима библиотека <a href="@lib_url@">@lib@</a>. Библиотеки должны находится в папке <var>lib/</var> в корне сайта. Но либо этой папки не существует, либо не хватает прав на запись. Необходимо или создать папку, или установить права на запись (обычно 777).',
 	'message_erreur_maj_inconnu' => 'Невозможно обновить неизвестный плагин (@id@).',
 	'message_erreur_plugin_introuvable' => 'Не получается найти плагин @plugin@ для @action@.',
 	'message_erreur_plugin_non_actif' => 'Нельзя отключить отключенный плагин.',
 	'message_incompatibilite_spip' => '@plugin@  не совместим с текущей версией вашей CMS SPIP.',
 	'message_nok_aucun_depot_disponible' => 'Нет доступных плагинов! Добавьте хотя бы один репозиторий на странице управления репозиториями.',
-	'message_nok_aucun_paquet_ajoute' => 'В репозитории « @url@ » нет новых пакетов по сравнению с плагинами в базе сайта. Репозиторий не был добавлен.',
+	'message_nok_aucun_paquet_ajoute' => 'В репозитории «@url@» нет новых пакетов по сравнению с плагинами в базе сайта. Репозиторий не был добавлен.',
 	'message_nok_aucun_plugin_selectionne' => 'Не выбран ни один плагин. Выберите плагин, который вы хотите установить.',
 	'message_nok_champ_obligatoire' => 'Поле, обязательное для заполнения',
-	'message_nok_depot_deja_ajoute' => 'URL « @url@ » соответствует уже добавленному репозиторию',
+	'message_nok_depot_deja_ajoute' => 'URL «@url@» соответствует уже добавленному репозиторию',
 	'message_nok_maj_introuvable' => 'Не удалось найти новую версию плагина @plugin@ .',
-	'message_nok_plugin_inexistant' => 'Запрошенный плагин не существует(@plugin@).',
+	'message_nok_plugin_inexistant' => 'Запрошенный плагин не существует (@plugin@).',
 	'message_nok_sql_insert_depot' => 'Произошла SQL ошибка при добавления репозитория @objet@',
-	'message_nok_url_depot_incorrecte' => 'Адрес « @url@ » задан неправильно',
-	'message_nok_xml_non_conforme' => 'Не подходит описание XML файла « @fichier@',
-	'message_nok_xml_non_recupere' => 'Не возможно восстановить XML файл « @fichier@ » ',
+	'message_nok_url_archive' => 'URL-адрес в архиве недействителен',
+	'message_nok_url_depot_incorrecte' => 'Адрес «@url@» задан неправильно',
+	'message_nok_xml_non_conforme' => 'Не подходит описание XML файла «@fichier@»',
+	'message_nok_xml_non_recupere' => 'Не возможно восстановить XML файл «@fichier@» ',
 	'message_ok_aucun_plugin_trouve' => 'Не найдены плагины по заданным критериям поиска.',
-	'message_ok_depot_ajoute' => 'Репозиторий « @url@ » успешно добавлен.',
-	'message_ok_plugins_trouves' => 'Найдено @nb_plugins@ плагин(ов) по запросу (@tri@). Вы можете выбрать какие плагины вы хотите скачать и установить.',
+	'message_ok_depot_ajoute' => 'Репозиторий «@url@» успешно добавлен.',
+	'message_ok_plugins_trouves' => 'Найдено @nb_plugins@ плагин(ов) по запросу (@tri@). Вы можете выбрать, какие плагины вы хотите скачать и установить.',
 	'message_telechargement_archive_effectue' => 'Файл успешно разархивирован в папке @dir@.',
 
 	// N
@@ -253,7 +260,7 @@ $GLOBALS[$GLOBALS['idx_lang']] = array(
 	'resume_table_plugins' => 'Плагины в разделе @categorie@',
 
 	// T
-	'telecharger_archive_plugin_explication' => 'Вы можете ввести прямую ссылку на файл с архивом плагина и он будет сохранен и установлен в папку « plugins/auto ».',
+	'telecharger_archive_plugin_explication' => 'Вы можете ввести прямую ссылку на файл с архивом плагина и он будет сохранен и установлен в папку «plugins/auto».',
 	'titre_depot' => 'Репозиторий',
 	'titre_depots' => 'Репозитории',
 	'titre_form_ajouter_depot' => 'Добавить репозиторий',
