@@ -2,42 +2,55 @@
 
 /**
  * Déclarations de fonctions
- * 
+ *
  * @plugin SVP pour SPIP
  * @license GPL
  * @package SPIP\SVP\Fonctions
-**/
+ **/
+
+function svp_importer_charset($texte) {
+	if ($GLOBALS['meta']['charset'] == 'utf-8') {
+		return $texte;
+	}
+
+	return importer_charset($texte, 'utf-8');
+}
 
 /**
  * Retourne un texte expliquant l'intervalle de compatibilité avec un plugin ou SPIP
  *
  * Retourne par exemple "2.0 <= SPIP < 3.1"
- * 
+ *
  * @param string $intervalle
  *     L'intervalle tel que déclaré dans paquet.xml. Par exemple "[2.1;3.0.*]"
  * @param string $logiciel
  *     Nom du plugin pour qui est cette intervalle
  * @return string
  *     Texte expliquant l'intervalle
-**/
-function svp_afficher_intervalle($intervalle, $logiciel){
-	if (!strlen($intervalle)) return '';
-	if (!preg_match(',^[\[\(\]]([0-9.a-zRC\s\-]*)[;]([0-9.a-zRC\s\-\*]*)[\]\)\[]$,Uis',$intervalle,$regs)) return false;
+ **/
+function svp_afficher_intervalle($intervalle, $logiciel) {
+	if (!strlen($intervalle)) {
+		return '';
+	}
+	if (!preg_match(',^[\[\(\]]([0-9.a-zRC\s\-]*)[;]([0-9.a-zRC\s\-\*]*)[\]\)\[]$,Uis', $intervalle, $regs)) {
+		return false;
+	}
 	$mineure = $regs[1];
 	$majeure = preg_replace(',\.99$,', '.*', $regs[2]);
-	$mineure_inc = $intervalle{0}=="[";
-	$majeure_inc = substr($intervalle,-1)=="]";
-	if (strlen($mineure)){
-		if (!strlen($majeure))
+	$mineure_inc = $intervalle{0} == "[";
+	$majeure_inc = substr($intervalle, -1) == "]";
+	if (strlen($mineure)) {
+		if (!strlen($majeure)) {
 			$version = $logiciel . ($mineure_inc ? ' &ge; ' : ' &gt; ') . $mineure;
-		else
-			$version = $mineure . ($mineure_inc ? ' &le; ' : ' &lt; ') .  $logiciel . ($majeure_inc ? ' &le; ' : ' &lt; ') . $majeure;
-	}
-	else {
-		if (!strlen($majeure))
+		} else {
+			$version = $mineure . ($mineure_inc ? ' &le; ' : ' &lt; ') . $logiciel . ($majeure_inc ? ' &le; ' : ' &lt; ') . $majeure;
+		}
+	} else {
+		if (!strlen($majeure)) {
 			$version = $logiciel;
-		else
-			$version =  $logiciel . ($majeure_inc ? ' &le; ' : ' &lt; ') . $majeure;
+		} else {
+			$version = $logiciel . ($majeure_inc ? ' &le; ' : ' &lt; ') . $majeure;
+		}
 	}
 
 	return $version;
@@ -53,18 +66,20 @@ function svp_afficher_intervalle($intervalle, $logiciel){
  *     Le type d'état (stable, test, ...)
  * @return string
  *     Traduction de l'état dans la langue en cours
-**/
+ **/
 function svp_afficher_etat($etat) {
 	include_spip('plugins/afficher_plugin');
+
 	return plugin_etat_en_clair($etat);
 }
 
 /**
- * Retourne un texte HTML présentant la liste des dépendances d'un plugin 
+ * Retourne un texte HTML présentant la liste des dépendances d'un plugin
  *
  * Des liens vers les plugins dépendants sont présents lorsque les plugins
  * en dépendance sont connus dans notre base.
- * 
+ *
+ * @uses svp_afficher_intervalle()
  * @param string $balise_serialisee
  *     Informations des dépendances (tableau sérialisé) tel que stocké
  *     en base dans la table spip_paquets
@@ -74,41 +89,44 @@ function svp_afficher_etat($etat) {
  * @param string $sep
  *     Séparateur entre les noms de dépendances
  * @param string $lien
- * 	   Type de lien affecté au plugin référencé dans la base locale. Prend les valeurs :
+ *     Type de lien affecté au plugin référencé dans la base locale. Prend les valeurs :
  *
- * 		- local : le lien pointe vers la page publique du plugin sur le site lui-même. Il faut
+ *    - local : le lien pointe vers la page publique du plugin sur le site lui-même. Il faut
  * donc que le site propose des pages publiques pour les plugins sinon une 404 sera affichée;
- * 		- pluginspip : le lien pointe vers la page du plugin sur le site de référence Plugins SPIP;
- * 		- non : aucun lien n'est affiché.
+ *    - pluginspip : le lien pointe vers la page du plugin sur le site de référence Plugins SPIP;
+ *    - non : aucun lien n'est affiché.
  * @return string
  *     Texte informant des dépendances
-**/
-function svp_afficher_dependances($balise_serialisee, $dependance='necessite', $sep='<br />', $lien='local') {
+ **/
+function svp_afficher_dependances($balise_serialisee, $dependance = 'necessite', $sep = '<br />', $lien = 'local') {
 	$texte = '';
-	
+
 	$t = unserialize($balise_serialisee);
 	$dependances = $t[$dependance];
 	if (is_array($dependances)) {
 		ksort($dependances);
-	
-		foreach($dependances as $_compatibilite => $_dependance) {
+
+		foreach ($dependances as $_compatibilite => $_dependance) {
 			$compatibilite = ($_compatibilite !== 0)
-					? _T('svp:info_compatibilite_dependance', array('compatibilite' => svp_afficher_intervalle($_compatibilite, 'SPIP')))
-					: '';
-			if ($compatibilite)
+				? _T('svp:info_compatibilite_dependance',
+					array('compatibilite' => svp_afficher_intervalle($_compatibilite, 'SPIP')))
+				: '';
+			if ($compatibilite) {
 				$texte .= ($texte ? str_repeat($sep, 2) : '') . $compatibilite;
+			}
 			foreach ($_dependance as $_plugin) {
-				if ($texte)
+				if ($texte) {
 					$texte .= $sep;
-				if (($dependance == 'necessite' ) OR ($dependance == 'utilise')) {
+				}
+				if (($dependance == 'necessite') or ($dependance == 'utilise')) {
 					if ($plugin = sql_fetsel('id_plugin, nom', 'spip_plugins', 'prefixe=' . sql_quote($_plugin['nom']))) {
 						$nom = extraire_multi($plugin['nom']);
-						if ($lien == 'non')
+						if ($lien == 'non') {
 							$logiciel = $nom;
-						else {
+						} else {
 							$url = ($lien == 'local')
-								 ? generer_url_entite($plugin['id_plugin'], 'plugin')
-								 : "http://plugins.spip.net/{$_plugin['nom']}.html";
+								? generer_url_entite($plugin['id_plugin'], 'plugin')
+								: "http://plugins.spip.net/{$_plugin['nom']}.html";
 							$bulle = _T('svp:bulle_aller_plugin');
 							$logiciel = '<a href="' . $url . '" title="' . $bulle . '">' . $nom . '</a>';
 						}
@@ -122,10 +140,10 @@ function svp_afficher_dependances($balise_serialisee, $dependance='necessite', $
 						$intervalle = svp_afficher_intervalle($_plugin['compatibilite'], $logiciel);
 					}
 					$texte .= ($intervalle) ? $intervalle : $logiciel;
+				} else // On demande l'affichage des librairies
+				{
+					$texte .= '<a href="' . $_plugin['lien'] . '" title="' . _T('svp:bulle_telecharger_librairie') . '">' . $_plugin['nom'] . '</a>';
 				}
-				else
-					// On demande l'affichage des librairies
-					$texte .= '<a href="' . $_plugin['lien'] . '" title="' . _T('svp:bulle_telecharger_librairie') . '">' .	$_plugin['nom'] . '</a>';
 			}
 		}
 	}
@@ -141,12 +159,13 @@ function svp_afficher_dependances($balise_serialisee, $dependance='necessite', $
  *     en base dans la table spip_paquets
  * @return bool
  *     Le plugin possède t'il des dépendances ?
-**/
+ **/
 function svp_dependances_existe($balise_serialisee) {
 	$dependances = unserialize($balise_serialisee);
-	foreach($dependances as $_dependance) {
-		if ($_dependance)
+	foreach ($dependances as $_dependance) {
+		if ($_dependance) {
 			return true;
+		}
 	}
 
 	return false;
@@ -154,11 +173,11 @@ function svp_dependances_existe($balise_serialisee) {
 
 
 /**
- * Retourne un texte HTML présentant les crédits d'un plugin 
+ * Retourne un texte HTML présentant les crédits d'un plugin
  *
  * Des liens vers les crédits sont présents lorsqu'ils sont déclarés
  * dans le paquet.xml.
- * 
+ *
  * @param string $balise_serialisee
  *     Informations des crédits (tableau sérialisé) tel que stocké
  *     en base dans la table spip_paquets
@@ -166,22 +185,23 @@ function svp_dependances_existe($balise_serialisee) {
  *     Séparateur entre les différents crédits
  * @return string
  *     Texte informant des crédits
-**/
-function svp_afficher_credits($balise_serialisee, $sep=', ') {
+ **/
+function svp_afficher_credits($balise_serialisee, $sep = ', ') {
 	$texte = '';
-	
+
 	$credits = unserialize($balise_serialisee);
 	if (is_array($credits)) {
 		foreach ($credits as $_credit) {
-			if ($texte) 
+			if ($texte) {
 				$texte .= $sep;
+			}
 			// Si le credit en cours n'est pas un array c'est donc un copyright
-			$texte .= 
-				(!is_array($_credit)) 
-				? PtoBR(propre($_credit)) // propre pour les [lien->url] des auteurs de plugin.xml ...
-				: ($_credit['url'] ? '<a href="' . $_credit['url'] . '">' : '') . 
-				  $_credit['nom'] .
-				  ($_credit['url'] ? '</a>' : '');
+			$texte .=
+				(!is_array($_credit))
+					? PtoBR(propre($_credit)) // propre pour les [lien->url] des auteurs de plugin.xml ...
+					: ($_credit['url'] ? '<a href="' . $_credit['url'] . '">' : '') .
+					$_credit['nom'] .
+					($_credit['url'] ? '</a>' : '');
 		}
 	}
 
@@ -190,31 +210,33 @@ function svp_afficher_credits($balise_serialisee, $sep=', ') {
 
 
 /**
- * Retourne un texte HTML présentant la liste des langues et traducteurs d'un plugin 
+ * Retourne un texte HTML présentant la liste des langues et traducteurs d'un plugin
  *
  * Des liens vers les traducteurs sont présents lorsqu'ils sont connus.
- * 
+ *
  * @param array $langues
  *     Tableau code de langue => traducteurs
  * @param string $sep
  *     Séparateur entre les différentes langues
  * @return string
  *     Texte informant des langues et traducteurs
-**/
-function svp_afficher_langues($langues, $sep=', '){
+ **/
+function svp_afficher_langues($langues, $sep = ', ') {
 	$texte = '';
-	
+
 	if ($langues) {
 		foreach ($langues as $_code => $_traducteurs) {
-			if ($texte) 
+			if ($texte) {
 				$texte .= $sep;
+			}
 			$traducteurs_langue = array();
 			foreach ($_traducteurs as $_traducteur) {
-				if (is_array($_traducteur))
+				if (is_array($_traducteur)) {
 					$traducteurs_langue[] =
 						($_traducteur['lien'] ? '<a href="' . $_traducteur['lien'] . '">' : '') .
 						$_traducteur['nom'] .
 						($_traducteur['lien'] ? '</a>' : '');
+				}
 			}
 			$texte .= $_code . (count($traducteurs_langue) > 0 ? ' (' . implode(', ', $traducteurs_langue) . ')' : '');
 		}
@@ -229,31 +251,32 @@ function svp_afficher_langues($langues, $sep=', '){
  *
  * Liste le nombre de plugins et de paquets d'un dépot
  * Indique aussi le nombre de dépots si l'on ne demande pas de dépot particulier.
- * 
+ *
+ * @uses svp_compter()
  * @param int $id_depot
  *     Identifiant du dépot
  * @return string
  *     Code HTML présentant les statistiques du dépot
-**/
-function svp_afficher_statistiques_globales($id_depot=0){
+ **/
+function svp_afficher_statistiques_globales($id_depot = 0) {
 	$info = '';
 
 	$total = svp_compter('depot', $id_depot);
 	if (!$id_depot) {
 		// Si on filtre pas sur un depot alors on affiche le nombre de depots
 		$info = '<li id="stats-depot" class="item">
-					<div class="unit size4of5">' . ucfirst(trim(_T('svp:info_depots_disponibles', array('total_depots'=>'')))) . '</div>
+					<div class="unit size4of5">' . ucfirst(trim(_T('svp:info_depots_disponibles', array('total_depots' => '')))) . '</div>
 					<div class="unit size1of5 lastUnit">' . $total['depot'] . '</div>
 				</li>';
 	}
 	// Compteur des plugins filtre ou pas par depot
 	$info .= '<li id="stats-plugin" class="item">
-				<div class="unit size4of5">' . ucfirst(trim(_T('svp:info_plugins_heberges',  array('total_plugins'=>'')))) . '</div>
+				<div class="unit size4of5">' . ucfirst(trim(_T('svp:info_plugins_heberges', array('total_plugins' => '')))) . '</div>
 				<div class="unit size1of5 lastUnit">' . $total['plugin'] . '</div>
 			</li>';
 	// Compteur des paquets filtre ou pas par depot
 	$info .= '<li id="stats-paquet" class="item">
-				<div class="unit size4of5">' . ucfirst(trim(_T('svp:info_paquets_disponibles', array('total_paquets'=>'')))) . '</div>
+				<div class="unit size4of5">' . ucfirst(trim(_T('svp:info_paquets_disponibles', array('total_paquets' => '')))) . '</div>
 				<div class="unit size1of5 lastUnit">' . $total['paquet'] . '</div>
 			</li>';
 
@@ -268,7 +291,8 @@ function svp_afficher_statistiques_globales($id_depot=0){
  * tel que l'appartenance à un certain dépot, une certaine catégorie
  * ou une certaine branche de SPIP et retourne une phrase traduite
  * tel que «78 paquets disponibles»
- * 
+ *
+ * @uses svp_compter()
  * @param int $id_depot
  *     Identifiant du dépot
  *     Zéro (par défaut) signifie ici : «dans tous les dépots distants»
@@ -279,10 +303,11 @@ function svp_afficher_statistiques_globales($id_depot=0){
  *     Numéro de branche de SPIP. (3.0, 2.1, ...)
  * @return string
  *     Texte indiquant un nombre total de paquets
-**/
-function svp_compter_telechargements($id_depot=0, $categorie='', $compatible_spip=''){
+ **/
+function svp_compter_telechargements($id_depot = 0, $categorie = '', $compatible_spip = '') {
 	$total = svp_compter('paquet', $id_depot, $categorie, $compatible_spip);
-	$info = _T('svp:info_paquets_disponibles', array('total_paquets'=>$total['paquet']));
+	$info = _T('svp:info_paquets_disponibles', array('total_paquets' => $total['paquet']));
+
 	return $info;
 }
 
@@ -293,7 +318,8 @@ function svp_compter_telechargements($id_depot=0, $categorie='', $compatible_spi
  * de ces différents totaux. Les totaux correspondent par défaut aux
  * plugins et paquets, mais l'on peut demander le total des autres contributions
  * avec le second paramètre.
- * 
+ *
+ * @uses svp_compter()
  * @param int $id_depot
  *     Identifiant du dépot
  *     Zéro (par défaut) signifie ici : «dans tous les dépots distants»
@@ -306,25 +332,24 @@ function svp_compter_telechargements($id_depot=0, $categorie='', $compatible_spi
  *     certains jeux de squelettes.
  * @return string
  *     Texte indiquant certains totaux tel que nombre de plugins, nombre de paquets...
-**/
-function svp_compter_depots($id_depot, $contrib='plugin'){
+ **/
+function svp_compter_depots($id_depot, $contrib = 'plugin') {
 	$info = '';
 
 	$total = svp_compter('depot', $id_depot);
 	if (!$id_depot) {
-		$info = _T('svp:info_depots_disponibles', array('total_depots'=>$total['depot'])) . ', ' .
-				_T('svp:info_plugins_heberges', array('total_plugins'=>$total['plugin'])) . ', ' .
-				_T('svp:info_paquets_disponibles', array('total_paquets'=>$total['paquet']));
-	}
-	else {
+		$info = _T('svp:info_depots_disponibles', array('total_depots' => $total['depot'])) . ', ' .
+			_T('svp:info_plugins_heberges', array('total_plugins' => $total['plugin'])) . ', ' .
+			_T('svp:info_paquets_disponibles', array('total_paquets' => $total['paquet']));
+	} else {
 		if ($contrib == 'plugin') {
-			$info = _T('svp:info_plugins_heberges', array('total_plugins'=>$total['plugin'])) . ', ' .
-					_T('svp:info_paquets_disponibles', array('total_paquets'=>$total['paquet']-$total['autre']));
-		}
-		else {
-			$info = _T('svp:info_contributions_hebergees', array('total_autres'=>$total['autre']));
+			$info = _T('svp:info_plugins_heberges', array('total_plugins' => $total['plugin'])) . ', ' .
+				_T('svp:info_paquets_disponibles', array('total_paquets' => $total['paquet'] - $total['autre']));
+		} else {
+			$info = _T('svp:info_contributions_hebergees', array('total_autres' => $total['autre']));
 		}
 	}
+
 	return $info;
 }
 
@@ -336,7 +361,8 @@ function svp_compter_depots($id_depot, $contrib='plugin'){
  * tel que l'appartenance à un certain dépot, une certaine catégorie
  * ou une certaine branche de SPIP et retourne une phrase traduite
  * tel que «64 plugins disponibles»
- * 
+ *
+ * @uses svp_compter()
  * @param int $id_depot
  *     Identifiant du dépot
  *     Zéro (par défaut) signifie ici : «dans tous les dépots distants»
@@ -347,10 +373,11 @@ function svp_compter_depots($id_depot, $contrib='plugin'){
  *     Numéro de branche de SPIP. (3.0, 2.1, ...)
  * @return string
  *     Texte indiquant un nombre total de paquets
-**/
-function svp_compter_plugins($id_depot=0, $categorie='', $compatible_spip='') {
+ **/
+function svp_compter_plugins($id_depot = 0, $categorie = '', $compatible_spip = '') {
 	$total = svp_compter('plugin', $id_depot, $categorie, $compatible_spip);
-	$info = _T('svp:info_plugins_disponibles', array('total_plugins'=>$total['plugin']));
+	$info = _T('svp:info_plugins_disponibles', array('total_plugins' => $total['plugin']));
+
 	return $info;
 }
 
@@ -365,11 +392,11 @@ function svp_compter_plugins($id_depot=0, $categorie='', $compatible_spip='') {
  *
  * Lorsque l'entité demandée est un dépot, le tableau des totaux possède,
  * en plus du nombre de dépots, le nombre de plugins et paquets.
- * 
+ *
  * @note
  *     Attention le critère de compatibilite SPIP pris en compte est uniquement
  *     celui d'une branche SPIP
- * 
+ *
  * @param string $entite
  *     De quoi veut-on obtenir des comptes. Peut être 'depot', 'plugin',
  *    'paquet' ou 'categorie'
@@ -383,48 +410,49 @@ function svp_compter_plugins($id_depot=0, $categorie='', $compatible_spip='') {
  *     Numéro de branche de SPIP. (3.0, 2.1, ...)
  * @return array
  *     Couples (entite => nombre).
-**/
-function svp_compter($entite, $id_depot=0, $categorie='', $compatible_spip=''){
+ **/
+function svp_compter($entite, $id_depot = 0, $categorie = '', $compatible_spip = '') {
 	$compteurs = array();
 
 	$group_by = array();
 	$where = array();
-	if ($id_depot)
+	if ($id_depot) {
 		$where[] = "t1.id_depot=" . sql_quote($id_depot);
-	else
+	} else {
 		$where[] = "t1.id_depot>0";
+	}
 
 	if ($entite == 'plugin') {
 		$from = 'spip_plugins AS t2, spip_depots_plugins AS t1';
 		$where[] = "t1.id_plugin=t2.id_plugin";
-		if ($categorie)
+		if ($categorie) {
 			$where[] = "t2.categorie=" . sql_quote($categorie);
+		}
 		if ($compatible_spip) {
 			$creer_where = charger_fonction('where_compatible_spip', 'inc');
-			$where[] =  $creer_where($compatible_spip, 't2', '>');
+			$where[] = $creer_where($compatible_spip, 't2', '>');
 		}
 		$compteurs['plugin'] = sql_count(sql_select('t2.id_plugin', $from, $where));
-	}
-	elseif ($entite == 'paquet') {
+	} elseif ($entite == 'paquet') {
 		if ($categorie) {
-			$ids = sql_allfetsel('id_plugin', 'spip_plugins', 'categorie='.sql_quote($categorie));
+			$ids = sql_allfetsel('id_plugin', 'spip_plugins', 'categorie=' . sql_quote($categorie));
 			$ids = array_map('reset', $ids);
 			$where[] = sql_in('t1.id_plugin', $ids);
 		}
 		if ($compatible_spip) {
 			$creer_where = charger_fonction('where_compatible_spip', 'inc');
-			$where[] =  $creer_where($compatible_spip, 't1', '>');
+			$where[] = $creer_where($compatible_spip, 't1', '>');
 		}
 		$compteurs['paquet'] = sql_countsel('spip_paquets AS t1', $where);
-	}
-	elseif ($entite == 'depot') {
-		$champs = array('COUNT(t1.id_depot) AS depot', 
-						'SUM(t1.nbr_plugins) AS plugin', 
-						'SUM(t1.nbr_paquets) AS paquet',
-						'SUM(t1.nbr_autres) AS autre');
+	} elseif ($entite == 'depot') {
+		$champs = array(
+			'COUNT(t1.id_depot) AS depot',
+			'SUM(t1.nbr_plugins) AS plugin',
+			'SUM(t1.nbr_paquets) AS paquet',
+			'SUM(t1.nbr_autres) AS autre'
+		);
 		$compteurs = sql_fetsel($champs, 'spip_depots AS t1', $where);
-	}
-	elseif ($entite == 'categorie') {
+	} elseif ($entite == 'categorie') {
 		$from = array('spip_plugins AS t2');
 		$where_depot = $where[0];
 		$where = array();
@@ -435,13 +463,14 @@ function svp_compter($entite, $id_depot=0, $categorie='', $compatible_spip=''){
 		}
 		if ($compatible_spip) {
 			$creer_where = charger_fonction('where_compatible_spip', 'inc');
-			$where[] =  $creer_where($compatible_spip, 't2', '>');
+			$where[] = $creer_where($compatible_spip, 't2', '>');
 		}
-		if ($categorie)
+		if ($categorie) {
 			$where[] = "t2.categorie=" . sql_quote($categorie);
-		else
+		} else {
 			$group_by = array('t2.categorie');
-		$compteurs['categorie'] = sql_countsel($from, $where, $group_by); 
+		}
+		$compteurs['categorie'] = sql_countsel($from, $where, $group_by);
 	}
 
 	return $compteurs;
@@ -449,7 +478,7 @@ function svp_compter($entite, $id_depot=0, $categorie='', $compatible_spip=''){
 
 
 /**
- * Compile la balise #SVP_CATEGORIES
+ * Compile la balise `#SVP_CATEGORIES`
  *
  * Cette balise retourne un tableau listant chaque type de catégorie
  * en index, associé à sa traduction en valeur.
@@ -463,23 +492,24 @@ function svp_compter($entite, $id_depot=0, $categorie='', $compatible_spip=''){
  *     #SVP_CATEGORIES{ordre_alpha}
  *     #SVP_CATEGORIES{ordre_cle,auteur}
  *
- * @balise svp_categories
+ * @balise
  * @see calcul_svp_categories()
  * @param Champ $p
  *     Pile au niveau de la balise
  * @return Champ
  *     Pile complétée par le code à générer
-**/
+ **/
 function balise_SVP_CATEGORIES($p) {
 	// tri, peut être 'ordre_cle' ou 'ordre_alpha'
-	if (!$tri = interprete_argument_balise(1,$p)) {
+	if (!$tri = interprete_argument_balise(1, $p)) {
 		$tri = "'ordre_cle'";
 	}
 	// catégorie (pour n'en prendre qu'une au lieu de toutes)
-	if (!$categorie = interprete_argument_balise(2,$p)) {
+	if (!$categorie = interprete_argument_balise(2, $p)) {
 		$categorie = "''";
 	}
-	$p->code = 'calcul_svp_categories(' . $tri .  ',' . $categorie . ')';
+	$p->code = 'calcul_svp_categories(' . $tri . ',' . $categorie . ')';
+
 	return $p;
 }
 
@@ -487,63 +517,67 @@ function balise_SVP_CATEGORIES($p) {
  * Retourne un tableau listant chaque type de catégorie
  * en index, associé à sa traduction en valeur.
  *
+ * @uses svp_traduire_categorie()
+ *
  * @param string $tri
  *     Type de tri (ordre_cle ou ordre_alpha)
  * @param string $categorie
  *     Restreindre le tableau de retour à cette catégorie si elle existe
  * @return array
  *     Couples (type de catégorie => Texte de la catégorie)
-**/
-function calcul_svp_categories($tri='ordre_cle', $categorie='') {
+ **/
+function calcul_svp_categories($tri = 'ordre_cle', $categorie = '') {
 
 	$retour = array();
 	include_spip('inc/svp_phraser'); // pour $GLOBALS['categories_plugin']
 	$svp_categories = $GLOBALS['categories_plugin'];
 
 	if (is_array($svp_categories)) {
-		if (($categorie) AND in_array($categorie, $svp_categories))
+		if (($categorie) and in_array($categorie, $svp_categories)) {
 			$retour[$categorie] = _T('svp:categorie_' . strtolower($categorie));
-		else {
+		} else {
 			if ($tri == 'ordre_alpha') {
 				sort($svp_categories);
 				// On positionne l'absence de categorie en fin du tableau
 				$svp_categories[] = array_shift($svp_categories);
 			}
-			foreach ($svp_categories as $_alias)
+			foreach ($svp_categories as $_alias) {
 				$retour[$_alias] = svp_traduire_categorie($_alias);
+			}
 		}
 	}
-	
+
 	return $retour;
 }
 
 
 /**
- * Compile la balise #SVP_BRANCHES_SPIP
+ * Compile la balise `#SVP_BRANCHES_SPIP`
  *
  * Cette balise retourne une liste des branches de SPIP
  *
  * Avec un paramètre indiquant une branche, la balise retourne
  * une liste des bornes mini et maxi de cette branche.
- * 
+ *
  * @example
  *     #SVP_BRANCHES_SPIP       : array('1.9', '2.0', '2.1', ....)
  *     #SVP_BRANCHES_SPIP{3.0}  : array('3.0.0', '3.0.99')
  *
- * @balise svp_branches_spip
+ * @balise
  * @see calcul_svp_branches_spip()
- * 
+ *
  * @param Champ $p
  *     Pile au niveau de la balise
  * @return Champ
  *     Pile complétée par le code à générer
-**/
+ **/
 function balise_SVP_BRANCHES_SPIP($p) {
 	// nom d'une branche en premier argument
-	if (!$branche = interprete_argument_balise(1,$p)) {
+	if (!$branche = interprete_argument_balise(1, $p)) {
 		$branche = "''";
 	}
-	$p->code = 'calcul_svp_branches_spip('.$branche.')';
+	$p->code = 'calcul_svp_branches_spip(' . $branche . ')';
+
 	return $p;
 }
 
@@ -556,7 +590,7 @@ function balise_SVP_BRANCHES_SPIP($p) {
  * @return array
  *     Liste des branches array('1.9', '2.0', '2.1', ....)
  *     ou liste mini et maxi d'une branche array('3.0.0', '3.0.99')
-**/
+ **/
 function calcul_svp_branches_spip($branche) {
 
 	$retour = array();
@@ -564,52 +598,53 @@ function calcul_svp_branches_spip($branche) {
 	$svp_branches = $GLOBALS['infos_branches_spip'];
 
 	if (is_array($svp_branches)) {
-		if (($branche) AND in_array($branche, $svp_branches))
-			// On renvoie les bornes inf et sup de la branche specifiee
+		if (($branche) and in_array($branche, $svp_branches)) // On renvoie les bornes inf et sup de la branche specifiee
+		{
 			$retour = $svp_branches[$branche];
-		else {
+		} else {
 			// On renvoie uniquement les numeros de branches
 			$retour = array_keys($svp_branches);
 		}
 	}
-	
+
 	return $retour;
 }
 
 /**
- * Traduit un type de catégorie de plugin 
+ * Traduit un type de catégorie de plugin
  *
  * @param string $alias
  *     Type de catégorie (auteur, communication, date...)
  * @return string
  *     Titre complet et traduit de la catégorie
-**/
+ **/
 function svp_traduire_categorie($alias) {
 	$traduction = '';
 	if ($alias) {
 		$traduction = _T('svp:categorie_' . strtolower($alias));
 	}
+
 	return $traduction;
 }
 
 /**
- * Traduit un type de dépot de plugin 
+ * Traduit un type de dépot de plugin
  *
  * @param string $type
  *     Type de dépot (svn, git, manuel)
  * @return string
  *     Titre complet et traduit du type de dépot
-**/
+ **/
 function svp_traduire_type_depot($type) {
 
 	$traduction = '';
 	if ($type) {
 		$traduction = _T('svp:info_type_depot_' . $type);
 	}
+
 	return $traduction;
 }
 
-
 /**
  * Calcule l'url exacte d'un lien de démo en fonction de son écriture
  *
@@ -620,37 +655,34 @@ function svp_traduire_type_depot($type) {
  *     Tous les autres types d'url renvoient une chaine vide
  * @return string
  *     URL calculée en fonction de l'URL d'entrée
-**/
-function svp_calculer_url_demo($url_demo, $url_absolue=false) {
+ **/
+function svp_calculer_url_demo($url_demo, $url_absolue = false) {
 
 	$url_calculee = '';
-    $url_demo = trim($url_demo);
-    if (strlen($url_demo) > 0) {
-        $url_elements = @parse_url($url_demo);
-        if (isset($url_elements['scheme']) AND $url_elements['scheme']) {
-            // Cas 1 : http://xxxx. C'est donc une url absolue que l'on conserve telle qu'elle.
-            $url_calculee = $url_demo;
-        }
-        else {
-            if (!$url_absolue) {
-                if (isset($url_elements['query']) AND $url_elements['query']) {
-                    // Cas 2 : ?exec=xxx ou ?page=yyy. C'est donc une url relative que l'on transforme
-                    // en url absolue privée ou publique en fonction de la query.
-                    $egal = strpos($url_elements['query'], '=');
-                    $page = substr($url_elements['query'], $egal+1, strlen($url_elements['query']) - $egal - 1);
-                    if (strpos($url_elements['query'], 'exec=') !== false) {
-                        $url_calculee = generer_url_ecrire($page);
-                    }
-                    else {
-                        $url_calculee = generer_url_public($page);
-                    }
-                }
-                elseif (isset($url_elements['path']) AND $url_elements['path']) {
-                    // Cas 3 : xxx/yyy. C'est donc une url relative que l'on transforme
-                    $url_calculee = generer_url_public($url_demo);
-                }
-            }
-        }
+	$url_demo = trim($url_demo);
+	if (strlen($url_demo) > 0) {
+		$url_elements = @parse_url($url_demo);
+		if (isset($url_elements['scheme']) and $url_elements['scheme']) {
+			// Cas 1 : http://xxxx. C'est donc une url absolue que l'on conserve telle qu'elle.
+			$url_calculee = $url_demo;
+		} else {
+			if (!$url_absolue) {
+				if (isset($url_elements['query']) and $url_elements['query']) {
+					// Cas 2 : ?exec=xxx ou ?page=yyy. C'est donc une url relative que l'on transforme
+					// en url absolue privée ou publique en fonction de la query.
+					$egal = strpos($url_elements['query'], '=');
+					$page = substr($url_elements['query'], $egal + 1, strlen($url_elements['query']) - $egal - 1);
+					if (strpos($url_elements['query'], 'exec=') !== false) {
+						$url_calculee = generer_url_ecrire($page);
+					} else {
+						$url_calculee = generer_url_public($page);
+					}
+				} elseif (isset($url_elements['path']) and $url_elements['path']) {
+					// Cas 3 : xxx/yyy. C'est donc une url relative que l'on transforme
+					$url_calculee = generer_url_public($url_demo);
+				}
+			}
+		}
 	}
 
 	return $url_calculee;
@@ -658,24 +690,24 @@ function svp_calculer_url_demo($url_demo, $url_absolue=false) {
 
 /**
  * Critère de compatibilité avec une version précise ou une branche de SPIP.
- * 
+ *
  * Fonctionne sur les tables spip_paquets et spip_plugins
  *
  * Si aucune valeur n'est explicité dans le critère, tous les enregistrements
  * sont retournés.
  *
  * Le ! (NOT) fonctionne sur le critère BRANCHE
- * 
- * @critere compatible_spip
+ *
+ * @critere
  * @example
  *   {compatible_spip}
  *   {compatible_spip 2.0.8} ou {compatible_spip 1.9}
  *   {compatible_spip #ENV{vers}} ou {compatible_spip #ENV{vers, 1.9.2}}
  *   {compatible_spip #GET{vers}} ou {compatible_spip #GET{vers, 2.1}}
- * 
- * @param string $idb     Identifiant de la boucle
- * @param array $boucles  AST du squelette
- * @param Critere $crit   Paramètres du critère dans cette boucle
+ *
+ * @param string $idb Identifiant de la boucle
+ * @param array $boucles AST du squelette
+ * @param Critere $crit Paramètres du critère dans cette boucle
  * @return void
  */
 function critere_compatible_spip_dist($idb, &$boucles, $crit) {
@@ -695,7 +727,7 @@ function critere_compatible_spip_dist($idb, &$boucles, $crit) {
 	if (isset($crit->param[0][0])) {
 		$version = calculer_liste(array($crit->param[0][0]), array(), $boucles, $boucle->id_parent);
 		$boucle->hash .= '
-		$where = $creer_where('.$version.', \''.$table.'\', \''.$op.'\');
+		$where = $creer_where(' . $version . ', \'' . $table . '\', \'' . $op . '\');
 		';
 	}
 	// pas de version/branche explicite dans l'appel du critere
@@ -703,7 +735,7 @@ function critere_compatible_spip_dist($idb, &$boucles, $crit) {
 	else {
 		$boucle->hash .= '
 		$version = isset($Pile[0][\'compatible_spip\']) ? $Pile[0][\'compatible_spip\'] : \'\';
-		$where = $creer_where($version, \''.$table.'\', \''.$op.'\');
+		$where = $creer_where($version, \'' . $table . '\', \'' . $op . '\');
 		';
 	}
 
@@ -713,7 +745,7 @@ function critere_compatible_spip_dist($idb, &$boucles, $crit) {
 /**
  * Retourne la liste des plugins trouvés par une recherche
  *
- * @filtre construire_recherche_plugins
+ * @filtre
  * @param string $phrase
  *     Texte de la recherche
  * @param string $categorie
@@ -732,15 +764,22 @@ function critere_compatible_spip_dist($idb, &$boucles, $crit) {
  *     Tableau classé par pertinence de résultat
  *     - 'prefixe' => tableau de description du paquet (si pas de doublons demandé)
  *     - n => tableau de descriptions du paquet (si doublons autorisés)
-**/
-function filtre_construire_recherche_plugins($phrase='', $categorie='', $etat='', $depot='', $afficher_exclusions=true, $afficher_doublons=false) {
+ **/
+function filtre_construire_recherche_plugins(
+	$phrase = '',
+	$categorie = '',
+	$etat = '',
+	$depot = '',
+	$afficher_exclusions = true,
+	$afficher_doublons = false
+) {
 
 	// On traite les paramètres d'affichage
 	$afficher_exclusions = ($afficher_exclusions == 'oui') ? true : false;
 	$afficher_doublons = ($afficher_doublons == 'oui') ? true : false;
 
 	$tri = ($phrase) ? 'score' : 'nom';
-	$version_spip = $GLOBALS['spip_version_branche'].".".$GLOBALS['spip_version_code'];
+	$version_spip = $GLOBALS['spip_version_branche'] . "." . $GLOBALS['spip_version_code'];
 
 	// On recupere la liste des paquets:
 	// - sans doublons, ie on ne garde que la version la plus recente
@@ -763,16 +802,17 @@ function filtre_construire_recherche_plugins($phrase='', $categorie='', $etat=''
  *
  * @return int
  *     Nombre d'heures (sinon 0)
-**/
+ **/
 function filtre_svp_periode_actualisation_depots() {
 	include_spip('genie/svp_taches_generales_cron');
+
 	return _SVP_CRON_ACTUALISATION_DEPOTS ? _SVP_PERIODE_ACTUALISATION_DEPOTS : 0;
 }
 
 
 /**
  * Retourne 'x.y.z' à partir de '00x.00y.00z'
- * 
+ *
  * Retourne la chaine de la version x.y.z sous sa forme initiale,
  * sans remplissage à gauche avec des 0.
  *
@@ -781,21 +821,22 @@ function filtre_svp_periode_actualisation_depots() {
  *     Numéro de version normalisée
  * @return string
  *     Numéro de version dénormalisée
-**/
-function denormaliser_version($version_normalisee='') {
+ **/
+function denormaliser_version($version_normalisee = '') {
 
 	$version = '';
 	if ($version_normalisee) {
 		$v = explode('.', $version_normalisee);
-		foreach($v as $_nombre) {
+		foreach ($v as $_nombre) {
 			$n = ltrim($_nombre, '0');
 			// On traite les cas du type 001.002.000-dev qui doivent etre transformes en 1.2.0-dev.
 			// Etant donne que la denormalisation est toujours effectuee sur une version normalisee on sait
 			// que le suffixe commence toujours pas '-'
-			$vn[] = ((strlen($n)>0) AND substr($n, 0, 1)!='-' ) ? $n : "0$n";
+			$vn[] = ((strlen($n) > 0) and substr($n, 0, 1) != '-') ? $n : "0$n";
 		}
 		$version = implode('.', $vn);
 	}
+
 	return $version;
 }
 
@@ -804,7 +845,7 @@ function denormaliser_version($version_normalisee='') {
  *
  * Ce répertoire permet de télécharger dedans des plugins
  * lorsqu'il est présent.
- * 
+ *
  * @return bool
  *     Le répertoire de chargement des plugins auto est-il présent
  *     et utilisable ?
@@ -815,6 +856,6 @@ function test_plugins_auto() {
 		include_spip('inc/plugin'); // pour _DIR_PLUGINS_AUTO
 		$test = (defined('_DIR_PLUGINS_AUTO') and _DIR_PLUGINS_AUTO and is_writable(_DIR_PLUGINS_AUTO));
 	}
+
 	return $test;
 }
-?>
