@@ -10,25 +10,43 @@
  *  Pour plus de details voir le fichier COPYING.txt ou l'aide en ligne.   *
 \***************************************************************************/
 
-if (!defined("_ECRIRE_INC_VERSION")) return;
+/**
+ * Gestion de l'action urls_actualiser
+ *
+ * @package SPIP\Urls_etendues\Action
+ **/
 
-// http://code.spip.net/@action_instituer_syndic_article_dist
+if (!defined("_ECRIRE_INC_VERSION")) {
+	return;
+}
+
+/**
+ * Action qui actualise toutes URLs
+ *
+ * Actualise les éléments (objet/id_objet) de la table des urls,
+ * ajoutant donc à chacun une URL plus récente si son calcul
+ * est différent de ce qui est stocké.
+ *
+ * Cette action ne supprime pas les anciennes urls.
+ * Elle n'invalide pas non plus les URLs «permanentes».
+ **/
 function action_urls_actualiser_dist() {
 
 	$securiser_action = charger_fonction('securiser_action', 'inc');
 	$arg = $securiser_action();
 
-	if (!defined('_VAR_URLS')) define('_VAR_URLS',true);
+	if (!defined('_VAR_URLS')) {
+		define('_VAR_URLS', true);
+	}
 	$type = $id = "";
-	$res = sql_select("type,id_objet","spip_urls","","","type,id_objet");
-	while ($row = sql_fetch($res)){
-		if ($row['id_objet']!==$id
-			OR $row['type']!==$type){
+	$res = sql_select("type,id_objet", "spip_urls", "", "", "type,id_objet");
+	while ($row = sql_fetch($res)) {
+		if ($row['id_objet'] !== $id
+			or $row['type'] !== $type
+		) {
 			$id = $row['id_objet'];
 			$type = $row['type'];
-			generer_url_entite($id,$type,"","",true);
+			generer_url_entite($id, $type, "", "", true);
 		}
 	}
 }
-
-?>
