@@ -10,7 +10,9 @@
  *  Pour plus de details voir le fichier COPYING.txt ou l'aide en ligne.   *
 \***************************************************************************/
 
-if (!defined("_ECRIRE_INC_VERSION")) return; // securiser
+if (!defined("_ECRIRE_INC_VERSION")) {
+	return;
+} // securiser
 
 /*
 Ce jeu d'URLs est une variante de inc-urls-propres, qui ajoute
@@ -29,14 +31,15 @@ define('URLS_PROPRES_QS_EXEMPLE', '?Titre-de-l-article');
 # specifier le form de config utilise pour ces urls
 define('URLS_PROPRES_QS_CONFIG', 'propres');
 
-if (!defined('_terminaison_urls_propres'))
-	define ('_terminaison_urls_propres', '');
+if (!defined('_terminaison_urls_propres')) {
+	define('_terminaison_urls_propres', '');
+}
 
-defined('_debut_urls_propres') || define ('_debut_urls_propres', './?');
+defined('_debut_urls_propres') || define('_debut_urls_propres', './?');
 
 // http://code.spip.net/@urls_propres_qs_dist
-function urls_propres_qs_dist($i, &$entite, $args='', $ancre='') {
+function urls_propres_qs_dist($i, &$entite, $args = '', $ancre = '') {
 	$f = charger_fonction('propres', 'urls');
+
 	return $f($i, $entite, $args, $ancre);
 }
-?>
