@@ -1,7 +1,7 @@
 <?php
 
-if (!defined('_ECRIRE_INC_VERSION')) return;
+if (!defined('_ECRIRE_INC_VERSION')) {
+	return;
+}
 
 include_spip('formulaires/selecteur/selecteur_fonctions');
-
-?>
\ No newline at end of file
