@@ -10,29 +10,34 @@
  *  Pour plus de details voir le fichier COPYING.txt ou l'aide en ligne.   *
 \***************************************************************************/
 
-if (!defined('_ECRIRE_INC_VERSION')) return;
+if (!defined('_ECRIRE_INC_VERSION')) {
+	return;
+}
 
-function formulaires_configurer_logos_charger_dist(){
-	foreach(array(
-		"activer_logos",
-		"activer_logos_survol",
-		) as $m)
+function formulaires_configurer_logos_charger_dist() {
+	foreach (array(
+		         "activer_logos",
+		         "activer_logos_survol",
+	         ) as $m) {
 		$valeurs[$m] = $GLOBALS['meta'][$m];
+	}
 
 	return $valeurs;
 }
 
 
-function formulaires_configurer_logos_traiter_dist(){
-	$res = array('editable'=>true);
-	foreach(array(
-		"activer_logos",
-		"activer_logos_survol",
-		) as $m)
-		if (!is_null($v=_request($m)))
-			ecrire_meta($m, $v=='oui'?'oui':'non');
+function formulaires_configurer_logos_traiter_dist() {
+	$res = array('editable' => true);
+	foreach (array(
+		         "activer_logos",
+		         "activer_logos_survol",
+	         ) as $m) {
+		if (!is_null($v = _request($m))) {
+			ecrire_meta($m, $v == 'oui' ? 'oui' : 'non');
+		}
+	}
 
 	$res['message_ok'] = _T('config_info_enregistree');
+
 	return $res;
 }
-
