@@ -201,7 +201,16 @@ function formulaires_editer_auteur_verifier_dist(
 		}
 	}
 
+	// corriger un cas si frequent : www.example.org sans le http:// qui precede
 	if ($url = _request('url_site') and !tester_url_absolue($url)) {
+		if (strpos($url, ':') === false and strncasecmp($url, 'www.', 4) === 0) {
+			$url = 'http://' . $url;
+			set_request('url_site', $url);
+		}
+	}
+	// traiter les liens implicites avant de tester l'url
+	include_spip('inc/lien');
+	if ($url = calculer_url(_request('url_site')) and !tester_url_absolue($url)) {
 		$erreurs['url_site'] = _T('info_url_site_pas_conforme');
 	}
 
